+++
title = "Active structural vibration control: a review"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
:


Reference
: ([Alkhatib and Golnaraghi 2003](#org9ef6ccc))

Author(s)
: Alkhatib, R., & Golnaraghi, M. F.

Year
: 2003


## Process of designing an active vibration control system {#process-of-designing-an-active-vibration-control-system}

1.  Analyze the structure to be controled
2.  Obtain an idealized mathematical model with FEM or experimental modal analysis
3.  Reduce the model order is necessary
4.  Analyze the resulting model: dynamics properties, types of disturbances, ...
5.  Quantify sensors and actuators requirements. Decide on their types and location
6.  Analyze the impact of the sensors and actuators on the overall dynamic characteristics
7.  Specify performance criteria and stability tradeoffs
8.  Device of the type of control algorythm to be employed and design a controller to meet the specifications
9.  Simulate the resulting controlled system on a computer
10. If the controller does not meet the requirements, adjust the specifications or modify the type of controller
11. Choose hardware and software and integrate the components on a pilot plant
12. Formulate experiments and perform system identification and model updating
13. Implement controller and carry out system test to evaluate the performance


## Feedback control {#feedback-control}


### Active damping {#active-damping}

The objective is to reduce the resonance peaks of the closed loop transfer function.

\\[T(s) = \frac{G(s)H(s)}{1+G(s)H(s)}\\]

Then \\(T(s) \approx G(s)\\) except near the resonance peaks where the amplitude is reduced.

This method can be realized without a model of the structure with **guaranteed stability**, granted that the actuators and sensors are **collocated**.


### Model based feedback {#model-based-feedback}

Objective: keep a control variable (position, velocity, ...) to a desired value in spite of external disturbances \\(d(s)\\).

We have \\[\frac{y(s)}{d(s)} = \frac{1}{1+G(s)H(s)}\\] so we need large values of \\(G(s)H(s)\\) in the frequency range where the disturbance has considerable effect.

To do so, we need a mathematical model of the system, then the control bandwidth and effectiveness are restricted by the accuracy of the model.
Unmodeled structural dynamics may destabilize the system.


## Feedforward Control {#feedforward-control}

We need a signal that is correlated to the disturbance. Then feedforward can improve performance over simple feedback control.

An adaptive filter manipulates the signal correlated to the disturbance and the output is applied to the system by the actuator.
The filter coefficients are adapted in such a way that an error signal is minimized.
The idea is to generate a secondary disturbance, which destructively interferes with the effect of the primary distance at the location of the error sensor.
However, there is no guarantee that the global response is also reduced at other locations.

The method is considered to be a **local technique**, in contrast to feedback which is global.

Contrary to active damping which can only reduce the vibration near the resonance, **feedforward control can be effective for any frequency**.
The major restriction to the application of feedforward adaptive filtering is the accessibility of a reference signal correlated to the disturbance.

<a id="table--table:comparison-constrol-strat"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--table:comparison-constrol-strat">Table 1</a></span>:
  Comparison of control strategies
</div>

| Type of control                | Advantages                                  | Disadvantages                                 |
|--------------------------------|---------------------------------------------|-----------------------------------------------|
| Active Damping                 | Simple to implement                         | Effective only near resonance                 |
|                                | Does not required accurate model            |                                               |
|                                | Guaranteed stability (collocated)           |                                               |
| Model Based                    | Global method                               | Requires accurate model                       |
|                                | Attenuate all disturbance within bandwidth  | Required low delay                            |
|                                |                                             | Limited bandwidth                             |
|                                |                                             | Spillover                                     |
| Feedforward Adaptive filtering | No model is necessary                       | Error signal required                         |
|                                | Robust to change in plant transfer function | Local method: may amplify vibration elsewhere |
|                                | More effective for narrowband disturbance   | Large amount of real-time computation         |


## Controllability and Observability {#controllability-and-observability}

Controllability and Observability are two fundamental qualitave properties of dynamic systems.

A system is said to be **controllable** if every state vector can be transform to a desirate state in finite time by the application of unconstrained control inputs.

A system is said to be **observable** at time \\(t\_0\\) if for a state \\(z(t\_0)\\), there is a finite time \\(t\_1>t\_0\\) such that the knowledge of the input \\(u(t)\\) and output \\(y(t)\\) from \\(t\_0\\) to \\(t\_1\\) are sufficient to determine the state \\(z(t\_0)\\).


## Coordinate Coupling Control {#coordinate-coupling-control}

Coordinate coupling control (CCC) is an **energy-basded method**.

The idea is to **transfer the vibrations** from a low or undamped oscilatory system (the plant) to a damped system (the controller).

This can be implemented passively using tuned mass damper. But the key advantage of this technique is that one can replace the physical absorber with a computer model. The coupling terms can then be selected to maximise the energy transfer.


## Robust control {#robust-control}

Robust control concentrates on the **tradeoffs between performance and stability** in the presence of uncertainty in the system model as well as the exogenous inputs to which it is subjected.

Uncertainty can be divided into four types:

-   parameter errors
-   error in model order
-   neglected disturbances
-   neglected nonlinearities

The \\(\mathcal{H}\_\infty\\)  controller is developed to address uncertainty by systematic means.
A general block diagram of the control system is shown figure [1](#org3926a79).

A **frequency shaped filter** \\(W(s)\\) coupled to selected inputs and outputs of the plant is included.
The outputs of this frequency shaped filter define the error ouputs used to evaluate the system performance and generate the **cost** that will be used in the design process.

<a id="org3926a79"></a>

{{< figure src="/ox-hugo/alkhatib03_hinf_control.png" caption="Figure 1: Block diagram for robust control" >}}

The generalized plan \\(G\\) can be partitionned according to the input-output variables. And we have that the transfer function matrix from \\(d\\) to \\(z\\) is:
\\[ H\_{z/d} = G\_{z/d} + G\_{z/u} K (I - G\_{y/u} K)^{-1} G\_{y/d} \\]
This transfer function matrix contains measures of performance and stability robustness.

The objective of \\(\mathcal{H}\_\infty\\) control is to design an admissible control \\(u(s)=K(s)y(s)\\) such that \\(\\| H\_{z/d} \\|\_\infty\\) is minimum.


## Optimal Control {#optimal-control}

The control \\(u(t)\\) is designed to minimize a cost function \\(J\\), given the initial conditions \\(z(t\_0)\\) and \\(\dot{z}(t\_0)\\) subject to the constraint that:

\begin{align\*}
\dot{z} &= Az + Bu\\\\\\
y &= Cz
\end{align\*}

One such cost function appropriate to a vibration control is
\\[J = 1/2 \int\_{t\_0}^{t\_f} ( z^T A z + u^T R u ) dt\\]
Where \\(Q\\) and \\(R\\) and positive definite symmetric weighting matrices.


## State Observers (Estimators) {#state-observers--estimators}

It is not always possible to determine the entire state variables. There are usualy too many degrees of freedom and only limited measurements.

The state vector \\(z(t)\\) can be estimated independently of the control problem, and the resulting estimate \\(\hat{z}(t)\\) can be used.


## Intelligent Structure and Controller {#intelligent-structure-and-controller}

Intelligent structure would have the capability to:

-   recognize the present dynamic state of its own structure and evaluate the functional performance of the structure
-   identify functional descriptions of external and internal disturbances
-   detect changes in structural properties and changes in external and internal disturbances
-   predict possible future changes in structural properties
-   make intelligent decisions regarding compensations for disturbances and adequately generale actuation forces
-   learn from past performance to improve future actions

Two main methodologies:

-   artificial neural networks
-   fuzzy logic


## Adaptive Control {#adaptive-control}

Adaptive control is frequently used to control systems whose parameters are unknown, uncertain, or slowly varying.

The design of an adaptive controller involves several steps:

-   selection of a controller structure with adjustable parameters
-   selection of an adaptation law for adjusting those parameters
-   selection of a performance index
-   real-time evaluation of the performance with respect to some desired behavior
-   real-time plant identification and model updating
-   real-time adjustment of the controller parameters to bring the performance closer to the desired behavior

It essentially consists of a real-time system identification technique integrated with a control algorithm.

Two different methods

-   **Direct method**: the controller parameters are adjusted directly based on the error between the measured and desired outputs.
-   **Indirect method**: the computations are divided into two consecutive phases. First, the plant model is first estimated in real time. Second, the controller parameters are modified based on the most recent updated plant parameters.


## Active Control Effects on the System {#active-control-effects-on-the-system}

<a id="org07db29f"></a>

{{< figure src="/ox-hugo/alkhatib03_1dof_control.png" caption="Figure 2: 1 DoF control of a spring-mass-damping system" >}}

Consider the control system figure [2](#org07db29f), the equation of motion of the system is:
\\[ m\ddot{x} + c\dot{x} + kx = f\_a + f \\]

The controller force can be expressed as: \\(f\_a = -g\_a \ddot{x} + g\_v \dot{x} + g\_d x\\). The equation of motion becomes:
\\[ (m+g\_a)\ddot{x} + (c+g\_v)\dot{x} + (k+g\_d)x = f \\]

Depending of the type of signal used, the active control adds/substracts mass, damping and stiffness.


## Time Delays {#time-delays}

One of the limits to the performance of active control is the time delay in controllers and actuators. Time delay introduces phase shift, which deteriorates the controller performance or even causes instability in the system.


## Optimal Placement of Actuators {#optimal-placement-of-actuators}

The problem of optimizing the locations of the actuators can be more significant than the control law itself.

If the actuator is placed at the wrong location, the system will require a greater force control. In that case, the system is said to have a **low degree of controllability**.


## Bibliography {#bibliography}

<a id="org9ef6ccc"></a>Alkhatib, Rabih, and M. F. Golnaraghi. 2003. “Active Structural Vibration Control: A Review.” _The Shock and Vibration Digest_ 35 (5):367–83. <https://doi.org/10.1177/05831024030355002>.
