+++
title = "Enhanced damping of flexible structures using force feedback"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Active Damping]({{< relref "active_damping" >}}), [Integral Force Feedback]({{< relref "integral_force_feedback" >}})

Reference
: ([Chesné, Milhomem, and Collette 2016](#org2953ca1))

Author(s)
: Simon Chesné, Milhomem, A., & Collette, C.

Year
: 2016

One problem of Integral Force Feedback (IFF) is that the achievable damping decreases at high frequency.
A modification of the IFF is proposed in order to significantly increase the damping of **a** selected mode.

The test system is shown in Figure [1](#org9c0dbe3).

Classical IFF corresponds to:

\begin{equation}
H(s) = \frac{g}{s}
\end{equation}

<a id="org9c0dbe3"></a>

{{< figure src="/ox-hugo/chesne16_2dof_system.png" caption="Figure 1: Two DoF system representing a flexible structuer controlled by an active mount" >}}

The proposed controller, called **alpha controller** is:

\begin{equation}
H(s) = g \frac{s + \alpha}{s^2}
\end{equation}

where \\(\alpha\\) is a parameter.

A new pair of pole/zero has been introduced.
The new pole is located at \\(s = 0\\) and the zeros at \\(s = -\alpha\\).

For \\(\omega > \alpha\\) the controller is essentially an integrator.
For \\(\omega < \alpha\\) the controller is a double integrator.

Depending on the chosen \\(\alpha\\) we obtain different root locus as shown in Figure [2](#org08e7f67).
There is an optimal gain \\(\alpha^\star\\) at which the attainable damping of the flexible mode is maximized.

<a id="org08e7f67"></a>

{{< figure src="/ox-hugo/chesne16_root_locus_alpha.png" caption="Figure 2: Root locus with the alpha controller for different values of \\(\alpha\\)" >}}

The obtained transmissibility is shown without controller, for classical IFF and for \\(\alpha\\) controller in Figure [3](#org2c2d3d7).

Using the \\(\alpha\\) controller, the compliance is however degraded a lot.

<a id="org2c2d3d7"></a>

{{< figure src="/ox-hugo/chesne16_transmissibility.png" caption="Figure 3: Transmissibility \\(x\_1/x\_0\\)" >}}

In order to recover the compliance at low frequency, high pass filters can be added to the controller.

\begin{equation}
H(s) = g \frac{s + \alpha}{(s + \beta)^2}
\end{equation}

The condition for stability found here is:

\begin{equation}
\alpha \ge \beta/2
\end{equation}

<div class="sum">
  <div></div>

The active damping of flexible structures with collocated force sensor/actuator pairs have been reviewed in this Note.
In the first part of the Note, two limitations of the integral force feedback (IFF) have been discussed, which are the limited damping of flexible modes and the loss of compliance.
By slightly modifying the controller, it has been shown that the active damping of a target mode can be significantly increased.
Analytical formulas of the optimal parameters have been derived.
In the second part, the loss of compliance inherent to IFF has been addressed.
It has been shown that, when a high-pass filter is inserted into the IFF controller, the compliance at low frequency can be recovered but the unconditional stability is lost.
On the other side, with the new proposed control law, the stability is always guaranteed even when using a high-pass filter.

</div>


## Bibliography {#bibliography}

<a id="org2953ca1"></a>Chesné, Simon, Ariston Milhomem, and Christophe Collette. 2016. “Enhanced Damping of Flexible Structures Using Force Feedback.” _Journal of Guidance, Control, and Dynamics_ 39 (7):1654–58. <https://doi.org/10.2514/1.g001620>.
