+++
title = "Vibration control of flexible structures using fusion of inertial sensors and hyper-stable actuator-sensor pairs"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Vibration Isolation]({{< relref "vibration_isolation" >}}), [Sensor Fusion]({{< relref "sensor_fusion" >}})

Reference
: ([Collette and Matichard 2014](#orged1e033))

Author(s)
: Collette, C., & Matichard, F.

Year
: 2014


## Introduction {#introduction}

Sensor fusion is used  to combine the benefits of different types of sensors:

-   Relative sensor for DC positioning capability at low frequency
-   Inertial sensors for isolation at high frequency
-   Force sensor / collocated sensor to improve the robustness


## Different types of sensors {#different-types-of-sensors}

In this paper, three types of sensors are used. Their advantages and disadvantages are summarized table [1](#table--tab:sensors).

> Several types of sensors can be used for the feedback control of vibration isolation systems:
>
> -   Feedback control based on **relative motion sensors** (inductive, capactive, ferromagnetic sensors...) typically permits to servo-position a system or platform relative to a reference (e.g. floor or support base), but does not provide isolation from the ground motion.
> -   Feedback control based on **force sensors** typically lowers the effective natural frequency, and therefore increases the isolation, but sacrifices the systems compliance in doing so.
> -   Feedback control based on **inertial sensors** (geophones, seismometers, accelerometers...) improves not only the vibration isolation but also the compliance. Inertial sensors are, however, AC coupled and noisy at low frequencies.

<a id="table--tab:sensors"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:sensors">Table 1</a></span>:
  Types of sensors
</div>

| Sensors          | Advantages                       | Disadvantages                         |
|------------------|----------------------------------|---------------------------------------|
| Relative motion  | Servo-position                   | No isolation from gorund motion       |
| Force sensors    | Improve isolation                | Increase compliance                   |
| Inertial sensors | Improve isolation and compliance | AC couple and noisy at high frequency |


## Inertial Control and sensor fusion configurations {#inertial-control-and-sensor-fusion-configurations}

For a simple 1DoF model, two fusion-sensor configuration are studied. The results are summarized Table [2](#table--tab:fusion-trade-off).

<a id="table--tab:fusion-trade-off"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:fusion-trade-off">Table 2</a></span>:
  Sensor fusion configurations
</div>

| Low freq. sensor | High freq. sensor | Transmissibility | Compliance | Trade-off                                          |
|------------------|-------------------|------------------|------------|----------------------------------------------------|
| Inertial         | Force sensor      | Unchanged        | Degraded   | Sensor noise filtering / compliance degradation    |
| Inertial         | Relative sensor   | Degraded         | Unchanged  | Isolation in the bandwidth / amplification outside |


## Flexible structure {#flexible-structure}

Flexibility is added between the inertial sensor and the actuator.
Now the sensor and actuator are not collocated anymore and the system is unstable because there is no zero between the two poles.
We use sensor fusion to obtain stability at high frequency.


### Inertial and small accelerometer {#inertial-and-small-accelerometer}

The idea is to use a small accelerometer which is easier to locate near the actuator at high frequency.
However, it is important to verify that the noise introduced by the accelerometer does not degrades too much the isolation performance.


### Inertial and force sensor {#inertial-and-force-sensor}

Here the advantage is that the deformation mode is almost not present in the open-loop transfer function.
This simplifies the loop shaping of the controller.


### Inertial and relative sensor {#inertial-and-relative-sensor}

The relative sensor introduces coupling between both side of the actuator which induces degradation of the isolation at high frequency. However, the compliance remains unchanged at high frequency.


## Conclusion {#conclusion}

Fusion of inertial instruments with sensors collocated with the actuator permits to increase the feedback control bandwidth of active isolation systems.

Three types of sensors have been considered for the high frequency part of the fusion:

-   The fusion with a **relative sensor** improves the stability but compromises the transmissibility. It can be of interested for stiff suspension where high frequency isolation can be sacrified to improve stability.
-   The fusion with an **accelerometre** is used to increase the loop gain. However, as the accelerometer is not dual with the actuator, there is no guaranty stability when the isolation stage is mounted on a flexible support.
-   The fusion with a **force sensor** can be used to increase the loop gain with little effect on the compliance and passive isolation, provided that the blend is possible and that no active damping of flexible modes is required.


## Bibliography {#bibliography}

<a id="orged1e033"></a>Collette, C., and F Matichard. 2014. “Vibration Control of Flexible Structures Using Fusion of Inertial Sensors and Hyper-Stable Actuator-Sensor Pairs.” In _International Conference on Noise and Vibration Engineering (ISMA2014)_.
