+++
title = "Nanopositioning system with force feedback for high-performance tracking and vibration control"
author = ["Thomas Dehaeze"]
draft = false
+++

Backlinks:

-   [Force Sensors]({{< relref "force_sensors" >}})
-   [Piezoelectric Actuators]({{< relref "piezoelectric_actuators" >}})

Tags
: [Sensor Fusion]({{< relref "sensor_fusion" >}}), [Force Sensors]({{< relref "force_sensors" >}})

Reference
: ([Fleming 2010](#org28aeac7))

Author(s)
: Fleming, A.

Year
: 2010


## Summary {#summary}

-   The noise generated by a piezoelectric force sensor is much less than a capacitive sensor
-   Dynamical model of a piezoelectric stack actuator and piezoelectric force sensor
-   Noise of a piezoelectric force sensor
-   IFF with a piezoelectric stack actuator and piezoelectric force sensor
-   A force sensor is used as a displacement sensor below the frequency of the first zero
-   Sensor fusion architecture with a capacitive sensor and a force sensor and using complementary filters
-   Virtual sensor fusion architecture (called low-frequency bypass)
-   Analog implementation of the control strategies to avoid quantization noise, finite resolution and sampling delay


## Model of a multi-layer monolithic piezoelectric stack actuator {#model-of-a-multi-layer-monolithic-piezoelectric-stack-actuator}

<a id="org7145764"></a>

{{< figure src="/ox-hugo/fleming10_piezo_model.png" caption="Figure 1: Schematic of a multi-layer monolithic piezoelectric stack actuator model" >}}

The actuator experiences an internal stress in response to an applied voltage.
This stress is represented by the voltage dependent force \\(F\_a\\) and is related to free displacement by
\\[ \Delta L = \frac{F\_a}{k\_a} \\]

-   \\(\Delta L\\) is the change in actuator length in [m]
-   \\(k\_a\\) is the actuator stiffness in [N/m]

The developed force \\(F\_a\\) is related to the applied voltage by:
\\[ \Delta L = d\_{33} n V\_a \\]

-   \\(d\_{33}\\) is the piezoelectric strain constant in [m/V]
-   \\(n\\) is the number of layers
-   \\(V\_a\\) is the applied voltage in [V]

Combining the two equations, we obtain:
\\[ F\_a = d\_{33} n k\_a V\_a \\]

The ratio of the developed force to applied voltage is \\(d\_{33} n k\_a\\) in [N/V].
We denote this constant by \\(g\_a\\) and:
\\[ F\_a = g\_a V\_a, \quad g\_a = d\_{33} n k\_a \\]


## Dynamics of a piezoelectric force sensor {#dynamics-of-a-piezoelectric-force-sensor}

Piezoelectric force sensors provide a high sensitivity and bandwidth with low noise at high frequencies.

If a **single wafer** of piezoelectric material is sandwiched between the actuator and platform:
\\[ D = d\_{33} T \\]

-   \\(D\\) is the amount of generated charge per unit area in \\([C/m^2]\\)
-   \\(T\\) is the stress in \\([N/m^2]\\)
-   \\(d\_{33}\\) is the piezoelectric strain constant in \\([m/V] = [C/N]\\)

The generated charge is then
\\[ q = d\_{33} F\_s \\]

If an **n-layer** piezoelectric transducer is used as a force sensor, the generated charge is then:
\\[ q = n d\_{33} F\_s \\]

---

We can use a **charge amplifier** to measure the force \\(F\_s\\).

{{< figure src="/ox-hugo/fleming10_charge_ampl_piezo.png" caption="Figure 2: Electrical model of a piezoelectric force sensor is shown in gray. Developed charge \\(q\\) is proportional to the strain and hence the force experienced by the sensor. Op-amp charge amplifier produces an output voltage \\(V\_s\\) equal to \\(-q/C\_s\\)" >}}

The output voltage \\(V\_s\\) is equal to
\\[ V\_s = -\frac{q}{C\_s} = -\frac{n d\_{33}F\_s}{C\_s} \\]
that is, the scaling between the force and voltage is \\(-\frac{n d\_{33}F\_s}{C\_s}\ [V/N]\\) .

---

We can also use a voltage amplifier.
In that case, the generated charge is deposited on the transducer's internal capacitance.

The open-circuit voltage of a piezoelectric force sensor is:
\\[ V\_s = \frac{n d\_{33} F\_s}{C} \\]

-   \\(C\\) is the transducer capacitance defined by \\(C = n \epsilon\_T A / h\\) in [F]
    -   \\(A\\) is the area in \\([m^2]\\)
    -   \\(h\\) is the layer thickness in [m]
    -   \\(\epsilon\_T\\) is the dielectric permittivity under a constant stress in \\([F/m]\\)

We obtain
\\[ V\_s = g\_s F\_s, \quad g\_s = \frac{n d\_{33}}{C} \\]


## Noise of a piezoelectric force sensor {#noise-of-a-piezoelectric-force-sensor}

As piezoelectric sensors have a capacitive source impedance, the sensor noise density \\(N\_{V\_s}(\omega)\\) is primarily due to current noise \\(i\_n\\) reacting the capacitive source impedance:
\\[ N\_{V\_s}(\omega) = i\_n \frac{1}{C \omega} \\]

-   \\(N\_{V\_s}\\) is the measured noise in \\(V/\sqrt{\text{Hz}}\\)
-   \\(i\_n\\) is the current noise in \\(A/\sqrt{\text{Hz}}\\)
-   \\(C\\) is the capacitance of the piezoelectric in \\(F\\)

The current noise density of a general purpose LM833 FET-input op-amp is \\(0.5\ pA/\sqrt{\text{Hz}}\\).
The capacitance of a piezoelectric stack is typically between \\(1 \mu F\\) and \\(100 \mu F\\).


## Tested feedback control strategies {#tested-feedback-control-strategies}

<a id="org9ecbbcf"></a>

{{< figure src="/ox-hugo/fleming10_fb_control_strats.png" caption="Figure 3: Comparison of: (a) basic integral control. (b) direct tracking control. (c) dual-sensor feedback. (d) low frequency bypass" >}}


## Bibliography {#bibliography}

<a id="org28aeac7"></a>Fleming, A.J. 2010. “Nanopositioning System with Force Feedback for High-Performance Tracking and Vibration Control.” _IEEE/ASME Transactions on Mechatronics_ 15 (3):433–47. <https://doi.org/10.1109/tmech.2009.2028422>.
