+++
title = "A review of nanometer resolution position sensors: operation and performance"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Position Sensors]({{< relref "position_sensors" >}})

Reference
: ([Fleming 2013](#org336a947))

Author(s)
: Fleming, A. J.

Year
: 2013

-   Define concise performance metric and provide expressions for errors sources (non-linearity, drift, noise)
-   Review current position sensor technologies and compare their performance


## Sensor Characteristics {#sensor-characteristics}


### Calibration and nonlinearity {#calibration-and-nonlinearity}

Usually quoted as a percentage of the fill-scale range (FSR):

\begin{equation}
  \text{mapping error (\%)} = \pm 100 \frac{\max{}|e\_m(v)|}{\text{FSR}}
\end{equation}

With \\(e\_m(v)\\) is the mapping error.

<a id="org3c27d5a"></a>

{{< figure src="/ox-hugo/fleming13_mapping_error.png" caption="Figure 1: The actual position versus the output voltage of a position sensor. The calibration function \\(f\_{cal}(v)\\) is an approximation of the sensor mapping function \\(f\_a(v)\\) where \\(v\\) is the voltage resulting from a displacement \\(x\\). \\(e\_m(v)\\) is the residual error." >}}


### Drift and Stability {#drift-and-stability}

If the shape of the mapping function actually varies with time, the maximum error due to drift must be evaluated by finding the worst-case mapping error.

<a id="org69dcb2d"></a>

{{< figure src="/ox-hugo/fleming13_drift_stability.png" caption="Figure 2: The worst case range of a linear mapping function \\(f\_a(v)\\) for a given error in sensitivity and offset." >}}


### Bandwidth {#bandwidth}

The bandwidth of a position sensor is the frequency at which the magnitude of the transfer function \\(P(s) = v(s)/x(s)\\) drops by \\(3\,dB\\).

Although the bandwidth specification is useful for predicting the resolution of sensor, it reveals very little about the measurement errors caused by sensor dynamics.

The frequency domain position error is

\begin{equation}
  \begin{aligned}
    e\_{bw}(s) &= x(s) - v(s) \\\\\\
              &= x(s) (1 - P(s))
  \end{aligned}
\end{equation}

If the actual position is a sinewave of peak amplitude \\(A = \text{FSR}/2\\):

\begin{equation}
  \begin{aligned}
    e\_{bw} &= \pm \frac{\text{FSR}}{2} |1 - P(s)| \\\\\\
           &\approx \pm A n \frac{f}{f\_c}
  \end{aligned}
\end{equation}

with \\(n\\) is the low pass filter order corresponding to the sensor dynamics and \\(f\_c\\) is the measurement bandwidth.

Thus, the sensor bandwidth must be significantly higher than the operating frequency if dynamic errors are to be avoided.


### Noise {#noise}

In addition to the actual position signal, all sensors produce some additive measurement noise.
In many types of sensor, the majority of noise arises from the thermal noise in resistors and the voltage and current noise in conditioning circuit transistors.
These noise processes can usually be approximated by a Gaussian random process.<br />

A Gaussian random process is usually described by its autocorrelation function or its Power Spectral Density.

The autocorrelation function of a random process \\(\mathcal{X}\\) is

\begin{equation}
  R\_{\mathcal{X}}(\tau) = E[\mathcal{X}(t)\mathcal{X}(t + \tau)]
\end{equation}

where \\(E\\) is the expected value operator.

The variance of the process is equal to \\(R\_\mathcal{X}(0)\\) and is the expected value of the varying part squared:

\begin{equation}
  \text{Var} \mathcal{X} = E \left[ (\mathcal{X} - E[\mathcal{X}])^2 \right]
\end{equation}

The standard deviation \\(\sigma\\) is the square root of the variance:

\begin{equation}
  \sigma\_\mathcal{X} = \sqrt{\text{Var} \mathcal{X}}
\end{equation}

The standard deviation is also the Root Mean Square (RMS) value of a zero-mean random process.

The Power Spectral Density \\(S\_\mathcal{X}(f)\\) of a random process represents the distribution of power (or variance) across frequency \\(f\\).

For example, if the random process under consideration was measured in volts, the power spectral density would have the units of \\(V^2/\text{Hz}\\).

The Power Spectral Density can be obtained from the autocorrelation function from the Wiener-Khinchin relation:

\begin{equation}
  S\_{\mathcal{X}} = 2 \mathcal{F}\\{ R\_\mathcal{X}(\tau) \\} = 2 \int\_{-\infty}^{\infty} R\_\mathcal{X}(\tau) e^{-2j\pi f \tau} d\tau
\end{equation}

If the power Spectral Density is known, the variance of the generating process can be found from the area under the curve:

\begin{equation}
  \sigma\_\mathcal{X}^2 = E[\mathcal{X}^2(t)] = R\_\mathcal{X}(0) = \int\_0^\infty S\_\mathcal{X}(f) df
\end{equation}

Rather than plotting the frequency distribution of power, it is often convenient to plot the frequency distribution of the standard deviation, which is referred to as the spectral density.
It is related to the power spectral density by a square root:

\begin{equation}
  \text{spectral density} = \sqrt{S\_\mathcal{X}(f)}
\end{equation}

The units of \\(\sqrt{S\_\mathcal{X}(f)}\\) are \\(\text{units}/\sqrt{Hz}\\).

The spectral density if preferred in the electronics literature as the RMS value of a noise process can be determined directly from the noise density and effective bandwidth.


### Resolution {#resolution}

The random noise of a position sensor causes an uncertainty in the measured position.
If the distance between two measured locations is smaller than the uncertainty, it is possible to mistake one point for the other.

To characterize the resolution, we use the probability that the measured value is within a certain error bound.

If the measurement noise is approximately Gaussian, the resolution can be quantified by the standard deviation \\(\sigma\\) (RMS value).

The empirical rule states that there is a \\(99.7\%\\) probability that a sample of a Gaussian random process lie within \\(\pm 3 \sigma\\).
This if we define the resolution as \\(\delta = 6 \sigma\\), we will referred to as the \\(6\sigma\text{-resolution}\\).

Another important parameter that must be specified when quoting resolution is the sensor bandwidth.
There is usually a trade-off between bandwidth and resolution (figure [3](#orge95682f)).

<a id="orge95682f"></a>

{{< figure src="/ox-hugo/fleming13_tradeoff_res_bandwidth.png" caption="Figure 3: The resolution versus banwidth of a position sensor." >}}

Many type of sensor have a limited full-scale-range (FSR) and tend to have an approximated proportional relationship between the resolution and range.
As a result, it is convenient to consider the ratio of resolution to the FSR, or equivalently, the dynamic range (DNR).
A convenient method for reporting this ratio is in parts-per-million (ppm):

\begin{equation}
  \text{DNR}\_{\text{ppm}} = 10^6 \frac{\text{full scale range}}{6\sigma\text{-resolution}}
\end{equation}


## Comparison and summary {#comparison-and-summary}

<a id="table--tab:summary-position-sensors"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:summary-position-sensors">Table 1</a></span>:
  Summary of position sensor characteristics. The dynamic range (DNR) and resolution are approximations based on a full-scale range of \(100\,\mu m\) and a first order bandwidth of \(1\,kHz\)
</div>

| Sensor Type    | Range                            | DNR     | Resolution | Max. BW  | Accuracy  |
|----------------|----------------------------------|---------|------------|----------|-----------|
| Metal foil     | \\(10-500\,\mu m\\)              | 230 ppm | 23 nm      | 1-10 kHz | 1% FSR    |
| Piezoresistive | \\(1-500\,\mu m\\)               | 5 ppm   | 0.5 nm     | >100 kHz | 1% FSR    |
| Capacitive     | \\(10\,\mu m\\) to \\(10\,mm\\)  | 24 ppm  | 2.4 nm     | 100 kHz  | 0.1% FSR  |
| Electrothermal | \\(10\,\mu m\\) to \\(1\,mm\\)   | 100 ppm | 10 nm      | 10 kHz   | 1% FSR    |
| Eddy current   | \\(100\,\mu m\\) to \\(80\,mm\\) | 10 ppm  | 1 nm       | 40 kHz   | 0.1% FSR  |
| LVDT           | \\(0.5-500\,mm\\)                | 10 ppm  | 5 nm       | 1 kHz    | 0.25% FSR |
| Interferometer | Meters                           |         | 0.5 nm     | >100kHz  | 1 ppm FSR |
| Encoder        | Meters                           |         | 6 nm       | >100kHz  | 5 ppm FSR |



## Bibliography {#bibliography}

<a id="org336a947"></a>Fleming, Andrew J. 2013. “A Review of Nanometer Resolution Position Sensors: Operation and Performance.” _Sensors and Actuators a: Physical_ 190 (nil):106–26. <https://doi.org/10.1016/j.sna.2012.10.016>.
