+++
title = "Sensors and control of a space-based six-axis vibration isolation system"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Stewart Platforms]({{< relref "stewart_platforms" >}}), [Vibration Isolation]({{< relref "vibration_isolation" >}}), [Cubic Architecture]({{< relref "cubic_architecture" >}})

Reference
: ([Hauge and Campbell 2004](#orge4a516e))

Author(s)
: Hauge, G., & Campbell, M.

Year
: 2004

**Discusses**:

-   Choice of sensors and control architecture
-   Predictability and limitations of the system dynamics
-   Two-Sensor control architecture
-   Vibration isolation using a Stewart platform
-   Experimental comparison of Force sensor and Inertial Sensor and associated control architecture for vibration isolation

<a id="org59ac043"></a>

{{< figure src="/ox-hugo/hauge04_stewart_platform.png" caption="Figure 1: Hexapod for active vibration isolation" >}}

**Stewart platform** (Figure [1](#org59ac043)):

-   Low corner frequency
-   Large actuator stroke (\\(\pm5mm\\))
-   Sensors in each strut (Figure [2](#org59c0ee0)):
    -   three-axis load cell
    -   base and payload geophone in parallel with the struts
    -   LVDT

<a id="org59c0ee0"></a>

{{< figure src="/ox-hugo/hauge05_struts.png" caption="Figure 2: Strut" >}}

> Force sensors typically work well because they are not as sensitive to payload and base dynamics, but are limited in performance by a low-frequency zero pair resulting from the cross-axial stiffness.

**Performance Objective** (frequency domain metric):

-   The transmissibility should be close to 1 between 0-1.5Hz
    \\(-3dB < |T(\omega)| < 3db\\)
-   The transmissibility should be below -20dB in the 5-20Hz range
    \\(|T(\omega)| < -20db\\)

With \\(|T(\omega)|\\) is the Frobenius norm of the transmissibility matrix and is used to obtain a scalar performance metric.

**Challenge**:

-   small frequency separation between the two requirements

**Robustness**:

-   minimization of the transmissibility amplification (Bode's "pop") outside the performance region

**Model**:

-   single strut axis as the cubic Stewart platform can be decomposed into 6 single-axis systems

<a id="org5b75feb"></a>

{{< figure src="/ox-hugo/hauge04_strut_model.png" caption="Figure 3: Strut model" >}}

**Zero Pair when using a Force Sensor**:

-   The frequency of the zero pair corresponds to the resonance frequency of the payload mass and the "parasitic" stiffness (sum of the cross-axial, suspension, wiring stiffnesses)
-   This zero pair is usually not predictable nor repeatable
-   In this Stewart platform, this zero pair uncertainty is due to the internal wiring of the struts

**Control**:

-   Single-axis controllers => combine them into a full six-axis controller => evaluate the full controller in terms of stability and robustness
-   Sensitivity weighted LQG controller (SWLQG) => address robustness in flexible dynamic systems
-   Three type of controller:
    -   Force feedback (cell-based)
    -   Inertial feedback (geophone-based)
    -   Combined force/velocity feedback (load cell/geophone based)

> The use of multivariable and robust control on the full 6x6 hexapod does not improve performance over single-axis designs.

<a id="table--tab:hauge05-comp-load-cell-geophone"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:hauge05-comp-load-cell-geophone">Table 1</a></span>:
  Typical characteristics of sensors used for isolation in hexapod systems
</div>

|                                         | **Load cell**                   | **Geophone**                        |
|-----------------------------------------|---------------------------------|-------------------------------------|
| Type                                    | Relative                        | Inertial                            |
| Relationship with voice coil            | Collocated and Dual             | Non-Collocated and non-Dual         |
| Open loop transfer function             | (+) Alternating poles/zeros     | (-) Large phase drop                |
| Limitation from low-frequency zero pair | (-) Yes                         | (+) No                              |
| Sensitive to payload/base dynamics      | (+) No                          | (-) Yes                             |
| Best frequency range                    | High (low-freq zero limitation) | Low (high-freq toll-off limitation) |

**Ability of a sensor-actuator pair to improve performance**:
General system with input \\(u\\), performance \\(z\\), output \\(y\\) disturbance \\(u\\).

Given a sensor \\(u\\) and actuator \\(y\\) and a controller \\(u = -K(s) y\\), the closed loop disturbance to performance transfer function can be written as:

\\[ \left[ \frac{z}{w} \right]\_\text{CL} = \frac{G(s)\_{zw} + K(G(s)\_{zw} G(s)\_{yu} - G(s)\_{zu} G(s)\_{yw})}{1 + K G(s)\_{yu}} \\]

In order to obtain a significant performance improvement is to use a high gain controller, _provided_ the term \\(G(s)\_{zw} + K(G(s)\_{zw} G(s)\_{yu} - G(s)\_{zu} G(s)\_{yw})\\) is small.

We can compare the transfer function from \\(w\\) to \\(z\\) with and without a high gain controller.
And we find that for \\(u\\) and \\(y\\) to be an acceptable pair for high gain control:
\\[ \left| \frac{G(j\omega)\_{zw} G(j\omega)\_{yu} - G(j\omega)\_{zu} G(j\omega)\_{yw}}{K G(j\omega)\_{yu}} \right| \ll |G\_{zw}(j\omega)| \\]

**Controllers**:

**Force feedback**:

-   Performance limited by the low frequency zero-pair
-   It is desirable to separate the zero-pair and first most are separated by at least a decade in frequency
-   This can be achieve by reducing the cross-axis stiffness
-   If the low frequency zero pair is inverted, robustness is lost
-   Thus, the force feedback controller should be designed to have combined performance and robustness at frequencies at least a decade above the zero pair
-   The presented controller as a high pass filter at to reduce the gain below the zero-pair, a lag at low frequency to improve phase margin, and a low pass filter for roll off

**Inertial feedback**:

-   Non-Collocated => multiple phase drops that limit the bandwidth of the controller
-   Good performance, but the transmissibility "pops" due to low phase margin and thus this indicates robustness problems

**Combined force/velocity feedback**:

-   Use the low frequency performance advantages of geophone sensor with the high robustness advantages of the load cell sensor
-   A Single-Input-Multiple-Outputs (SIMO) controller is found using LQG
-   The performance requirements are met
-   Good robustness

<a id="org4a7177a"></a>

{{< figure src="/ox-hugo/hauge04_obtained_transmissibility.png" caption="Figure 4: Experimental open loop (solid) and closed loop six-axis transmissibility using the geophone only controller (dotted), and combined geophone/load cell controller (dashed)" >}}


## Bibliography {#bibliography}

<a id="orge4a516e"></a>Hauge, G.S., and M.E. Campbell. 2004. “Sensors and Control of a Space-Based Six-Axis Vibration Isolation System.” _Journal of Sound and Vibration_ 269 (3-5):913–31. <https://doi.org/10.1016/s0022-460x(03)>00206-2.
