+++
title = "Simultaneous, fault-tolerant vibration isolation and pointing control of flexure jointed hexapods"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Stewart Platforms]({{< relref "stewart_platforms" >}}), [Vibration Isolation]({{< relref "vibration_isolation" >}}), [Cubic Architecture]({{< relref "cubic_architecture" >}}), [Flexible Joints]({{< relref "flexible_joints" >}}), [Multivariable Control]({{< relref "multivariable_control" >}})

Reference
: ([Li 2001](#org7799941))

Author(s)
: Li, X.

Year
: 2001


## Introduction {#introduction}

**Stewart Platform**:

-   Cubic (mutually orthogonal)
-   Flexure Joints => eliminate friction and backlash but add complexity to the dynamics

<a id="org6847e54"></a>

{{< figure src="/ox-hugo/li01_stewart_platform.png" caption="Figure 1: Flexure jointed Stewart platform used for analysis and control" >}}

**Goal**:

-   Precise pointing in two axes (sub micro-radians)
-   simultaneously, providing both passive and active vibration isolation in six axes

**Jacobian Analysis**:
\\[ \delta \mathcal{L} = J \delta \mathcal{X} \\]
The origin of \\(\\{P\\}\\) is taken as the center of mass of the payload.

**Decoupling**:
If we refine the (force) inputs and (displacement) outputs as shown in Figure [2](#org7d1b81f) or in Figure [3](#orgc8972f9), we obtain a decoupled plant provided that:

1.  the payload mass/inertia matrix must be diagonal (the CoM is coincident with the origin of frame \\(\\{P\\}\\))
2.  the geometry of the hexapod and the attachment of the payload to the hexapod must be carefully chosen

> For instance, if the hexapod has a mutually orthogonal geometry (cubic configuration), the payload's center of mass must coincide with the center of the cube formed by the orthogonal struts.

<a id="org7d1b81f"></a>

{{< figure src="/ox-hugo/li01_decoupling_conf.png" caption="Figure 2: Decoupling the dynamics of the Stewart Platform using the Jacobians" >}}

<a id="orgc8972f9"></a>

{{< figure src="/ox-hugo/li01_decoupling_conf_bis.png" caption="Figure 3: Decoupling the dynamics of the Stewart Platform using the Jacobians" >}}


## Simultaneous Vibration Isolation and Pointing Control {#simultaneous-vibration-isolation-and-pointing-control}

Basic idea:

-   acceleration feedback is used to provide high-frequency vibration isolation
-   cartesian pointing feedback can be used to provide low-frequency pointing

The compensation is divided in frequency because:

-   pointing sensors often have low bandwidth
-   acceleration sensors often have a poor low frequency response

The control bandwidth is divided as follows:

-   low-frequency disturbances as attenuated and tracking is accomplished by feedback from low bandwidth pointing sensors
-   mid-frequency disturbances are attenuated by feedback from band-pass sensors like accelerometer or load cells
-   high-frequency disturbances are attenuated by passive isolation techniques


### Vibration Isolation {#vibration-isolation}

The system is decoupled into six independent SISO subsystems using the architecture shown in Figure [4](#orgabd1d61).

<a id="orgabd1d61"></a>

{{< figure src="/ox-hugo/li01_vibration_isolation_control.png" caption="Figure 4: Figure caption" >}}

One of the subsystem plant transfer function is shown in Figure [4](#orgabd1d61)

<a id="org5a1c162"></a>

{{< figure src="/ox-hugo/li01_vibration_control_plant.png" caption="Figure 5: Plant transfer function of one of the SISO subsystem for Vibration Control" >}}

Each compensator is designed using simple loop-shaping techniques.

The unity control bandwidth of the isolation loop is designed to be from **5Hz to 50Hz**.

> Despite a reasonably good match between the modeled and the measured transfer functions, the model based decoupling algorithm does not produce the expected decoupling.
> Only about 20 dB separation is achieve between the diagonal and off-diagonal responses.


### Pointing Control {#pointing-control}

A block diagram of the pointing control system is shown in Figure [6](#orga9c8d31).

<a id="orga9c8d31"></a>

{{< figure src="/ox-hugo/li01_pointing_control.png" caption="Figure 6: Figure caption" >}}

The plant is decoupled into two independent SISO subsystems.
The compensators are design with inverse-dynamics methods.

The unity control bandwidth of the pointing loop is designed to be from **0Hz to 20Hz**.

A feedforward control is added as shown in Figure [7](#org78d2b0e).

<a id="org78d2b0e"></a>

{{< figure src="/ox-hugo/li01_feedforward_control.png" caption="Figure 7: Feedforward control" >}}


### Simultaneous Control {#simultaneous-control}

The simultaneous vibration isolation and pointing control is approached in two ways:

1.  design and implement the vibration isolation control first, identify the pointing plant when the isolation loops are closed, then implement the pointing compensators
2.  the reverse design order

Figure [8](#org94ed578) shows a parallel control structure where \\(G\_1(s)\\) is the dynamics from input force to output strut length.

<a id="org94ed578"></a>

{{< figure src="/ox-hugo/li01_parallel_control.png" caption="Figure 8: A parallel scheme" >}}

The transfer function matrix for the pointing loop after the vibration isolation is closed is still decoupled. The same happens when closing the pointing loop first and looking at the transfer function matrix of the vibration isolation.

The effect of the isolation loop on the pointing loop is large around the natural frequency of the plant as shown in Figure [9](#orgae8c117).

<a id="orgae8c117"></a>

{{< figure src="/ox-hugo/li01_effect_isolation_loop_closed.png" caption="Figure 9: \\(\theta\_x/\theta\_{x\_d}\\) transfer function with the isolation loop closed (simulation)" >}}

The effect of pointing control on the isolation plant has not much effect.

> The interaction between loops may affect the transfer functions of the **first** closed loop, and thus affect its relative stability.

The dynamic interaction effect:

-   only happens in the unity bandwidth of the loop transmission of the first closed loop.
-   affect the closed loop transmission of the loop first closed (see Figures [10](#org00362f7) and [11](#org77c322d))

As shown in Figure [10](#org00362f7), the peak resonance of the pointing loop increase after the isolation loop is closed.
The resonances happen at both crossovers of the isolation loop (15Hz and 50Hz) and they may show of loss of robustness.

<a id="org00362f7"></a>

{{< figure src="/ox-hugo/li01_closed_loop_pointing.png" caption="Figure 10: Closed-loop transfer functions \\(\theta\_y/\theta\_{y\_d}\\) of the pointing loop before and after the vibration isolation loop is closed" >}}

The same happens when first closing the vibration isolation loop and after the pointing loop (Figure [11](#org77c322d)).
The first peak resonance of the vibration isolation loop at 15Hz is increased when closing the pointing loop.

<a id="org77c322d"></a>

{{< figure src="/ox-hugo/li01_closed_loop_vibration.png" caption="Figure 11: Closed-loop transfer functions of the vibration isolation loop before and after the pointing control loop is closed" >}}

> The isolation loop adds a second resonance peak at its high-frequency crossover in the pointing closed-loop transfer function, which may cause instability.
> Thus, it is recommended to design and implement the isolation control system first, and then identify the pointing plant with the isolation loop closed.


### Experimental results {#experimental-results}

Two hexapods are stacked (Figure [12](#org5977cb3)):

-   the bottom hexapod is used to generate disturbances matching candidate applications
-   the top hexapod provide simultaneous vibration isolation and pointing control

<a id="org5977cb3"></a>

{{< figure src="/ox-hugo/li01_test_bench.png" caption="Figure 12: Stacked Hexapods" >}}

Using the vibration isolation control alone, no attenuation is achieved below 1Hz as shown in figure [13](#org4707691).

<a id="org4707691"></a>

{{< figure src="/ox-hugo/li01_vibration_isolation_control_results.png" caption="Figure 13: Vibration isolation control: open-loop (solid) vs. closed-loop (dashed)" >}}

The simultaneous control is of dual use:

-   it provide simultaneous pointing and isolation control
-   it can also be used to expand the bandwidth of the isolation control to low frequencies because the pointing loops suppress pointing errors due to both base vibrations and tracking

The results of simultaneous control is shown in Figure [14](#orge4b1f73) where the bandwidth of the isolation control is expanded to very low frequency.

<a id="orge4b1f73"></a>

{{< figure src="/ox-hugo/li01_simultaneous_control_results.png" caption="Figure 14: Simultaneous control: open-loop (solid) vs. closed-loop (dashed)" >}}


## Future research areas {#future-research-areas}

Proposed future research areas include:

-   **Include base dynamics in the control**:
    The base dynamics is here neglected since the movements of the base are very small.
    The base dynamics could be measured by mounting accelerometers at the bottom of each strut or by using force sensors.
    It then could be included in the feedforward path.
-   **Robust control and MIMO design**
-   **New decoupling method**:
    The proposed decoupling algorithm do not produce the expected decoupling, despite a reasonably good match between the modeled and the measured transfer functions.
    Incomplete decoupling increases the difficulty in designing the controller.
    New decoupling methods are needed.
    These methods must be static in order to be implemented practically on precision hexapods
-   **Identification**:
    Many advanced control methods require a more accurate model or identified plant.
    A closed-loop identification method is propose to solve some problems with the current identification methods used.
-   **Other possible sensors**:
    Many sensors can be used to expand the utility of the Stewart platform:
    -   **3-axis load cells** to investigate the Coriolis and centripetal terms and new decoupling methods
    -   **LVDT** to provide differential position of the hexapod payload with respect to the base
    -   **Geophones** to provide payload and base velocity information



## Bibliography {#bibliography}

<a id="org7799941"></a>Li, Xiaochun. 2001. “Simultaneous, Fault-Tolerant Vibration Isolation and Pointing Control of Flexure Jointed Hexapods.” University of Wyoming.
