+++
title = "Respect the unstable"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
:


Reference
: ([Stein 2003](#org50b7ac8))

Author(s)
: Stein, G.

Year
: 2003


## Introduction {#introduction}

> The second trend has been evident at our conferences, and certainly in our journal, over the years.
> This trend is the increasing worship of abstract mathematical results in control at the expense of more specific examinations of their practical, physical consequences.

<div class="important">
  <div></div>

**Basic facts about unstable plants**:

-   Unstable systems are fundamentally, and quantifiably more difficult to control than stable ones
-   Controllers for unstable systems are operationally critical
-   Closed-loop systems with unstable components are only locally stable

</div>


## The Bode Integrals {#the-bode-integrals}

<div class="important">
  <div></div>

**Bode Integrals**:

The first integral applies to stable plants and the second to unstable plants.
They are valid for every stabilizing controller, assuming only that both plan and controller have finite bandwidths.
In words, the integrals state that the log of magnitude of sensitivity function of a SISO feedback system, integrated over frequency, is constant.
The constant is zero for stable plants, and it is positive for unstable ones.
It becomes larger as the number of unstable poles increases and/or as the poles more farther into the right-half plane.

\begin{align}
  \int\_0^\infty \ln |S(j\omega)| d \omega & = 0 \label{eq:bode\_integral\_stable} \\\\\\
  \int\_0^\infty \ln |S(j\omega)| d \omega & = \pi \sum\_{p \in P} \text{Re}(p) \label{eq:bode\_integral\_unstable}
\end{align}

</div>


## A Bode Integral Interpretation {#a-bode-integral-interpretation}

Bode integral can be thought as **conservation laws**.
They state that a certain quantity, the integrated value of the log of the magnitude of the sensitivity function, is conserved under the action of feedback.
The total amount of this quantity is always the same.
It is equal to zero for stable plant/compensator pairs, and it is equal to some fixed positive amount for unstable ones.

Since we are talking about the log of sensitivity magnitude, it follows that negative values are good, and positive values are bad.

<div class="definition">
  <div></div>

It is curious, somehow, that our field has not adopted a name for this quantity being conserved (i.e. the integrated log of sensitivity magnitude).
It is here proposed to call it **dirt**

</div>

The job of a serious control designer is then to more dirt from one place to another, using appropriate tools, without being able to get rid of any of it (illustrated in Figure [1](#org956e0bf)).

<a id="org956e0bf"></a>

{{< figure src="/ox-hugo/stein03_serious_design.png" caption="Figure 1: Sensitivity reduction at low frequency unavoidably leads to sensitivity increase at higher frequencies" >}}

In the same spirit, the job of a more academic control designer with more abstract tools such as LQG, \\(\mathcal{H}\_\infty\\), is to set parameters (weights) of a synthesis machine to adjust the contours of the machine's digging blades to get just the right shape for the sensitivity function (Figure [2](#org73c6dd3)).

<a id="org73c6dd3"></a>

{{< figure src="/ox-hugo/stein03_formal_design.png" caption="Figure 2: Sensitivity shaping automated by modern control tools" >}}


## Available bandwidth {#available-bandwidth}

An argument is sometimes made that the Bode integrals are not really restrictive because we only seek to dig holes over finite frequency bands.
We then have an infinite frequency range left over into which to dump the dirt, so we can make the layer arbitrarily thin (Figure [3](#orgb2839fe)).

<a id="orgb2839fe"></a>

{{< figure src="/ox-hugo/stein03_spreading_it_thin.png" caption="Figure 3: It is possible to spead the increase of the sensitivity function over a larger frequency band" >}}

The weakness of this argument is evident from standard classical theory.
A thin layer, say with \\(\ln|S| = \epsilon\\) requires a loop transfer function whose Nyquist diagram falls on a near-unit circle, centered at \\((-1 + j 0)\\) with a radius \\(\approx (1-\epsilon)\\), over a wide frequency range.
This means that the loop cannot simply attenuate at high frequencies but must attenuate in a very precise way.
The loop must maintain very good frequency response fidelity over wide frequency ranges.

But a key fact about physical systems is that they do not exhibit good frequency response fidelity beyond a certain bandwidth.
This is due to uncertain or unmodeled dynamics in the plant, to digital control implementations, to power limits, to nonlinearities, and to many other factors.
Let us call that bandwidth the available bandwidth" \\(\Omega\_a\\), to distinguish it from other bandwidths such as crossover or \\(3-dB\\) magnitude loss.
The available bandwidth is the frequency up to which we can keep \\(G(j\omega) K(j\omega)\\) close to a nominal design and beyond which we can only guarantee that the actual loop magnitude will attenuate rapidly enough (e.g. \\(|G(j\omega) K(j\omeg\\))| < &delta;/&omega;^2$).
In today's popular robust control jargon, the available bandwidth is the frequency range over which the unstructured multiplicative perturbations are substantially less than unity.

Note that the available bandwidth is not a function of the compensator or of the control design process.
Rather, it is an a priori constraint imposed by the physical hardware we use in the control loop.
Most importantly, the available bandwidth is always finite.

Given all this, Bode's integrals really reduce to finite integrals over the range \\(0 \ge \omega \ge \Omega\_a\\):

\begin{align}
  \int\_0^{\Omega\_a} \ln{|S(j \omega)|} d \omega &= \delta \\\\\\
  \int\_0^{\Omega\_a} \ln{|S(j \omega)|} d \omega &= \pi \sum\_{p \in P} \text{Re}(p) + \delta
\end{align}

All the action of the feedback design, the sensitivity improvements as well as the sensitivity deterioration, must occur within \\(0 \ge \omega \ge \Omega\_a\\).
Only a small error \\(\delta\\) occurs outside that range, associated with the tail of the complete integrals.


## Bibliography {#bibliography}

<a id="org50b7ac8"></a>Stein, Gunter. 2003. “Respect the Unstable.” _IEEE Control Systems Magazine_ 23 (4). IEEE:12–25.
