+++
title = "Dynamic modeling and decoupled control of a flexible stewart platform for vibration isolation"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Stewart Platforms]({{< relref "stewart_platforms" >}}), [Vibration Isolation]({{< relref "vibration_isolation" >}}), [Flexible Joints]({{< relref "flexible_joints" >}}), [Cubic Architecture]({{< relref "cubic_architecture" >}})

Reference
: ([Yang et al. 2019](#org8fbcee2))

Author(s)
: Yang, X., Wu, H., Chen, B., Kang, S., & Cheng, S.

Year
: 2019

**Discusses**:

-   flexible-rigid model of Stewart platform
-   the impact of joint stiffness is compensated using a displacement sensor and a force sensor
-   then the MIMO system is decoupled in modal space and 6 SISO controllers are applied for vibration isolation using force sensors

The joint stiffness impose a limitation on the control performance using force sensors as it adds a zero at low frequency in the dynamics.
Thus, this stiffness is taken into account in the dynamics and compensated for.

**Stewart platform** (Figure [1](#org006c2df)):

-   piezoelectric actuators
-   flexible joints (Figure [2](#org8725dbf))
-   force sensors (used for vibration isolation)
-   displacement sensors (used to decouple the dynamics)
-   cubic (even though not said explicitly)

<a id="org006c2df"></a>

{{< figure src="/ox-hugo/yang19_stewart_platform.png" caption="Figure 1: Stewart Platform" >}}

<a id="org8725dbf"></a>

{{< figure src="/ox-hugo/yang19_flexible_joints.png" caption="Figure 2: Flexible Joints" >}}

The stiffness of the flexible joints (Figure [2](#org8725dbf)) are computed with an FEM model and shown in Table [1](#table--tab:yang19-stiffness-flexible-joints).

<a id="table--tab:yang19-stiffness-flexible-joints"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:yang19-stiffness-flexible-joints">Table 1</a></span>:
  Stiffness of flexible joints obtained by FEM
</div>

| \\(k\_{\theta u},\ k\_{\psi u}\\) | \\(72 Nm/rad\\) |
|-----------------------------------|-----------------|
| \\(k\_{\theta s}\\)               | \\(51 Nm/rad\\) |
| \\(k\_{\psi s}\\)                 | \\(62 Nm/rad\\) |
| \\(k\_{\gamma s}\\)               | \\(64 Nm/rad\\) |

**Dynamics**:
If the bending and torsional stiffness of the flexible joints are neglected:
\\[ M \ddot{x} + C \dot{x} + K x = J^T f \\]

-   \\(M\\) is the mass matrix
-   \\(C\\) is the damping matrix
-   \\(K\\) is the stiffness matrix
-   \\(x\\) is the generalized coordinates, representing the displacement and orientation of the payload plate
-   \\(f\\) is the actuator forces
-   \\(J\\) is the Jacobian matrix

In this paper, the parasitic bending stiffness of the flexible joints are considered:
\\[ M \ddot{x} + C \dot{x} + (K + K\_e) x = J^T f \\]
where \\(K\_e\\) is the stiffness matrix induced by the parasitic stiffness of the flexible joints.

Analytical expression for \\(K\_e\\) are derived in the paper.

**Controller Design**:
There is a strong coupling between the input forces and the state variables in the task space.
The traditional modal decoupled control strategy cannot work with the flexible Stewart platform because it is impossible to achieve simultaneous diagonalization of the mass, damped and stiffness matrices.

To make the six-dof system decoupled into six single-dof isolators, a controller based on the leg's force and position feedback is designed.

> The idea is to synthesize the control force that can compensate the parasitic bending and torsional torques of the flexible joints and simultaneously achieve diagonalization of the matrices \\(M\\), \\(C\\) and \\(K\\)

The force measured by the force sensors are:
\\[ y = f - k J x - c J \dot{x} \\]
The displacements measured by the position sensors are:
\\[ z = [\Delta l\_1\ \dots\ \Delta l\_6]^T \\]

Let's apply the feedback control based on both the force sensor and the position sensor:
\\[ f = -H(s) y + (1 + H(s)) K\_{el} z \\]
where \\(K\_{el} = J^{-T} K\_e J^T\\) is the stiffness matrix of the flexible joints expressed in joint space.

We thus obtain:
\\[ f = \frac{H(s)}{1 + H(s)} (k J x + c J \dot{x}) + J^{-T} K\_e x \\]

If we substitute \\(f\\) in the dynamic equation, we obtain that the parasitic stiffness effect of the flexible joints has been compensated by the actuation forces and the system can now be decoupled in modal space \\(x = \Phi u\\).
\\(\Phi\\) is the modal matrix selected such that \\(\Phi^T M \Phi = I\_6\\) and \\(k \Phi^T J^T J \Phi = \text{diag}(\omega\_1^2\ \dots\ \omega\_6^2)\\):
\\[ s^2 + \frac{1}{1 + H(s)} \frac{c \omega\_i^2}{k} s + \frac{1}{1 + H(s)} \omega\_i^2 = 0, \quad i = 1,\ \dots,\ 6 \\]

The six-dof system is now transformed into a six one-dof system where \\(H(s)\\) can be designed for control purpose.

In order to apply this control strategy:

-   A force sensor and displacement sensor are need in each strut
-   The joint stiffness has to be known
-   The jacobian has to be computed
-   No information about modal matrix is needed

The block diagram of the control strategy is represented in Figure [3](#org820f661).

<a id="org820f661"></a>

{{< figure src="/ox-hugo/yang19_control_arch.png" caption="Figure 3: Control Architecture used" >}}

\\(H(s)\\) is designed as a proportional plus integral compensator:
\\[ H(s) = k\_p + k\_i/s \\]

Substituting \\(H(s)\\) in the equation of motion gives that:

-   an increase of \\(k\_i\\) increase the damping and thus suppress the resonance peaks
-   an increase of \\(k\_p\\) lowers the resonance frequency and thus the bandwidth of vibration isolation is examped

**Experimental Validation**:
An external Shaker is used to excite the base and accelerometers are located on the base and mobile platforms to measure their motion.
The results are shown in Figure [4](#org990744b).
In theory, the vibration performance can be improved, however in practice, increasing the gain causes saturation of the piezoelectric actuators and then the instability occurs.

<a id="org990744b"></a>

{{< figure src="/ox-hugo/yang19_results.png" caption="Figure 4: Frequency response of the acceleration ratio between the paylaod and excitation (Transmissibility)" >}}

> A model-based controller is then designed based on the leg’s force and position feedback.
> The position feedback compensates the effect of parasitic bending and torsional stiffness of the flexible joints.
> The force feedback makes the six-DOF MIMO system decoupled into six SISO subsystems in modal space, where the control gains can be designed and analyzed more effectively and conveniently.
> The proportional and integral gains in the sub-controller are used to separately regulate the vibration isolation bandwidth and active damping simultaneously for the six vibration modes.


## Bibliography {#bibliography}

<a id="org8fbcee2"></a>Yang, XiaoLong, HongTao Wu, Bai Chen, ShengZheng Kang, and ShiLi Cheng. 2019. “Dynamic Modeling and Decoupled Control of a Flexible Stewart Platform for Vibration Isolation.” _Journal of Sound and Vibration_ 439 (January). Elsevier BV:398–412. <https://doi.org/10.1016/j.jsv.2018.10.007>.
