+++
title = "Multivariable control systems: an engineering approach"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Multivariable Control]({{< relref "multivariable_control" >}})

Reference
: ([Albertos and Antonio 2004](#orgb06343d))

Author(s)
: Albertos, P., & Antonio, S.

Year
: 2004


## Introduction to Multivariable Control {#introduction-to-multivariable-control}


## Linear System Representation: Models and Equivalence {#linear-system-representation-models-and-equivalence}


## Linear Systems Analysis {#linear-systems-analysis}


## Solutions to the Control Problem {#solutions-to-the-control-problem}


## Decentralised and Decoupled Control {#decentralised-and-decoupled-control}


### Decoupling {#decoupling}

In cases when multi-loop control is not effective in reaching the desired specifications, a possible strategy for tackling the MIMO control could be to transform the transfer function matrix into a diagonal dominant one.
This strategy is called **decoupling**.

[Decoupled Control]({{< relref "decoupled_control" >}}) can be achieved in two ways:

-   feedforward cancellation of the cross-coupling terms
-   based on state measurements, via a feedback law


#### Feedforward Decoupling {#feedforward-decoupling}

A pre-compensator can be added to transform the open-loop characteristics into a new one as chosen by the designer.
This decoupler can be taken as the inverse of the plant provided it does not include RHP-zeros.

**Approximate decoupling**:
To design low-bandwidth loops, insertion of the inverse DC-gain before the loop ensures decoupling at least at steady-state.
If further bandwidth extension is desired, an approximation of \\(G^{-1}\\) valid in low frequencies can be used.


#### Feedback Decoupling {#feedback-decoupling}

Although at first glance, decoupling seems an appealing idea, there are some drawbacks:

-   as decoupling is achieved via the coordination of sensors and actuators to achieve an "apparent" diagonal behavior, the failure of one the actuators may heavily affects all loops.
-   a decoupling design (inverse-based controller) may not be desirable for all disturbance-rejection tasks.
-   many MIMO non-minimum phase systems, when feedforward decoupled, increase the RHP-zero multiplicity so performance limitations due to its presence are exacerbated.
-   decoupling may be very sensitive to modeling errors, specially for ill-conditionned plants
-   feedback decoupling needs full state measurements


#### SVD Decoupling {#svd-decoupling}

A matrix \\(M\\) can be expressed, using the [Singular Value Decomposition]({{< relref "singular_value_decomposition" >}}) as:

\begin{equation}
M = U \Sigma V^T
\end{equation}

where \\(U\\) and \\(V\\) are orthogonal matrices and \\(\Sigma\\) is diagonal.

The SVD can be used to obtain decoupled equations between linear combinations of sensors and linear combinations of actuators.
In this way, although losing part of its intuitive sense, a decoupled design can be carried out even for non-square plants.

If sensors are multiplied by \\(U^T\\) and control actions multiplied by \\(V\\), as in Figure [1](#org3d5b40c), then the loop, in the transformed variables, is decoupled, so a diagonal controller \\(K\_D\\) can be used.
Usually, the sensor and actuator transformations are obtained using the DC gain, or a real approximation of \\(G(j\omega)\\), where \\(\omega\\) is around the desired closed-loop bandwidth.

<a id="org3d5b40c"></a>

{{< figure src="/ox-hugo/albertos04_svd_decoupling.png" caption="Figure 1: SVD decoupling: \\(K\_D\\) is a diagonal controller designed for \\(\Sigma\\)" >}}

The transformed sensor-actuator pair corresponding to the maximum singular value is the direction with biggest "gain" on the plant, that is, the combination of variables being "easiest to control".

In ill-conditioned plants, the ratio between the biggest and lower singular value is large (for reference, greater than 20).
They are very sensitive to input uncertainty as some "input directions" have much bigger gain than other ones.

SVD decoupling produces the most suitable combinations for independent "multi-loop" control in the transformed variables, so its performance may be better than RGA-based design (at the expense of losing physical interpretability).
If some of the vectors in \\(V\\) (input directions) have a significant component on a particular input, and the corresponding output direction is also significantly pointing to a particular output, that combination is a good candidate for an independent multi-loop control.


## Fundamentals of Centralised Closed-loop Control {#fundamentals-of-centralised-closed-loop-control}


## Optimisation-based Control {#optimisation-based-control}


## Designing for Robustness {#designing-for-robustness}


## Implementation and Other Issues {#implementation-and-other-issues}


## Appendices {#appendices}


### Summary of SISO System Analysis {#summary-of-siso-system-analysis}


### Matrices {#matrices}


### Signal and System Norms {#signal-and-system-norms}


### Optimisation {#optimisation}


### Multivariable Statistics {#multivariable-statistics}


### Robust Control Analysis and Synthesis {#robust-control-analysis-and-synthesis}



## Bibliography {#bibliography}

<a id="orgb06343d"></a>Albertos, P., and S. Antonio. 2004. _Multivariable Control Systems: An Engineering Approach_. Advanced Textbooks in Control and Signal Processing. Springer-Verlag. <https://doi.org/10.1007/b97506>.
