+++
title = "Multi-stage actuation systems and control"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
:


Reference
: ([Du and Pang 2019](#orgfa82dec))

Author(s)
: Du, C., & Pang, C. K.

Year
: 2019

<div style="display: none;">
\(
\newcommand{\SI}[2]{#1\,#2}
% Simulate SIunitx
\newcommand{\ang}[1]{#1^{\circ}}
\newcommand{\degree}{^{\circ}}
\newcommand{\radian}{\text{rad}}
\newcommand{\percent}{\%}
\newcommand{\decibel}{\text{dB}}
\newcommand{\per}{/}
\)
</div>


## Mechanical Actuation Systems {#mechanical-actuation-systems}


### Introduction {#introduction}

When high bandwidth, high position accuracy and long stroke are required simultaneously: dual-stage systems composed of a coarse (or primary) actuator and a fine actuator working together are used.

Popular choices for coarse actuator are:

-   DC motor
-   Voice coil motor (VCM)
-   Permanent magnet stepper motor
-   Permanent magnet linear synchronous motor

As fine actuators, most of the time piezoelectric actuator are used.

In order to overcome fine actuator stringent stroke limitation and increase control bandwidth, three-stage actuation systems are necessary in practical applications.


### Actuators {#actuators}


#### Primary Actuator {#primary-actuator}

Without loss of generality, the VCM actuator is used as the primary actuator.
When current passes through the coil, a force is produced which accelerates the actuator radially.
The produced force is a function of the current \\(i\_c\\):
\\[ f\_m = k\_t i\_c \\]
where \\(k\_t\\) is a linearized nominal value called the torque constant.

The resonance of the actuator is mainly due to the flexibility of the pivot bearing, arm, suspension.

Then the bandwidth of the control loop is low and the resonances are not a limiting factor of the control design, the actuator model can be considered as follows:
\\[ P\_v(s) = \frac{k\_{vcm}}{s^2} \\]

When the bandwidth is high, the actuator resonances have to be considered in the control design since the flexible resonance modes will reduce the system stability and affect the control performance. Then the actuator model becomes
\\[ P\_v(s) = \frac{k\_{vcm}}{s^2} P\_r(s) \\]
which includes the resonance model
\\[ P\_r(s) = \Pi\_{i=1}^{N} P\_{ri}(s) \\]
and the resonance \\(P\_{ri}(s)\\) can be represented as one of the following forms

\begin{align\*}
 P\_{ri}(s) &= \frac{\omega\_i^2}{s^2 + 2 \xi\_i \omega\_i s + \omega\_i^2} \\\\\\
 P\_{ri}(s) &= \frac{b\_{1i} \omega\_i s + b\_{0i} \omega\_i^2}{s^2 + 2 \xi\_i \omega\_i s + \omega\_i^2} \\\\\\
 P\_{ri}(s) &= \frac{b\_{2i} s^2 + b\_{1i} \omega\_i s + b\_{0i} \omega\_i^2}{s^2 + 2 \xi\_i \omega\_i s + \omega\_i^2}
\end{align\*}


#### Secondary Actuators {#secondary-actuators}

We here consider two types of secondary actuators: the PZT milliactuator (figure [1](#org2501c9c)) and the microactuator.

<a id="org2501c9c"></a>

{{< figure src="/ox-hugo/du19_pzt_actuator.png" caption="Figure 1: A PZT-actuator suspension" >}}

There are three popular types of micro-actuators: electrostatic moving-slider microactuator, PZT slider-driven microactuator and thermal microactuator.
There characteristics are shown on table [1](#table--tab:microactuator).

<a id="table--tab:microactuator"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:microactuator">Table 1</a></span>:
  Performance comparison of microactuators
</div>

|             | Elect.                                        | PZT                                           | Thermal                    |
|-------------|-----------------------------------------------|-----------------------------------------------|----------------------------|
| TF          | \\(\frac{K}{s^2 + 2\xi\omega s + \omega^2}\\) | \\(\frac{K}{s^2 + 2\xi\omega s + \omega^2}\\) | \\(\frac{K}{\tau s + 1}\\) |
| \\(\tau\\)  | \\(<\SI{0.1}{ms}\\)                           | \\(<\SI{0.05}{ms}\\)                          | \\(>\SI{0.1}{ms}\\)        |
| \\(omega\\) | \\(1-\SI{2}{kHz}\\)                           | \\(20-\SI{25}{kHz}\\)                         | \\(>\SI{15}{kHz}\\)        |


### Single-Stage Actuation Systems {#single-stage-actuation-systems}

A typical closed-loop control system is shown on figure [2](#org3f9b6d4), where \\(P\_v(s)\\) and \\(C(z)\\) represent the actuator system and its controller.

<a id="org3f9b6d4"></a>

{{< figure src="/ox-hugo/du19_single_stage_control.png" caption="Figure 2: Block diagram of a single-stage actuation system" >}}


### Dual-Stage Actuation Systems {#dual-stage-actuation-systems}

Dual-stage actuation mechanism for the hard disk drives consists of a VCM actuator and a secondary actuator placed between the VCM and the sensor head.
The VCM is used as the primary stage to provide long track seeking but with poor accuracy and slow response time, while the secondary stage actuator is used to provide higher positioning accuracy and faster response but with a stroke limit.

<a id="org59cb446"></a>

{{< figure src="/ox-hugo/du19_dual_stage_control.png" caption="Figure 3: Block diagram of dual-stage actuation system" >}}


### Three-Stage Actuation Systems {#three-stage-actuation-systems}

Due to the limited allowed stroke of the microactuator, the control bandwidth has to be restricted and that limits the dual-stage disturbance rejection capability.

A three-stage actuation system is therefore introduced to further increase the bandwidth.

Typically, a VCM actuator is used as the primary actuator, PZT milliactuator as the second stage actuator and a third actuator more collocated is used.


## High-Precision Positioning Control of Dual-Stage Actuation Systems {#high-precision-positioning-control-of-dual-stage-actuation-systems}


### Introduction {#introduction}

The sensitivity function of the closed-loop system has provided a straightforward view of its disturbance rejection capability.
It is demanded that the sensitivity function magnitude in the low-frequency range be sufficiently low, while its hump in high-frequency range stays low enough.
In view of this, the controller design for dual-stage actuation systems adopts a weighting function to shape the sensitivity function.


### Control Schemes {#control-schemes}

A popular control scheme for dual-stage actuation system is the **decoupled structure** as shown in figure [4](#org371fae9).

-   \\(C\_v(z)\\) and \\(C\_p(z)\\) are the controllers respectively, for the primary VCM actuator \\(P\_v(s)\\) and the secondary actuator \\(P\_p(s)\\).
-   \\(\hat{P}\_p(z)\\) is an approximation of \\(P\_p\\) to estimate \\(y\_p\\).
-   \\(d\_1\\) and \\(d\_2\\) denote internal disturbances
-   \\(n\\) is the measurement noise
-   \\(d\_u\\) stands for external vibration

<a id="org371fae9"></a>

{{< figure src="/ox-hugo/du19_decoupled_control.png" caption="Figure 4: Decoupled control structure for the dual-stage actuation system" >}}

The open-loop transfer function from \\(pes\\) to \\(y\\) is
\\[ G(z) = P\_p(z) C\_p(z) + P\_v(z) C\_v(z) + P\_v(z) C\_v(z) \hat{P}\_p(z) C\_p(z) \\]
And the overall sensitivity function of the closed loop system from \\(r\\) to \\(pes\\) is
\\[ S(z) = \frac{1}{1 + G(z)} \\]
which is approximately
\\[ S(z) = \frac{1}{[1 + P\_p(z) C\_p(z)] [1 + P\_v(z)C\_v(z)]} \\]
since within a certain bandwidth
\\[ \hat{P}\_p(z) \approx P\_p(z) \\]

The sensitivity functions of the VCM loop and the secondary actuator loop are

\begin{equation}
  S\_v(z) = \frac{1}{1 + P\_v(z) C\_v(z)}, \quad S\_p(z) = \frac{1}{1 + P\_p(z) C\_p(z)}
\end{equation}

And we obtain that the dual-stage sensitivity function \\(S(z)\\) is the product of \\(S\_v(z)\\) and \\(S\_p(z)\\).
Thus, the dual-stage system control design can be decoupled into two independent controller designs.

Another type of control scheme is the **parallel structure** as shown in figure [5](#org3d4cd09).
The open-loop transfer function from \\(pes\\) to \\(y\\) is
\\[ G(z) = P\_p(z) C\_p(z) + P\_v(z) C\_v(z) \\]

The overall sensitivity function of the closed-loop system from \\(r\\) to \\(pes\\) is
\\[ S(z) = \frac{1}{1 + G(z)} = \frac{1}{1 + P\_p(z) C\_p(z) + P\_v(z) C\_v(z)} \\]

<a id="org3d4cd09"></a>

{{< figure src="/ox-hugo/du19_parallel_control_structure.png" caption="Figure 5: Parallel control structure for the dual-stage actuator system" >}}

Because of the limited displacement range of the secondary actuator, the control efforts for the two actuators should be distributed properly when designing respective controllers to meet the required performance, make the actuators not conflict with each other, as well as prevent the saturation of the secondary actuator.


### Controller Design Method in the Continuous-Time Domain {#controller-design-method-in-the-continuous-time-domain}

\\(\mathcal{H}\_\infty\\) loop shaping method is used to design the controllers for the primary and secondary actuators.
The structure of the \\(\mathcal{H}\_\infty\\) loop shaping method is plotted in figure [6](#org6dcd465) where \\(W(s)\\) is a weighting function relevant to the designed control system performance such as the sensitivity function.

For a plant model \\(P(s)\\), a controller \\(C(s)\\) is to be designed such that the closed-loop system is stable and

\begin{equation}
  \\|T\_{zw}\\|\_\infty < 1
\end{equation}

is satisfied, where \\(T\_{zw}\\) is the transfer function from \\(w\\) to \\(z\\): \\(T\_{zw} = S(s) W(s)\\).

<a id="org6dcd465"></a>

{{< figure src="/ox-hugo/du19_h_inf_diagram.png" caption="Figure 6: Block diagram for \\(\mathcal{H}\_\infty\\) loop shaping method to design the controller \\(C(s)\\) with the weighting function \\(W(s)\\)" >}}

Equation [1](#orgd1210d7) means that \\(S(s)\\) can be shaped similarly to the inverse of the chosen weighting function \\(W(s)\\).
One form of \\(W(s)\\) is taken as

\begin{equation}
  W(s) = \frac{\frac{1}{M}s^2 + 2\xi\omega\frac{1}{\sqrt{M}}s + \omega^2}{s^2 + 2\omega\sqrt{\epsilon}s + \omega^2\epsilon}
\end{equation}

where \\(\omega\\) is the desired bandwidth, \\(\epsilon\\) is used to determine the desired low frequency level of sensitivity magnitude and \\(\xi\\) is the damping ratio.

The controller can then be synthesis using the linear matrix inequality (LMI) approach.

The primary and secondary actuator control loops are designed separately for the dual-stage control systems.
But when designing their respective controllers, certain performances are required for the two actuators, so that control efforts for the two actuators are distributed properly and the actuators don't conflict with each other's control authority.
As seen in figure [7](#orgbe7f7d1), the VCM primary actuator open loop has a higher gain at low frequencies, and the secondary actuator open loop has a higher gain in the high-frequency range.

<a id="orgbe7f7d1"></a>

{{< figure src="/ox-hugo/du19_dual_stage_loop_gain.png" caption="Figure 7: Frequency responses of \\(G\_v(s) = C\_v(s)P\_v(s)\\) (solid line) and \\(G\_p(s) = C\_p(s) P\_p(s)\\) (dotted line)" >}}

The sensitivity functions are shown in figure [8](#orgfed486e), where the hump of \\(S\_v\\) is arranged within the bandwidth of \\(S\_p\\) and the hump of \\(S\_p\\) is lowered as much as possible.
This needs to decrease the bandwidth of the primary actuator loop and increase the bandwidth of the secondary actuator loop.

<a id="orgfed486e"></a>

{{< figure src="/ox-hugo/du19_dual_stage_sensitivity.png" caption="Figure 8: Frequency response of \\(S\_v(s)\\) and \\(S\_p(s)\\)" >}}

A basic requirement of the dual-stage actuation control system is to make the individual primary and secondary loops stable.
It also required that the primary actuator path has a higher gain than the secondary actuator path at low frequency range and the secondary actuator path has a higher gain than the primary actuator path in high-frequency range.
These can be achieve by choosing appropriate weighting function for the controllers design.


### Conclusion {#conclusion}

The controller design has been discussed for high-precision positioning control of the dual-stage actuation systems.
The \\(\mathcal{H}\_\infty\\) loop shaping method has been applied and the design method has been presented.
With the weighting functions, the desired sensitivity function can achieved.
Such a design method can produce robust controllers with more disturbance rejection in the low frequency range and less disturbance amplification in the high-frequency range.


## Modeling and Control of a Three-Stage Actuation System {#modeling-and-control-of-a-three-stage-actuation-system}


### Introduction {#introduction}

In view of the additional bandwidth requirement which is limited by stroke constraint and saturation of secondary actuators, three-stage actuation systems are thereby proposed to meet the demand of a higher bandwidth.
In this section, a specific three-stage actuation system is presented and a controller strategy is proposed, which is based on a decoupled master-slave dual-stage control structure combined with a third stage actuation in parallel format.


### Actuator and Vibration Modeling {#actuator-and-vibration-modeling}

A VCM actuator is used as the first-stage actuator denoted by \\(P\_v(s)\\), a PZT milliactuator as the second-stage actuator denoted by \\(P\_p(s)\\), and a thermal microactuator denoted by \\(P\_m(s)\\).


### Control Strategy and Controller Design {#control-strategy-and-controller-design}

Figure [9](#orga4074a3) shows the control structure for the three-stage actuation system.

The control scheme is based on the decoupled master-slave dual-stage control and the third stage microactuator is added in parallel with the dual-stage control system.
The parallel format is advantageous to the overall control bandwidth enhancement, especially for the microactuator having limited stroke which restricts the bandwidth of its own loop.
The reason why the decoupled control structure is adopted here is that its overall sensitivity function is the product of those of the two individual loops, and the VCM and the PTZ controllers can be designed separately.

<a id="orga4074a3"></a>

{{< figure src="/ox-hugo/du19_three_stage_control.png" caption="Figure 9: Control system for the three-stage actuation system" >}}

The open-loop transfer function of the three-stage actuation system is derived as

\begin{equation}
  G(z) = G\_v(z) + G\_p(z) + G\_v(z) G\_p(z) + G\_m(z)
\end{equation}

with

  \begin{align\*}
  G\_v(z) &= P\_v(z) C\_v(z) \\\\\\
  G\_p(z) &= P\_p(z) C\_p(z) \\\\\\
  G\_m(z) &= P\_m(z) C\_m(z)
\end{align\*}

The overall sensitivity function is given by

\begin{equation}
  S(z) = \frac{1}{1 + G(z)}
\end{equation}

The VCM actuator \\(P\_v(s)\\) works in a low bandwidth below \\(\SI{1}{kHz}\\).
The PZT actuated milliactuator \\(P\_p(s)\\) works under a reasonably high bandwidth up to \\(\SI{3}{kHz}\\).
The third-stage actuator \\(P\_m(s)\\) is used to further push the bandwidth as high as possible.

The control performances of both the VCM and the PZT actuators are limited by their dominant resonance modes.
The open-loop frequency responses of the three stages are shown on figure [10](#org11a6581).

<a id="org11a6581"></a>

{{< figure src="/ox-hugo/du19_open_loop_three_stage.png" caption="Figure 10: Frequency response of the open-loop transfer function" >}}

The obtained sensitivity function is shown on figure [11](#org58e9561).

<a id="org58e9561"></a>

{{< figure src="/ox-hugo/du19_sensitivity_three_stage.png" caption="Figure 11: Sensitivity function of the VCM single stage, the dual-stage and the three-stage loops" >}}


### Performance Evaluation {#performance-evaluation}

External vibration from the system working environment is much higher than the internal disturbance, especially for ultra-high precision positioning systems.
In the presence of external vibration, the actuators control effort is dominantly determined by the external vibration.
But because the actuator input is constrained, the external vibration level has to be limited.
Otherwise, saturation will occur in the control loop and the control system performance will be degraded.

Therefore, the stroke specification of the actuators, especially milliactuator and microactuators, is very important for achievable control performance.
Higher stroke actuators have stronger abilities to make sure that the control performances are not degraded in the presence of external vibrations.

For the three-stage control architecture as shown on figure [9](#orga4074a3), the position error is
\\[ e = -S(P\_v d\_1 + d\_2 + d\_e) + S n \\]
The control signals and positions of the actuators are given by

\begin{align\*}
  u\_p &= C\_p e,\ y\_p = P\_p C\_p e \\\\\\
  u\_m &= C\_m e,\ y\_m = P\_m C\_m e \\\\\\
  u\_v &= C\_v ( 1 + \hat{P}\_pC\_p ) e,\ y\_v = P\_v ( u\_v + d\_1 )
\end{align\*}

The controller design for the microactuators with input constraints must take into account both external vibration requirements and actuators' stroke, based on which an appropriate bandwidth should be decided when designing the control system.
Higher bandwidth/higher level of disturbance generally means high stroke needed.


### Different Configurations of the Control System {#different-configurations-of-the-control-system}

A decoupled control structure can be used for the three-stage actuation system (see figure [12](#org066c259)).

The overall sensitivity function is
\\[ S(z) = \approx S\_v(z) S\_p(z) S\_m(z) \\]
with \\(S\_v(z)\\) and \\(S\_p(z)\\) are defined in equation [1](#org7c7e2b1) and
\\[ S\_m(z) = \frac{1}{1 + P\_m(z) C\_m(z)} \\]

Denote the dual-stage open-loop transfer function as \\(G\_d\\)
\\[ G\_d(z) = G\_v(z) + G\_p(z) + G\_v(z) G\_p(z) \\]

The open-loop transfer function of the overall system is
\\[ G(z) = G\_d(z) + G\_m(z) + G\_d(z) G\_m(z) \\]

<a id="org066c259"></a>

{{< figure src="/ox-hugo/du19_three_stage_decoupled.png" caption="Figure 12: Decoupled control structure for the three-stage actuation system" >}}

The control signals and the positions of the three actuators are

\begin{align\*}
  u\_p &= C\_p(1 + \hat{P}\_m C\_m) e, \ y\_p = P\_p u\_p \\\\\\
  u\_m &= C\_m e, \ y\_m = P\_m M\_m e \\\\\\
  u\_v &= C\_v(1 + \hat{P}\_p C\_p) (1 + \hat{P}\_m C\_m) e, \ y\_v = P\_v u\_v
\end{align\*}

The decoupled configuration makes the low frequency gain much higher, and consequently there is much better rejection capability at low frequency compared to the parallel architecture (see figure [13](#org8c9fc90)).

<a id="org8c9fc90"></a>

{{< figure src="/ox-hugo/du19_three_stage_decoupled_loop_gain.png" caption="Figure 13: Frequency responses of the open-loop transfer functions for the three-stages parallel and decoupled structure" >}}


### Conclusion {#conclusion}

The relationship among the external vibration, the microactuator stroke, and the achievable control bandwidth has been discussed for being considered in the controller design.
The discussion suggests that in addition to the traditional wisdom of just increasing the resonant frequency, adding more stroke to the microactuator will give more freedom to the loop shaping for the control system design.


## Dual-Stage System Control Considering Secondary Actuator Stroke Limitation {#dual-stage-system-control-considering-secondary-actuator-stroke-limitation}


### Introduction {#introduction}


### More Freedom Loop Shaping for Microactuator Controller Design {#more-freedom-loop-shaping-for-microactuator-controller-design}


### Dual-Stage System Control Design for 5 kHz Bandwidth {#dual-stage-system-control-design-for-5-khz-bandwidth}


### Evaluation with the Consideration of External Vibration and Microactuator Stroke {#evaluation-with-the-consideration-of-external-vibration-and-microactuator-stroke}


### Conclusion {#conclusion}


## Saturation Control for Microactuators in Dual-Stage Actuation Systems {#saturation-control-for-microactuators-in-dual-stage-actuation-systems}


### Introduction {#introduction}


### Modeling and Feedback Control {#modeling-and-feedback-control}


### Anti-Windup Compensation Design {#anti-windup-compensation-design}


### Simulation and Experimental Results {#simulation-and-experimental-results}


### Conclusion {#conclusion}


## Time Delay and Sampling Rate Effect on Control Performance of Dual-Stage Actuation Systems {#time-delay-and-sampling-rate-effect-on-control-performance-of-dual-stage-actuation-systems}


### Introduction {#introduction}


### Modeling of Time Delay {#modeling-of-time-delay}


### Dual-Stage Actuation System Modeling with Time Delay for Controller Design {#dual-stage-actuation-system-modeling-with-time-delay-for-controller-design}


### Controller Design with Time Delay for the Dual-Stage Actuation Systems {#controller-design-with-time-delay-for-the-dual-stage-actuation-systems}


### Time Delay Effect on Dual-Stage System Control Performance {#time-delay-effect-on-dual-stage-system-control-performance}


### Sampling Rate Effect on Dual-Stage System Control Performance {#sampling-rate-effect-on-dual-stage-system-control-performance}


### Conclusion {#conclusion}


## PZT Hysteresis Modeling and Compensation {#pzt-hysteresis-modeling-and-compensation}


### Introduction {#introduction}


### Modeling of Hysteresis {#modeling-of-hysteresis}


#### PI Model {#pi-model}


#### GPI Model {#gpi-model}


#### Inverse GPI Model {#inverse-gpi-model}


### Application of GPI Model to a PZT-Actuated Structure {#application-of-gpi-model-to-a-pzt-actuated-structure}


#### Modeling of the Hysteresis in the PZT-Actuated Structure {#modeling-of-the-hysteresis-in-the-pzt-actuated-structure}


#### Hysteresis Compensator Design {#hysteresis-compensator-design}


#### Experimental Verification {#experimental-verification}


### Conclusion {#conclusion}


## Seeking Control of Dual-Stage Actuation Systems with Trajectory Optimization {#seeking-control-of-dual-stage-actuation-systems-with-trajectory-optimization}


### Introduction {#introduction}


### Current Profile of VCM Primary Actuator {#current-profile-of-vcm-primary-actuator}


#### PTOS Method {#ptos-method}


#### A General Form of VCM Current Profiles {#a-general-form-of-vcm-current-profiles}


### Control System Structure for the Dual-Stage Actuation System {#control-system-structure-for-the-dual-stage-actuation-system}


### Design of VCM Current Profile a[sub(v)] and Dual-Stage Reference Trajectory r[sub(d)] {#design-of-vcm-current-profile-a-sub--v--and-dual-stage-reference-trajectory-r-sub--d}


### Seeking within PZT Milliactuator Stroke {#seeking-within-pzt-milliactuator-stroke}


### Seeking over PZT Milliactuator Stroke {#seeking-over-pzt-milliactuator-stroke}


### Conclusion {#conclusion}


## High-Frequency Vibration Control Using PZT Active Damping {#high-frequency-vibration-control-using-pzt-active-damping}


### Introduction {#introduction}


### Singular Perturbation Method-Based Controller Design {#singular-perturbation-method-based-controller-design}


#### Singular Perturbation Control Topology {#singular-perturbation-control-topology}


#### Identification of Fast Dynamics Using PZT as a Sensor {#identification-of-fast-dynamics-using-pzt-as-a-sensor}


#### Design of Controllers {#design-of-controllers}


##### Fast Subsystem Estimator  G[sub(v)][sup(\*)] {#fast-subsystem-estimator-g-sub--v--sup}


##### Fast Controller C[sub(v)] {#fast-controller-c-sub--v}


##### Slow Controller C[sub(v)] {#slow-controller-c-sub--v}


#### Simulation and Experimental Results {#simulation-and-experimental-results}


##### Frequency Responses {#frequency-responses}


##### Time Responses {#time-responses}


### H[sub(2)] Controller Design {#h-sub--2--controller-design}


### Design of C[sub(d)](z) with H[sub(2)] Method and Notch Filters {#design-of-c-sub--d----z--with-h-sub--2--method-and-notch-filters}


### Design of Mixed H[sub(2)]/H[sub(∞)] Controller C[sub(d)](z) {#design-of-mixed-h-sub--2--h-sub-----controller-c-sub--d----z}


### Application Results {#application-results}


#### System Modeling {#system-modeling}


#### H[sub(2)] Active Damping Control {#h-sub--2--active-damping-control}


#### Mixed H[sub(2)]/H[sub(∞)] Active Damping Control {#mixed-h-sub--2--h-sub-----active-damping-control}


#### Experimental Results {#experimental-results}


### Conclusion {#conclusion}


## Self-Sensing Actuation of Dual-Stage Systems {#self-sensing-actuation-of-dual-stage-systems}


### Introduction {#introduction}


### Estimation of PZT Secondary Actuator’s Displacement y[sub(p)][sup(\*)] {#estimation-of-pzt-secondary-actuator-s-displacement-y-sub--p--sup}


#### Self-Sensing Actuation and Bridge Circuit {#self-sensing-actuation-and-bridge-circuit}


#### PZT Displacement Estimation Circuit H[sub(B)] {#pzt-displacement-estimation-circuit-h-sub--b}


### Design of Controllers {#design-of-controllers}


#### VCM Controller and Controller C[sub(D)] {#vcm-controller-and-controller-c-sub--d}


#### PZT Controller {#pzt-controller}


### Performance Evaluation {#performance-evaluation}


#### Effectiveness of C[sub(D)] {#effectiveness-of-c-sub--d}


#### Position Errors {#position-errors}


### Conclusion {#conclusion}


## Modeling and Control of a MEMS Micro X–Y Stage Media Platform {#modeling-and-control-of-a-mems-micro-x-y-stage-media-platform}


### Introduction {#introduction}


### MEMS Micro X–Y Stage {#mems-micro-x-y-stage}


#### Design and Simulation of Micro X–Y Stage {#design-and-simulation-of-micro-x-y-stage}


##### Static {#static}


##### Dynamic {#dynamic}


#### Modeling of Micro X–Y Stage {#modeling-of-micro-x-y-stage}


#### Fabrication of the MEMS Micro X–Y Stage {#fabrication-of-the-mems-micro-x-y-stage}


### Capacitive Self-Sensing Actuation {#capacitive-self-sensing-actuation}


#### Design of CSSA Bridge Circuit {#design-of-cssa-bridge-circuit}


#### Experimental Verification {#experimental-verification}


### Robust Decoupling Controller Design {#robust-decoupling-controller-design}


#### Choice of Pre-Shaping Filters {#choice-of-pre-shaping-filters}


#### Controller Synthesis {#controller-synthesis}


#### Frequency Responses {#frequency-responses}


#### Time Responses {#time-responses}


#### Robustness Analysis {#robustness-analysis}


### Conclusion {#conclusion}


## Conclusions {#conclusions}

Many secondary actuators have been developed in addition to primary actuators in the field of mechanical actuation systems.
The aim is to provide high performance such as high precision and fast response.
Several types of secondary actuators have been introduced such as PZT milliactuator, electrostatic microactuator, PZT microactuator, and thermal microactuator.
Comparison of these secondary actuators has been made, and these secondary actuators have made dual and multi-stage actuation mechanisms possible.

Three-stage actuation systems have been proposed for the demand of wider bandwidth, to overcome the limitation by stroke constraint and saturation of secondary actuators.
After the characteristics of the three-stage systems have been developed and the models have been identified, the control strategy and algorithm have been developed to deal with vibrations and meet different requirements.
Particularly, for the three-stage actuation systems, the presented control strategies make it easy to further push the bandwidth and meet the performance requirement.
The control of the thermal microactuator based dual-stage system has been discussed in detail, including linearization and controller design method.

The developed advanced algorithms applied in the multi-stage systems include \\(\mathcal{H}\_\infty\\) loop shaping, anti-windup compensation, \\(\mathcal{H}\_2\\) control method,
and mixed \\(\mathcal{H}\_2/\mathcal{H}\_\infty\\) control method.
Typical problems of the milli and micro-actuators as the secondary actuators have been considered and appropriate solutions have been presented such as saturation compensation, hysteresis modeling and compensation, stroke limitation, and PZT self-sensing scheme.
Time delay and sampling rate effect on the control performance have been analyzed to help select appropriate sampling rate and design suitable controllers.

Specific usage of PZT elements has been produced for system performance improvement.
Using PZT elements as a sensor to deal with high-frequency vibration beyond the bandwidth has been proposed and systematic controller design methods have been developed.
As a more advanced concept, PZT elements being used as actuator and sensor simultaneously has also been addressed in this book with detailed scheme and controller design methodology for effective utilization.


## Bibliography {#bibliography}

<a id="orgfa82dec"></a>Du, Chunling, and Chee Khiang Pang. 2019. _Multi-Stage Actuation Systems and Control_. Boca Raton, FL: CRC Press.
