+++
title = "Grounding and shielding: circuits and interference"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Electronics]({{< relref "electronics" >}})

Reference
: ([Morrison 2016](#orgc3a94fb))

Author(s)
: Morrison, R.

Year
: 2016


## Voltage and Capacitors {#voltage-and-capacitors}

<div class="sum">
  <div></div>

This first chapter described the electric field that is basic to all electrical activity.
The electric or \\(E\\) field represents forces between charges.
The basic charge is the electron.
When charges are placed on conductive surfaces, these forces move the charges to positions that store the least potential energy.
This energy is stored in an electric field.
The work required to move a unit of charge between two points in this field is the voltage between those two points.

Capacitors are conductor geometries used to store electric field energy.
The ability to store energy is enhanced by using dielectrics.
It is convenient to use two measures of the electric field.
The field that is created by charges is called the \\(D\\) field and the field that results in forces is the \\(E\\) field.
A changing \\(D\\) field represents a displacement current in space.
This changing current has an associated magnetic field.
This displacement current flows when charges are added or removed from the plates of a capacitor.

</div>


### Introduction {#introduction}


### Charges and Electrons {#charges-and-electrons}


### The electric force field {#the-electric-force-field}


### Field representation {#field-representation}

<a id="orgbb971cb"></a>

{{< figure src="/ox-hugo/morrison16_E_field_charge.svg" caption="Figure 1: The force field lines around a positively chaged conducting sphere" >}}


### The definition of voltage {#the-definition-of-voltage}


### Equipotential surfaces {#equipotential-surfaces}


### The force field or \\(E\\) field between two conducting plates {#the-force-field-or--e--field-between-two-conducting-plates}

<a id="org0a58e51"></a>

{{< figure src="/ox-hugo/morrison16_force_field_plates.svg" caption="Figure 2: The force field between two conducting plates with equal and opposite charges and spacing distance \\(h\\)" >}}


### Electric field patterns {#electric-field-patterns}

<a id="org2812c15"></a>

{{< figure src="/ox-hugo/morrison16_electric_field_ground_plane.svg" caption="Figure 3: The electric field pattern of one circuit trace and two circuit traces over a ground plane" >}}

<a id="orge3117ef"></a>

{{< figure src="/ox-hugo/morrison16_electric_field_shielded_conductor.svg" caption="Figure 4: Field configuration around a shielded conductor" >}}


### The energy stored in an electric field {#the-energy-stored-in-an-electric-field}


### Dielectrics {#dielectrics}


### The \\(D\\) field {#the--d--field}

<a id="orgd76a948"></a>

{{< figure src="/ox-hugo/morrison16_E_D_fields.svg" caption="Figure 5: The electric field pattern in the presence of a dielectric" >}}


### Capacitance {#capacitance}


### Mutual capacitance {#mutual-capacitance}


### Displacement current {#displacement-current}


### Energy stored in a capacitor {#energy-stored-in-a-capacitor}


### Forces in the electric field {#forces-in-the-electric-field}


### Capacitors {#capacitors}


### Dielectric absorption {#dielectric-absorption}


### Resistance of plane conductors {#resistance-of-plane-conductors}


## Magnetics {#magnetics}

<div class="sum">
  <div></div>

This chapter discusses magnetic fields.
As in the electric field, there are two measures of the same magnetic field.
The \\(H\\) field is the direct result of current flow.
The \\(B\\) field is the force of induction field that operates motors and transformers.
As in the electric field, the magnetic field is represented by field lines.
The \\(B\\) field lines are continuous and form closed curves.
The \\(H\\) field flux lines follow the \\(B\\) field lines but change intensity depending on the permeability of the material in the magnetic path.

In this chapter, the movement of electrical energy into inductors or across transformers is discussed.
This extends the ideas that both fields are need to move energy.
Both electric and magnetic fields are need in transformers action or to place energy into an inductor.
It will be shown that iron cores in transformers reduce the magnetizing current so that transformer action is practical at power frequencies.
The idea that a changing electric field creates both a displacement current and a magnetic field discussed in Chapter 1.
In this chapter, it is shown that a changing magnetic field produces both an electric field and voltages.
Both fields must be in transition before an electrical energy can be moved.

</div>


### Magnetic Fields {#magnetic-fields}

In a few elements, the atomic structure is such that atoms align to generate a net magnetic field (neodymium, iron, cobalt, ...).

The flow of electrons is another way to generate a magnetic field.

The letter \\(H\\) is reserved for the magnetic field generated by a current.
Figure [6](#org198efb1) shows the shape of the \\(H\\) field around a long, straight conductor carrying a direct current \\(I\\).

<a id="org198efb1"></a>

{{< figure src="/ox-hugo/morrison16_H_field.svg" caption="Figure 6: The \\(H\\) field around a current-carrying conductor" >}}

The magnetic field is a force field.
This force can only be exerted on another magnetic field.
The direction of the force, the direction of the current flow and the direction of the field lines are all perpendicular to each other.


### Ampere's law {#ampere-s-law}

Ampere's law states that the integral of the \\(H\\) field intensity in a closed-loop path is equal to the current threading that loop

\begin{equation} \label{eq:ampere\_law}
\boxed{\oint H dl = I}
\end{equation}

The simplest path to use for this integration is the one of the concentric circles in Figure [6](#org198efb1), where \\(H\\) is constant and \\(r\\) is the distance from the conductor.
Solving for \\(H\\), we obtain

\begin{equation}
H = \frac{I}{2 \pi r}
\end{equation}

And we see that \\(H\\) has units of amperes per meter.


### The solenoid {#the-solenoid}

The magnetic field of a solenoid is shown in Figure [7](#org7535570).
The field intensity inside the solenoid is nearly constant, while outside its intensity falls of rapidly.

Using Ampere's law \eqref{eq:ampere_law}:

\begin{equation}
\oint H dl \approx n I l
\end{equation}

<a id="org7535570"></a>

{{< figure src="/ox-hugo/morrison16_solenoid.svg" caption="Figure 7: The \\(H\\) field around a solenoid" >}}


### Faraday's law and the induction field {#faraday-s-law-and-the-induction-field}

When a conducting coil is moved through a magnetic field, a voltage appears at the open ends of the coil.
This is illustrated in Figure [8](#orgd2dee77).
The voltage depends on the number of turns in the coil and the rate at which the flux is changing.

<a id="orgd2dee77"></a>

{{< figure src="/ox-hugo/morrison16_voltage_moving_coil.svg" caption="Figure 8: A voltage induced into a moving coil" >}}

The magnetic field has two measured.
The \\(H\\) or magnetic field that is proportional to current flow.
The force field representation that induces voltage is called the \\(B\\) or induction field.
The relation between \\(B\\) and \\(H\\) fields is given by:

\begin{equation} \label{eq:relation\_B\_H}
\boxed{B = \mu\_R \mu\_0 H}
\end{equation}

where the factor \\(\mu\_0\\) is the permeability of free space and \\(\mu\_R\\) is the relative permeability of the medium.

For an area of constant field intensity, the magnetic flux \\(\phi\\) is simply the product \\(BA\\) where \\(B\\) is in tesla, \\(A\\) is the area in square meters, and \\(\phi\\) is the flux in webers.

The voltage induced in a conducting coil is given by the **Faraday's law**:

\begin{equation} \label{eq:faraday\_law}
\boxed{V = n \frac{d\phi}{dt} = n A \frac{dB}{dt}}
\end{equation}

where \\(n\\) is the number of turns in the coil.
If the induction flux \\(B\\) increases linearly, a steady voltage \\(B\\) must exist at the coil ends.
The inverse is also true.


### The definition of inductance {#the-definition-of-inductance}

<div class="definition">
  <div></div>

Inductance is defined as the ratio of magnetic flux generated per unit current.
The unit of inductance if the henry.

</div>

For the  coil in Figure [7](#org7535570):

\begin{equation} \label{eq:inductance\_coil}
V = n^2 A k \mu\_0 \frac{dI}{dt} = L \frac{dI}{dt}
\end{equation}

where \\(k\\) relates to the geometry of the coil.

Equation \eqref{eq:inductance_coil} states that if \\(V\\) is one volt, then for an inductance of one henry, the current will rise at the rate of one ampere per second.


### The energy stored in an inductance {#the-energy-stored-in-an-inductance}

One way to calculate the work stored in a magnetic field is to use Eq. \eqref{eq:inductance_coil}.
The voltage \\(V\\) applied to a coil results in a linearly increasing current.
At any time \\(t\\), the power \\(P\\) supplied is equal to \\(VI\\).
Power is the rate of change of energy or \\(P = d\bm{E}/dt\\) where \\(\bm{E}\\) is the stored energy in the inductance.
We then have the stored energy in an inductance:

\begin{equation} \label{eq:energy\_inductance}
\boxed{\bm{E} = L \int\_0^I I dI = \frac{1}{2} L I^2}
\end{equation}

<div class="important">
  <div></div>

An inductor stores field energy.
It does not dissipate energy.

</div>

The presence of a voltage \\(V\\) on the terminals of an inductor implies an electric field.
The movement of energy into the inductor thus requires both an electric and a magnetic field.
This is due to the Faraday's law that requires a voltage when changing magnetic flux couples to a coil.

<div class="exampl">
  <div></div>

Consider a 1mH inductor carrying a current of 0.1A.
The stored energy is \\(5 \times 10^{-4} J\\).
Assume the shunt capacitance equals 100pF.
When this energy is fully transferred to the capacitance, the voltage must be 3116 V.
This would probably destroy the component.

In order to absorb the stored magnetic field energy and avoid a high voltage, a reverse diode accross the coil can be used to provide a path for interrupted current flow.

</div>


### Magnetic field energy in space {#magnetic-field-energy-in-space}

The energy \\(\bm{E}\\) stored is

\begin{equation}
\bm{E} = \frac{1}{2} \frac{B^2 \bm{V}}{\mu\_0}
\end{equation}

where is volume \\(\bm{V} = Ad\\) and \\(\mu\_0\\) is the permeability of free space.


### Electron drift {#electron-drift}

Current flow in conductors is the movement of charge.
The velocity of energy flow is the speed of light, but the average velocity of electrons in a typical circuit is extremely low.
In a typical circuit, conductor carrying current, the average electron velocity is less than 0.025mm/s.


## Digital Electronics {#digital-electronics}

<div class="sum">
  <div></div>

This chapter shows that both electric and magnetic field are needed to move energy over pairs of conductors.
The idea of transporting electrical energy in field is extended to traces and conducting planes on printed circuit boards.
Logic signals are waves that carry field energy between points on the board.
These waves are reflected and transmitted when different transmission lines are interfaces.
There are several sources of first energy that play a role in circuit performance.
These sources are connected logic, the ground/power plane structure, and decoupling capacitors.
Decoupling capacitors are actually short stub transmission lines that supply energy.

The use of vias in the transmission paths is discussed in detail.
The fact that energy cannot pass through a conducting plane is stressed.
Limiting interference coupling in an A/D converter is a problem in keeping analog and logic fields separated.
Terminating balanced transmission lines is also discussed.

The concept of displacement current and its associated magnetic field is important.
These ideas show how field energy flows into a transmission line and is placed into capacitance at the leading edge of the wave.
Radiation occurs at the leading edge of a wave as it moves down the transmission line.

</div>


### Introduction {#introduction}


### The Transport of Electrical Energy {#the-transport-of-electrical-energy}


### Transmission Lines–Introduction {#transmission-lines-introduction}


### Transmission Line Operations {#transmission-line-operations}


### Transmission line field patterns {#transmission-line-field-patterns}


### A terminated transmission line {#a-terminated-transmission-line}


### The unterminated transmission line {#the-unterminated-transmission-line}


### A short circuit termination {#a-short-circuit-termination}


### The real world {#the-real-world}


### Sine waves versus step voltages {#sine-waves-versus-step-voltages}


### A bit of history {#a-bit-of-history}


### Ideal conditions {#ideal-conditions}


### Reflection and tramission coefficients {#reflection-and-tramission-coefficients}


### Taking energy from an ideal energy source {#taking-energy-from-an-ideal-energy-source}


### A capacitor as a transmission line {#a-capacitor-as-a-transmission-line}


### Decoupling capacitors and natural frequencies {#decoupling-capacitors-and-natural-frequencies}


### Printed circuit boards {#printed-circuit-boards}


### Two-layer logic boards {#two-layer-logic-boards}


### Vars {#vars}


### The termination of transmission lines {#the-termination-of-transmission-lines}


### Energy in the ground/power plane capacitance {#energy-in-the-ground-power-plane-capacitance}


### Poynting's vector {#poynting-s-vector}


### Skin effect {#skin-effect}


### Measurement problems: ground bounce {#measurement-problems-ground-bounce}


### Balance transmission {#balance-transmission}


### Ribbon cable and connectors {#ribbon-cable-and-connectors}


### Interfacing analog and digital circuits {#interfacing-analog-and-digital-circuits}


## Analog Circuits {#analog-circuits}

<div class="sum">
  <div></div>

This chapter treats the general problem of analog instrumentation.
The signals of interest are often generated while testing functioning hardware.
Tests can take place over time, in a harsh environment, during an explosion, during a flight, or in a collision.
The signals of interest usually have dc content and can be generating from floating, grounded, balanced or unbalanced transducers.
These transducers may require external balancing, calibration, or excitation.
Accuracy is an important consideration.
Where data must be sampled, the signals may require filtering to avoid aliasing errors.
The general two-ground system is examined.
Protecting signals using guard shields, transformer shields, and cable shields is described.
The use of feedback and tests for stability in circuit design is considered.
Strain-gauge configuration, thermocouple grounding, and charge amplifiers are discussed.

</div>


### Introduction {#introduction}

This chapter is devoted to analog circuits that operate below 100kHz.
The techniques that are described can be applied to audio amplifiers, power supplies as well as instrumentation.

The availability of integrated circuits has simplified many aspects of analog circuit design.
Instrumentation must often handle long signal lines, reject ground potential differences, and maintain circuit stability.

The general problem of analog design is called signal conditioning, which includes gain, filtering, offsets, bridge balancing, common-mode rejection, transducer excitation and calibration.
Once a signal has sufficient resolution and the bandwidth has been controlled, the signal can be digitized and transmitted over a digital link to a computer.
This chapter treats the problems of conditioning signals before they are sampled and recorded.


### Instrumentation {#instrumentation}

There are many transducers that can measure temperature, strain, stress, position and vibration.
The signals generated are usually in the milli-volt range and must be amplified, conditioned, and then recorded for later analysis.

<div class="important">
  <div></div>

It can be very difficult to verify that the measurement is valid.
For example, signals that overload an input stage can produce noise that may look like signal.

</div>

<div class="definition">
  <div></div>

1.  **Reference Conductor**.
    Any conductor used as the zero of voltage.
    If a signal is measured with respect to a conductor called ground, it becomes the reference signal conductor.
    In an analog circuit, there may be several reference conductors.
2.  **Signal common / Signal ground**
    A signal reference conductor.
3.  **Balance signal(s)**.
    Two signals measured with respect to a reference conductor whose sum is always zero.
4.  **An unbalanced signal / A single-ended signal**.
    A single voltage measured with respect to a reference conductor.
5.  **Common-mode voltage**.
    The average interfering voltage on a group of signal conductors measured with respect to a reference conductor.
6.  **Normal-mode signal**.
    The signal of interest.
7.  **Differential signal / Difference signal**.
    The voltage difference of interest.
8.  **Instrumentation amplifier**.
    A general-purpose differential amplifier with bandwidth from DC to perhaps 100kHz and variable gains from 1 to 5000.

</div>


### The basic shield enclosure {#the-basic-shield-enclosure}

Consider the simple amplifier circuit shown in Figure [9](#orgd60f7ec) with:

-   \\(V\_1\\) the input lead
-   \\(V\_2\\) the output lead
-   \\(V\_3\\) the conducting enclosure which is floating and taken as the reference conductor
-   \\(V\_4\\) a signal common or reference conductor

Every conductor pair has a mutual capacitance, which are shown in Figure [9](#orgd60f7ec) (b).
The equivalent circuit is shown in Figure [9](#orgd60f7ec) (c) and it is apparent that there is some feedback from the output to the input or the amplifier.

<a id="orgd60f7ec"></a>

{{< figure src="/ox-hugo/morrison16_parasitic_capacitance_amp.svg" caption="Figure 9: Parasitic capacitances in a simple circuit. (a) Field lines in a circuit. (b) Mutual capacitance diagram. (b) Circuit representation" >}}

It is common practice in analog design to connect the enclosure to circuit common (Figure [10](#org412bfcb)).
When this connection is made, the feedback is removed and the enclosure no longer couples signals into the feedback structure.
The conductive enclosure is called a **shield**.
Connecting the signal common to the conductive enclosure is called "**grounding the shield**".
This "grounding" usually removed "hum" from the circuit.

<a id="org412bfcb"></a>

{{< figure src="/ox-hugo/morrison16_grounding_shield_amp.svg" caption="Figure 10: Grounding the shield to limit feedback" >}}

Most practical circuits provide connections to external points.
To see the effect of making a _single_ external connection, open the conductive enclosure and connect the input circuit common to an external ground.
Figure [11](#org5d67d92) (a) shows this grounded connection surrounded by an extension of the enclosure called the _cable shield_.
A problem can be caused by an incorrect location of the connection between the cable shield and the enclosure.
In Figure [11](#org5d67d92) (a), the electromagnetic field in the area induces a voltage in the loop and a resulting current to flow in conductor (1)-(2).
This conductor being the common ground that might have a resistance \\(R\\) or \\(1\,\Omega\\), this current induced voltage that it added to the transmitted signal.
Our goal in this chapter is to find ways of keeping interference currents from flowing in any input signal conductor.
To remove this coupling, the shield connection to circuit common must be made at the point, where the circuit common connects to the external ground.
This connection is shown in Figure [11](#org5d67d92) (b).
This connection keeps the circulation of interference current on the outside of the shield.

There is only one point of zero signal potential external to the enclosure and that is where the signal common connects to an external hardware ground.
The input shield should not be connected to any other ground point.
The reason is simple.
If there is an external electromagnetic field, there will be current flow in the shield and a resulting voltage gradient.
A voltage gradient will couple interference capacitively to the signal conductors.

<div class="important">
  <div></div>

An input circuit shield should connect to the circuit common, where the signal common makes its connection to the source of signal.
Any other shield connection will introduce interference.

</div>

<div class="important">
  <div></div>

Shielding is not an issue of finding a "really good ground".
It is an issue of using the _right_ ground.

</div>

<a id="org5d67d92"></a>

{{< figure src="/ox-hugo/morrison16_enclosure_shield_1_2_leads.png" caption="Figure 11: (a) The problem of bringing one lead out of a shielded region. Unwanted current circulates in the signal lead 2. (b) The \\(E\\) field circulate current in the shield, not in the signal conductor." >}}


### The enclosure and utility power {#the-enclosure-and-utility-power}

When utility power is introduced into an enclosure, a new set of problems results.
The power transformer couples fields from the external environment into the enclosure.
The obvious coupling results from capacitance between the primary coil and the secondary coil.
Note that the secondary coil is connected to the circuit common conductor.

<a id="orgb45b4f3"></a>

{{< figure src="/ox-hugo/morrison16_power_transformer_enclosure.png" caption="Figure 12: A power transformer added to the circuit enclosure" >}}


### The two-ground problem {#the-two-ground-problem}


### Instrumentation and the two-ground problem {#instrumentation-and-the-two-ground-problem}

The basic analog problem is to condition a signal associated with one ground reference potential and transport this signal to a second ground reference potential without adding interference.

<a id="org75ed03f"></a>

{{< figure src="/ox-hugo/morrison16_two_ground_problem.svg" caption="Figure 13: The two-circuit enclosures used to transport signals between grounds" >}}


### Strain-gauge instrumentation {#strain-gauge-instrumentation}


### The floating strain-gauge {#the-floating-strain-gauge}


### The thermocouple {#the-thermocouple}


### The basic low-gain differential amplifier (forward referencing amplifier) {#the-basic-low-gain-differential-amplifier--forward-referencing-amplifier}

<a id="orge28ae4f"></a>

{{< figure src="/ox-hugo/morrison16_low_gain_diff_amp.svg" caption="Figure 14: The low-gain differential amplifier applied to the two-ground problem" >}}


### Shielding in power transformers {#shielding-in-power-transformers}


### Calibration and interference {#calibration-and-interference}


### The guard shield above 100kHz {#the-guard-shield-above-100khz}


### Signal flow paths in analog circuits {#signal-flow-paths-in-analog-circuits}

<div class="important">
  <div></div>

Here are a few rule that will help in analog board layout:

1.  Maintain a flow of signal and signal common from input to output.
    The area between the signal path and the signal reference conductor should be kept small.
2.  Components associated with the input should not be near output circuit components.
3.  Power supply connections (DC voltages) should enter at the output and thread back toward the input.
    This avoids common-impedance coupling (parasitic feedback).
4.  The greatest attention should be paid to the input circuit geometry.
    Lead length for components connecting to the input path should be kept short.
    Another way of describing this requirements is to interconnect the components to minimize the amount of bare copper connected to the input signal path.
5.  Feedback summing points are critical.
    Keep lead lengths short at these nodes.

</div>


### Parallel active components {#parallel-active-components}


### Feedback stability - Introduction {#feedback-stability-introduction}


### Feedback theory {#feedback-theory}

<a id="orgbf57c39"></a>

{{< figure src="/ox-hugo/morrison16_basic_feedback_circuit.svg" caption="Figure 15: The basic feedback circuit" >}}

<a id="org795e24d"></a>

{{< figure src="/ox-hugo/morrison16_LR_stabilizing_network.svg" caption="Figure 16: An LR-stabilizing network" >}}


### Output loads and circuit stability {#output-loads-and-circuit-stability}


### Feedback around a power stage {#feedback-around-a-power-stage}


### Constant current loops {#constant-current-loops}


### Filters and aliasing errors {#filters-and-aliasing-errors}


### Isolation and DC-to-DC converters {#isolation-and-dc-to-dc-converters}


### Charge converter basics {#charge-converter-basics}

In vibration analysis, piezoelectric sensors are used which are electrically equivalent to a capacitor.
When a force is exerted to the piezoelectric material, charges or voltage are generated.
The relationship between charge and voltage is \\(V = Q/C\\) where \\(C\\) is the transducer capacitance.

The voltage on the transducer can be amplifier by a high-impedance amplifier.
The input cable capacitance attenuates the input signal and this makes calibration a function of cable length.
The preferred method of amplifying signals from piezoelectric transducers is to measure charge generation and not voltage generation.
The charge is first converted to a voltage and the voltage is then amplified.
This type of instrument is called a **charge amplifier**.

The basic feedback around an operational amplifier usually involves two resistors.
The voltage gain is simply the ratio of the two resistors.
If the resistors are replaced by capacitors, the gain is the ratio of reactances.
This feedback circuit is called a **charge converter**.
The charge on the input capacitor is transferred to the feedback capacitor.
If the feedback capacitor is smaller than the transducer capacitance by a factor of 100, then the voltage across the feedback capacitor will be 100 times greater than the open-circuit transducer voltage.
This feedback arrangement is shown in Figure [17](#org964dc8b).
The open-circuit input signal voltage is \\(Q/C\_T\\).
The output voltage is \\(Q/C\_{FB}\\).
The voltage gain is therefore \\(C\_T/C\_{FB}\\).
Note that there is essentially no voltage at the summing node \\(s\_p\\).

<div class="important">
  <div></div>

A charge converter does not amplifier charge.
It converts a charge signal to a voltage.

</div>

<a id="org964dc8b"></a>

{{< figure src="/ox-hugo/morrison16_charge_amplifier.svg" caption="Figure 17: A basic charge amplifier" >}}

<a id="orgdd200ce"></a>

{{< figure src="/ox-hugo/morrison16_charge_amplifier_feedback_resistor.svg" caption="Figure 18: The resistor feedback arrangement to control the low-frequency response" >}}


### DC power supplies {#dc-power-supplies}


### Guard rings {#guard-rings}


### Thermocouple effects {#thermocouple-effects}


### Some thoughts on instrumentation {#some-thoughts-on-instrumentation}


## Utility Power and Facility Grounding {#utility-power-and-facility-grounding}

<div class="sum">
  <div></div>

This chapter discusses the relationship between utility power and the performance of electrical circuits.
Utility installations in facilities are controller by the NEC (National Electrical Code).
Safety and lighting protection requires that facilities connect their systems to earth.
Designers of electric hardware use utility power and also make electrical connections to earthed conductors.
This sharing of the earth connection creates many problems that are considered in this chapter.

Ground planes and isolation transformers can be used to limit interference.
The role of line filters, equipment grounds, and ground planes in facilities is explained.
The problems associated with using isolated ground conductors are discussed.
Lighting protection in facilities and for watercraft is a big safety issue.
The fact that current cannot enter the water below the water line is considered.
The battery action that causes the metal on boats to corrode is discussed.
The grounding methods in the Pacific Intertie are unique.
Solar winds can disrupt power distribution and damage oil pipelines.

</div>


### Introduction {#introduction}


### Semantics {#semantics}

Here are the key words used by a power engineer as defined by the NEC:

Ground
:


Equipment ground
:


The grounded conductor
:


The ungrounded conductor
:


Neutral
:


Isolated ground
:


Service entrance
:


Grounding electrode system
:


Feeder circuit
:


Branch circuit
:


Separately derived power
:


Listed equipment
:


### Utility power {#utility-power}


### The earth as a conductor {#the-earth-as-a-conductor}


### The neutral conneciton to earth {#the-neutral-conneciton-to-earth}


### Group potential differences {#group-potential-differences}


### Field coupling to power conductors {#field-coupling-to-power-conductors}


### Neutral conductors {#neutral-conductors}


### \\(k\\) factor in transformers {#k--factor-in-transformers}


### Power factor correction {#power-factor-correction}


### Ungrounded power {#ungrounded-power}


### A request for power {#a-request-for-power}


### Earth power currents {#earth-power-currents}


### Line filters {#line-filters}


### Isolated grounds {#isolated-grounds}


### Facility ground - Some history {#facility-ground-some-history}


### Ground planes in facilities {#ground-planes-in-facilities}


### Other ground planes {#other-ground-planes}


### Ground planes at remote sites {#ground-planes-at-remote-sites}


### Extending ground planes {#extending-ground-planes}


### Lightning {#lightning}


### Lightning and facilities {#lightning-and-facilities}


### Lightning protection for boats and ships {#lightning-protection-for-boats-and-ships}


### Grounding of boats and ships at dock {#grounding-of-boats-and-ships-at-dock}


### Aircraft grounding (fueling) {#aircraft-grounding--fueling}


### Ground Fault Interruption (GFI) {#ground-fault-interruption--gfi}


### Isolation transformers {#isolation-transformers}


## Radiation {#radiation}

<div class="sum">
  <div></div>

This chapter discusses radiation from circuit boards, transmission lines, conductor loops, and antennas.
The frequency spectrum of square waves and pulses is presented.
Matching of impedances is required to move energy from a transmission line to an antenna so that it can radiate this energy into free space.
Common-mode and normal-mode coupling of fields to conductors is considered.
The concept of wave impedance and its relation to shielding is considered.
Interference can be analyzed by using a rise-time frequency to represent pulses or step functions.

Effective radiated power from various transmitters is presented.
The field intensities for lightning and electrostatic discharge are given.
Loops generate low-impedance fields that are often difficult to shield.
Simple tools for locating sources of radiation are suggested.

</div>


### Handling radiation and susceptibility {#handling-radiation-and-susceptibility}


### Radiation {#radiation}


### Sine waves and transmission lines {#sine-waves-and-transmission-lines}


### Approximations for pulses and square waves {#approximations-for-pulses-and-square-waves}


### Radiation from components {#radiation-from-components}


### The dipole antenna {#the-dipole-antenna}


### Wave impedance {#wave-impedance}


### Field strength and antenna gain {#field-strength-and-antenna-gain}


### Radiation from loops {#radiation-from-loops}


### E-field coupling to a loop {#e-field-coupling-to-a-loop}


### Radiation from printed circuit boards {#radiation-from-printed-circuit-boards}


### The sniffer and the antenna {#the-sniffer-and-the-antenna}


### Microwave ovens {#microwave-ovens}


## Shielding from Radiation {#shielding-from-radiation}

<div class="sum">
  <div></div>

Cable shields are often made of aluminum foil or tinned copper braid.
Drain wires make it practical to connect to the foil.
Coaxial cables have a smooth inner surface that allows for the circulation of current and provide control of characteristic impedance.
Transfer impedance is a measure of shielding effectivity.
Multiple shields, low-noise cable, and conduit each have merits that are discussed.

The penetration of fields into enclosures is considered.
This includes independent and dependent apertures, the wave penetration of conducting surfaces, and waveguides.
The use of gaskets, honeycombs, and backshell connectors are described.
Handling utility power, line filters, and signal lines at a hardware interface are discussed.
Methods for limiting field penetration into and out of a screen are offered.

</div>


### Cables with shields {#cables-with-shields}

In analog work, an aluminum foil is often used as a shield around a cable.
The inside of the aluminum foil is anodized to provide protection against corrosion.
Because it is difficult to terminate the foil at the cable ends, a drain wire is provided on the outside of the cable foil.
This drain wire is made of multistranded tinned copper wires that make contact with the foil along the length of the cable.
If the foil should break, the drain wire connects the segments together.

In audio work, where a cable carries a microphone signal, the cable can be a shielded single conductor.
In instrumentation, best practice requires that the signal common and the shield be separate conductors.

An aluminum foil over a group of conductors provides an **excellent electrostatic shield at low frequencies**.
In analog work, the shield should be connected at one end to the reference conductor preferable where it connects to a ground.
If the drain wire is connected to grounded hardware at both ends, then interference can result.
Electromagnetic fields in the area will cause current flow in the resulting loop.

A foil seam does not allow current to flow freely around the cable.
Also the foil doesn't form a very stable geometry.
For these reasons, foil shields should not be used where the characteristic impedance of the cable needs to be controlled.
The termination of shields at a hardware interface can be critical.
A cable terminated by a drain wire allows field energy to penetrate the hardware at the hardware at the connector.
A woven braid can provide 360 degree termination.

The term coax is generally applied to cable where the characteristic impedance is controller.
A typical coax is a single conductor surrounded by a shield with a controlled geometry.
For applications from DC to about 1MHz, the characteristic impedance may not be important.
Above this frequency, coaxial cables is preferred.
The manufacturer supplies specifications relating to signal loss at high frequencies.

The characteristic impedance of a transmission line is a function of the conductor geometry and of the dielectric constant.
To transport RF power without reflections, the source impedance and the terminating impedance must match the line impedance.


### Low-noise cables {#low-noise-cables}


### Transfer impedance {#transfer-impedance}


### Waveguides {#waveguides}


### Electromagnetic fields over a ground plane {#electromagnetic-fields-over-a-ground-plane}


### Fields and conductors {#fields-and-conductors}


### Conductive enclosures - Introduction {#conductive-enclosures-introduction}


### Coupling through enclosure walls by an induction fields {#coupling-through-enclosure-walls-by-an-induction-fields}


### Reflection and absorption of field energy at a conducting surface {#reflection-and-absorption-of-field-energy-at-a-conducting-surface}


### Independent apertures {#independent-apertures}


### Dependent apertures {#dependent-apertures}


### Honeycombs {#honeycombs}


### Summing field penetrations {#summing-field-penetrations}


### Power line filters {#power-line-filters}


### Backshell connectors {#backshell-connectors}


### H-field coupling {#h-field-coupling}


### Gaskets {#gaskets}


### Finger stock {#finger-stock}


### Glass apertures {#glass-apertures}


### Guarding large transistors {#guarding-large-transistors}


### Mounting components on surfaces {#mounting-components-on-surfaces}


### Zappers {#zappers}


### Shielded and screen rooms {#shielded-and-screen-rooms}


## Bibliography {#bibliography}

<a id="orgc3a94fb"></a>Morrison, Ralph. 2016. _Grounding and Shielding: Circuits and Interference_. John Wiley & Sons.
