+++
title = "Vibration Control of Active Structures - Fourth Edition"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Vibration Isolation]({{< relref "vibration_isolation" >}}), [Reference Books]({{< relref "reference_books" >}}), [Stewart Platforms]({{< relref "stewart_platforms" >}}), [HAC-HAC]({{< relref "hac_hac" >}})

Reference
: ([Preumont 2018](#org29acb4a))

Author(s)
: Preumont, A.

Year
: 2018


## Introduction {#introduction}


### Active Versus Passive {#active-versus-passive}

Active structure may be cheaper or lighter than passive structures of comparable performances; or they may offer performances that no passive structure could offer.

Active is not always better, and a **control systems cannot compensate for a bad design**. Active solution should be considered only after all other passive means have been exhausted.

Feedback control can compensate for external disturbances only in a limited frequency range (the bandwidth), the disturbances are actually amplified by the control system outside this frequency band.


### Vibration Suppression {#vibration-suppression}

Vibration reduction can be achieved in many different ways:

-   **stiffening**: consists of shifting the resonance frequency of the structure beyond the frequency band of excitation
-   **damping**: consists of reducing the resonance peaks by dissipating the vibration energy
-   **isolation**: consists of preventing the propagation of disturbances to sensitive parts of the system

The design of an active control system involves many issues such as how to configurate the sensors and actuators, how to secure stability and robustness. The power requirements will often determine the size of the actuators and the cost of the project.


### Smart Materials and Structures {#smart-materials-and-structures}

An active structure consists of a structure provided with a set of actuators and sensors coupled by a controller. If the bandwidth of the controller includes some vibration modes of the structure, its dynamic response must be considered.

If the set of actuators and sensors are located at discrete points of the structure, they can be treated separately. However, for smart structures, the actuators and sensors are often distributed and have a high degree of integration inside the structure, which makes a separate modelling impossible.

Some smart materials are:

-   **Shape Memory Alloys** (SMA): recoverable strain of \\(\SI{5}{\percent}\\) induced by temperature. They can be used at low frequency and for low precision applications
-   **Piezoelectric materials**: recoverable strain of \\(\SI{0.1}{\percent}\\) under electric field. They can be used as actuators as well as sensors. Two main classes: ceramics and polymers. Piezopolymers are used mostly as sensors as they require high voltage. The best-known piezoceramic is the Lead-Zirconate-Titanate (PZT).
-   **Magnetostrictive materials**: recoverable strain of \\(\SI{0.15}{\percent}\\) under magnetic field
-   **Magneto-Rheological fluids** (MR): consists of viscous fluids containing micronsized particules of magnetic material. When the fluid is subjected to a magnetic field, the particules create colunmar structures requiring a minimum shear stress to initiate the flow.


### Control Strategies {#control-strategies}

There are two radically different approached to disturbance rejection: feedback and feedforward.


#### Feedback {#feedback}

<a id="orga09f785"></a>

{{< figure src="/ox-hugo/preumont18_classical_feedback_small.png" caption="Figure 1: Principle of feedback control" >}}

The principle of feedback is represented on figure [1](#orga09f785). The output \\(y\\) of the system is compared to the reference signal \\(r\\), and the error signal \\(\epsilon = r-y\\) is passed into a compensator \\(K(s)\\) and applied to the system \\(G(s)\\), \\(d\\) is the disturbance.
The design problem consists of finding the appropriate compensator \\(K(s)\\) such that the closed-loop system is stable and behaves in the appropriate manner.

In the control of lightly damped structures, feedback control is used for two distinct and complementary purposes: **active damping** and **model-based feedback**.

**Active Damping**:

-   The objective of active damping is to reduce the effect of resonant peaks on the response of the structure.
-   From \\(\frac{y}{d} = \frac{1}{1 + GK}\\), this requires \\(GK \gg 1\\) near the resonances
-   It can be generally be achieved without a model of the structure, with guaranteed stability, provided that the actuator and sensor are **collocated** and have perfect dynamics.

**Model based feedback**:
The objective is to control a variable \\(y\\) to a desired value \\(r\\) in spite of the external disturbances \\(d\\).

-   From \\(\frac{y}{r} = \frac{GK}{1 + GK}\\) we see that this requires large values of \\(GK\\) in the frequency range where \\(y\approx r\\) (bandwidth)
-   The bandwidth \\(\omega\_c\\) is limited by the accuracy of the model
-   The disturbance rejection within the bandwidth of the control system is always compensated by an amplification of the disturbances outside the bandwidth
-   When implemented digitally, the sampling frequency \\(\omega\_s\\) must always be two orders of magnitude larger than \\(\omega\_c\\) to preseve reasonably the behavior of the continuous system


#### Feedforward {#feedforward}

<a id="org57ee378"></a>

{{< figure src="/ox-hugo/preumont18_feedforward_adaptative.png" caption="Figure 2: Principle of feedforward control" >}}

The method relies on the availability of a **reference signal correlated to the primary disturbance**.
The idea is to produce a second disturbance such that is cancels the effect of the primary disturbance at the location of the sensor error. Its principle is explained in figure [2](#org57ee378).

The filter coefficients are adapted in such a way that the error signal at one or several critical points is minimized.

There is no guarantee that the global response is reduced at other locations. This method is therefor considered as a local one.
Because it is less sensitive to phase lag than feedback, it can be used at higher frequencies (\\(\omega\_c \approx \omega\_s/10\\)).

The table [1](#table--tab:adv-dis-type-control) summarizes the main features of the two approaches.

<a id="table--tab:adv-dis-type-control"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:adv-dis-type-control">Table 1</a></span>:
  Advantages and Disadvantages of some types of control
</div>

|                                    | **Advantages**                                | **Disadvantages**                                 |
|------------------------------------|-----------------------------------------------|---------------------------------------------------|
| **Active Damping**                 | - Simple to implement                         | - Effective only near resonance                   |
|                                    | - Does not required accurate model            |                                                   |
|                                    | - Guaranteed stability (collocated)           |                                                   |
| **Model Based**                    | - Global method                               | - Requires accurate model                         |
|                                    | - Attenuate all disturbance within bandwidth  | - Limited bandwidth                               |
|                                    |                                               | - Spillover                                       |
|                                    |                                               | - Amplification of disturbances outside bandwidth |
| **Feedforward Adaptive filtering** | - No model is necessary                       | - Error signal required                           |
|                                    | - Robust to change in plant transfer function | - Local method: may amplify vibration elsewhere   |
|                                    | - More effective for narrowband disturbance   | - Large amount of real-time computation           |


### The Various Steps of the Design {#the-various-steps-of-the-design}

<a id="org8ea735d"></a>

{{< figure src="/ox-hugo/preumont18_design_steps.png" caption="Figure 3: The various steps of the design" >}}

The various steps of the design of a controlled structure are shown in figure [3](#org8ea735d).

The **starting point** is:

-   Mechanical system
-   Performance objectives
-   Specification of the disturbances

Then the **open loop performances** can be evaluated:

-   The need for active control can be assessed
-   The needed bandwidth can be roughly specified

The next step consist of selecting the proper **type and location of sensors and actuators**:

-   The controllability and Observability are important concepts

A **model of the structure** is developped:

-   FEM or identification
-   Model reduction to limit the DoF

If the dynamics of the sensors and actuators may significantly affect the behavior of the system, they must be included in the model before the controller design.


### Plant Description, Error and Control Budget {#plant-description-error-and-control-budget}

From the block diagram of the control system (figure [4](#orga135390)):

\begin{align\*}
y &= (I - G\_{yu}H)^{-1} G\_{yw} w\\\\\\
z &= T\_{zw} w = [G\_{zw} + G\_{zu}H(I - G\_{yu}H)^{-1} G\_{yw}] w
\end{align\*}

<a id="orga135390"></a>

{{< figure src="/ox-hugo/preumont18_general_plant.png" caption="Figure 4: Block diagram of the control System" >}}

The frequency content of the disturbance \\(w\\) is usually described by its **power spectral density** \\(\Phi\_w (\omega)\\) which describes the frequency distribution of the meas-square value.

<div class="cbox">
  <div></div>

\\[\sigma\_w = \sqrt{\int\_0^\infty \Phi\_w(\omega) d\omega}\\]

</div>

Even more interesting for the design is the **Cumulative Mean Square** response defined by the integral of the PSD in the frequency range \\([\omega, \infty[\\).

<div class="cbox">
  <div></div>

\\[\sigma\_z^2(\omega) = \int\_\omega^\infty \Phi\_z(\nu) d\nu = \int\_\omega^\infty |T\_{zw}|^2 \Phi\_w(\nu) d\nu \\]

</div>

It is a monotonously decreasing function of frequency and describes the contribution of all frequencies above \\(\omega\\) to the mean-square value of \\(z\\).
\\(\sigma\_z(0)\\) is then the global RMS response.

A typical plot of \\(\sigma\_z(\omega)\\) is shown figure [5](#orge835b98).
It is useful to **identify the critical modes** in a design, at which the effort should be targeted.

The diagram can also be used to **assess the control laws** and compare different actuator and sensor configuration.

<a id="orge835b98"></a>

{{< figure src="/ox-hugo/preumont18_cas_plot.png" caption="Figure 5: Error budget distribution in OL and CL for increasing gains" >}}


### Pseudo-inverse {#pseudo-inverse}


#### Under-actuated System {#under-actuated-system}

Consider the linear system of equation:
\\[w = J v\\]
With:

-   \\(w\\) a vector with \\(m\\) components (measurements)
-   \\(v\\) a vector with \\(n\\) components (inputs)
-   We assume \\(m>n\\) (under-actuated)

We seek the pseudo-inverse of \\(J\\) such that \\(v = J^+ w\\)

The columns of \\(J\\) are the influence function of the actuators.
If the columns of \\(J\\) are independant, the Jacobian is full rang (\\(r=n\\)) and the **Moore-Penrose pseudo inverse** is:
\\[J^+ = (J^T J)^{-1} J^T\\]


#### Over-actuated System {#over-actuated-system}

If there are more actuator than sensor (\\(m<n\\)), we obtain:
\\[J^+ = J^T(J  J^T)^{-1}\\]

Note that the Singular Value Decomposition offers a practical way to compute the pseudo-inverse, both for \\(m>n\\) and \\(n>m\\).


#### Singular Value Decomposition {#singular-value-decomposition}

The **Singular Value Decomposition** (SVD) is a generalization of the eigenvalue decomposition of a rectangular matrix:
\\[ J = U \Sigma V^T = \sum\_{i=1}^r \sigma\_i u\_i v\_i^T \\]
With:

-   \\(U\\) and \\(V\\) orthogonal matrices. The columns \\(u\_i\\) and \\(v\_i\\) of \\(U\\) and \\(V\\) are the eigenvectors of the square matrices \\(JJ^T\\) and \\(J^TJ\\) respectively
-   \\(\Sigma\\) a rectangular diagonal matrix of dimension \\(m \times n\\) containing the square root of the common non-zero eigenvalues of \\(JJ^T\\) and \\(J^TJ\\)
-   \\(r\\) is the number of non-zero singular values of \\(J\\)

The pseudo-inverse of \\(J\\) is:
\\[ J^+ = V\Sigma^+U^T = \sum\_{i=1}^r \frac{1}{\sigma\_i} v\_i u\_i^T \\]

The conditioning of the Jacobian is measured by the **condition number**:
\\[ c(J) = \frac{\sigma\_{max}}{\sigma\_{min}} \\]

When \\(c(J)\\) becomes large, the most straightforward way to handle the ill-conditioning is to truncate the smallest singular value out of the sum.
This will have usually little impact of the fitting error while reducing considerably the actuator inputs \\(v\\).


## Some Concepts in Structural Dynamics {#some-concepts-in-structural-dynamics}


### Equation of Motion of a Discrete System {#equation-of-motion-of-a-discrete-system}

The general form of the equation of motion governing the dynamic equilibrium between the external, elastic, inertia and damping forces acting on a discrete, flexible structure with a finite number \\(n\\) of degrees of freedom is

<div class="cbox">
  <div></div>

\begin{equation}
  M \ddot{x} + C \dot{x} + K x = f
\end{equation}

With:

-   \\(x\\) is the vector of generalized displacements (translations and rotations)
-   \\(f\\) is the vector of generalized forces (point forces and torques)
-   \\(M\\), \\(C\\) and \\(K\\) are respectively the mass, damping and stiffness matrices; they are symmetric and semi-positive definite

</div>

The damping matrix \\(C\\) represents the various dissipation mechanisms in the structure, which are usually poorly known. One of the popular hypotheses is the Rayleigh damping.

<div class="cbox">
  <div></div>

\begin{equation}
  C = \alpha M + \beta K
\end{equation}

</div>

\\(\alpha\\) and \\(\beta\\) are selected to fit the structure under consideration.


### Vibration Modes {#vibration-modes}

Consider the free response of an undamped system of order \\(n\\):
\\[ M\ddot{x} + K x = 0 \\]

If one tries a solution of the form \\(x = \phi\_i e^{j\omega\_i t}\\), \\(\phi\_i\\) and \\(\omega\_i\\) must statisfy the eigenvalue problem
\\[ (K - \omega\_i^2 M)\phi\_i = 0 \\]
with:

-   \\(\omega\_i\\): the **natural frequency**
-   \\(\phi\_i\\): the corresponding **mode shape**

The number of mode shapes is equal to the number of degrees of freedom \\(n\\).

The mode shapes are orthogonal with respect to the stiffness and mass matrices:

\begin{align}
  \phi\_i^T M \phi\_j &= \mu\_i \delta\_{ij} \\\\\\
  \phi\_i^T K \phi\_j &= \mu\_i \omega\_i^2 \delta\_{ij}
\end{align}

With \\(\mu\_i\\) the **modal mass** (also called the generalized mass) of mode \\(i\\).


### [Modal Decomposition]({{< relref "modal_decomposition" >}}) {#modal-decomposition--modal-decomposition-dot-md}


#### Structure Without Rigid Body Modes {#structure-without-rigid-body-modes}

Let perform a change of variable from physical coordinates \\(x\\) to modal coordinates \\(z\\).

<div class="cbox">
  <div></div>

\begin{equation}
  x = \Phi z
\end{equation}

With:

-   \\(\Phi = [\phi\_1, \phi\_2, ..., \phi\_n]\\) the matrix of the mode shapes
-   \\(z\\) the vector of modal amplitudes

</div>

The dynamic equation of the system becomes:
\\[ M \Phi \ddot{z} + C \Phi \dot{z} + K \Phi z = f \\]

If we left multiply the equation by \\(\Phi^T\\) and we use the orthogonalily relationships:
\\[ diag(\mu\_i) \ddot{z} + \Phi^T C \Phi + diag(\mu\_i \omega\_i^2) z = \Phi^T f \\]

If \\(\Phi^T C \Phi\\) is diagonal, the **damping is said classical or normal**. In this case:
\\[ \Phi^T C \Phi = diag(2 \xi\_i \mu\_i \omega\_i) \\]

One can verify that the Rayleigh damping \eqref{eq:rayleigh_damping} complies with this condition with modal damping ratios \\(\xi\_i = \frac{1}{2} ( \frac{\alpha}{\omega\_i} + \beta\omega\_i )\\).

And we obtain decoupled modal equations \eqref{eq:modal_eom}.

<div class="cbox">
  <div></div>

\begin{equation}
  \ddot{z} + 2 \xi \Omega \dot{z} + \Omega^2 z = z^{-1} \Phi^T f
\end{equation}

with:

-   \\(\xi = diag(\xi\_i)\\)
-   \\(\Omega = diag(\omega\_i)\\)
-   \\(\mu = diag(\mu\_i)\\)

</div>

Typical values of the modal damping ratio are summarized on table [tab:damping_ratio](#tab:damping_ratio).

<a id="table--tab:damping-ratio"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:damping-ratio">Table 2</a></span>:
  Typical Damping ratio
</div>

| **Damping Ratio**              | **Application**         |
|--------------------------------|-------------------------|
| \\(\xi \simeq 0.001 - 0.005\\) | Space structures        |
| \\(\xi \simeq 0.01 - 0.02\\)   | Mechanical engineering  |
| \\(\xi \simeq 0.05\\)          | Civil engineering       |
| \\(\xi \simeq 0.2\\)           | When ground is involved |

The assumption of classical damping is often justified for light damping, but it is questionable when the damping is large.

If one accepts the assumption of classical damping, the only difference between equation \eqref{eq:general_eom} and \eqref{eq:modal_eom} lies in the change of coordinates.
However, in physical coordinates, the number of degrees of freedom is usually very large.
If a structure is excited in by a band limited excitation, its response is dominated by the modes whose natural frequencies are inside the bandwidth of the excitation and the equation \eqref{eq:modal_eom} can often be restricted to theses modes.
Therefore, the number of degrees of freedom contribution effectively to the response is **reduced drastically** in modal coordinates.


#### Dynamic Flexibility Matrix {#dynamic-flexibility-matrix}

If we consider the steady-state response of equation \eqref{eq:general_eom} to harmonic excitation \\(f=F e^{j\omega t}\\), the response is also harmonic \\(x = Xe^{j\omega t}\\). The amplitude of \\(F\\) and \\(X\\) is related by:
\\[ X = G(\omega) F \\]

Where \\(G(\omega)\\) is called the **Dynamic flexibility Matrix**:
\\[ G(\omega) = (-\omega^2 M + j\omega C + K)^{-1} F \\]

From the modal expansion of the dynamic flexibility matrix can be obtained by coordinate transformation \\(x = \phi z\\) and we obtain:

\begin{equation}
  G(\omega) = \sum\_{i=1}^n \frac{\phi\_i \phi\_i^T}{\mu\_i \omega\_i^2} D\_i(\omega)
\end{equation}

With:

-   \\(D\_i(\omega)\\) is the dynamic amplification factor of mode \\(i\\) given by

\begin{equation}
  D\_i(\omega) = \frac{1}{1 - \omega^2/\omega\_i^2 + 2 j \xi\_i \omega/\omega\_i}
\end{equation}

<a id="orga21e5bb"></a>

{{< figure src="/ox-hugo/preumont18_neglected_modes.png" caption="Figure 6: Fourier spectrum of the excitation \\(F\\) and dynamic amplitification \\(D\_i\\) of mode \\(i\\) and \\(k\\) such that \\(\omega\_i < \omega\_b\\) and \\(\omega\_k \gg \omega\_b\\)" >}}

If the excitation has a limited bandwidth \\(\omega\_b\\), the contribution of the high frequency modes \\(\omega\_k \gg \omega\_b\\) can be evaluated by assuming \\(D\_k(\omega) \approx 1\\) (as shown on figure [6](#orga21e5bb)).

And \\(G(\omega)\\) can be rewritten on terms of the **low frequency modes only**:
\\[ G(\omega) \approx \sum\_{i=1}^m \frac{\phi\_i \phi\_i^T}{\mu\_i \omega\_i^2} D\_i(\omega) + R \\]

The quasi-static correction of the high frequency modes \\(R\\) is called the **residual mode**. This introduces a **feedthrough** component in the transfer matrix.


#### Structure with Rigid Body Modes {#structure-with-rigid-body-modes}


### Collocated Control System {#collocated-control-system}

<div class="cbox">
  <div></div>

A **collocated control system** is a control system where:

-   the actuator and the sensor are **attached to the same degree of freedom**
-   they are **dual**: the product of the actuator signal and the sensor signal represents the energy exchange between the structure and the control system

</div>

<a id="table--tab:dual-actuator-sensor"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:dual-actuator-sensor">Table 3</a></span>:
  Examples of dual actuators and sensors
</div>

| **Actuator** | **Sensor**  |
|--------------|-------------|
| Force        | Translation |
| Torque       | Rotation    |

The open-loop FRF of a collocated system corresponds to a diagonal component of the dynamic flexibility matrix.

If we assumes that the collocated system is undamped and is attached to the DoF \\(k\\), the open-loop FRF is purely real:
\\[ G\_{kk}(\omega) = \sum\_{i=1}^m \frac{\phi\_i^2(k)}{\mu\_i (\omega\_i^2 - \omega^2)} + R\_{kk} \\]

\\(G\_{kk}\\) is a monotonously increasing function of \\(\omega\\) (figure [7](#org4ad84e0)).

<a id="org4ad84e0"></a>

{{< figure src="/ox-hugo/preumont18_collocated_control_frf.png" caption="Figure 7: Open-Loop FRF of an undamped structure with collocated actuator/sensor pair" >}}

The amplitude of the FRF goes from \\(-\infty\\) at the resonance frequencies \\(\omega\_i\\) to \\(+\infty\\) at the next resonance frequency \\(\omega\_{i+1}\\). Therefore, in every interval, there is a frequency \\(z\_i\\) such that \\(\omega\_i < z\_i < \omega\_{i+1}\\) where the amplitude of the FRF vanishes. The frequencies \\(z\_i\\) are called **anti-resonances**.

<div class="cbox">
  <div></div>

Undamped **collocated control systems** have **alternating poles and zeros** on the imaginary axis.
For lightly damped structure, the poles and zeros are just moved a little bit in the left-half plane, but they are still interlacing.

</div>

If the undamped structure is excited harmonically by the actuator at the frequency of the transmission zero \\(z\_i\\), the amplitude of the response of the collocated sensor vanishes. That means that the structure oscillates at the frequency \\(z\_i\\) according to the mode shape shown in dotted line figure [8](#org0d5b542).

<a id="org0d5b542"></a>

{{< figure src="/ox-hugo/preumont18_collocated_zero.png" caption="Figure 8: Structure with collocated actuator and sensor" >}}

<div class="cbox">
  <div></div>

The frequency of the transmission zero \\(z\_i\\) and the mode shape associated are the **natural frequency** and the **mode shape** of the system obtained by **constraining the d.o.f. on which the control systems acts**.

The open-loop zeros are asymptotic values of the closed-loop poles when the feedback gain goes to infinity.

The open-loop poles are independant of the actuator and sensor configuration while the open-loop zeros do depend on it.

</div>

By looking at figure [7](#org4ad84e0), we see that neglecting the residual mode in the modelling amounts to translating the FRF diagram vertically. That produces a shift in the location of the transmission zeros to the right.

<a id="org6f76f34"></a>

{{< figure src="/ox-hugo/preumont18_alternating_p_z.png" caption="Figure 9: Bode plot of a lighly damped structure with collocated actuator and sensor" >}}

The open-loop transfer function of a lighly damped structure with a collocated actuator/sensor pair can be written:

\begin{equation}
  G(s) = G\_0 \frac{\Pi\_i(s^2/z\_i^2 + 2 \xi\_i s/z\_i + 1)}{\Pi\_j(s^2/\omega\_j^2 + 2 \xi\_j s /\omega\_j + 1)}
\end{equation}

The corresponding Bode plot is represented in figure [9](#org6f76f34). Every imaginary pole at \\(\pm j\omega\_i\\) introduces a \\(\SI{180}{\degree}\\) phase lag and every imaginary zero at \\(\pm jz\_i\\) introduces a phase lead of \\(\SI{180}{\degree}\\).
In this way, the phase diagram is always contained between \\(\SI{0}{\degree}\\) and \\(\SI{-180}{\degree}\\) as a consequence of the interlacing property.


## Electromagnetic and Piezoelectric Transducers {#electromagnetic-and-piezoelectric-transducers}


### Introduction {#introduction}

Transducers are critical in active structures technology.
In many applications, the actuators are the most critical part of the system; however, the sensors become very important in precision engineering where submicron amplitudes must be detected.

Two broad categories of actuators can be distinguish:

-   **grounded actuator**: react on a fixed support. They include torque motors, force motors (shakers), tendons
-   **structure borne actuator**: includes jets, reaction wheels, proof-mass actuators, piezo strips, ...


### Voice Coil Transducer {#voice-coil-transducer}

A voice coil transducer is an energy transformer which converts electrical power into mechanical power and vice versa.

The system consists of (see figure [10](#orgc872907)):

-   A permanent magnet which produces a uniform flux density \\(B\\) normal to the gap
-   A coil which is free to move axially

<a id="orgc872907"></a>

{{< figure src="/ox-hugo/preumont18_voice_coil_schematic.png" caption="Figure 10: Physical principle of a voice coil transducer" >}}

We note:

-   \\(v\\) the velocity of the coil
-   \\(f\\) the external force acting to maintain the coil in equilibrium againt the electromagnetic forces
-   \\(e\\) the voltage difference across the coil
-   \\(i\\) the current into the coil

<div class="cbox">
  <div></div>

**Faraday's law**:

\begin{equation}
  e = 2\pi n r B v = T v
\end{equation}

With \\(T = 2\pi n r B\\) is the **transducer constant**.

**Lorentz force law**:

\begin{equation}
  f = -i 2\pi n r B = - T i
\end{equation}

</div>

The total power delivered to the moving coil transducer is equal to the sum of the electric power and the mechanical power:
\\[ ei + fv = 0 \\]

Thus, at any time, there is an equilibrium between the electrical power absorbed by the device and the mechanical power delivered.


#### Proof-Mass Actuator {#proof-mass-actuator}

A reaction mass \\(m\\) is conected to the support structure by a spring \\(k\\) , and damper \\(c\\) and a force actuator \\(f = T i\\) (figure [11](#org4783db3)).

<a id="org4783db3"></a>

{{< figure src="/ox-hugo/preumont18_proof_mass_actuator.png" caption="Figure 11: Proof-mass actuator" >}}

If we apply the second law of Newton on the mass:
\\[ m\ddot{x} + c\dot{x} + kx = f = Ti \\]

In the Laplace domain:
\\[ x = \frac{Ti}{ms^2 + cs + k} \\]

The total force applied on the support is:
\\[ F = -f + cs + k = -m s^2 x = \frac{-ms^2Ti}{ms^2 + cs + k} \\]

The transfer function between the total force and the current \\(i\\) applied to the coil is :

<div class="cbox">
  <div></div>

\begin{equation}
  \frac{F}{i} = \frac{-s^2 T}{s^2 + 2\xi\_p \omega\_p s + \omega\_p^2}
\end{equation}

with:

-   \\(T\\) is the transducer constant
-   \\(\omega\_p = \frac{k}{m}\\) is the natural frequency of the spring-mass system
-   \\(\xi\_p\\) is the damping ratio

</div>

Above some critical frequency \\(\omega\_c \approx 2\omega\_p\\), **the proof-mass actuator can be regarded as an ideal force generator** (figure [12](#org1a21332)).

<a id="org1a21332"></a>

{{< figure src="/ox-hugo/preumont18_proof_mass_tf.png" caption="Figure 12: Bode plot \\(F/i\\) of the proof-mass actuator" >}}


#### Geophone {#geophone}

The geophone is a transducer which behaves like an **absolute velocity sensor** above some cutoff frequency.
The voltage \\(e\\) of the coil is used as the sensor output.

If \\(x\_0\\) is the displacement of the support and if the voice coil is open (\\(i=0\\)), the governing equations are:

\begin{align\*}
  m\ddot{x} + c(\dot{x}-\dot{x\_0}) + k(x-x\_0) &= 0\\\\\\
  T(\dot{x}-\dot{x\_0}) &= e
\end{align\*}

By using the two equations, we obtain:

\begin{equation}
  \frac{e}{\dot{x\_0}} = \frac{-s^2 T}{s^2 + 2\xi\_p\omega\_p s + \omega\_p^2}
\end{equation}

Above the corner frequency, the gain of the geophone is equal to the transducer constant \\(T\\).

<a id="orgb1e0d40"></a>

{{< figure src="/ox-hugo/preumont18_geophone.png" caption="Figure 13: Model of a geophone based on a voice coil transducer" >}}

Designing geophones with very low corner frequency is in general difficult. Active geophones where the frequency is lowered electronically may constitute a good alternative option.


### General Electromechanical Transducer {#general-electromechanical-transducer}

The consitutive behavior of a wide class of electromechanical transducers can be modelled as in figure [14](#orgf2af0aa).

<a id="orgf2af0aa"></a>

{{< figure src="/ox-hugo/preumont18_electro_mechanical_transducer.png" caption="Figure 14: Electrical analog representation of an electromechanical transducer" >}}

In Laplace form the constitutive equations read:

\begin{align}
  e & = Z\_e    i + T\_{em} v \label{eq:gen\_trans\_e} \\\\\\
  f & = T\_{em} i + Z\_m    v \label{eq:gen\_trans\_f}
\end{align}

With:

-   \\(e\\) is the Laplace transform of the input voltage across the electrical terminals
-   \\(i\\) is the input current
-   \\(f\\) is the force applied to the mechanical terminals
-   \\(v\\) is the velocity of the mechanical part
-   \\(Z\_e\\) is the blocked electrical impedance (for \\(v=0\\))
-   \\(T\_{em}\\) is the transduction coefficient representing the electromotive force (in \\(\si{\volt\second\per\meter}\\))
-   \\(T\_{me}\\) is the transduction coefficient representing the force acting on the mechanical terminals to balance the electromagnetic force induced per unit current input (in \\(\si{\newton\per\ampere}\\))
-   \\(Z\_m\\) is the mechanical impedance measured when \\(i=0\\)

Equation \eqref{eq:gen_trans_e} shows that the voltage across the electrical terminals of any electromechanical transducer is the sum of a contribution proportional to the current applied and a contribution proportional to the velocity of the mechanical terminals.
Thus, if \\(Z\_ei\\) can be measured and substracted from \\(e\\), a signal proportional to the velocity is obtained.

To do so, the bridge circuit as shown on figure [15](#orgeb5cb84) can be used.

We can show that

\begin{equation}
  V\_4 - V\_2 = \frac{-Z\_b T\_{em}}{Z\_e + Z\_b} v
\end{equation}

which is indeed a linear function of the velocity \\(v\\) at the mechanical terminals.

<a id="orgeb5cb84"></a>

{{< figure src="/ox-hugo/preumont18_bridge_circuit.png" caption="Figure 15: Bridge circuit for self-sensing actuation" >}}


### Smart Materials {#smart-materials}

Smart materials have the ability to respond significantly to stimuli of different physical nature.
Figure [16](#org1e5bcfc) lists various effects that are observed in materials in response to various inputs.

<a id="org1e5bcfc"></a>

{{< figure src="/ox-hugo/preumont18_smart_materials.png" caption="Figure 16: Stimulus response relations indicating various effects in materials. The smart materials corresponds to the non-diagonal cells" >}}


### Piezoelectric Transducer {#piezoelectric-transducer}

Piezoelectric materials exhibits two effects described below.

<div class="cbox">
  <div></div>

Ability to generate an electrical charge in proportion to an external applied force.

</div>

<div class="cbox">
  <div></div>

An electric filed parallel to the direction of polarization induces an expansion of the material.

</div>

The most popular piezoelectric materials are Lead-Zirconate-Titanate (PZT) which is a ceramic, and Polyvinylidene fluoride (PVDF) which is a polymer.

We here consider a transducer made of one-dimensional piezoelectric material.

<div class="cbox">
  <div></div>

\begin{subequations}
  \begin{align}
    D & = \epsilon^T E + d\_{33} T\\\\\\
    S & = d\_{33} E     + s^E T
  \end{align}
\end{subequations}

With:

-   \\(D\\) is the electric displacement \\([C/m^2]\\)
-   \\(E\\) is the electric field \\([V/m]\\)
-   \\(T\\) is the stress \\([N/m^2]\\)
-   \\(S\\) is the strain
-   \\(\epsilon^T\\) is the dielectric constant under constant stress
-   \\(s^E\\) is the compliance when the eletric field is constant (inverse of Young modulus)
-   \\(d\_{33}\\) is the piezoelectric constant \\([m/V]\\) or \\([C/N]\\) in the poling direction of the material (convention)

</div>


#### Constitutive Relations of a Discrete Transducer {#constitutive-relations-of-a-discrete-transducer}

The set of equations \eqref{eq:piezo_eq} can be written in a matrix form:

\begin{equation}
\begin{bmatrix}D\\S\end{bmatrix}
=
\begin{bmatrix}
\epsilon^T & d\_{33}\\\\\\
d\_{33}     & s^E
\end{bmatrix}
\begin{bmatrix}E\\T\end{bmatrix}
\end{equation}

Where \\((E, T)\\) are the independent variables and \\((D, S)\\) are the dependent variable.

If \\((E, S)\\) are taken as independant variables:

\begin{equation}
\begin{bmatrix}D\\T\end{bmatrix}
=
\begin{bmatrix}
\epsilon^T(1-k^2) & e\_{33}\\\\\\
-e\_{33}           & c^E
\end{bmatrix}
\begin{bmatrix}E\\S\end{bmatrix}
\end{equation}

With:

-   \\(c^E = \frac{1}{s^E}\\) is the Young modulus under short circuited electrodes (\\(E = 0\\)) in \\([N/m^2]\\)
-   \\(e\_{33} = \frac{d\_{33}}{s^E}\\) is the constant relating the electric displacement to the strain for short-circuited electrodes \\([C/m^2]\\)

<div class="cbox">
  <div></div>

\begin{equation}
  k^2 = \frac{{d\_{33}}^2}{s^E \epsilon^T} = \frac{{e\_{33}}^2}{c^E \epsilon^T}
\end{equation}

\\(k\\) is called the **electromechanical coupling factor** of the material.
It measures the efficiency of the conversion of the mechanical energy into electrical energy, and vice versa.

</div>

If one assumes that all the electrical and mechanical quantities are uniformly distributed in a linear transducer formed by a **stack** (see figure [17](#orgffdc1af)) of \\(n\\) disks of thickness \\(t\\) and cross section \\(A\\), the global constitutive equations of the transducer are obtained by integrating \eqref{eq:piezo_eq_matrix_bis} over the volume of the transducer:

\begin{equation}
\begin{bmatrix}Q\\\Delta\end{bmatrix}
=
\begin{bmatrix}
C & nd\_{33}\\\\\\
nd\_{33} & 1/K\_a
\end{bmatrix}
\begin{bmatrix}V\\f\end{bmatrix}
\end{equation}

where

-   \\(Q = n A D\\) is the total electric charge on the electrodes of the transducer
-   \\(\Delta = S l\\) is the total extension (\\(l = nt\\) is the length of the transducer)
-   \\(f = AT\\) is the total force
-   \\(V\\) is the voltage applied between the electrodes of the transducer
-   \\(C = \epsilon^T A n^2/l\\) is the capacitance of the transducer with no external load (\\(f = 0\\))
-   \\(K\_a = A/s^El\\) is the stiffness with short-circuited electrodes (\\(V = 0\\))

<a id="orgffdc1af"></a>

{{< figure src="/ox-hugo/preumont18_piezo_stack.png" caption="Figure 17: Piezoelectric linear transducer" >}}

Equation \eqref{eq:piezo_stack_eq} can be inverted to obtain

\begin{equation}
\begin{bmatrix}V\\f\end{bmatrix}
=
\frac{K\_a}{C(1-k^2)}
\begin{bmatrix}
1/K\_a & -nd\_{33}\\\\\\
-nd\_{33} & C
\end{bmatrix}
\begin{bmatrix}Q\\\Delta\end{bmatrix}
\end{equation}


#### Energy Stored in the Piezoelectric Transducer {#energy-stored-in-the-piezoelectric-transducer}

Let us write the total stored electromechanical energy of a discrete piezoelectric transducer as shown on figure [18](#org890e9f3).

The total power delivered to the transducer is the sum of electric power \\(V i\\) and the mechanical power \\(f \dot{\Delta}\\). The net work of the transducer is

\begin{equation}
  dW = V i dt + f \dot{\Delta} dt = V dQ + f d\Delta
\end{equation}

<a id="org890e9f3"></a>

{{< figure src="/ox-hugo/preumont18_piezo_discrete.png" caption="Figure 18: Discrete Piezoelectric Transducer" >}}

By integrating equation \eqref{eq:piezo_work} and using the constitutive equations \eqref{eq:piezo_stack_eq_inv}, we obtain the analytical expression of the stored electromechanical energy for the discrete transducer:

\begin{equation}
  W\_e(\Delta, Q) = \frac{Q^2}{2 C (1 - k^2)} - \frac{n d\_{33} K\_a}{C(1-k^2)} Q\Delta + \frac{K\_a}{1-k^2}\frac{\Delta^2}{2}
\end{equation}

-   The first term is the electrical energy stored in the capacitance \\(C(1-k^2)\\) (corresponding to fixed geometry \\(\Delta = 0\\))
-   The second term is the piezoelectric energy
-   The third term is the elastic strain energy stored in a spring stiffness \\(K\_a/(1-k^2)\\) (corresponding to open electrodes \\(Q=0\\))

The constitutive equations can be recovered by differentiate the stored energy:
\\[ f = \frac{\partial W\_e}{\partial \Delta}, \quad V = \frac{\partial W\_e}{\partial Q} \\]


#### Interpretation of \\(k^2\\) {#interpretation-of--k-2}

Consider a piezoelectric transducer subjected to the following mechanical cycle: first, it is loaded with a force \\(F\\) with short-circuited electrodes; the resulting extension is \\(\Delta\_1 = F/K\_a\\) where \\(K\_a = A/(s^El)\\) is the stiffness with short-circuited electrodes.
The energy stored in the system is:
\\[ W\_1 = \int\_0^{\Delta\_1} f dx = \int\_0^{\Delta\_1} K\_a x dx = \frac{F^2}{2 K\_a} \\]

At this point, the electrodes are open and the transducer is unloaded according to a path of slope \\(K\_a/(1-k^2)\\), the resulting extension is \\(\Delta\_2 = \frac{F(1-k^2)}{K\_a}\\).
The energy recovered is
\\[ W\_1 = \int\_0^{\Delta\_2} f dx = \frac{F \Delta\_2}{2} = \frac{F^2(1-k^2)}{2 K\_a} \\]

The ratio between the remaining stored energy and the initial stored energy is
\\[ \frac{W\_1 - W\_2}{W\_1} = k^2 \\]


#### Admittance of the Piezoelectric Transducer {#admittance-of-the-piezoelectric-transducer}

Consider the system of figure [19](#org87aa6cd), where the piezoelectric transducer is assumed massless and is connected to a mass \\(M\\).
The force acting on the mass is negative of that acting on the transducer, \\(f = -M \ddot{x}\\).

<a id="org87aa6cd"></a>

{{< figure src="/ox-hugo/preumont18_piezo_stack_admittance.png" caption="Figure 19: Elementary dynamical model of the piezoelectric transducer" >}}

From the constitutive equations, one finds

\begin{equation}
  \frac{I}{V} = s C (1-k^2) \frac{s^2 + z^2}{s^2 + p^2}
\end{equation}

where the poles and zeros are respectively
\\[ p^2 = \frac{K\_a}{M},\quad z^2 = \frac{K\_a/(1-k^2)}{M} \\]

And one can see that

\begin{equation}
  \frac{z^2 - p^2}{z^2} = k^2
\end{equation}

Equation \eqref{eq:distance_p_z} constitutes a practical way to determine the electromechanical coupling factor from the poles and zeros of the admittance measurement (figure [20](#org12f8fb9)).

<a id="org12f8fb9"></a>

{{< figure src="/ox-hugo/preumont18_piezo_admittance_curve.png" caption="Figure 20: Typical admittance FRF of the transducer" >}}


## Piezoelectric Beam, Plate and Truss {#piezoelectric-beam-plate-and-truss}


### Piezoelectric Material {#piezoelectric-material}


#### Constitutive Relations {#constitutive-relations}


#### Coenergy Density Function {#coenergy-density-function}


### Hamilton's Principle {#hamilton-s-principle}


### Piezoelectric Beam Actuator {#piezoelectric-beam-actuator}


#### Hamilton's Principle {#hamilton-s-principle}


#### Piezoelectric Loads {#piezoelectric-loads}


### Laminar Sensor {#laminar-sensor}


#### Current and Charge Amplifiers {#current-and-charge-amplifiers}


#### Distributed Sensor Output {#distributed-sensor-output}


#### Charge Amplifier Dynamics {#charge-amplifier-dynamics}


### Spatial Modal Filters {#spatial-modal-filters}


#### Modal Actuator {#modal-actuator}


#### Modal Sensor {#modal-sensor}


### Active Beam with Collocated Actuator/Sensor {#active-beam-with-collocated-actuator-sensor}


#### Frequency Response Function {#frequency-response-function}


#### Pole-Zero Pattern {#pole-zero-pattern}


#### Modal Truncation {#modal-truncation}


### Admittance of a Beam with a Piezoelectric Patch {#admittance-of-a-beam-with-a-piezoelectric-patch}


### Piezoelectric Laminate {#piezoelectric-laminate}


#### Two-Dimensional Constitutive Equations {#two-dimensional-constitutive-equations}


#### Kirchhoff Theory {#kirchhoff-theory}


#### Stiffness Matrix of a Multilayer Elastic Laminate {#stiffness-matrix-of-a-multilayer-elastic-laminate}


#### Multilayer Laminate with a Piezoelectric Layer {#multilayer-laminate-with-a-piezoelectric-layer}


#### Equivalent Piezoelectric Loads {#equivalent-piezoelectric-loads}


#### Sensor Output {#sensor-output}


#### Beam Model Versus Plate Model {#beam-model-versus-plate-model}


#### Additional Remarks {#additional-remarks}


### Active Truss {#active-truss}


#### Open-Loop Transfer Function {#open-loop-transfer-function}


#### Admittance Function {#admittance-function}


### Finite Element Formulation {#finite-element-formulation}


### Problems {#problems}


### References {#references}


## Passive Damping with Piezoelectric Transducers {#passive-damping-with-piezoelectric-transducers}


### Introduction {#introduction}


### Resistive Shunting {#resistive-shunting}


### Inductive Shunting {#inductive-shunting}


#### Equal Peak Design {#equal-peak-design}


#### Robustness of the Equal Peak Design {#robustness-of-the-equal-peak-design}


### Switched Shunt {#switched-shunt}


#### Equivalent Damping Ratio {#equivalent-damping-ratio}


## Collocated Versus Non-collocated Control {#collocated-versus-non-collocated-control}


### Pole-Zero Flipping {#pole-zero-flipping}

<div class="cbox">
  <div></div>

The Root Locus shows, in a graphical form, the evolution of the poles of the closed-loop system as a function of the scalar gain \\(g\\) applied to the compensator.
The Root Locus is the locus of the solution \\(s\\) of the closed loop characteristic equation \\(1 + gG(s)H(s) = 0\\) when \\(g\\) goes from zero to infinity.

</div>

If the open-loop transfer function is written
\\[ G(s)H(s) = k \frac{\Pi\_{i=1}^{m} (s - z\_i)}{\Pi\_{i=1}^{n} (s - p\_i)} \\]
The locus goes from the poles \\(p\_i\\) (for \\(g=0\\)) to the zeros \\(z\_i\\) (as \\(g \rightarrow \infty\\)).


### The Two-Mass Problem {#the-two-mass-problem}


#### Collocated Control {#collocated-control}


#### Non-collocated Control {#non-collocated-control}


### Notch Filter {#notch-filter}


### Effect of Pole-Zero Flipping on the Bode Plots {#effect-of-pole-zero-flipping-on-the-bode-plots}


### Nearly Collocated Control System {#nearly-collocated-control-system}


### Non-collocated Control Systems {#non-collocated-control-systems}


### The Role of Damping {#the-role-of-damping}


## Active Damping with Collocated System {#active-damping-with-collocated-system}


### Introduction {#introduction}

The role of active damping is to increase the negative real parts of system poles wile maintaining the natural frequencies essentially unchanged.

Active damping requires relatively little control effort; this is why it is also called Low Authority Control (LAC).
Other control strategies which fully relocate the closed loop poles are called High Autority Control (HAC).


### Lead Control {#lead-control}

\\[H(s) = g \frac{s+z}{z+p} \quad p \gg z \\]

It produces a phase lead in the frequency band between \\(z\\) and \\(p\\), bringing active damping to all the modes belonging to \\(z < \omega\_i < p\\).

The closed-loop poles start at the open-llop poles for \\(g=0\\) and go to the open-loop zeros for \\(g\rightarrow\infty\\).

The controller does not have any roll-off, but the roll-off of the structure is enough to guarantee gain stability at high frequency.


### Direct Velocity Feedback (DVF) {#direct-velocity-feedback--dvf}

This is a particular case of the Lead controller as \\(z\rightarrow 0\\) and \\(p\rightarrow\infty\\).

Structure:
\\[M \ddot{x} + K x = b u\\]

Output is a velocity sensor:
\\[y = b^T \dot{x}\\]

Control:
\\[u = -g y\\]


### Positive Position Feedback (PPF) {#positive-position-feedback--ppf}

Sometimes the plant does not have a roll-off of \\(-40dB/\text{decade}\\), then we can use a second-order PPF:
\\[H(s) = \frac{-g}{s^2 + 2 \xi\_f \omega\_f s + {\omega\_f}^2}\\]


### Integral Force Feedback (IFF) {#integral-force-feedback--iff}


### Duality Between the Lead and the IFF Controllers {#duality-between-the-lead-and-the-iff-controllers}


#### Root Locus of a Single Mode {#root-locus-of-a-single-mode}


#### Open-Loop Poles and Zeros {#open-loop-poles-and-zeros}


### Actuator and Sensor Dynamics {#actuator-and-sensor-dynamics}


### Decentralized Control with Collocated Pairs {#decentralized-control-with-collocated-pairs}


#### Cross talk {#cross-talk}


#### Force Actuator and Displacement Sensor {#force-actuator-and-displacement-sensor}


#### Displacement Actuator and Force Sensor {#displacement-actuator-and-force-sensor}


### Proof of Equation (7.18)–(7.32) {#proof-of-equation--7-dot-18----7-dot-32}


## Vibration Isolation {#vibration-isolation}


### Introduction {#introduction}


### Relaxation Isolator {#relaxation-isolator}


#### Electromagnetic Realization {#electromagnetic-realization}


### Active Isolation {#active-isolation}


#### Sky-Hook Damper {#sky-hook-damper}


#### Integral Force Feedback {#integral-force-feedback}


### Flexible Body {#flexible-body}


#### Free-Free Beam with Isolator {#free-free-beam-with-isolator}


### Payload Isolation in Spacecraft {#payload-isolation-in-spacecraft}


#### Interaction Isolator/Attitude Control {#interaction-isolator-attitude-control}


#### Gough–Stewart Platform {#gough-stewart-platform}


### Six-Axis Isolator {#six-axis-isolator}


#### Relaxation Isolator {#relaxation-isolator}


#### Integral Force Feedback {#integral-force-feedback}


#### Spherical Joints, Modal Spread {#spherical-joints-modal-spread}


### Active Versus Passive {#active-versus-passive}


### Car Suspension {#car-suspension}


## State Space Approach {#state-space-approach}


### Introduction {#introduction}


### State Space Description {#state-space-description}


#### Single Degree of Freedom Oscillator {#single-degree-of-freedom-oscillator}


#### Flexible Structure {#flexible-structure}


#### Inverted Pendulum {#inverted-pendulum}


### System Transfer Function {#system-transfer-function}


#### Poles and Zeros {#poles-and-zeros}


### Pole Placement by State Feedback {#pole-placement-by-state-feedback}


#### Example: Oscillator {#example-oscillator}


### Linear Quadratic Regulator {#linear-quadratic-regulator}


#### Symmetric Root Locus {#symmetric-root-locus}


#### Inverted Pendulum {#inverted-pendulum}


### Observer Design {#observer-design}


### Kalman Filter {#kalman-filter}


#### Inverted Pendulum {#inverted-pendulum}


### Reduced-Order Observer {#reduced-order-observer}


#### Oscillator {#oscillator}


#### Inverted Pendulum {#inverted-pendulum}


### Separation Principle {#separation-principle}


### Transfer Function of the Compensator {#transfer-function-of-the-compensator}


#### The Two-Mass Problem {#the-two-mass-problem}


## Analysis and Synthesis in the Frequency Domain {#analysis-and-synthesis-in-the-frequency-domain}


### Gain and Phase Margins {#gain-and-phase-margins}


### Nyquist Criterion {#nyquist-criterion}


#### Cauchy's Principle {#cauchy-s-principle}


#### Nyquist Stability Criterion {#nyquist-stability-criterion}


### Nichols Chart {#nichols-chart}


### Feedback Specification for SISO Systems {#feedback-specification-for-siso-systems}


#### Sensitivity {#sensitivity}


#### Tracking Error {#tracking-error}


#### Performance Specification {#performance-specification}


#### Unstructured Uncertainty {#unstructured-uncertainty}


#### Robust Performance and Robust Stability {#robust-performance-and-robust-stability}


### Bode Gain–Phase Relationships {#bode-gain-phase-relationships}


### The Bode Ideal Cutoff {#the-bode-ideal-cutoff}


### Non-minimum Phase Systems {#non-minimum-phase-systems}


### Usual Compensators {#usual-compensators}


#### System Type {#system-type}


#### Lead Compensator {#lead-compensator}


#### PI Compensator {#pi-compensator}


#### Lag Compensator {#lag-compensator}


#### PID Compensator {#pid-compensator}


### Multivariable Systems {#multivariable-systems}


#### Performance Specification {#performance-specification}


#### Small Gain Theorem {#small-gain-theorem}


#### Stability Robustness Tests {#stability-robustness-tests}


#### Residual Dynamics {#residual-dynamics}


## Optimal Control {#optimal-control}


### Introduction {#introduction}


### Quadratic Integral {#quadratic-integral}


### Deterministic LQR {#deterministic-lqr}


### Stochastic Response to a White Noise {#stochastic-response-to-a-white-noise}


#### Remark {#remark}


### Stochastic LQR {#stochastic-lqr}


### Asymptotic Behavior of the Closed Loop {#asymptotic-behavior-of-the-closed-loop}


### Prescribed Degree of Stability {#prescribed-degree-of-stability}


### Gain and Phase Margins of the LQR {#gain-and-phase-margins-of-the-lqr}


### Full State Observer {#full-state-observer}


#### Covariance of the Reconstruction Error {#covariance-of-the-reconstruction-error}


### Kalman Filter (KF) {#kalman-filter--kf}


### Linear Quadratic Gaussian (LQG) {#linear-quadratic-gaussian--lqg}


### Duality {#duality}


### Spillover {#spillover}


#### Spillover Reduction {#spillover-reduction}


### Loop Transfer Recovery (LTR) {#loop-transfer-recovery--ltr}


### Integral Control with State Feedback {#integral-control-with-state-feedback}


### Frequency Shaping {#frequency-shaping}

Weakness of LQG:

-   use frequency independant cost function
-   use noise statistics with uniform distribution

To overcome the weakness => frequency shaping either by:

-   considering a frequency dependant cost function
-   using colored noise statistics


#### Frequency-Shaped Cost Functionals {#frequency-shaped-cost-functionals}


#### Noise Model {#noise-model}


## Controllability and Observability {#controllability-and-observability}


### Introduction {#introduction}


#### Definitions {#definitions}


### Controllability and Observability Matrices {#controllability-and-observability-matrices}


### Examples {#examples}


#### Cart with Two Inverted Pendulums {#cart-with-two-inverted-pendulums}


#### Double Inverted Pendulum {#double-inverted-pendulum}


#### Two d.o.f. Oscillator {#two-d-dot-o-dot-f-dot-oscillator}


### State Transformation {#state-transformation}


#### Control Canonical Form {#control-canonical-form}


#### Left and Right Eigenvectors {#left-and-right-eigenvectors}


#### Diagonal Form {#diagonal-form}


### PBH Test {#pbh-test}


### Residues {#residues}


### Example {#example}


### Sensitivity {#sensitivity}


### Controllability and Observability Gramians {#controllability-and-observability-gramians}


### Internally Balanced Coordinates {#internally-balanced-coordinates}


### Model Reduction {#model-reduction}


#### Transfer Equivalent Realization {#transfer-equivalent-realization}


#### Internally Balanced Realization {#internally-balanced-realization}


#### Example {#example}


## Stability {#stability}


### Introduction {#introduction}


#### Phase Portrait {#phase-portrait}


### Linear Systems {#linear-systems}


#### Routh--Hurwitz Criterion {#routh-hurwitz-criterion}


### Lyapunov's Direct Method {#lyapunov-s-direct-method}


#### Introductory Example {#introductory-example}


#### Stability Theorem {#stability-theorem}


#### Asymptotic Stability Theorem {#asymptotic-stability-theorem}


#### Lasalle's Theorem {#lasalle-s-theorem}


#### Geometric Interpretation {#geometric-interpretation}


#### Instability Theorem {#instability-theorem}


### Lyapunov Functions for Linear Systems {#lyapunov-functions-for-linear-systems}


### Lyapunov's Indirect Method {#lyapunov-s-indirect-method}


### An Application to Controller Design {#an-application-to-controller-design}


### Energy Absorbing Controls {#energy-absorbing-controls}


## Applications {#applications}


### Digital Implementation {#digital-implementation}


#### Sampling, Aliasing, and Prefiltering {#sampling-aliasing-and-prefiltering}


#### Zero-Order Hold, Computational Delay {#zero-order-hold-computational-delay}


#### Quantization {#quantization}


#### Discretization of a Continuous Controller {#discretization-of-a-continuous-controller}


### Active Damping of a Truss Structure {#active-damping-of-a-truss-structure}


#### Actuator Placement {#actuator-placement}


#### Implementation, Experimental Results {#implementation-experimental-results}


### Active Damping Generic Interface {#active-damping-generic-interface}


#### Active Damping {#active-damping}


#### Experiment {#experiment}


#### Pointing and Position Control {#pointing-and-position-control}


### Active Damping of a Plate {#active-damping-of-a-plate}


#### Control Design {#control-design}


### Active Damping of a Stiff Beam {#active-damping-of-a-stiff-beam}


#### System Design {#system-design}


### The HAC/LAC Strategy {#the-hac-lac-strategy}

In active structures for precision engineering applications, the control system is used to reduce the effect of transient and steady-state disturbances on the controlled variables.
Active damping is very effective in reducing the settling time of transient disturbances and the effect of steady state disturbances near the resonance frequencies of the system; however, away from the resonances, the active damping is completely ineffective and leaves the closed-loop response essentially unchanged.
Such low-gain controllers are often called Low Authority Controllers (LAC), because they modify the poles of the system only slightly.

To attenuate wide-band disturbances, the controller needs larger gains, in order to cause more substantial modifications to the poles of the open-loop system; this is the reason why they are often called High Authority Controllers (HAC).
Their design requires a model of the structure, and there is usually a trade-off between the conflicting requirements of performance-bandwidth and stability in the face of parametric uncertainty and unmodelled dynamics.

When collocated actuator/sensor pairs can be used, stability can be achieved using positivity concepts, but in many situations, collocated pairs are not feasible for HAC.

The HAC/LAC approach consist of combining the two approached in a dual-loop control as shown in Figure [21](#orgca40454).
The inner loop uses a set of collocated actuator/sensor pairs for decentralized active damping with guaranteed stability ; the outer loop consists of a non-collocated HAC based on a model of the actively damped structure.
This approach has the following advantages:

-   The active damping extends outside the bandwidth of the HAC and reduces the settling time of the modes which are outsite the bandwidth
-   The active damping makes it easier to gain-stabilize the modes outside the bandwidth of the output loop (improved gain margin)
-   The larger damping of the modes within the controller bandwidth makes them more robust to the parmetric uncertainty (improved phase margin)

<a id="orgca40454"></a>

{{< figure src="/ox-hugo/preumont18_hac_lac_control.png" caption="Figure 21: Principle of the dual-loop HAC/LAC control" >}}


#### Wide-Band Position Control {#wide-band-position-control}


#### Compensator Design {#compensator-design}


#### Results {#results}


### Vibroacoustics: Volume Displacement Sensors {#vibroacoustics-volume-displacement-sensors}


#### QWSIS Sensor {#qwsis-sensor}


#### Discrete Array Sensor {#discrete-array-sensor}


#### Spatial Aliasing {#spatial-aliasing}


#### Distributed Sensor {#distributed-sensor}


## Tendon Control of Cable Structures {#tendon-control-of-cable-structures}


### Introduction {#introduction}


### Tendon Control of Strings and Cables {#tendon-control-of-strings-and-cables}


### Active Damping Strategy {#active-damping-strategy}


### Basic Experiment {#basic-experiment}


### Linear Theory of Decentralized Active Damping {#linear-theory-of-decentralized-active-damping}


### Guyed Truss Experiment {#guyed-truss-experiment}


### Microprecision Interferometer Testbed {#microprecision-interferometer-testbed}


### Free-Floating Truss Experiment {#free-floating-truss-experiment}


### Application to Cable-Stayed Bridges {#application-to-cable-stayed-bridges}


#### Laboratory Experiment {#laboratory-experiment}


#### Control of Parametric Resonance {#control-of-parametric-resonance}


#### Large Scale Experiment {#large-scale-experiment}


### Application to Suspension Bridges {#application-to-suspension-bridges}


#### Footbridge {#footbridge}


#### Laboratory Experiment {#laboratory-experiment}


## Active Control of Large Telescopes:  Adaptive Optics {#active-control-of-large-telescopes-adaptive-optics}


### Introduction {#introduction}


#### Wavefront Sensor {#wavefront-sensor}


#### Zernike Modes {#zernike-modes}


#### Fried Length, Seeing {#fried-length-seeing}


#### Kolmogorov Turbulence Model {#kolmogorov-turbulence-model}


#### Strehl Ratio {#strehl-ratio}


#### Power Spectral Density of the Zernike Modes {#power-spectral-density-of-the-zernike-modes}


### Deformable Mirror for Adaptive Optics {#deformable-mirror-for-adaptive-optics}


#### Stoney Formula {#stoney-formula}


#### Stroke Versus Natural Frequency {#stroke-versus-natural-frequency}


### Feedback Control of an AO Mirror {#feedback-control-of-an-ao-mirror}


#### Quasi-static Control {#quasi-static-control}


#### Control of the Mirror Based on the Jacobian {#control-of-the-mirror-based-on-the-jacobian}


#### Control of Zernike Modes {#control-of-zernike-modes}


### Dynamic Response of the AO Mirror {#dynamic-response-of-the-ao-mirror}


#### Dynamic Model of the Mirror {#dynamic-model-of-the-mirror}


#### Control-Structure Interaction {#control-structure-interaction}


#### Passive Damping {#passive-damping}


#### Active Damping {#active-damping}


### Miscellaneous {#miscellaneous}


#### Segmented AO Mirror {#segmented-ao-mirror}


#### Initial Curvature of the AO Mirror {#initial-curvature-of-the-ao-mirror}


## Active Control of Large Telescopes: Active Optics {#active-control-of-large-telescopes-active-optics}


### Introduction {#introduction}


### Monolithic Primary Mirror {#monolithic-primary-mirror}


### Segmented Primary Mirror {#segmented-primary-mirror}


### SVD Controller {#svd-controller}


#### Loop Shaping of the SVD Controller {#loop-shaping-of-the-svd-controller}


### Dynamics of a Segmented Mirror {#dynamics-of-a-segmented-mirror}


### Control-Structure Interaction {#control-structure-interaction}


#### SISO System {#siso-system}


#### MIMO System {#mimo-system}


#### Spillover Alleviation {#spillover-alleviation}


### Scaling Rules {#scaling-rules}


#### Static Deflection Under Gravity {#static-deflection-under-gravity}


#### First Resonance Frequency {#first-resonance-frequency}


#### Control Bandwidth {#control-bandwidth}


## Adaptive Thin Shell Space Reflectors {#adaptive-thin-shell-space-reflectors}


### Introduction {#introduction}


### Adaptive Plates Versus Adaptive Shells {#adaptive-plates-versus-adaptive-shells}


### Adaptive Spherical Shell {#adaptive-spherical-shell}


### Quasi-static Control: Hierarchical Approach {#quasi-static-control-hierarchical-approach}


### Petal Configuration {#petal-configuration}


### MATS Demonstrator {#mats-demonstrator}


#### Manufacturing of the Demonstrator {#manufacturing-of-the-demonstrator}


## Semi-active Control {#semi-active-control}


### Introduction {#introduction}


### Magneto-Rheological Fluids {#magneto-rheological-fluids}


### MR Devices {#mr-devices}


### Semi-active Suspension {#semi-active-suspension}


#### Semi-active Devices {#semi-active-devices}


### Narrow-Band Disturbance {#narrow-band-disturbance}


#### Quarter-Car Semi-active Suspension {#quarter-car-semi-active-suspension}


### Problems {#problems}



## Bibliography {#bibliography}

<a id="org29acb4a"></a>Preumont, Andre. 2018. _Vibration Control of Active Structures - Fourth Edition_. Solid Mechanics and Its Applications. Springer International Publishing. <https://doi.org/10.1007/978-3-319-72296-2>.
