+++
title = "Machine dynamics in mechatronic systems: an engineering approach."
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Finite Element Model]({{< relref "finite_element_model" >}})

Reference
: ([Rankers 1998](#org98ff031))

Author(s)
: Rankers, A. M.

Year
: 1998


## Summary {#summary}

Despite the fact, that mechanical vibrations in a servo device can be very complex and often involve the motion of many components of the system, there are three fundamental mechanisms that are often observed.
These there basic dynamic phenomena can be indicated by:

-   _Actuator flexibility_: the mechanical system does not behave as one rigid body, due to flexibility between the location at which the servo force is applied and the actual point that needs to be positioned
-   _Guiding system flexibility_: the device usually rely on the guiding system to suppress motion in an undesired direction
-   _Limited mass and stiffness of the stationary machine part_: the reaction force that comes with the driving force will introduce a motion of the "stationary" part of the mechanical system

Whereas the first two phenomena mainly affect the stability of the control loop, the last phenomena manifests itself more often as a dynamic positional error in the set-point response.

A tool that can be very useful in understanding the nature of more complex resonance phenomena and the underlying motion of the mechanical system, is "Modal Analysis".
Translating the mathematics of one single decoupled "modal" equation into a graphical representation, which includes all relevant data such as (effective) modal mass and stiffness plus the motion of each physical DoF, facilitates a better understanding of the modal concept.
It enables a very intuitive link between the modal and the physical domain, and thus leads to a more creative use of "modal analysis" without the complications of the mathematical formalism.

Dynamic phenomena of the mechanics in a servo positioning device can lead to stability problems of the control loop.
Therefore it is important to investigate the frequency response (\\(x/F\\)), which characterizes the dynamics of the mechanical system, and especially the influence of mechanical resonances on it.
Once the behavior of one individual mode is fully understood it is not so difficult to construct this frequency response and the interaction between the rigid-body motion of the device, and the dynamics of one additional mode.
This leads to four interaction patterns:

-   -2 slope / zero / pole / -2 slope
-   -2 slope / pole / zero / -2 slope
-   -2 slope / pole / -4 slope
-   -2 slope / pole / -2 slope (non-minimum phase and rarely occurring)

It is not possible to judge the potential destabilizing effect of each of the typical characteristics without considering the frequency of the resonance in relation to the envisaged bandwidth of the control loop.
The phase plot of a typical open loop frequency response of a PID controlled positioning device without mechanical resonances can be divided into three frequency ranges:

-   at low frequencies, the phase lies below -180 deg due to integrator action of the controller
-   at medium frequency (centered by the bandwidth frequency), the phase lies above -180 deg due to the differential action of the controller, which is necessary in order to achieve a stable position control-loop
-   at high frequencies, the phase eventually drops again below -180 deg due to additional low-pass filtering

The potential destabilizing effect of each of the three typical characteristics can be judged in relation to the frequency range.
Whether instability occurs depends very strongly on the resonance amplitude and damping of the additional mode.

-   A -2 slope / zero / pole / -2 slope characteristics leads to a phase lead and is therefore potentially destabilizing in the low-frequency and high frequency regions.
    In the medium frequency region it adds an extra phase leads to the already existing margin, which does not harm the stability.
-   A -2 slope / pole / zero / -2 slope combination has the reverse effect.
    It is potentially destabilizing in the medium-frequency range and is harmless in the low and high frequency ranges.
-   The -2 slope / poles / -4 slope behavior always has a devastating effect on the stability of the loop if located in the low or medium frequency range.

On the basis of these considerations, it is possible to give design guidelines for servo positioning devices.

The subject of machine dynamics and its interaction with the control system plays a dominant role in fast and accurate positioning devices, so it is vital to consider these issues during the entire design process.
Modeling and simulation can be adequate tools for that purpose; however, two conditions are crucial to the success:

-   usefulness of results
-   speed

The analysis process has usually a top-down structure.
Starting with very elementary simulation models to support the selection of the proper concept, these models should become more refined, just like the product or machine under development.

In various project throughout the past years, a three-step modeling approach has evolved, in which the following phases can be distinguished:

-   concept analysis
-   system analysis
-   component analysis

In the _concept analysis_ the viability of various concepts is evaluated on the basis of very simple models consisting of a limited number of lumped masses connected by springs.
Once a concept has been chosen and the first rough 3D sketches become available, a _system analysis_ can be done, based on a limited number of 3D rigid components connected by springs.
In this phase a lot of important spatial information is added to the model (such as the location of the center of gravity and connecting stiffnessses, plus the location of the driving force and of the sensors).
Finally, in the _component analysis_ phase critical components are no longer considered rigid, and their internal dynamics are evaluated via FE modeling.
In cases in which a separate analysis of a critical component is considered insufficient to judge its influence on the overall dynamics, a detailed FE-based description can be used to replace the former rigid description in the system model.

In case many parts of the system need to be modeled in great detail, it is not very practical (error-prone, huge model size, time consuming) to build on, single, huge FE model of the entire system.
A technique that overcomes these disadvantages is the so-called "sub-structuring technique".
In this approach the system is divided into substructures or components, which are analyzed separately.
Then, after application of a reduction technique which preserves the most dominant dynamic properties, the (reduced) models of the components are assemble to form the overall system.
By doing so, the size of the final system model is reduced significantly.


## Introduction {#introduction}


### General {#general}

In the development of servo-controlled positioning devices, it is essential to consider the effect of the dynamics of the mechanical system on the performance of th overall, because the following effects can be observed:

-   mechanical resonances can endanger the stability of the control loop
-   vibration of the mechanical system, which are cause by the servo forces during a prescribed motion, can lead to positional errors

To obtain a well-balanced design with respect to the effort in the mechanical design and the control design, one has to adapt a mechatronics approach in which the structural design and the control design are integrated.
Integrated modelling and simulation of structural and control aspects should be part of the product-creation process of any mechatronic positioning device from the very beginning.
Such an approach is the only way the enhance the score of success and achieve "first-time-right".


### State of the Art {#state-of-the-art}

In general, the modelling of certain phenomena that take place in a machine can be divided into two major steps:

1.  From reality/design to a physical model
2.  From the physical model to a mathematical model

In the first step, the real structure of design drawing of a structure needs to be translated into a physical model, which is a simplification of the reality that contains all relations considered to be important to describe the phenomenon.
Once this physical model has been derived, the second step consists of translating this physical model into a mathematical model which is usually straightforward using adapted software.

The following questions are only seldom addressed:

-   which analysis must be carried out
-   how should the results be interpreted
-   what sort of physical model gives a reasonable balance between accuracy and required effort

There is a huge gap between available theory about modal analysis and engineering practice which is also true for the field of control theory.
The integration of machine dynamics and control system design is also limited.
The two topics are generally taught by different departments.
Machine dynamics is an issue addressed by the mechanical engineer, whereas the control system is designed by the electrical engineer.

<div class="important">
  <div></div>

The lack of integral knowledge of machine dynamics, control and the interaction between these two topics is a serious threshold in finding the optimal solution to a mechatronic design problem.

</div>


### Scope and Purpose {#scope-and-purpose}

This thesis aims at bridging the gap between existing theoretical knowledge in the field of machine dynamics and control, and the practical application of this knowledge during the design of a product or machine.

The idea is to show that a basic understanding of machine dynamics suffices to interpret complex mechanical vibrations.
Moreover, in combination with basic control theory it is possible to derive the typical patterns that can be observed in an open-loop frequency response of a mechanical servo-system including resonances, and to draw conclusions with respect to the effect of these resonances on the stability of the control loop.
Based on the idea that the controlled system must satisfy certain disturbance rejection and bandwidth criteria, design guidelines can be given for the mechanical system such that the chance of realizing the required bandwidth without introduction stability problems is maximized.
By using a step-wise modelling approach it is possible to investigate and predict these phenomena during the design phase, and to make design decisions which take the dynamics and control aspects into account.


### Preview {#preview}

<div class="question">
  <div></div>

The basic questions that are addressed in this thesis are:

-   What sort of dynamic effects are important in mechatronic devices?
-   How can the dynamics of a complex system be described and understood?
-   What is the influence of mechanical resonances on the stability of a control loop?
-   Which design rules can be given to minimize the destabilizing effect of machine dynamics?
-   How can one predict the machine dynamics in an industrial way, such that simulation and modelling is experienced as an effective design tool?

</div>


## Mechanical Servo Systems {#mechanical-servo-systems}


### Basic Control Aspects {#basic-control-aspects}

A block diagram representation of a typical servo-system is shown in Figure [1](#orgfda2012).
The main task of the system is achieve a desired positional relation between two or more components of the system.
Therefore, a sensor measures the position which is then compared to the desired value, and the resulting error is used to generate correcting forces.
In most systems, the "actual output" (e.g. position of end-effector) cannot be measured directly, and the feedback will therefore be based on a "measured output" (e.g. encoder signal at the motor).
It is important to realize that these two outputs can differ, first due to resilience in the mechanical system, and second because of geometrical imperfections in the mechanical transmission between motor and end-effector.

<a id="orgfda2012"></a>

{{< figure src="/ox-hugo/rankers98_basic_el_mech_servo.png" caption="Figure 1: Basic elements of mechanical servo system" >}}

The basic ingredient of most feedback control-systems is a PID controller, which is a combination of a proportional gain \\(P\\), and integral control \\(I\\) to enhance steady state behavior, and a derivative action \\(D\\) to improve damping and stability.
The correction force \\(F\\) is defined by:

\begin{equation}
F = k\_p \epsilon + k\_d \dot{\epsilon} + k\_i \int \epsilon dt
\end{equation}

It is illustrative to see that basically the proportional and derivative part of such a position control loop is very similar to a mechanical spring and damper that connect two points (Figure [2](#org2d694a7)).
If \\(c\\) and \\(d\\) represent the constant mechanical stiffness and damping between points \\(A\\) and \\(B\\), and a reference position profile \\(h(t)\\) is applied at \\(A\\), then an opposing force \\(F\\) is generated as soon as the position \\(x\\) and speed \\(\dot{x}\\) of point \\(B\\) does not correspond to \\(h(t)\\) and \\(\dot{h}(t)\\).

<a id="org2d694a7"></a>

{{< figure src="/ox-hugo/rankers98_basic_elastic_struct.png" caption="Figure 2: Basic Elastic Structure" >}}

The resulting spring/damper force is equal to:

\begin{equation}
F = c (h(t) - x) + d(\dot{h}(t) - \dot{x})
\end{equation}

Thus, in this example a PD position-control loop can be treated in the same way as a mechanical system with a spring \\(c = k\_p\\) and damper \\(d = k\_d\\).
The most important difference is the fact that a mechanical spring/damper is a _passive_ element, whereas firstly a control loop is an _active_ element, and secondly the servo forces that are applied between points \\(A\\) and \\(B\\) can be based on a measurement at a different location.
These properties are very essential since they introduce the issue of **servo stability**, which can be seriously endangered by mechanical resonances.

An important aspect of a feedback controller is the fact that control forces can only result from an error signal.
Thus any desired set-point profile first leads to a position error before the corresponding driving forces are generated.
Most modern servo-systems have not only a feedback section, but also a feedforward section, as indicated in Figure [3](#org0c46a44).

<a id="org0c46a44"></a>

{{< figure src="/ox-hugo/rankers98_feedforward_example.png" caption="Figure 3: Mechanical servo system with feedback and feedforward control" >}}

In the feedforward section, control signals are derived from the desired output (position, speed and acceleration) using a model of the mechanical servo-system.
In practice, a feedforward section gives a significant performance improvement in case of point-to-point and tacking applications, but a feedback section will always be necessary.
First, because the model used in the calculation of the feedforward signal is not a perfect representation of the actual system and second because of the presence of unknown disturbances.

Practicing engineers generally accomplish the feedback design and analysis on the basis of the frequency response.
One of the major benefits of this approach is the close link to experimental information that can be obtained by exciting the system with sinusoidal inputs and varying frequency and measuring the amplitude and phase of the output.
Such frequency response can either be plotted using a Bode diagram of a Nyquist diagram.

An engineering approach to stability evaluation is the so-called "Left Hand Rule", which reads:

> If a system contains only stable elements in the open loop, then the closed loop system is stable if the point \\((-1,0)\\) in the Nyquist diagram lies on the left hand side of the open loop response when it is run through in the direction of increasing frequency.

In order to quantify the level of stability, two criteria have been introduced: gain and phase margin which measure how close the open loop response approaches the point \\((-1,0)\\) in the Nyquist diagram.


### Specifications {#specifications}

Specification of a feedback controller is very closely linked to disturbance rejection, especially in modern controllers that incorporate a feedforward section.
The required performance of the feedback section, which is generally expressed in terms of bandwidth, depends very much on the disturbances that act on the system.

These disturbances can be very different, and vary from application to application:

-   Random floor vibration
-   Imperfections of the guiding systems
-   Harmonic excitation forces due to the presence of pumps or ventilators
-   Acoustic excitation


### Interaction Dynamics and Control {#interaction-dynamics-and-control}

Basically, machine dynamics can have two deterioration effects in mechanical servo systems:

-   Mechanical resonances can endanger servo stability, and thus limit the bandwidth and the amount of disturbance rejection.
-   Vibrations can lead to positional errors at the end of a set-point motion, or during a tracking motion.


### Three Important Dynamic Effects {#three-important-dynamic-effects}


#### Actuator Flexibility {#actuator-flexibility}

The basic characteristics of what is called "actuator flexibility" is the fact that in the frequency range of interest (usually \\(0-10\times \text{bandwidth}\\)) the driven system no longer behaves as one rigid body (Figure [4](#org765d5f4)) due to compliance between the motor and the load.

<a id="org765d5f4"></a>

{{< figure src="/ox-hugo/rankers98_actuator_flexibility.png" caption="Figure 4: Actuator Flexibility" >}}


#### Guiding System Flexibility {#guiding-system-flexibility}

The second category of dynamic phenomena results from the limited stiffness of the guiding system in combination with the fact the the device is driven in such a way that it has to rely on the guiding system to suppress motion in an undesired direction (in case of a linear direct drive system this occurs if the driving force is not applied at the center of gravity).

In general, a rigid actuator possesses six degrees of freedom, five of which need to be suppressed by the guiding system in order to leave one mobile degree of freedom.
In the present discussion, a planar actuator with three degrees of freedom will be considered (Figure [5](#org387cdc7)).

<a id="org387cdc7"></a>

{{< figure src="/ox-hugo/rankers98_guiding_flexibility_planar.png" caption="Figure 5: Planar actuator with guiding system flexibility" >}}

The carriage is free to move in the guiding direction \\(x\\), whereas the perpendicular displacement \\(y\\) and the rotation \\(\phi\\) is prevented via two fixtures with limited stiffness \\(c\\).
The limited support stiffness and the inertia properties of the actuator will result in two resonances, which can be characterized as perpendicular mode and rocking mode.

Every actuator as some sort of guiding system in order to suppress certain DoF, and thus possesses guiding modes.
However, whether this leads to dynamic problems depends very much on the location of the driving force and the sensor.
By choosing the proper location of the driving force one can avoid excitation of these modes, whereas the location of the sensor influences the effect of such a mode on the servo stability where excitation of the mode could not be avoided.

In general, it should be attempted to design the actuator (mass distribution and location of driving force) such that it will perform the desired motion even in the absence of the guiding system.


#### Limited Mass and Stiffness of Stationary Machine Part {#limited-mass-and-stiffness-of-stationary-machine-part}

The last category of dynamic phenomena results from the limited mass and stiffness of the stationary part of a mechanical servo-system.
In contrast to many textbooks on mechanics and machine dynamics, it is good practice always to look at the combination of driving force on the moving part, and reaction force on the stationary part, of a positioning device.
When doing so, one has to consider what the effect of the reaction force on the systems performance will be.
In the discussion of the previous two dynamic phenomena, the stationary part of the machine was assumed to be infinitely stiff and heavy, and therefore the effect of the reaction force was negligible.
However, in general the stationary part is neither infinitely heavy, nor is it connected to its environment with infinite stiffness, so the stationary part will exhibit a resonance that is excited by the reaction forces (Figure [6](#orgb3f73d2)).

<a id="orgb3f73d2"></a>

{{< figure src="/ox-hugo/rankers98_limited_m_k_stationary_machine_part.png" caption="Figure 6: Limited Mass and Stiffness of Stationary Machine Part" >}}


## [Modal Decomposition]({{< relref "modal_decomposition" >}}) {#modal-decomposition--modal-decomposition-dot-md}


### Mathematics of Modal Decomposition {#mathematics-of-modal-decomposition}

The general equation of motion of a linear mechanical system with a finite number of DoF, and without damping is:

\begin{equation}
M \ddot{x}(t) + K x(t) = f(t)
\end{equation}

in which \\(M\\) and \\(K\\) stand for the symmetric semi-positive definite mass and stiffness matrix, \\(x(t)\\) and \\(\ddot{x}(t)\\) represent the displacement and acceleration vectors, and \\(f(t)\\) denotes the vector of forces.

Generally this system of equations is coupled but it can always be decoupled by using a transformation based on the non-trivial solutions (the eigenvectors) of the following eigenvalue problem:

\begin{equation}
(K + \omega\_i^2 M) \phi\_i = 0
\end{equation}

Solving the eigenvalue problem gives the eigenvalues \\(\omega\_1^2, \omega\_2^2, \dots, \omega\_n^2\\) and the corresponding eigenvectors or mode-shape vectors \\(\phi\_1, \phi\_2, \dots, \phi\_n\\).

These eigenvectors have the following orthogonality properties, or can always be chosen such that:

\begin{equation} \label{eq:eigenvector\_orthogonality\_mass}
\phi\_i^T M \phi\_j = 0 \quad (i \neq j)
\end{equation}

For \\(i=j\\) the result of the multiplication according to equation \eqref{eq:eigenvector_orthogonality_mass} yields a non-zero result, which is normally indicated as modal mass \\(\mathit{m}\_i\\):

\begin{equation} \label{eq:modal\_mass}
\phi\_i^T M \phi\_i = \mathit{m}\_i
\end{equation}

Because only the direction but not the length of an eigenvector is defined, several scaling methods are used, all based on equation \eqref{eq:modal_mass}:

-   \\(|\phi\_i| = 1\\):: Each eigenvector \\(\phi\_i\\) is scaled such that its length is equal to \\(1\\). The modal mass are then calculated from equation \eqref{eq:modal_mass}.
-   \\(\max(\phi\_i) = 1\\):: Each eigenvector \\(\phi\_i\\) is scaled such that its largest element is equation to \\(1\\). The modal mass is then calculated from equation \eqref{eq:modal_mass}.
-   \\(m\_i = 1\\):: The modal mass \\(\mathit{m}\_i\\) is set to \\(1\\). The scaling of the mode vector \\(\phi\_i\\) follows from equation \eqref{eq:modal_mass}.

The orthogonality properties also apply to the stiffness matrix \\(K\\):

\begin{align}
\phi\_i^T K \phi\_j &= 0 \quad (i \neq j) \\\\\\
\phi\_i^T K \phi\_i &= \omega\_i^2 \mathit{m}\_i = \mathit{k}\_i
\end{align}

Because the \\(n\\) eigenvectors \\(\phi\_i\\) form a base in the n-dimensional space, any displacement vector \\(x(t)\\) can be written as a linear combination of the eigenvectors.
Let \\(q\_i(t)\\) be the response of the decopled mode \\(i\\), then the resulting displacement vector \\(x(t)\\) will be:

\begin{equation}
x(t) = q\_1(t) \phi\_1 + q\_2(t) \phi\_2 + \dots + q\_n(t) \phi\_n
\end{equation}

For one individual physical DoF \\(x\_k\\):

\begin{equation}
x(t) = q\_1(t) \phi\_{1k} + q\_2(t) \phi\_{2k} + \dots + q\_n(t) \phi\_{nk}
\end{equation}

with \\(\phi\_{ik}\\) being the element of the mode-shape vector \\(\phi\_i\\) that corresponds to the physical DoF \\(x\_k\\).

The physical interpretation of the above two equations is that any motion of the system can be regarded as a combination of the contribution of the various modes.

On can combine the eigenvectors in a matrix \\(\Phi\\) and the coefficients \\(q\_i\\) in a vector \\(q(t)\\) which leads to:

\begin{equation}
x(t) = \Phi q(t)
\end{equation}

With:

\begin{align\*}
 \Phi &= \begin{bmatrix} \phi\_1 & \phi\_2 & \dots & \phi\_n \end{bmatrix} \\\\\\
 q(t) &= \begin{bmatrix} q\_1(t) \\ q\_2(t) \\ \vdots \\ q\_n(t) \end{bmatrix}
\end{align\*}

Substitution of \\(x(t) = \Phi q(t)\\) into the original equation of motion and premultiplication with \\(\Phi^T\\) results in:

\begin{equation}
\Phi^T M \Phi \ddot{q}(t) + \Phi^T K \Phi q(t) = \Phi^T f(t)
\end{equation}

Which finally leads to a set of **uncoupled** equations of motion that describe the contribution of each mode:

\begin{equation}
\begin{bmatrix}
m\_1 & & & \\\\\\
& m\_2 & & \\\\\\
& & \ddots & \\\\\\
& & & m\_n
\end{bmatrix} \begin{bmatrix}
\ddot{q}\_1 \\ \ddot{q}\_2 \\ \vdots \\ \ddot{q}\_n
\end{bmatrix} + \begin{bmatrix}
k\_1 & & & \\\\\\
& k\_2 & & \\\\\\
& & \ddots & \\\\\\
& & & k\_n
\end{bmatrix} \begin{bmatrix}
q\_1 \\ q\_2 \\ \vdots \\ q\_n
\end{bmatrix} = \begin{bmatrix}
\phi\_1^T f \\ \phi\_2^T f \\ \vdots \\ \phi\_n^T f
\end{bmatrix}
\end{equation}

For the i-th modal coordinate \\(q\_i\\) the equation of motion is:

\begin{equation} \label{eq:eoq\_modal\_i}
m\_i \ddot{q\_i}(t) + k\_i q\_i(t) = \phi\_i^T f(t)
\end{equation}

which is a simple second order differential equation similar to that of a single mass spring system.
Using basic formulae that are derived for a simple mass spring system, one is now able to analyse the time and frequency response of all individual modes.
Having done that, the total motion of the system can simply be obtained by summing the contributions of all modes.

Characterisation of the dynamics of a mechanical system in terms of frequency response behavior plays a major role in the stability analysis of the control loop of a mechatronic device.
In such an analysis one is typically interested in the transfer function between a measured displacement \\(x\_l\\) and a force \\(f\_k\\), which acts at the physical DoF \\(x\_k\\).
Applying the principle of modal decomposition, any transfer function can be derived by first calculating the behavior of the individual modes, and then summing all modal contributions.

The contribution of one single mode \\(i\\) to the transfer function \\(x\_l/f\_k\\) can be derived by first considering the response of the modal DoF \\(q\_i\\) to a force vector \\(f\\) with only one non-zero component \\(f\_k\\).
In that case, equation \eqref{eq:eoq_modal_i} is reduced to:

\begin{equation}
m\_i \ddot{q}\_i(t) + k\_i q\_i(t) = \phi\_{ik} f\_k(t)
\end{equation}

After a Laplace transformation and some rearrangement:

\begin{equation}
q\_i(s) = f\_k(s) \frac{\phi\_{ik}}{m\_i s^2 + k\_i}
\end{equation}

Once the modal response \\(q\_i\\) is known, the response of the physical DoF \\(x\_l\\) is found by a simple premultiplication with \\(\phi\_{il}\\), which finally leads to the following expression for the contribution of mode \\(i\\) to the transfer function:

\begin{equation}
\left( \frac{x\_l}{f\_k} \right)\_i = \frac{\phi\_{ik}\phi\_{il}}{m\_i s^2 + k\_i}
\end{equation}

The overall transfer function can be found by summation of the individual modal contributions, which all have the same structure:

\begin{equation}
\left( \frac{x\_l}{f\_k} \right) = \sum\_{i = 1}^n \left( \frac{x\_l}{f\_k} \right)\_i = \sum\_{i = 1}^n \frac{\phi\_{ik} \phi\_{il}}{m\_i s^2 + k\_i}
\end{equation}


### Graphical Representation {#graphical-representation}


### Physical Meaning of Modal Parameters {#physical-meaning-of-modal-parameters}


### A Pragmatic View on Sensitivity Analysis {#a-pragmatic-view-on-sensitivity-analysis}


### Modal Superposition {#modal-superposition}


### Suspension Modes {#suspension-modes}


## Modes and Servo Stability {#modes-and-servo-stability}


### Basic Characteristics of Mechanical FRF {#basic-characteristics-of-mechanical-frf}

Consider the position control loop of Figure [7](#orgeee8a5d).

<a id="orgeee8a5d"></a>

{{< figure src="/ox-hugo/rankers98_mechanical_servo_system.png" caption="Figure 7: Mechanical position servo-system" >}}

In the ideal situation the mechanical system behaves as one rigid body with mass \\(m\\), so the mechanical transfer function can be written as:

\begin{equation}
\frac{x\_{\text{servo}}}{F\_{\text{servo}}} = \frac{1}{m s^2}
\end{equation}

<a id="org2ffb1b1"></a>

{{< figure src="/ox-hugo/rankers98_ideal_bode_nyquist.png" caption="Figure 8: FRF of an ideal system with no resonances" >}}

In the case of one extra modal contribution, the equation for the mechanical transfer function needs to be extended with one extra term:

\begin{equation} \label{eq:effect\_one\_mode}
\frac{x\_{\text{servo}}}{F\_{\text{servo}}} = \frac{1}{m s^2} + \frac{\phi\_{i,\text{servo}} \phi\_{i,\text{force}}}{m\_i s^2 + k\_i} = \frac{1}{m s^2} + \frac{\phi\_{i,\text{servo}} \phi\_{i,\text{force}}}{m\_i s^2 + m\_i \omega\_i^2}
\end{equation}

The final transfer function and the exact interaction between the two parts depends on the values of the various parameters.

Let's introduce a variable \\(\alpha\\), which relates the high-frequency contribution of the mode to that of the rigid-body motion:

\begin{equation} \label{eq:alpha}
\alpha = \frac{\frac{\phi\_{i,\text{servo}} \phi\_{i,\text{force}}}{m\_i}}{\frac{1}{m}}
\end{equation}

which simplifies equation \eqref{eq:effect_one_mode} to:

\begin{equation}
\frac{x\_{\text{servo}}}{F\_{\text{servo}}} = \frac{1}{ms^2} + \frac{\alpha}{m s^2 + m \omega\_i^2}
\end{equation}

<a id="orgc9ecb0c"></a>

{{< figure src="/ox-hugo/rankers98_frf_effect_alpha.png" caption="Figure 9: Contribution of rigid-body motion and modal dynamics to the amplitude and phase of FRF for various values of \\(\alpha\\)" >}}

<a id="org5180ee3"></a>

{{< figure src="/ox-hugo/rankers98_final_frf_alpha.png" caption="Figure 10: Bode diagram of final FRF (\\(x\_{\text{servo}}/F\_{\text{servo}}\\)) for six values of \\(\alpha\\)" >}}


#### FRF with "-2 slope/zero/pole/-2 slope" behavior {#frf-with-2-slope-zero-pole-2-slope-behavior}


#### FRF with "-2 slope/pole/zero/-2 slope" behavior {#frf-with-2-slope-pole-zero-2-slope-behavior}


#### FRF with "-2 slope/pole/-4 slope" behavior {#frf-with-2-slope-pole-4-slope-behavior}


#### FRF with "-2 slope/pole/-2 slope" behavior {#frf-with-2-slope-pole-2-slope-behavior}


### Destabilising Effect of Modes {#destabilising-effect-of-modes}


### Design for Stability {#design-for-stability}


## Predictive Modelling {#predictive-modelling}


### Steps in a Modelling Activity {#steps-in-a-modelling-activity}


### Step-wise Refined Modelling {#step-wise-refined-modelling}


### Practical Modelling Issues {#practical-modelling-issues}


## Conclusions {#conclusions}

Machine dynamics, and the interaction with the control system, plays a dominant role in the performance of fast and accurate servo-controlled positioning devices such as compact disc, wafer-steppers, and component-mounters.

"Modal analysis" is a numerical and experimental tool that can be very profitable in understanding the nature of complicated mechanical resonances.
The mathematics of a single decoupled "modal" equation of motion can be translated into a graphical representation including all relevant data, which simplifies the understanding and creative use of the modal concept.
The introduction of the terms "effective" modal mass and stiffnesses enables a unique link between the modal and the physical domain.

From a servo stability point of view it is essential to investigate the mechanical FRF (\\(x/F\\)) which characterizes the dynamic properties of the mechanical system.
Once the dynamics of the one individual mode is fully understood it is straightforward to construct this FRF and the interaction between the desired rigid body motion and the contribution of one additional mode.
A closer investigation of this interaction reveals that only four interaction patterns exists.
The destabilizing effect of a mechanical resonance depends not only on the resulting typical interaction pattern in the FRF, but also on its frequency in relation to the intended bandwidth frequency of the control loop.
On the basis of these stability considerations, design guidelines for the mechanics of a servo positioning devices are derived, so as to minimize the effect of mechanical vibrations on the stability of the controlled system.

In view of its importance to the overall performance, the effect of machine dynamics should be monitored during the entire design process through the use of modelling and simulation techniques.
However, it is vital for the success of modelling and simulation as a tool to support design decisions, that analysis data are translated into useful information, and that this information is available on time.
This requires a proper balance between accuracy and speed that can best be achieved by a top-down analysis process, which is closely linked to the phases in the design process, and in which the simulation models are step-wise refined.

When many parts of the mechanical system need to be modelled in great detail it is not  to build one, single, huge FE model but rather to apply a so-called "sub-structuring" techniques.
The Craig-Bampton approach, which is a component mode technique based on a combination of all boundary constraint modes plus a limited number of fixed interface normal modes, was found to be favorable.
It has static solution capacity, and the frequency of the highest fixed-interface normal mode gives a good indication of the frequency range up to which the overall system results are valid.

Through the enormous performance drive in mechatronics systems, much has been learned in the past years about the influence of machine dynamics in servo positioning-devices.


## Bibliography {#bibliography}

<a id="org98ff031"></a>Rankers, Adrian Mathias. 1998. “Machine Dynamics in Mechatronic Systems: An Engineering Approach.” University of Twente.
