+++
title = "Analog to Digital Converters"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Electronics]({{< relref "electronics" >}})


## Types of Analog to Digital Converters {#types-of-analog-to-digital-converters}

<https://dewesoft.com/daq/types-of-adc-converters>

-   Delta Sigma ([Baker 2011](#orgb22f10b))
-   Successive Approximation


## Power Spectral Density of the Quantization Noise {#power-spectral-density-of-the-quantization-noise}

This analysis is taken from [here](https://www.allaboutcircuits.com/technical-articles/quantization-nois-amplitude-quantization-error-analog-to-digital-converters/).

Let's note:

-   \\(q = \frac{\Delta V}{2^n}\\) the quantization in [V], which is the corresponding value in [V] of the least significant bit
-   \\(\Delta V\\) is the full range of the ADC in [V]
-   \\(n\\) is the number of ADC's bits
-   \\(f\_s\\) is the sample frequency in [Hz]

Let's suppose that the ADC is ideal and the only noise comes from the quantization error.
Interestingly, the noise amplitude is uniformly distributed.

The quantization noise can take a value between \\(\pm q/2\\), and the probability density function is constant in this range (i.e., it’s a uniform distribution).
Since the integral of the probability density function is equal to one, its value will be \\(1/q\\) for \\(-q/2 < e < q/2\\) (Fig. [1](#org57805de)).

<a id="org57805de"></a>

{{< figure src="/ox-hugo/probability_density_function_adc.png" caption="Figure 1: Probability density function \\(p(e)\\) of the ADC error \\(e\\)" >}}

Now, we can calculate the time average power of the quantization noise as

\begin{equation}
  P\_q = \int\_{-q/2}^{q/2} e^2 p(e) de = \frac{q^2}{12}
\end{equation}

The other important parameter of a noise source is the power spectral density (PSD), which indicates how the noise power spreads in different frequency bands.
To find the power spectral density, we need to calculate the Fourier transform of the autocorrelation function of the noise.

Assuming that the noise samples are not correlated with one another, we can approximate the autocorrelation function with a delta function in the time domain.
Since the Fourier transform of a delta function is equal to one, the **power spectral density will be frequency independent**.
Therefore, the quantization noise is white noise with total power equal to \\(P\_q = \frac{q^2}{12}\\).

Thus, the two-sided PSD (from \\(\frac{-f\_s}{2}\\) to \\(\frac{f\_s}{2}\\)), we should divide the noise power \\(P\_q\\) by \\(f\_s\\):

\begin{equation}
  \int\_{-f\_s/2}^{f\_s/2} \Gamma(f) d f = f\_s \Gamma = \frac{q^2}{12}
\end{equation}

<div class="important">
  <div></div>

Finally, the Power Spectral Density of the quantization noise of an ADC is equal to:

\begin{equation}
  \begin{aligned}
    \Gamma &= \frac{q^2}{12 f\_s} \\\\\\
          &= \frac{\left(\frac{\Delta V}{2^n}\right)^2}{12 f\_s} \text{ in } \left[ \frac{V^2}{Hz} \right]
  \end{aligned}
\end{equation}

</div>

<div class="exampl">
  <div></div>

Let's take a 18bits ADC with a range of +/-10V and a sample frequency of 10kHz.

The quantization is:
\\[ q = \frac{20}{2^{18}} = 0.000076 \ [V] = 76 \ [\mu V] \\]

\\[ \Gamma\_Q = \frac{q^2}{12 f\_N} = 4.85 \cdot 10^{-14} \quad [V^2/Hz] \\]

</div>

{{< youtube b9lxtOJj3yU >}}



## Bibliography {#bibliography}

<a id="orgb22f10b"></a>Baker, Bonnie. 2011. “How Delta-Sigma Adcs Work, Part.” _Analog Applications_ 7.
