+++
title = "Fractional Order Transfer Functions"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
:


## Example Using the FOMCON toolbox {#example-using-the-fomcon-toolbox}

The documentation for the toolbox is accessible [here](https://fomcon.net/fomcon-toolbox/overview/).

Here are the parameters that are used to define the wanted properties of the fractional model:

```matlab
wb = 2*pi*0.1; % Lowest frequency bound
wh = 2*pi*1e3; % Highest frequency bound
n  = 8; % Approximation order
r = 0.5; % Wanted slope, The corresponding phase will be pi*r
```

Then, to create an approximation of a fractional-order operator \\(s^r\\) of order \\(n\\) which is valid in the frequency range \\([\omega\_b\, \omega\_h]\\), the `oustafod` function can be used:

```matlab
G = oustafod(r,n,wb,wh);
```

```text
G =

  79.27 s^17 + 7.93e05 s^16 + 2.918e09 s^15 + 5.143e12 s^14 + 4.782e15 s^13 + 2.453e18 s^12 + 7.103e20 s^11 + 1.175e23 s^10 + 1.119e25 s^9 + 6.138e26 s^8 + 1.942e28 s^7 + 3.534e29 s^6 + 3.675e30 s^5 + 2.157e31 s^4 + 6.984e31 s^3 + 1.193e32 s^2 + 9.764e31 s + 2.939e31
  -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
    s^17 + 1.312e04 s^16 + 6.327e07 s^15 + 1.462e11 s^14 + 1.783e14 s^13 + 1.199e17 s^12 + 4.553e19 s^11 + 9.877e21 s^10 + 1.232e24 s^9 + 8.866e25 s^8 + 3.678e27 s^7 + 8.775e28 s^6 + 1.196e30 s^5 + 9.208e30 s^4 + 3.909e31 s^3 + 8.755e31 s^2 + 9.395e31 s + 3.707e31

Continuous-time transfer function.
```

Few examples of different slopes are shown in Figure [1](#orgaa7c066).

<a id="orgaa7c066"></a>

{{< figure src="/ox-hugo/approximate_deriv_int.png" caption="Figure 1: Example of fractional approximations" >}}

<./biblio/references.bib>
