+++
title = "IRR and FIR Filters"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Digital Filters]({{< relref "digital_filters" >}})

<div class="table-caption">
  <span class="table-number">Table 1</span>:
  Comparison of IRR and FIR Filters
</div>

|           | **IIR**                                    | **FIR**                               |
|-----------|--------------------------------------------|---------------------------------------|
| Phase     | No particular phase                        | Linear phase possible                 |
| Stability | Can be unstable                            | Always stable (feedback not involved) |
| Analog    | Derived from analog filter                 | Cannot simulate analog response       |
| Linearity | Used for applications which are not linear | Linear-phase characteristic           |
| num/den   | Both numerator and denominator             | Only has numerators                   |

> Digital filters with finite-duration impulse response (all-zero, or FIR filters) have both advantages and disadvantages compared to infinite-duration impulse response (IIR) filters.
>
> FIR filters have the following primary advantages:
>
> -   They can have exactly linear phase.
> -   They are always stable.
> -   The design methods are generally linear.
> -   They can be realized efficiently in hardware.
> -   The filter startup transients have finite duration.
>
> The primary disadvantage of FIR filters is that they often require a much higher filter order than IIR filters to achieve a given level of performance. Correspondingly, the delay of these filters is often much greater than for an equal performance IIR filter.

From ([Shaw and Srinivasan 1990](#orge62ce0f))

> The FIR are capable of realizing filters with linear phase shift characteristics and furthermore are less susceptible to signal input and filter coefficient quantization effects.
> However, their computational demands are excessively large because of the large number of multiplications and additions to be performed at each sampling interval.
> The effective time delay corresponding to the linear phase shift is large and would have a destabilizing effect in closed loop applications.
> IIR filters are computationally less demanding. The fact that their phase shift characteristics do not vary linearly with frequency is not a disadvantage in this application.
> IIR filters are however, more susceptible to signal input and coefficient quantization effects.

From <https://dsp.stackexchange.com/a/30999>

> FIR filters are fairly common in some areas of control theory. As they usually incur a lot of added phase/time-delay, they are not really usable in the feedback path of regular control systems, but they are useful when the added phase/time-delay is not affecting the system in an adverse way, or when the particular phase response and time-delay is desired.
>
> Examples:
>
> -   Feed-forward control. FIR filters are useful for producing filters that approximate arbitrary frequency responses, hence they can be used to shape a reference signal. A typical example is to use an FIR filter with the inverse frequency response of the plant -- trying to counteract the dynamics of the plant in order to get a desired output. Phase/time-delay is not interfering with the stability or performance since the computation can be done offline. FIR filters can often produce higher performance than IIR filters, especially where there are non-minimum phase zeros.



## Bibliography {#bibliography}

<a id="orge62ce0f"></a>Shaw, F.R., and K. Srinivasan. 1990. “Bandwidth Enhancement of Position Measurements Using Measured Acceleration.” _Mechanical Systems and Signal Processing_ 4 (1):23–38. <https://doi.org/10.1016/0888-3270(90)>90038-m.
