+++
title = "Piezoelectric Actuators"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Actuators]({{< relref "actuators" >}}), [Voltage Amplifier]({{< relref "voltage_amplifier" >}})


## Piezoelectric Stack Actuators {#piezoelectric-stack-actuators}


### Manufacturers {#manufacturers}

| Manufacturers                                                                                                        | Country   |
|----------------------------------------------------------------------------------------------------------------------|-----------|
| [Cedrat](http://www.cedrat-technologies.com/)                                                                        | France    |
| [PI](https://www.physikinstrumente.com/en/)                                                                          | USA       |
| [Piezo System](https://www.piezosystem.com/products/piezo%5Factuators/stacktypeactuators/)                           | Germany   |
| [Noliac](http://www.noliac.com/products/actuators/plate-stacks/)                                                     | Denmark   |
| [Thorlabs](https://www.thorlabs.com/newgrouppage9.cfm?objectgroup%5Fid=8700)                                         | USA       |
| [PiezoDrive](https://www.piezodrive.com/actuators/)                                                                  | Australia |
| [Mechano Transformer](http://www.mechano-transformer.com/en/products/10.html)                                        | Japan     |
| [CoreMorrow](http://www.coremorrow.com/en/pro-9-1.html)                                                              | China     |
| [PiezoData](https://www.piezodata.com/piezo-stack-actuator-2/)                                                       | China     |
| [Queensgate](https://www.nanopositioning.com/product-category/nanopositioning/nanopositioning-actuators-translators) | UK        |
| [Matsusada Precision](https://www.matsusada.com/product/pz/)                                                         | Japan     |
| [Sinocera](http://www.china-yec.net/piezoelectric-ceramics/)                                                         | China     |
| [Fuji Ceramisc](http://www.fujicera.co.jp/en/)                                                                       | Japan     |


### Model {#model}

A model of a multi-layer monolithic piezoelectric stack actuator is described in ([Fleming 2010](#org8e467ce)) ([Notes]({{< relref "fleming10_nanop_system_with_force_feedb" >}})).

Basically, it can be represented by a spring \\(k\_a\\) with the force source \\(F\_a\\) in parallel.

The relation between the applied voltage \\(V\_a\\) to the generated force \\(F\_a\\) is:
\\[ F\_a = g\_a V\_a, \quad g\_a = d\_{33} n k\_a \\]
with:

-   \\(d\_{33}\\) is the piezoelectric strain constant [m/V]
-   \\(n\\) is the number of layers
-   \\(k\_a\\) is the actuator stiffness [N/m]


## Piezoelectric Plate Actuators {#piezoelectric-plate-actuators}

Some manufacturers propose "raw" plate actuators that can be used as actuator / sensors.

| Manufacturers                                                       | Country |
|---------------------------------------------------------------------|---------|
| [Noliac](http://www.noliac.com/products/actuators/plate-actuators/) | Denmak  |


## Mechanically Amplified Piezoelectric actuators {#mechanically-amplified-piezoelectric-actuators}

The Amplified Piezo Actuators principle is presented in ([Claeyssen et al. 2007](#org5363d27)):

> The displacement amplification effect is related in a first approximation to the ratio of the shell long axis length to the short axis height.
> The flatter is the actuator, the higher is the amplification.

A model of an amplified piezoelectric actuator is described in ([Lucinskis and Mangeot 2016](#org6963733)).

<a id="org050f47d"></a>

{{< figure src="/ox-hugo/ling16_topology_piezo_mechanism_types.png" caption="Figure 1: Topology of several types of compliant mechanisms <sup id=\"d9e8b33774f1e65d16bd79114db8ac64\"><a href=\"#ling16_enhan_mathem_model_displ_amplif\" title=\"Mingxiang Ling, Junyi Cao, Minghua Zeng, Jing Lin, \&amp; Daniel J Inman, Enhanced Mathematical Modeling of the Displacement  Amplification Ratio for Piezoelectric Compliant Mechanisms, {Smart Materials and Structures}, v(7), 075022 (2016).\">ling16_enhan_mathem_model_displ_amplif</a></sup>" >}}

| Manufacturers                                                                                      | Country   |
|----------------------------------------------------------------------------------------------------|-----------|
| [Cedrat](https://www.cedrat-technologies.com/en/products/actuators/amplified-piezo-actuators.html) | France    |
| [PiezoDrive](https://www.piezodrive.com/actuators/ap-series-amplified-piezoelectric-actuators/)    | Australia |
| [Dynamic-Structures](https://www.dynamic-structures.com/category/piezo-actuators-stages)           | USA       |
| [Thorlabs](https://www.thorlabs.com/newgrouppage9.cfm?objectgroup%5Fid=8700)                       | USA       |
| [Noliac](http://www.noliac.com/products/actuators/amplified-actuators/)                            | Denmark   |
| [Mechano Transformer](http://www.mechano-transformer.com/en/products/01a%5Factuator%5F5.html)      | Japan     |
| [CoreMorrow](http://www.coremorrow.com/en/pro-13-1.html)                                           | China     |
| [PiezoData](https://www.piezodata.com/piezoelectric-actuator-amplifier/)                           | China     |


## Specifications {#specifications}


### Typical Specifications {#typical-specifications}

Typical specifications of piezoelectric stack actuators are usually in terms of:

-   Displacement/ Travel range \\([\mu m]\\)
-   Blocked force \\([N]\\)
-   Stiffness \\([N/\mu m]\\)
-   Resolution \\([nm]\\)
-   Length \\([mm]\\)
-   Electrical Capacitance \\([nF]\\)


### Displacement and Length {#displacement-and-length}

The maximum displacement specified is the displacement of the actuator when the maximum voltage is applied without any load.

Typical maximum strain of Piezoelectric Stack Actuators is \\(0.1\%\\).
The free displacement \\(\Delta L\_{f}\\) is then related to the length \\(L\\) of piezoelectric stack by:

\begin{equation}
  \Delta L\_f \approx \frac{L}{1000}
\end{equation}

> A “free” actuator — one that experiences no resistance to movement — will produce its maximum displacement, often referred to as “free stroke,” and generate zero force.

Note that this maximum displacement is only attainable at DC.
For dynamical applications, the electrical capacitance of the piezoelectric actuator is an important factor (see bellow).


### Blocked Force {#blocked-force}

The blocked force \\(F\_b\\) is measured by first applying the maximum voltage to the piezoelectric stack without any load.
Thus, the piezoelectric stack experiences its maximum displacement.

A force is then applied to return the actuator to its original length.
This force is measured and recorded as the blocking force.

The blocking force is also the maximum force that can produce the piezoelectric stack in contact with an infinitely stiff environment.

> When an actuator is blocked from moving, it will produce its maximum force, which is referred to as the blocked, or blocking, force.


### Stiffness {#stiffness}

The stiffness of the actuator is the ratio of the blocking force to the free stroke:

\begin{equation}
  k\_p = \frac{F\_b}{\Delta L\_f}
\end{equation}

with:

-   \\(k\_p\\): stiffness of the piezo actuator
-   \\(F\_b\\): blocking force
-   \\(\Delta L\_f\\): free stroke


### Resolution {#resolution}

The resolution is limited by the noise in the [Voltage Amplifier]({{< relref "voltage_amplifier" >}}).

Typical [Signal to Noise Ratio]({{< relref "signal_to_noise_ratio" >}}) of voltage amplifiers is \\(100dB = 10^{5}\\).
Thus, for a piezoelectric stack with a displacement \\(L\\), the resolution will be

\begin{equation}
  r \approx \frac{L}{10^5}
\end{equation}

For a piezoelectric stack with a displacement of \\(100\,[\mu m]\\), the resolution will be \\(\approx 1\,[nm]\\).


### Electrical Capacitance {#electrical-capacitance}

The electrical capacitance may limit the maximum voltage that can be used to drive the piezoelectric actuator as a function of frequency (Figure [2](#org8857f21)).
This is due to the fact that voltage amplifier has a limitation on the deliverable current.

[Voltage Amplifier]({{< relref "voltage_amplifier" >}}) with high maximum output current should be used if either high bandwidth is wanted or piezoelectric stacks with high capacitance are to be used.

<a id="org8857f21"></a>

{{< figure src="/ox-hugo/piezoelectric_capacitance_voltage_max.png" caption="Figure 2: Maximum sin-wave amplitude as a function of frequency for several piezoelectric capacitance" >}}


## Piezoelectric actuator experiencing a mass load {#piezoelectric-actuator-experiencing-a-mass-load}

When the piezoelectric actuator is supporting a payload, it will experience a static deflection due to its finite stiffness \\(\Delta l\_n = \frac{mg}{k\_p}\\), but its stroke will remain unchanged (Figure [3](#org35eead3)).

<a id="org35eead3"></a>

{{< figure src="/ox-hugo/piezoelectric_mass_load.png" caption="Figure 3: Motion of a piezoelectric stack actuator under external constant force" >}}


## Piezoelectric actuator in contact with a spring load {#piezoelectric-actuator-in-contact-with-a-spring-load}

Then the piezoelectric actuator is in contact with a spring load \\(k\_e\\), its maximum stroke \\(\Delta L\\) is less than its free stroke \\(\Delta L\_f\\) (Figure [4](#orgf00c960)):

\begin{equation}
  \Delta L = \Delta L\_f \frac{k\_p}{k\_p + k\_e}
\end{equation}

<a id="orgf00c960"></a>

{{< figure src="/ox-hugo/piezoelectric_spring_load.png" caption="Figure 4: Motion of a piezoelectric stack actuator in contact with a stiff environment" >}}

For piezo actuators, force and displacement are inversely related (Figure [5](#orgb6392e0)).
Maximum, or blocked, force (\\(F\_b\\)) occurs when there is no displacement.
Likewise, at maximum displacement, or free stroke, (\\(\Delta L\_f\\)) no force is generated.
When an external load is applied, the stiffness of the load (\\(k\_e\\)) determines the displacement (\\(\Delta L\_A\\)) and force (\\(\Delta F\_A\\)) that can be produced.

<a id="orgb6392e0"></a>

{{< figure src="/ox-hugo/piezoelectric_force_displ_relation.png" caption="Figure 5: Relation between the maximum force and displacement" >}}


## Driving Electronics {#driving-electronics}

Piezoelectric actuators can be driven either using a voltage to charge converter or a [Voltage Amplifier]({{< relref "voltage_amplifier" >}}).


## Bibliography {#bibliography}

<a id="org5363d27"></a>Claeyssen, Frank, R. Le Letty, F. Barillot, and O. Sosnicki. 2007. “Amplified Piezoelectric Actuators: Static & Dynamic Applications.” _Ferroelectrics_ 351 (1):3–14. <https://doi.org/10.1080/00150190701351865>.

<a id="org8e467ce"></a>Fleming, A.J. 2010. “Nanopositioning System with Force Feedback for High-Performance Tracking and Vibration Control.” _IEEE/ASME Transactions on Mechatronics_ 15 (3):433–47. <https://doi.org/10.1109/tmech.2009.2028422>.

<a id="org6963733"></a>Lucinskis, R., and C. Mangeot. 2016. “Dynamic Characterization of an Amplified Piezoelectric Actuator.”
