+++
title = "Position Sensors"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Inertial Sensors]({{< relref "inertial_sensors" >}}), [Force Sensors]({{< relref "force_sensors" >}}), [Sensor Fusion]({{< relref "sensor_fusion" >}}), [Signal Conditioner]({{< relref "signal_conditioner" >}}), [Signal to Noise Ratio]({{< relref "signal_to_noise_ratio" >}})


## Types of Positioning sensors {#types-of-positioning-sensors}

High precision positioning sensors include:

-   [Interferometers]({{< relref "interferometers" >}})
-   [Capacitive Sensors]({{< relref "capacitive_sensors" >}})
-   [LVDT]({{< relref "linear_variable_differential_transformers" >}})
-   [Eddy Current Sensors]({{< relref "eddy_current_sensors" >}})
-   [Encoders]({{< relref "encoders" >}})


## Reviews of Relative Position Sensors {#reviews-of-relative-position-sensors}

-   Fleming, A. J., A review of nanometer resolution position sensors: operation and performance ([Fleming 2013](#org0cb5981)) ([Notes]({{< relref "fleming13_review_nanom_resol_posit_sensor" >}}))

<a id="table--tab:characteristics-relative-sensor"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:characteristics-relative-sensor">Table 1</a></span>:
  Characteristics of relative measurement sensors <a class='org-ref-reference' href="#collette11_review">collette11_review</a>
</div>

| Technology     | Frequency  | Resolution     | Range        | T Range     |
|----------------|------------|----------------|--------------|-------------|
| LVDT           | DC-200 Hz  | 10 nm rms      | 1-10 mm      | -50,100 °C  |
| Eddy current   | 5 kHz      | 0.1-100 nm rms | 0.5-55 mm    | -50,100 °C  |
| Capacitive     | DC-100 kHz | 0.05-50 nm rms | 50 nm - 1 cm | -40,100 °C  |
| Interferometer | 300 kHz    | 0.1 nm rms     | 10 cm        | -250,100 °C |
| Encoder        | DC-1 MHz   | 1 nm rms       | 7-27 mm      | 0,40 °C     |
| Bragg Fibers   | DC-150 Hz  | 0.3 nm rms     | 3.5 cm       | -30,80 °C   |

<a id="table--tab:summary-position-sensors"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:summary-position-sensors">Table 2</a></span>:
  Summary of position sensor characteristics. The dynamic range (DNR) and resolution are approximations based on a full-scale range of 100um and a first order bandwidth of \(1 kHz\) <a class='org-ref-reference' href="#fleming13_review_nanom_resol_posit_sensor">fleming13_review_nanom_resol_posit_sensor</a>
</div>

| Sensor Type    | Range                          | DNR     | Resolution | Max. BW  | Accuracy  |
|----------------|--------------------------------|---------|------------|----------|-----------|
| Metal foil     | \\(10-500 \mu m\\)             | 230 ppm | 23 nm      | 1-10 kHz | 1% FSR    |
| Piezoresistive | \\(1-500 \mu m\\)              | 5 ppm   | 0.5 nm     | >100 kHz | 1% FSR    |
| Capacitive     | \\(10 \mu m\\) to \\(10 mm\\)  | 24 ppm  | 2.4 nm     | 100 kHz  | 0.1% FSR  |
| Electrothermal | \\(10 \mu m\\) to \\(1 mm\\)   | 100 ppm | 10 nm      | 10 kHz   | 1% FSR    |
| Eddy current   | \\(100 \mu m\\) to \\(80 mm\\) | 10 ppm  | 1 nm       | 40 kHz   | 0.1% FSR  |
| LVDT           | \\(0.5-500 mm\\)               | 10 ppm  | 5 nm       | 1 kHz    | 0.25% FSR |
| Interferometer | Meters                         |         | 0.5 nm     | >100kHz  | 1 ppm FSR |
| Encoder        | Meters                         |         | 6 nm       | >100kHz  | 5 ppm FSR |

Capacitive Sensors and Eddy-Current sensors are compare [here](https://www.lionprecision.com/comparing-capacitive-and-eddy-current-sensors/).

<a id="org12bd001"></a>

{{< figure src="/ox-hugo/position_sensors_thurner15.png" caption="Figure 1: Overview of range and precision of different position displacement sensors. Taken from <sup id=\"53230532ada812541a7cd984b3aa2662\"><a href=\"#thurner15_fiber_based_distan_sensin_inter\" title=\"Thurner, Quacquarelli, Braun, Pierre-Fran\ccois, Dal Savio, Karrai \&amp; Khaled, Fiber-Based Distance Sensing Interferometry, {Applied optics}, v(10), 3051--3063 (2015).\">thurner15_fiber_based_distan_sensin_inter</a></sup>" >}}


## Bibliography {#bibliography}

<a id="org0cb5981"></a>Fleming, Andrew J. 2013. “A Review of Nanometer Resolution Position Sensors: Operation and Performance.” _Sensors and Actuators a: Physical_ 190 (nil):106–26. <https://doi.org/10.1016/j.sna.2012.10.016>.
