+++
title = "Voltage Amplifier"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Signal to Noise Ratio]({{< relref "signal_to_noise_ratio" >}}), [Piezoelectric Actuators]({{< relref "piezoelectric_actuators" >}}), [Electronics]({{< relref "electronics" >}})


## Voltage Amplifiers to drive Capacitive Loads {#voltage-amplifiers-to-drive-capacitive-loads}


### Manufacturers {#manufacturers}

| Manufacturers                                                                                                                                         | Country     |
|-------------------------------------------------------------------------------------------------------------------------------------------------------|-------------|
| [Piezo Drive](https://www.piezodrive.com/drivers/)                                                                                                    | Australia   |
| [Falco System](https://www.falco-systems.com/products.html)                                                                                           | Netherlands |
| [PI](https://www.pi-usa.us/en/products/controllers-drivers-motion-control-software/piezo-drivers-controllers-power-supplies-high-voltage-amplifiers/) | USA         |
| [Thorlabs](https://www.thorlabs.com/navigation.cfm?guide%5FID=2085)                                                                                   | USA         |
| [Lab Systems](https://www.lab-systems.com/products/amplifier/amplifier.html)                                                                          | Isreal      |
| [Piezomechanics](https://www.piezomechanik.com/products/)                                                                                             | Germany     |
| [Cedrat Technologies](https://www.cedrat-technologies.com/en/products/piezo-controllers/electronic-amplifier-boards.html)                             | France      |
| [Trek](https://www.trekinc.com/products/HV%5FAmp.asp)                                                                                                 | USA         |
| [Madcitylabs](http://www.madcitylabs.com/piezoactuators.html)                                                                                         | USA         |
| [Piezosystem](https://www.piezosystem.com/products/controller/)                                                                                       | Germany     |
| [Matsusada Precision](https://www.matsusada.com/product/pz/)                                                                                          | Japan       |
| [Mechano Transformer](http://www.mechano-transformer.com/en/products/08.html)                                                                         | Japan       |


### Limitation in Current {#limitation-in-current}

The piezoelectric stack can be represented as a capacitance.

Let's take a capacitance driven by a voltage amplifier (Figure [1](#org811725e)).

<a id="org811725e"></a>

{{< figure src="/ox-hugo/voltage_amplifier_capacitance.png" caption="Figure 1: Piezoelectric actuator model with a voltage source" >}}

The equation linking the voltage to the current is:
\\[ I = C \frac{dU}{dt} \\]

Suppose we want to drive the piezo with a voltage:
\\[ U(t) = U\_0 \sin(\omega\_0 t) \\]

The required current is:
\\[ I = C U\_0 \omega\_0 \cos(\omega\_0 t) \\]

Thus, for a specified maximum current \\(I\_\text{max}\\), the "power bandwidth" will be:
\\[ \omega\_{0, \text{max}} = \frac{I\_\text{max}}{C U\_0}, \quad f\_{0, \text{max}} = \frac{I\_\text{max}}{C U\_0} \frac{1}{2 \pi} \\]

-   Below \\(\omega\_{0, \text{max}}\\), a voltage amplitude \\(U\_0\\) can be applied to the piezoelectric load without reaching the maximum current \\(I\_\text{max}\\).
-   Above \\(\omega\_{0, \text{max}}\\), the maximum current \\(I\_\text{max}\\) is reached and the maximum voltage that can be applied decreases with frequency:
    \\[ U\_\text{max} = \frac{I\_\text{max}}{\omega C} \\]

The maximum voltage as a function of frequency is shown in Figure [2](#org8c7858f).

```matlab
  Vpkp = 170; % [V]
  Imax = 30e-3; % [A]
  C = 1e-6; % [F]

  (1/(2*pi))*Imax/(C * Vpkp/2) % Fmax [Hz]
```

```text
56.172
```

<a id="org8c7858f"></a>

{{< figure src="/ox-hugo/voltage_amplifier_max_V_piezo.png" caption="Figure 2: Maximum voltage as a function of the frequency for \\(C = 1 \mu F\\), \\(I\_\text{max} = 30mA\\) and \\(V\_{pkp} = 170 V\\)" >}}

Similarly, the voltage rise time is determined by the Capacitance of the piezoelectric stack and by the maximum current that the amplifier can deliver:
\\[ t\_c = \frac{\Delta U C}{I\_\text{max}} \\]
with \\(t\_c\\) in seconds, \\(\Delta U\\) in volts, \\(C\\) in Farads and \\(I\_\text{max}\\) in Amperes.

If driven at \\(\Delta U = 100V\\), \\(C = 1 \mu F\\) and \\(I\_\text{max} = 1 A\\), then:
\\[ t\_c = \frac{100 \cdot 10^{-6}}{1} = 0.1 ms \\]


### Amplifiers for Low Voltage PZT {#amplifiers-for-low-voltage-pzt}

Piezoelectric Stack Actuators are behaving like capacitor for the Amplifiers.

Specifications are usually:

-   Maximum Current
-   DC Gain (usually around 10)
-   Output Noise or [Signal to Noise Ratio]({{< relref "signal_to_noise_ratio" >}})

The bandwidth can be estimated from the Maximum Current and the Capacitance of the Piezoelectric Actuator.


### Problem to drive highly capacitive loads {#problem-to-drive-highly-capacitive-loads}

At high frequency, the impedance of the capacitive load is very small.
This can pose several problems:

-   the current to be supplied by the amplifier to have some voltage becomes very large
-   the internal impedance of the amplifier may be large compared to the load impedance, and thus large voltage drop will occur


### Noise {#noise}

Sources of noise in a system comprising a voltage amplifier and a capactive load are discussed in ([Spengen 2020](#org2123c0f)).

Proper enclosures and cabling are necessary to protect the system from capacitive and inductive interferance.


### Impedance of Voltage Amplifiers {#impedance-of-voltage-amplifiers}

The **input** impedance of voltage amplifiers are generally set to \\(50 \Omega\\) to avoid any reflections of the signal.

The **output** (or internal) impedance of voltage amplifier is generally wanted small in order to have a small voltage drop when large current are drawn.
However, for stability reasons and to avoid overshoot (due to the internal negative feedback loop), this impedance can be chosen quite large.

This is discussed in ([Spengen 2017](#orgc500938)).


## Bibliography {#bibliography}

<a id="org66151a2"></a>Fleming, Andrew J., and Kam K. Leang. 2014. _Design, Modeling and Control of Nanopositioning Systems_. Advances in Industrial Control. Springer International Publishing. <https://doi.org/10.1007/978-3-319-06617-2>.

<a id="orgc500938"></a>Spengen, W. Merlijn van. 2017. “High Voltage Amplifiers and the Ubiquitous 50 Ohms: Caveats and Benefits.” Falco Systems.

<a id="org2123c0f"></a>———. 2020. “High Voltage Amplifiers: So You Think You Have Noise!” Falco Systems.
