+++
title = "Modal testing: theory, practice and application"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [System Identification]({{< relref "system_identification" >}}), [Reference Books]({{< relref "reference_books" >}}), [Modal Analysis]({{< relref "modal_analysis" >}})

Reference
: ([Ewins 2000](#org300069f))

Author(s)
: Ewins, D.

Year
: 2000

PDF version
: [link](/ox-hugo/ewins00_modal.pdf)

<div style="display: none;">
\(
\newcommand{\tcmbox}[1]{\boxed{#1}}
% Simulate SIunitx
\newcommand{\SI}[2]{#1\,#2}
\newcommand{\ang}[1]{#1^{\circ}}
\newcommand{\degree}{^{\circ}}
\newcommand{\radian}{\text{rad}}
\newcommand{\percent}{\%}
\newcommand{\decibel}{\text{dB}}
\newcommand{\per}{/}
% Bug with subequations
\newcommand{\eatLabel}[2]{}
\newenvironment{subequations}{\eatLabel}{}
\)
</div>


## Overview {#overview}


### Introduction to Modal Testing {#introduction-to-modal-testing}

The **major objectives** of modal testing are:

-   Determining the nature and extent of vibration response levels in operation
-   Verifying theoretical models and predictions of the vibrations
-   Measurement of the essential materials properties under dynamic loading, such as damping capacity, friction and fatigue endurance

For many applications, vibrations is directly related to performance and it is important that the vibration levels are anticipated and brought under satisfactory control.

The two major vibration measurement objectives corresponds to two types of test:

1.  **Free vibration**: responses are measured during operation of the machine
2.  **Forced vibrations**: the structure is vibrated with a known excitation, often out of its normal service environment. This type of testing is generally made under more closely-controlled conditions than the first one, and yields to more accurate information

Modal Testing means "the processes involved in testing components or structure with the objective of obtaining a mathematical description of their dynamic of vibration behavior".
The form of "mathematical description" can vary from one application to the other: it can be an estimate of natural frequency and damping factor in one case and a full mass-spring-dashpot model for the next.


### Applications of modal testing {#applications-of-modal-testing}

We must remember that no single test or analysis procedure is best for all cases and so it is very important that a clear objective is defined before any industrial test is undertaken so that the optimum methods may be used.

The different objectives can be:

1.  Measurement of a structure's vibration properties in order to **compare these with a theoretical model** (finite element model for instance).
    This is usually used to **validate a model**. What is required for the test are:

    -   accurate estimates of natural frequencies
    -   descriptions of the mode shapes

    At this stage, accurate mode shape data are not essential. It is generally not possible to "predict" the damping in each mode of vibration from a theoretical model.
2.  **Adjust or correct the theoretical model** in order to bring its modal properties closer into line with the measured results.
    A **correlation** technique can be used: the two sets of data are combined, quantitatively, in order to identify specifically the causes of the discrepancies between predicted and measured properties. This however, requires precise description of the mode shapes (the eigenvectors) from the modal analysis.
3.  **Sub-structuring process**: use modal testing in order to produce a mathematical model of a component which may be incorporated into a structural assembly.
    Here, as it is a fully quantitative model that is sought, accurate data are required for natural frequencies, modal damping factors and mode shapes.
    Also, all modes must be included simultaneously as **out-of-range modes will influence the structure's behavior** in a given frequency range of interest for the complete assembly. This application is altogether more demanding than the previous ones.
4.  **Predicting the effects of modifications** to the original structure, as tested.
    For this application and the sub-structuring process, one need information about **rotational degrees-of-freedom**, i.e. moments and rotational displacements.
    These are generally ignore in experimental-based studies as they are much more difficult to measure.
5.  **Force Determination**. There are a number of situations where **knowledge of the dynamic forces causing vibration is required** but where direct measurement of these forces is not practical.
    For these cases, one solution is offered by a process whereby measurements of the response caused by the forces are combined with a mathematical description of the transfer functions of the structure in order to deduce the forces.
    This process can be very sensitive to the accuracy of the model used, and it is often essential that the model itself be derived from measurements

Usually, the normal procedure for modal testing is:

1.  **Measure**
2.  **Analyze** the measured data
3.  **Derive a mathematical model** of the structure

However, there are some cases where this is not the optimum procedure.
The last step is usually taken in order to reduce a vast quantity of actual measurements to a small and efficient data set usually referred to as the "modal model".
This reduction process has an additional benefit of eliminating small inconsistencies which will inevitably occur in measured data.


### Philosophy of Modal Testing {#philosophy-of-modal-testing}

One of the major requirements to apply modal testing is a thorough integration with an high level of understanding of three components:

1.  **Theoretical basis** of vibration
2.  **Accurate measurement** of vibration
3.  Realistic and detailed **data analysis**

For instance, there are many features of a frequency response function that can be assessed rapidly understanding some **theoretical basis**.
This could prevent the wasted effort of analyzing incorrect measurements.

Then, for the **practical** side, there are many choices of test methods: harmonic, random, transient excitation.
The experimenter should be aware of the limitations and implications of the various techniques used in the measurement phases.

Next, we consider the **analysis** stage where the measured data (Frequency Response Functions or FRF) are subjected to a range of curve-fitting procedures in an attempt to find the mathematical model which provides the closest description of the actually-observed behavior.
There are many approached, and one should be aware of the alternatives in order to choose the optimal one.

Often, an analysis may be conducted on each measured curve individually.
Then, there is a further step in the process: **modeling**.
This is the final stage where all the measured and processed data are combined to yield the most compact and efficient mathematical model of the test structure.

However, the averaging process is a valid and valuable technique only is provided that the data contain **random** vibrations.
Data with systematic trends, such as those causes by poor testing practices or non-linearities, should no be averaged in the same way.


### Summary of Theory {#summary-of-theory}

It is very important that a clear distinction is made between **free** vibrations and **forced** vibration analysis.

For the SDOF system, a free vibration analysis yields its natural frequency and damping factor, where a forced response analysis (assuming a harmonic excitation), leads to the definition of the frequency response function.
These two types of results are referred to as **modal properties** and **frequency response characteristics**.

Next, we consider the more general class of systems which have more than one degree-of-freedom.
For these, it is customary that the spatial properties (the values of the mass, stiffness, and damper elements) be expressed as matrices.
Those used are the mass matrix \\(M\\), the stiffness matrix \\(K\\), the viscous damping matrix \\(C\\) and the structural or hysteretic damping matrix \\(D\\).

There are three phases in the vibration analysis of such systems:

1.  **Setting up the governing equations of motion**, which means determining the elements of the above matrices
2.  **Free vibration analysis** using the equations of motion.
    This analysis produces first a set of \\(N\\) natural frequencies and damping factors, and secondly a matching set of \\(N\\) "mode shape" vectors, each one of these being associated with a specific natural frequency and damping factor.
    The complete free vibration solution is conveniently contained in two matrices \\(h^2\\) and \\(\phi\\), which are again referred to as "modal properties", or sometimes, as the **eigenvalue** and **eigenvector matrices**.
    One element from the diagonal eigenvalue matrix \\(\lambda\_r^2\\) contains **both the natural frequency and the damping factor** for the \\(r^{\text{th}}\\) normal mode of vibration of the system while the corresponding column \\(\phi\_r\\) describes the **shape of that same mode of vibration**
3.  **Forced response analysis**, and in particular harmonic excitation.
    By solving the equations of motion when harmonic forcing is applied, we are able to describe the complete solution by a single matrix, known as the **frequency response matrix** \\(H(\omega)\\).
    Thus, element \\(H\_{jk}(\omega)\\) represents the harmonic response, \\(X\_j\\) in one of the DOF \\(j\\) caused by a single harmonic force \\(F\_k\\) applied in the DOF \\(k\\).
    The particular relevance of these specific response characteristics is the fact that they are the quantities which are the most likely to be able to **measure in practice**.
    However, the same expressions can be **drastically simplified if we use the modal properties** instead of the spatial properties and it is possible to write an expressing for any FRF, \\(H\_{jk}(\omega)\\), which has the general form

    \begin{equation}
     H\_{jk}(\omega) = \frac{X\_j}{F\_k} = \sum\_{r=1}^{N}\frac{{}\_rA\_{jk}}{\lambda\_r^2 - \omega^2} \label{eq:frf\_modal}
    \end{equation}

    where \\(\lambda\_r^2\\) is the eigenvalue of the \\(r^{\text{th}}\\) mode, \\({}\_rA\_{jk}\\) (the modal constant) is constructed from \\(\phi\_{jk}\\) which is the \\(j^{\text{th}}\\) element of the \\(r^{\text{th}}\\) eigenvector \\(\phi\_r\\) and \\(N\\) is the number of degrees-of-freedom (or modes).
    This expression forms the foundation of modal analysis: it shows a **direct connection between the modal properties of a system and its response characteristics**.

Thus, we find that by making a thorough study of the theory of structural vibration, we are able to "predict" what we might expect to find if we make FRF measurements on actual hardware.
Indeed, we shall see later how these predictions can be quite detailed, to the point where it is possible to comment on the likely quality of measured data.


### Summary of measurement methods {#summary-of-measurement-methods}

The main measurement technique studied are those which will permit to make **direct measurements of the various FRF** properties of the test structure.

The type of test best suited to FRF measurement is shown in figure [1](#orge1f0d37).

<a id="orge1f0d37"></a>

{{< figure src="/ox-hugo/ewins00_modal_analysis_schematic.png" caption="Figure 1: Basic components of FRF measurement system" >}}

Essentially, there are three aspect of the measurement process which demand particular attention in order to ensure the acquisition of the high-quality data which are required for the next stage (data analysis). These are:

1.  The mechanical aspect of **supporting** and **correctly exciting the structure**
2.  The **correct transduction** of the quantities to be measured (force input and motion response)
3.  The **signal processing** which is appropriate to the type of test used


##### Mechanical Aspect {#mechanical-aspect}

We here encounter questions as how the testpiece should be suspended, or supported and how it should be excited.
Usually, one of three options is chosen for the support:

-   **Free or unrestrained**: usually means suspended on very soft springs, this has the advantage that free boundaries are easy to simulate
-   **Grounded**: requires rigid clamping at certain points
-   **In situ**: the testpiece is connected to some structure representing a non-rigid attachment

The mechanics of the excitation are achieve either by connection a **vibration generator** or shaker, or by using some form of **transient input**, such as a hammer blow or sudden release from a deformed position.
Both approaches have advantages and disadvantages and it can be very important to choose the best one in each case.


##### Transducers {#transducers}

Transducers are very important elements in the system as it is essential that accurate measurements be made of both the input to the structure and of its response.
Nowadays, **piezoelectric transducers** are widely used to detect both force and acceleration and the major problems associated with them are to ensure that they **interfere as little as possible with the test structure** and that their **performance is adequate for the ranges of frequency and amplitude** of the test.


##### Signal Processing {#signal-processing}

The FRF parameters to be measured can be obtained directly by applying an harmonic excitation and then measuring the resulting harmonic response.
This type of test is often referred to as **sinewave testing** and it requires the attachment of a shaker to the structure.
The frequency range is covered by sweeping the frequency continuously or by step.

Alternative excitation procedures are now widely used.
Transient (including burst signals) periodic, pseudo-random or **random excitation signals** often replace the signal wave approach and are made practical by the existence of complex signal processing analyser which are capable of resolving the frequency content of both input and response signals using Fourier analysis.

In modal testing applications of vibrations measurements, **accuracy of the measured data is of paramount importance**.
This is so because this data are generally to be submitted to a range of analysis procedures, in order to extract the results.
Some of these analysis processes are themselves quite complex and can seldom be regarded as insensitive to the accuracy of the input data.


### Summary of Modal Analysis Processes {#summary-of-modal-analysis-processes}

The third skill required for modal testing is concerned with the **analysis of the measured FRF data**.
This is quite separate from the signals processing which may be necessary to convert raw measurements into frequency response.

It is a procedure whereby the measured mobilities are analyzed in such a way as to find a theoretical model which most closely resembles the behavior of the actual testpiece.
This process itself falls into two stages:

1.  **Identify the appropriate type of model**
2.  **Determine the appropriate parameters** of the chosen model

Most of the effort goes into this second stage, which is widely referred to as "modal parameter extraction", or simply as "modal analysis".

We have seen that we can predict the form of the FRF plots for a multi degree-of-freedom system, and that these are directly related to the modal properties of that system.
The great majority of the modal analysis effort involves **curve-fitting** an expression such as equation \eqref{eq:frf_modal} to the measured FRF and thereby finding the appropriate modal parameters.

A completely general curve-fitting approach is possible but generally inefficient.
Mathematically, we can take an equation of the form
\\[ H(\omega) = \sum\_{r=1}^N \frac{A\_r}{\lambda\_r^2 - \omega^2} \\]
and curve fit a set of measured values \\(H\_m(\omega\_1), H\_m(\omega\_2), \dots\\) to this expression so that we obtain estimates for the coefficients \\(A\_1, A\_2, \dots, \lambda\_1^2, \lambda\_2^2, \dots\\).
These coefficients are closely related to the modal properties of the system.
However, although such approaches are made, they are **inefficient** and neither exploit the particular properties of resonant systems nor take due account of the unequal quality of the various measured points in the data set, both of which can have a significant influence on the overall analysis process.
Thus there is **no single modal analysis method**, but rater a selection, each being the most appropriate in differing conditions.

One of the most widespread and useful approaches is known as the **single-degree-of-freedom curve-fit**, or often as the **circle fit** procedure.
This method uses the fact that **at frequencies close to a natural frequency**, the FRF can often be **approximated to that of a single degree-of-freedom system** plus a constant offset term (which approximately accounts for the existence of other modes).
This assumption allows us to use the circular nature of a modulus/phase polar plot of the frequency response function of a SDOF system (see figure [2](#orgecf1743)).
This process can be **repeated** for each resonance individually until the whole curve has been analyzed.
At this stage, a theoretical regeneration of the FRF is possible using the set of coefficients extracted.

<a id="orgecf1743"></a>

{{< figure src="/ox-hugo/ewins00_sdof_modulus_phase.png" caption="Figure 2: Curve fit to resonant FRF data" >}}

These simple methods can be used for many of the cases encountered in practice but they become inadequate and **inaccurate when the structure has mode which are close**.
Under these conditions, it becomes necessary to use a more complex process which accepts the simultaneous influence of more than one mode.
These methods are referred to as **MDOF curve-fits** and are naturally more complicated and require more computation effort but, provided the data are accurate, they have the capability of producing more accurate estimates for the modal properties.

Some of more detailed considerations include: compensating for slightly non-linear behavior, simultaneously analyzing more than one FRF and curve-fitting to actual time histories.


### Review of Test Procedures and Levels {#review-of-test-procedures-and-levels}

The overall objective of the test is to determine a set of modal properties for a structure.
These consist of natural frequencies, damping factors and mode shapes.
The procedure consists of **three steps**:

1.  **Measure** an appropriate set of mobilities, or FRF
2.  **Analyze** these using appropriate curve-fitting procedures
3.  **Combine** the results of the curve-fits to construct the required model

Using our knowledge of the theoretical relationship between FRF functions and modal properties, it is possible to show that an "appropriate" set of FRFs to measure consists in most cases of **just one row or one column in the FRF matrix** \\(H(\omega)\\).
In practice this either means **exciting the structure at one point and measuring responses at all points** or **measuring the response at one point while the excitation is applied separately at each point in turn**.
This last option is most conveniently achieve using a hammer.

Even though the same overall procedure is always followed, there will be a **different level of detail** required for each different application.


## Theoretical Basis {#theoretical-basis}


### Introduction {#introduction}

Theoretical foundations of modal testing are of paramount importance to its successful implementation.

The three phases through a typical theoretical vibration analysis progresses are shown on figure [3](#orge69e740).
Generally, we start with a description of the structure's physical characteristics (mass, stiffness and damping properties), this is referred to as the **Spatial model**.

<a id="orge69e740"></a>

{{< figure src="/ox-hugo/ewins00_vibration_analysis_procedure.png" caption="Figure 3: Theoretical route to vibration analysis" >}}

Then, it is customary to perform a theoretical modal analysis of the spatial model which leads to a description of the structure's behavior as a set of vibration modes: the **modal model**.

<div class="definition">
  <div></div>

A **modal model** is defined a set of **natural frequencies** with corresponding **modal damping factors** and **vibration mode shapes**.
This solution describes the various ways in which the structure is capable of vibrating **naturally** (without any external forces or excitations), and so these are called the **natural** or **normal** modes of the structure.

</div>

The third stage is generally that in which we have the greatest interest; namely, the analysis of **exactly how the structure will respond under given excitation conditions**.
It is convenient to present an analysis of the structure's response to a "standard" excitation (from which the solution for **any particular case** can be constructed) and to describe this as the **response model**.
The **standard excitation** chosen is a **unit-amplitude sinusoidal force applied to each point on the structure individually**, and at every frequency within a specified range.
Thus our response model will consist  of a set of **frequency response functions**.

<div class="important">
  <div></div>

As indicated in figure [3](#orge69e740), it is also possible to do an analysis in the reverse directly: from a description of the response properties (FRFs), we can deduce modal properties and the spatial properties: this is the **experimental route** to vibration analysis.

</div>


### Single Degree of Freedom System Theory {#single-degree-of-freedom-system-theory}

Although very few practical structures could realistically be modeled by a SDOF system, the properties of such a system are very important because those for a more complex MDOF system can always be represented as a **linear superposition** of a number of SDOF characteristics.

<div class="important">
  <div></div>

Three classes of system model will be described:

-   Undamped
-   Viscously-damped
-   Hysteretically (or structurally) damped

</div>

The basic model for the SDOF system is shown in figure [4](#org115fa16) where \\(f(t)\\) and \\(x(t)\\) are general time-varying force and displacement response quantities.
The spatial model consists of a **mass** \\(m\\), a **spring** \\(k\\) and (when damped) either a **viscous dashpot** \\(c\\) or **hysteretic damper** \\(d\\).

<a id="org115fa16"></a>

{{< figure src="/ox-hugo/ewins00_sdof_model.png" caption="Figure 4: Single degree-of-freedom system" >}}


#### Undamped Systems {#undamped-systems}

The governing equation of motion is

\begin{equation}
  m \ddot{x} + k = 0
\end{equation}

The trial solution \\(x(t) = X e^{i\omega t}\\) leads to
\\[ k - m \omega^2 = 0 \\]

Hence the modal model consists of a single solution (mode of vibration) with a **natural frequency**
\\[ \omega\_0 = \sqrt{k/m} \\]

Turning next to a **frequency response analysis**, we consider an excitation of the form
\\[ f(t) = F e^{i\omega t} \\]
and assume a solution of the form
\\[ x(t) = X e^{i\omega t} \\]
where \\(F\\) and \\(X\\) are complex.
Now the equation of motion is

\begin{equation}
  (k - m \omega^2) X e^{i\omega t} = F e^{i\omega t}
\end{equation}

from which we extract the required response model in the form of a **frequency response function**.

<div class="important">
  <div></div>

Receptance FRF - Undamped System:

\begin{equation}
  \alpha(\omega) = \frac{X}{F} = \frac{1}{x - \omega^2 m} \label{eq:receptance}
\end{equation}

</div>

This particular form of FRF, where the response parameter is **displacement** (as opposed to velocity of acceleration) is called a **receptance**.


#### Viscous Damping {#viscous-damping}

If we add a **viscous dashpot** \\(c\\), the equation of motion becomes

\begin{equation}
  m \ddot{x} + c \dot{x} + k x = 0
\end{equation}

and we must now use a more general trial solution
\\[ x(t) = X e^{st} \\]
where \\(s\\) is **complex**.
We obtain the condition
\\[ ms^2 + cs + k = 0 \\]
which leads to

\begin{align}
  s\_{1, 2} &= -\frac{c}{2 m} \pm \frac{\sqrt{c^2 - 4 k m}}{2 m} \\\\\\
           &= - \bar{\omega}\_0 \xi \pm i \bar{\omega}\_0 \sqrt{1 - \xi^2} \nonumber
\end{align}

where
\\[ \bar{\omega}\_0^2 = \frac{k}{m};\quad \xi = \frac{c}{c\_0} = \frac{c}{2 \sqrt{km}} \\]

This implies a modal solution of the form
\\[ x(t) = X e^{-\bar{\omega}\_0 \xi t} e^{i (\bar{\omega}\_0 \sqrt{1 - \xi^2})t} = X e^{-a t} e^{i \omega\_0^\prime t} \\]
which is a single mode of vibration with a complex natural frequency having two part:

-   **An imaginary or oscillatory part**
-   **A real or decay part**

The physical significance of these two parts is illustrated in the typical free response plot shown in figure [5](#orgb1d4a98)

<a id="orgb1d4a98"></a>

{{< figure src="/ox-hugo/ewins00_sdof_response.png" caption="Figure 5: Oscillatory and decay part" >}}

Lastly, we consider the forced response when \\(f(t) = F e^{i\omega t}\\) and, as before, we assume \\(x(t) = Xe^{i\omega t}\\):
\\[ \left( -\omega^2 m + i \omega c + k \right) X e^{i\omega t} = F e^{i \omega t} \\]
gives a receptance FRF of the form

<div class="important">
  <div></div>

Receptance FRF - Viscous Damping:

\begin{equation}
  \alpha(\omega) = \frac{1}{(k - \omega^2 m) + i \omega c}
\end{equation}

which is now complex, containing both magnitude and phase information:

\begin{aligned}
  \frac{|X|}{|F|} &= \frac{1}{\sqrt{(k - \omega^2 m)^2 + (\omega c)^2}} \\\\\\
  \angle{X} - \angle{F} &= \text{tg}^{-1} \left( \frac{\omega c}{k - \omega^2 m} \right)
\end{aligned}

</div>


#### Structural Damping {#structural-damping}

All structures exhibit a degree of damping due to the **hysteresis properties** of the material(s) from which they are made.

A typical example of this effect is shown in the force displacement plot in figure [1](#org640f8a0) in which the **area contained by the loop represents the energy lost in one cycle of vibration** between the extremities shown.
The maximum energy stored corresponds to the elastic energy of the structure at the point of maximum deflection.
The damping effect of such a component can conveniently be defined by the ratio of these two:
\\[ \tcmbox{\text{damping capacity} = \frac{\text{energy lost per cycle}}{\text{maximum energy stored}}} \\]

<a id="table--fig:force-deflection-characteristics"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:force-deflection-characteristics">Table 1</a></span>:
  Force-deflection characteristics
</div>

| ![](/ox-hugo/ewins00_material_histeresis.png) | ![](/ox-hugo/ewins00_dry_friction.png) | ![](/ox-hugo/ewins00_viscous_damper.png) |
|-----------------------------------------------|----------------------------------------|------------------------------------------|
| <a id="org640f8a0"></a> Material hysteresis   | <a id="org915cf01"></a> Dry friction   | <a id="orgc37b9e9"></a> Viscous damper   |
| height=2cm                                    | height=2cm                             | height=2cm                               |

Another common source of energy dissipation in practical structures, is the **friction** which exist in joints between components of the structure.
It may be described very roughly by the simple **dry friction model** shown in figure [1](#org915cf01).

The mathematical model of the **viscous damper** which we have used can be compared with these more physical effects by plotting the corresponding force-displacement diagram for it, and this is shown in figure [1](#orgc37b9e9).
Because the relationship is linear between force and velocity, it is necessary to suppose harmonic motion, at frequency \\(\omega\\), in order to construct a force-displacement diagram.
The resulting diagram shows the nature of the approximation provided by the viscous damper model and the concept of the **effective or equivalent viscous damping coefficient** for any of the actual phenomena as being which provides the **same energy loss per cycle** as the real thing.

<div class="important">
  <div></div>

The problem which arises with the **viscous damping model** is that it has a **frequency-dependence in the amount of energy loss per cycle** whereas the dry friction mechanism is clearly unaffected by the frequency of loading and experiments suggests that the hysteresis effect is similarly independent of frequency.
Thus, we find a problem in obtaining a single equivalent viscous dashpot model which will be **valid over a range of frequencies**, such as will be necessary to represent the damping of a MDOF system over all, or at least several, of its modes of vibration.

</div>

An alternative theoretical damping model is provided by the **hysteretic** or **structural damper** which not only has the advantage that the **energy lost per cycle is independent of the frequency**, but also provides a much simpler analysis for MDOF systems.
However, it presents difficulties to a rigorous free vibration analysis and its application is generally focused on the forced response analysis.
In this case, we can write an equation of motion:
\\[ (-\omega^2 m + k + i d) X e^{i\omega t} = F e^{i \omega t} \\]

<div class="important">
  <div></div>

Receptance FRF - Structural Damping:

\begin{equation}
  \alpha(\omega) = \frac{1/k}{1 - \left(\omega/\bar{\omega}\_0\right)^2 + i \eta}
\end{equation}

where \\(\eta\\) is the **structural damping loss factor** and replaces the critical damping ratio used for the viscous damping model.

</div>


### Presentation and Properties of FRF data for SDOF system {#presentation-and-properties-of-frf-data-for-sdof-system}


#### Alternative Forms of FRF {#alternative-forms-of-frf}

So far we have defined our receptance frequency response function \\(\alpha(\omega)\\) as the ratio between a harmonic displacement response and the harmonic force \eqref{eq:receptance}.
This ratio is complex: we can look at its **amplitude** ratio \\(|\alpha(\omega)|\\) and its **phase** angle \\(\theta\_\alpha(\omega)\\).

We could have selected the response velocity \\(v(t)\\) as the output quantity and defined an alternative frequency response function \eqref{eq:mobility}.
Similarly we could use the acceleration parameter so we could define a third FRF parameter \eqref{eq:inertance}.

<div class="definition">
  <div></div>

**Mobility FRF**:

\begin{equation}
  \text{mobility} = Y(\omega) = \frac{V}{F} = i \omega \alpha(\omega) \label{eq:mobility}
\end{equation}

</div>

<div class="definition">
  <div></div>

**Inertance FRF**:

\begin{equation}
  \text{inertance} = A(\omega) = \frac{A}{F} = - \omega^2 \alpha(\omega) \label{eq:inertance}
\end{equation}

</div>

Table [2](#table--tab:frf-alternatives) gives details of all six of the FRF parameters and of the names used for them.

**Inverse response** can also be defined. For instance, the **dynamic stiffness** is defined as the force over the displacement.

<div class="definition">
  <div></div>

**Dynamic Stiffness**:

\begin{equation}
  \frac{\text{force}}{\text{displacement}} = (k - \omega^2 m) + (i \omega c) \label{eq:dynamic\_stiffness}
\end{equation}

</div>

It should be noted that that the use of displacement as the response is greatly encouraged as the other options can lead to confusion when used in MDOF system.

<a id="table--tab:frf-alternatives"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:frf-alternatives">Table 2</a></span>:
  Definition of Frequency Response Functions
</div>

|           | **Standard FRF**    | **Inverse FRF: FIR** |
|-----------|---------------------|----------------------|
| **Disp**. | Receptance          | Dynamic Stiffness    |
|           | Admittance          |                      |
|           | Dynamic compliance  |                      |
|           | Dynamic flexibility |                      |
| **Vel**.  | Mobility            | Mechanical Impedance |
| **Acc**.  | Accelerance         | Apparent Mass        |
|           | Inertance           |                      |


#### Graphical Displays of FRF Data {#graphical-displays-of-frf-data}

FRF data are complex and thus there are three quantities (frequency and two parts of the complex function) to display.
Any simple plot can only show two of the three quantities and so there are different possibilities available for the presentation of such data:

1.  Modulus of FRF vs Frequency and Phase of FRF vs Frequency: the **Bode plot**
2.  Real Part of FRF vs Frequency and Imaginary Part of FRF vs Frequency
3.  Real Part of reciprocal FRF vs Frequency and Imaginary part of reciprocal FRF vs Frequency
4.  Real part of FRF vs Imaginary part of FRF: the **Nyquist plot**


##### Bode Plot {#bode-plot}

Bode plot are usually displayed using logarithmic scales as shown on figure [3](#table--fig:bode-plots).

<a id="table--fig:bode-plots"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:bode-plots">Table 3</a></span>:
  FRF plots for undamped SDOF system
</div>

| ![](/ox-hugo/ewins00_bode_receptance.png) | ![](/ox-hugo/ewins00_bode_mobility.png) | ![](/ox-hugo/ewins00_bode_accelerance.png) |
|-------------------------------------------|-----------------------------------------|--------------------------------------------|
| <a id="org98a8b4c"></a> Receptance FRF    | <a id="orga72dec1"></a> Mobility FRF    | <a id="org92b33d3"></a> Accelerance FRF    |
| width=\linewidth                          | width=\linewidth                        | width=\linewidth                           |

Each plot can be divided into three regimes:

-   a low frequency straight line characteristic
-   a high frequency straight line characteristic
-   the resonant region with its abrupt magnitude and phase variations


##### Real part and Imaginary part of FRF {#real-part-and-imaginary-part-of-frf}

Real and imaginary part of a receptance FRF of a damped SDOF system is shown on figure [4](#table--fig:plot-receptance-real-imag).
This type of display is not widely used as we cannot use logarithmic axes (as we have to show positive and negative values).

<a id="table--fig:plot-receptance-real-imag"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:plot-receptance-real-imag">Table 4</a></span>:
  Plot of real and imaginary part for the receptance of a damped SDOF
</div>

| ![](/ox-hugo/ewins00_plot_receptance_real.png) | ![](/ox-hugo/ewins00_plot_receptance_imag.png) |
|------------------------------------------------|------------------------------------------------|
| <a id="org731c2d0"></a> Real part              | <a id="orgfb5a86a"></a> Imaginary part         |
| width=\linewidth                               | width=\linewidth                               |


##### Real part and Imaginary part of reciprocal FRF {#real-part-and-imaginary-part-of-reciprocal-frf}

It can be seen from the expression of the inverse receptance \eqref{eq:dynamic_stiffness} that the Real part depends entirely on the mass and stiffness properties while the Imaginary part is a only function of the damping.

Figure [5](#org50f821d) shows an example of a plot of a system with a combination of both viscous and structural damping. The imaginary part is a straight line whose slope is given by the viscous damping rate \\(c\\) and whose intercept at \\(\omega = 0\\) is provided by the structural damping coefficient \\(d\\).

<a id="table--fig:inverse-frf"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:inverse-frf">Table 5</a></span>:
  Inverse FRF plot for the system
</div>

| ![](/ox-hugo/ewins00_inverse_frf_mixed.png) | ![](/ox-hugo/ewins00_inverse_frf_viscous.png) |
|---------------------------------------------|-----------------------------------------------|
| <a id="org50f821d"></a> Mixed               | <a id="orgd67281f"></a> Viscous               |
| width=\linewidth                            | width=\linewidth                              |


##### Real part vs Imaginary part of FRF {#real-part-vs-imaginary-part-of-frf}

Figure [6](#table--fig:nyquist-receptance) shows Nyquist type FRF plots of a viscously damped SDOF system.
The missing information (in this case, the frequency) must be added by identifying the values of frequency corresponding to particular points on the curve.

<a id="table--fig:nyquist-receptance"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:nyquist-receptance">Table 6</a></span>:
  Nyquist FRF plots of the mobility for a SDOF system
</div>

| ![](/ox-hugo/ewins00_nyquist_receptance_viscous.png) | ![](/ox-hugo/ewins00_nyquist_receptance_structural.png) |
|------------------------------------------------------|---------------------------------------------------------|
| <a id="org09f1bd3"></a> Viscous damping              | <a id="org82484ab"></a> Structural damping              |
| width=\linewidth                                     | width=\linewidth                                        |

The Nyquist plot has the particularity of distorting the plot so as to focus on the resonance area.
This makes the Nyquist plot very effective for modal testing applications.


### Undamped MDOF Systems {#undamped-mdof-systems}


#### Free Vibration Solution - The modal Properties {#free-vibration-solution-the-modal-properties}

For an undamped MDOF system, with \\(N\\) degrees of freedom, the governing equations of motion can be written in matrix form \eqref{eq:undamped_mdof}.

<div class="important">
  <div></div>

**MDOF - Equation of Motion**;

\begin{equation}
  [M] \\{\ddot{x}(t)\\} + [K] \\{x(t)\\} = \\{f(t)\\} \label{eq:undamped\_mdof}
\end{equation}

where \\([M]\\) and \\([K]\\) are \\(N\times N\\) mass and stiffness matrices, and \\(\\{x(t)\\}\\) and \\(\\{f(t)\\}\\) are \\(N\times 1\\) vectors of time-varying displacements and forces.

</div>

We shall consider first the free vibration solution by taking \\(f(t) = 0\\).
In this case, we assume that a solution exists of the form \\(\\{x(t)\\} = \\{X\\} e^{i \omega t}\\) where \\(\\{X\\}\\) is an \\(N \times 1\\) vector of time-independent amplitudes.
Substitution of this condition into \eqref{eq:undamped_mdof} leads to

\begin{equation} \label{eq:free\_eom\_mdof}
  \left( [K] - \omega^2 [M] \right) \\{X\\} e^{i\omega t} = \\{0\\}
\end{equation}

for which the non trivial solutions are those which satisfy
\\[ \det \left| [K] - \omega^2 [M] \right| = 0 \\]
from which we can find \\(N\\) values of \\(\omega^2\\) corresponding to the undamped system's **natural frequencies**.

Substituting any of these back into \eqref{eq:free_eom_mdof} yields a corresponding set of relative values for \\(\\{X\\}\\): \\(\\{\psi\\}\_r\\) the so-called **mode shape** corresponding to that natural frequency.

<div class="important">
  <div></div>

The complete solution can be expressed in two \\(N \times N\\) **eigen matrices**.

\\[ \begin{bmatrix}
  \omega\_1^2 &        & 0 \\\\\\
             & \ddots &   \\\\\\
  0          &        & \omega\_n^2
\end{bmatrix}; \quad \Psi = \begin{bmatrix}
  & & \\\\\\
  \\{\psi\_1\\} & \dots & \\{\psi\_n\\} \\\\\\
  & &
\end{bmatrix} \\]

where \\(\bar{\omega}\_r^2\\) is the \\(r^\text{th}\\) **eigenvalue squared** and \\(\\{\psi\\}\_r\\) is a description of the corresponding **mode shape**

</div>

Various numerical procedures are available which take the system matrices \\([M]\\) and \\([K]\\) (the **Spatial Model**), and convert them to the two eigen matrices \\([\bar{\omega}\_r^2]\\) and \\([\Psi]\\) which constitute the **Modal Model**.

It is important to realize that whereas the eigenvalue matrix is unique, the eigenvector matrix is **not**.
Indeed, the natural frequencies are fixed quantities, and the mode shapes are subject to an **indeterminate scaling factor**.


#### Orthogonality Properties {#orthogonality-properties}

<div class="important">
  <div></div>

The modal model possesses some very important properties known as the **orthogonality properties**:

\begin{equation}
  \begin{aligned}
    [\Psi]^T[M][\Psi] &= [m\_r]\\\\\\
    [\Psi]^T[K][\Psi] &= [k\_r]
 \end{aligned}
\end{equation}

from which \\([\bar{\omega}\_r^2] = [m\_r]^{-1} [k\_r]\\) where \\(m\_r\\) and \\(k\_r\\) are often referred to as the **modal mass** and **modal stiffness** of mode \\(r\\).

</div>

Now, because the eigenvector matrix is subject to an **arbitrary scaling factor**, the values of \\(m\_r\\) and \\(k\_r\\) are not unique.

Among the many scaling or normalization processes, the **mass-normalization** has the most relevance.

<div class="important">
  <div></div>

The **mass-normalized eigenvectors** are written as \\([\Phi]\\) and have the particular property that

\begin{equation}
  \begin{aligned}
    [\Phi]^T[M][\Phi] &= [I]\\\\\\
    [\Phi]^T[K][\Phi] &= [\bar{\omega}\_r^2]
  \end{aligned}
\end{equation}

</div>

The relationship between the mass-normalized mode shape for mode \\(r\\) \\(\\{\Phi\\}\_r\\) and its more general form \\(\\{\Psi\\}\_r\\) is simply

\begin{equation}
  \\{\Phi\\}\_r = \frac{1}{\sqrt{m\_r}} \\{\Psi\\}\_r
\end{equation}


#### Modal, Generalized and Effective Mass and Stiffness {#modal-generalized-and-effective-mass-and-stiffness}

The **modal mass** is based on the mode shape vector for mode \\(r\\) and the system mass matrix.
As mentioned, there is no unique value for the modal mass as it is directly related to the scaling method which has been used to determine the mode shape eigenvector \\(\\{\Psi\\}\_r\\).
However, the ratio between any modal stiffness and its associated modal mass is unique and is equal to the corresponding eigenvalue.
The modal mass is generally used to convert the original mode shape vector \\(\\{\Psi\\}\_r\\) to the more useful mass-normalized mode shape vector \\(\\{\Phi\\}\_r\\).

<div class="definition">
  <div></div>

Using the mass-normalized mode shape vectors, we can see how to derive quantities which provide us with information about the **effective mass** (or stiffness) at any point on the structure (any DOF \\(j\\)).

The **effective mass** at DOF \\(j\\) for mode \\(r\\) is define as
\\[ (m\_{jj})\_r = \frac{1}{(\phi\_{jr})^2}, \text{ which as units of mass} \\]
and the **effective stiffness** at DOF \\(j\\) for mode \\(r\\)
\\[ (k\_{jj})\_r = \frac{\bar{\omega}\_r^2}{(\phi\_{jr}^2)} \\]

</div>

It can be seen that since the mass-normalized eigenvectors are unique, these effective mass and stiffness properties are also unique and represent a useful description of the behavior of the structure point by point, and mode by mode.

<div class="definition">
  <div></div>

The other quantities which are sometimes referred to as unique properties of each mode are the **generalized mass** and **generalized stiffness**.
The generalized mass (or stiffness) of the \\(r^{\text{th}}\\) mode is defined as the effective mass (or stiffness) at the DOF with the largest amplitude of response.
This quantity serves to provide a comparison of the **relative strength of each mode of the structure**.

</div>


#### Repeated Roots or Multiple Modes {#repeated-roots-or-multiple-modes}

There are situations where two (or more) different modes will have the **same natural frequency**.
This occurs frequently in structures which exhibit a degree of **symmetry** (especially axi-symmetry).
In these cases, there is no guarantee that the corresponding eigenvectors are orthogonal.
However, linear combinations of these vectors can always be found such that orthogonality is observed between the mode shapes.
It should be noted, that free vibration at that frequency is possible not only in each of the two vectors thus defined, but also in a deformation pattern which is given by **any linear combination** of these two vectors.


#### Force Response Solution - The FRF Characteristics {#force-response-solution-the-frf-characteristics}

Let's consider the case where the structure is excited sinusoidally by a set of forces all at the same frequency \\(\omega\\), but with individual amplitudes and phases: \\(\\{f(t)\\} = \\{F\\} e^{i\omega t}\\).

Assuming solutions of the form \\(\\{x(t)\\} = \\{X\\} e^{i \omega t}\\), equation of motion then becomes
\\[ \left( [K] - \omega^2 [M] \right) \\{X\\}e^{i\omega t} = \\{F\\}e^{i\omega t} \\]
That can be written in the following form:
\\[ \\{X\\} = \left( [K] - \omega^2 [M] \right)^{-1} \\{F\\} \\]

<div class="definition">
  <div></div>

We define the \\(N \times N\\) **receptance FRF matrix** as
\\[ [\alpha(\omega)] = \left( [K] - \omega^2 [M] \right)^{-1} \\]

It constitutes the **Response Model** of the system.

The general element in the receptance FRF matrix \\(\alpha\_{jk}(\omega)\\) is defined as follows
\\[ \alpha\_{jk}(\omega) = \frac{X\_j}{F\_k}, \quad F\_m = 0, m = 1 \dots N \neq k \\]

</div>

It is possible to determine values for the elements of \\([\alpha(\omega)]\\) at any frequency of interest by computing the inverse system matrix \\([K] - \omega^2[M]\\) at each frequency.
This has several disadvantages:

-   it becomes costly for large-order systems
-   it is inefficient if only a few of the individual FRF are required
-   it provides no insight into the form of the various FRF properties

An alternative means of deriving the FRF parameters is used which makes use of the **modal properties instead of the spatial properties**.
\\[ [K] - \omega^2 [M] = [\alpha(\omega)]^{-1} \\]
Pre-multiply both sides by \\([\Phi]^T\\) and post-multiply both sides by \\([\Phi]\\) to obtain
\\[ [\Phi]^T ([K] - \omega^2 [M]) [\Phi] = [\Phi]^T [\alpha(\omega)]^{-1} [\Phi] \\]
which leads to \eqref{eq:receptance_modal}.

<div class="important">
  <div></div>

Receptance FRF matrix - Modal Properties;

\begin{equation}
  [\alpha(\omega)] = [\Phi] \left[ \bar{\omega}\_r^2 - \omega^2 \right]^{-1} [\Phi]^T \label{eq:receptance\_modal}
\end{equation}

Equation \eqref{eq:receptance_modal} permits us to compute any individual FRF parameters \\(\alpha\_{jk}(\omega)\\) using the following formula

\begin{align}
  \alpha\_{jk}(\omega) &= \sum\_{r=1}^N \frac{\phi\_{jr} \phi\_{kr}}{\bar{\omega}\_r^2 - \omega^2}\\\\\\
                      &= \sum\_{r=1}^N \frac{\psi\_{jr} \psi\_{kr}}{m\_r (\bar{\omega}\_r^2 - \omega^2)}\\\\\\
                      &= \sum\_{r=1}^N \frac{{}\_rA\_{jk}}{\bar{\omega}\_r^2 - \omega^2}
\end{align}

where \\({}\_rA\_{jk}\\) is called the **modal constant**.

</div>

<div class="important">
  <div></div>

It is clear from equation \eqref{eq:receptance_modal} that the receptance matrix \\([\alpha(\omega)]\\) is **symmetric** and this will be recognized as the **principle of reciprocity**.

This principle of reciprocity applies to many structural characteristics.

Its implications in this situation are that

\begin{equation}
  \alpha\_{jk} = X\_j/F\_k = \alpha\_{kj} = X\_k/F\_j \label{eq:principle\_reciprocity}
\end{equation}

</div>


### MDOF Systems with Proportional Damping {#mdof-systems-with-proportional-damping}


#### General Concept and Features of Proportional Damping {#general-concept-and-features-of-proportional-damping}

The modes of a structure with proportional damping are almost identical to those of the undamped version of the model.
Specifically, the **mode shapes are identical** and the **natural frequencies are very similar**.

The equations of motion for an MDOF system with viscous damping is

\begin{equation}
  [M]\\{\ddot{x}\\} + [C]\\{\dot{x}\\} + [K]\\{x\\} = \\{f\\}
\end{equation}

Let's first study the special case where the damping matrix is directly **proportional to the stiffness matrix**:
\\[ [C] = \beta [K] \\]
In this case, we have that
\\[ [\Psi]^T [C] [\Psi] = \beta [k\_r] = [c\_r] \\]
where the diagonal elements \\(c\_{jj}\\) represent the **modal damping** of the various modes of the system.
The fact that this matrix is also diagonal means that the **undamped system mode shapes are also those of the damped system**, and this is a particular feature of this type of damping.

For the forced response analysis, we obtain
\\[ [\alpha(\omega)] = [ K + i \omega C - \omega^2 M ]^{-1} \\]
or

\begin{equation}
  \alpha\_{jk}(\omega) = \sum\_{r=1}^N \frac{\psi\_{jr}\psi\_{kr}}{(k\_r - \omega^2 m\_r) + i \omega c\_r}
\end{equation}


#### General Forms of Proportional Damping {#general-forms-of-proportional-damping}

If the damping matrix is proportional to the mass matrix, exactly the same type of result is obtained.
A usual definition of proportional damping is that the damping matrix \\([C]\\) should be of the form

\begin{equation} \label{eq:rayleigh\_damping}
  \tcmbox{[C] = \beta [K] + \gamma [M]}
\end{equation}

In this case, the damped system will have eigenvalues and eigenvectors as follows

\begin{align\*}
  &\omega\_r^\prime = \bar{\omega}\_r \sqrt{1 - \xi\_r^2} ; \quad \xi\_r = \frac{\beta \bar{\omega}\_r}{2} + \frac{\gamma}{2 \bar{\omega}\_r}\\\\\\
  &[\Psi\_\text{damped}] = [\Psi\_\text{undamped}]
\end{align\*}

Distributions of damping of this type are sometimes, tough not always, found to be plausible from a practical standpoint.
The actual damping mechanisms are usually to be found in parallel with stiffness elements (for **internal material of hysteresis damping**) or with mass elements (for **friction damping**).

Identical treatment can be made of an MDOF system with proportional **hysteretic damping**.
If the general system equations of motion are expressed as
\\[ [M]\\{\ddot{x}\\} + [K + iD]\\{x\\} = \\{f\\} \\]
and the hysteretic damping matrix \\([D]\\) has the form

\begin{equation}
  [D] = \beta [K] + \gamma [M]
\end{equation}

then, we find that the mode shapes for the damped system are again identical to those of the undamped system and that the eigenvalues take the complex form:
\\[ \lambda\_r^2 = \bar{\omega}\_r^2 (1 + i \eta\_r); \quad \bar{\omega}\_r^2 = \frac{k\_r}{m\_r}; \quad \eta\_r = \beta + \frac{\gamma}{\bar{\omega}\_r^2} \\]
and the general FRF is written as

\begin{equation}
  \alpha\_{jk}(\omega) = \sum\_{r=1}^N \frac{\psi\_{jr}\psi\_{kr}}{(k\_r - \omega^2 m\_r) + i \eta\_r k\_r}
\end{equation}


### MDOF Systems with Structural (Hysteretic) Damping {#mdof-systems-with-structural--hysteretic--damping}


#### Free Vibration Solution - Complex Modal Properties {#free-vibration-solution-complex-modal-properties}

We start by writing the general equation of motion for an MDOF system with hysteretic damping and harmonic excitation:
\\[ [M] \\{\ddot{x}\\} + [K]\\{x\\} +i[D]\\{x\\} = \\{F\\}e^{i\omega t} \\]

We consider first the case where there is no excitation and assume a solution of the form
\\[ \\{x\\} = \\{X\\} e^{i \lambda t} \\]
where \\(\lambda\\) is complex.

We then obtain **complex** eigenvalues and eigenvectors.

We choose to write the \\(r^\text{th}\\) eigenvalue as
\\[ \lambda\_r^2 = \omega\_r^2(1 + i \eta\_r) \\]
where \\(\omega\_r\\) is the **natural frequency** and \\(\eta\_r\\) is the **damping loss factor** for that mode.
The natural frequency \\(\omega\_r\\) is not necessarily equal to the natural frequency of the undamped system \\(\bar{\omega}\_r\\) although they are very close in practice.

The eigensolution can be seen to possess the same type of **orthogonality properties** as those demonstrated earlier for the undamped system:
\\[ [\Psi]^T[M][\Psi] = [m\_r] ; \quad [\Psi]^T[K + iD][\Psi] = [k\_r] \\]

The modal mass and stiffness parameters are now complex but still obey the relationship
\\[ \lambda\_r^2 = \frac{k\_r}{m\_r} \\]
and we define the mass-normalized eigenvectors
\\[ \\{\phi\\}\_r = \frac{1}{\sqrt{m\_r}} \\{\psi\\}\_r \\]


#### Forced Response Solution - FRF Characteristics {#forced-response-solution-frf-characteristics}

For the forced vibration analysis in the case of harmonic excitation and response, we obtain

\begin{equation} \label{eq:force\_response\_eom}
  \\{X\\} = \left( [K] + i[D] - \omega^2[M] \right)^{-1} \\{F\\}
\end{equation}

By multiplying both sides of the equation by the eigenvectors, we can write

\begin{equation} \label{eq:force\_response\_eom\_solution}
  [\alpha(\omega)] = [\Phi] [\lambda\_r^2 - \omega^2]^{-1} [\Phi]^T
\end{equation}

From this full matrix equation, we have:

\begin{align\*}
  \alpha\_{jk}(\omega) &= \sum\_{r=1}^N \frac{\phi\_{jr} \phi\_{kr}}{\omega\_r^2 - \omega^2 + i \eta\_r \omega\_r^2}\\\\\\
                      &= \sum\_{r=1}^N \frac{\psi\_{jr} \psi\_{kr}}{m\_r\left(\omega\_r^2 - \omega^2 + i \eta\_r \omega\_r^2\right)}\\\\\\
                      &= \sum\_{r=1}^N \frac{{}\_rA\_{jk}}{\omega\_r^2 - \omega^2 + i \eta\_r \omega\_r^2}\\\\\\
\end{align\*}


#### Excitation by a general Force Vector {#excitation-by-a-general-force-vector}


##### Operating deflection shape (ODS) {#operating-deflection-shape--ods}

Having derived an expression for the general term in the frequency response function matrix \\(\alpha\_{jk}(\omega)\\), it is appropriate to consider next the analysis of a situation where the system is **excited simultaneously at several points**.

The general behavior for this case is governed by equation \eqref{eq:force_response_eom} with solution \eqref{eq:force_response_eom_solution}.
However, a more explicit form of the solution is

\begin{equation} \label{eq:ods}
  \\{X\\} = \sum\_{r=1}^N \frac{\\{\phi\\}\_r^T \\{F\\} \\{\phi\\}\_r}{\omega\_r^2 - \omega^2 + i \eta\_r \omega\_r^2}
\end{equation}

This equation permits the calculation of one or more individual **responses to an excitation of several simultaneous harmonic forces** (all of which must have the same frequency but may vary in magnitude and phase).
The resulting vector of responses is sometimes referred to as **force vibration mode**, or more commonly, as an **Operating Deflection Shape** (**ODS**).


##### Pure mode excitation 1 - Damped system normal modes {#pure-mode-excitation-1-damped-system-normal-modes}

It is possible to choose the vector of individual forces such that the response of the structure is entirely controlled by a **single normal mode** of the structure.

<div class="definition">
  <div></div>

The **normal modes** are the characteristic modes of the structure in its actual (damped) state.
While it is possible to talk of the modes "that the structure would have if the damping could be removed", these are not the "normal" modes of the structures.
The properties of the normal modes of the undamped system are of interest because in most cases of test-analysis comparison, the analytical model will be undamped and so there is a desired to be able to extract the test structures "undamped" modes from the test data in order to do a direct comparison between prediction and measurement.

</div>

We are seeking an excitation vector \\(\\{F\\}\\) such that the **response** \\(\\{X\\}\\) **consists of a single modal component** so that all terms in \eqref{eq:ods} but one is zero.
This can be attained if \\(\\{F\\}\\) is chosen such that
\\[ \\{\phi\_r\\}^T \\{F\\}\_s = 0, \ r \neq s \\]


##### Pure mode excitation 2 - Associated undamped system normal modes {#pure-mode-excitation-2-associated-undamped-system-normal-modes}

We here consider an excitation vector of **mono-phased forces**.
We basically impose that all forces have the same frequency and phase.
What is of interest in this case it to see that there exist conditions under which it is possible to obtain a **similarly mono-phase response**.

Let the force and response vectors be represented by

\begin{align\*}
  \\{f\\} &= \\{\hat{F}\\} e^{i\omega t} \\\\\\
  \\{x\\} &= \\{\hat{X}\\} e^{i(\omega t - \theta)}
\end{align\*}

where both \\(\\{\hat{F}\\}\\) and \\(\\{\hat{X}\\}\\) are vectors of real quantities.
Substituting these into the equation of motion leads to a complex equation which can be split into real and imaginary parts to give

\begin{align\*}
  \left( (-\omega^2 [M] + [K]) \cos \theta + [D] \sin \theta \right) \\{\hat{X}\\} &= \\{\hat{F}\\} \\\\\\
  \left( (-\omega^2 [M] + [K]) \sin \theta - [D] \cos \theta \right) \\{\hat{X}\\} &= \\{0\\}
\end{align\*}

We can show that if we consider that the phase lag between all the forces and all the responses is exactly \\(\SI{90}{\degree}\\), the equation reduces to
\\[ (-\omega^2 [M] + [K])\\{\hat{X}\\} = 0 \\]
which is clearly the equation to be solved to find the undamped system natural frequencies and the mode shapes.

Thus we have the important results that it is always possible to find a set of mono-phased forces which will cause a mono-phased set of responses and, moreover, if these two sets are separated by exactly \\(\SI{90}{\degree}\\), then the frequency at which the system is vibrating is identical to one of its **undamped natural frequencies** and the displacement shape is the corresponding **undamped mode shape**.

This most important result is the basic for many of the multi-shaker test procedures used to isolate the undamped modes of the structures for comparison with theoretical predictions.
The physics of the technique are quite simple: the force vector is chosen so that it exactly balances all the damping forces.


##### Postscript {#postscript}

It is often observed that the analysis for hysteretic damping is less than rigorous when applied to the free vibration situation, as we have done above.
However, it is an admissible model of damping for describing harmonic forced vibration and this is the objective of most of our studies.
Moreover, it is always possible to express each of the receptance expression either as a ratio of two polynomials or as a series of simple terms.
Each of the terms in the series may be identified with one of the modes we have defined in the earlier free vibration analysis for the system.
Thus, whether or not the solution is strictly valid for a free vibration analysis, we can usefully and confidently consider each of the uncoupled terms or modes as being a genuine characteristic of the system.
As will be seen in the next section, the analysis required for the general case of viscous damping, which is more rigorous, is considerably more complicated than that used here which is, in effect, a very simple extension of the undamped case.


### MDOF systems with Viscous Damping {#mdof-systems-with-viscous-damping}


#### Free vibration solution - Complex modal properties {#free-vibration-solution-complex-modal-properties}

The general equation of motion for an MDOF system with viscous damping is

\begin{equation}
  [M] \\{\ddot{x}\\} + [C]\\{\dot{x}\\} + [K]\\{x\\} = \\{f\\}
\end{equation}

We first consider the case with no excitation, and consider solutions of the form
\\[ \\{x\\} = \\{X\\} e^{st} \\]

Substituting this into the equation of motion gives
\\[ \left( s^2 [M] + s[C] + [K] \right) \\{X\\} = \\{0\\} \\]

There are now \\(2N\\) eigenvalues \\(s\_r\\) (as opposed to \\(N\\) values of \\(\lambda\_r^2\\) before) but these now occur in **complex conjugate pairs**.
The eigenvectors also occur as **complex conjugates**.
The eigensolution can thus be described as
\\[ s\_r, s\_r^\*, \quad \\{\psi\\}\_r, \\{\psi\\}\_r^\*;\quad r = 1, N \\]

Each eigenvalue \\(s\_r\\) is expressed in the form
\\[ s\_r = \omega\_r \left( -\xi\_r + i\sqrt{1 - \xi\_r^2} \right) \\]
where \\(\omega\_r\\) is the **natural frequency** and \\(\xi\_r\\) is the **critical damping ratio** for that mode.

**Orthogonality equations** can also be derived:

\begin{align} \label{eq:viscous\_damping\_orthogonality}
  (s\_r + s\_q) \\{\psi\\}\_q^T [M] \\{\psi\\}\_r + \\{\psi\\}\_q^T [C] \\{\psi\\}\_r &= 0 \\\\\\
  s\_r s\_q \\{\psi\\}\_q^T [M] \\{\psi\\}\_r - \\{\psi\\}\_q^T [K] \\{\psi\\}\_r &= 0
\end{align}

When the modes \\(r\\) and \\(q\\) are a complex conjugate pair:
\\[ s\_r = \omega\_r \left( -\xi\_r - i\sqrt{1 - \xi\_r^2} \right); \quad \\{\psi\\}\_q = \\{\psi\\}\_r^\* \\]

From equations \eqref{eq:viscous_damping_orthogonality}, we can obtain

\begin{align}
  2 \omega\_r \xi\_r &= \frac{\\{\psi\\}\_r^H [C] \\{\psi\\}\_r}{\\{\psi\\}\_r^H [M] \\{\psi\\}\_r} = \frac{c\_r}{m\_r} \\\\\\
  \omega\_r^2 &= \frac{\\{\psi\\}\_r^H [K] \\{\psi\\}\_r}{\\{\psi\\}\_r^H [M] \\{\psi\\}\_r} = \frac{k\_r}{m\_r}
\end{align}


#### Forced response solution {#forced-response-solution}

Assuming a harmonic response \\(\\{x(t)\\} = \\{X\\} e^{i\omega t}\\), we can write the forced response solution directly as
\\[ \\{X\\} = \big( [K] - \omega^2 [M] + i\omega [C] \big)^{-1} \\{F\\} \\]
but this expression is not particularly convenient for numerical applications.

We then seek a similar series expansion that was found for the undamped, proportionally-damped and hysteretically damped systems.

The obtain result is
\\[ \alpha\_{jk}(\omega) = \sum\_{r=1}^N \frac{({}\_rR\_{jk}) + i (\omega/\omega\_r)({}\_rS\_{jk})}{\omega\_r^2 - \omega^2 + 2 i \omega \omega\_r \xi\_r} \\]
where the coefficients \\(R\\) and \\(S\\) are obtained from:

\begin{align\*}
  \\{{}\_rR\_k\\} &= 2 \left( \xi\_r \text{Re}\\{{}\_rG\_k\\} - \text{Im}\\{{}\_rG\_k\\} \sqrt{1 - \xi\_r^2} \right)\\\\\\
  \\{{}\_rS\_k\\} &= 2 \text{Re}\\{{}\_rG\_k\\}\\\\\\
  \\{{}\_rG\_k\\} &= (\theta\_{kr}/a\_r) \\{\theta\\}\_r
\end{align\*}

The main difference with the result obtained with the proportional damping is in the **frequency dependence of the numerator** in case of viscous damping.


### Complex Modes {#complex-modes}


#### Real and Complex modes, stationary and traveling waves {#real-and-complex-modes-stationary-and-traveling-waves}

We saw that we can obtain complex eigenvalues whose real part represents the decay and imaginary part the oscillatory component.
We can also obtain **complex eigenvectors** which means that the **mode shapes are complex**.

<div class="definition">
  <div></div>

A **complex mode** is one in which each part of the structure has not only its own magnitude of vibration but also its **own phase**.
As a result, each part of a structure which is vibrating in a complex mode will **reach its own maximum deflection at a different instant in the vibration cycle** to that of its neighbors.

</div>

<div class="definition">
  <div></div>

A **real mode** is one in which the phase angles are all identically \\(\SI{0}{\degree}\\) or \\(\SI{180}{\degree}\\) and which there has the property that all parts in the structure do reach their own maxima at the same time.
Equally, in a real mode, all parts of the structure pass through their **zero deflection position at the same instant** so that there are two moments in each vibration cycle when the structure is completely un-deformed.

</div>

While the real mode has the appearance of a **standing wave**, the complex mode is better described as exhibiting **traveling waves** (illustrated on figure [6](#org9e29afc)).

<a id="org9e29afc"></a>

{{< figure src="/ox-hugo/ewins00_real_complex_modes.png" caption="Figure 6: Real and complex mode shapes displays" >}}

Another method of displaying **modal complexity** is by plotting the elements of the eigenvector on an **Argand diagram**, such as the ones shown in figure [7](#table--fig:argand-diagram).
Note that the almost-real mode shape does not necessarily have vector elements with near \\(\SI{0}{\degree}\\) or near \\(\SI{180}{\degree}\\) phase, what matters are the **relative phases** between the different elements.

<a id="table--fig:argand-diagram"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:argand-diagram">Table 7</a></span>:
  Complex mode shapes plotted on Argand diagrams
</div>

| ![](/ox-hugo/ewins00_argand_diagram_a.png) | ![](/ox-hugo/ewins00_argand_diagram_b.png) | ![](/ox-hugo/ewins00_argand_diagram_c.png)    |
|--------------------------------------------|--------------------------------------------|-----------------------------------------------|
| <a id="orgc5f0718"></a> Almost-real mode   | <a id="org8caca26"></a> Complex Mode       | <a id="org4118fbf"></a> Measure of complexity |
| width=\linewidth                           | width=\linewidth                           | width=\linewidth                              |


#### Measurement of modal complexity {#measurement-of-modal-complexity}

There exist few indicators of the modal complexity.
The first one, a simple and crude one, called **MCF1** consists of summing all the phase differences between every combination of two eigenvector elements:
\\[ \text{MCF1} = \sum\_{j=1}^N \sum\_{k=1 \neq j}^N (\theta\_{rj} - \theta\_{rk}) \\]

The second measure is shown on figure [7](#org4118fbf) where a polygon is drawn around the extremities of the individual vectors.
The obtained area of this polygon is then compared with the area of the circle which is based on the length of the largest vector element. The resulting ratio is used as an indication of the complexity of the mode, and is defined as **MCF2**.


#### Origins of complex modes {#origins-of-complex-modes}

Complex modes occur in practice for variety of **physical reasons** as well as **poor measurement or analysis**:

-   The types of modes which are referred to as **operating deflection shapes** will frequently exhibit the relative phases differences between responses of adjacent parts of the structure which indicate a complex mode.
-   Complex normal modes can exist even in simple structures which contain rotating components that are prone to gyroscopic forces.
-   However, normal modes of non-rotating linear structures can be complex only if the **damping is distributed in a non-proportional way**.
    This situation can arise quite readily in practice because while the internal (hysteresis) damping of most structural elements is distributed in a way which is essentially proportional to the stiffness distribution, the **majority of the damping** in real structures is generally found to be **concentrated at the joints** between components of a structural assembly and this does not usually result in a proportional distribution.
-   Another ingredient is found to be necessary to generate significant complexity in a structure's mode and that is the requirement that **two or mode of its modes are close**.
    Close modes are those whose natural frequencies are separated by an amount which is less than the prevailing damping in either or both modes.


### Characteristics of MDOF FRF data {#characteristics-of-mdof-frf-data}


#### A note about natural frequencies {#a-note-about-natural-frequencies}

The basic definition derives from the **undamped system's eigenvalues** which yield the frequencies at which **free vibration of the system can take place**.
These undamped system natural frequencies are given by the square roots of the eigenvalues and are identified by the symbol \\(\bar{\omega}\_r\\).
This occurs in expressions for both free and forced vibration response:
\\[ x(t) = \sum\_{r=1}^N x\_r e^{i\bar{\omega}\_r t}; \quad \alpha(\omega) = \sum\_{r=1}^N \frac{A\_r}{\bar{\omega}\_r^2 - \omega^2} \\]

For **damped systems**, two alternative characteristics frequency are defined:

-   \\(\omega\_r^\prime\\) for **free vibration**
-   \\(\omega\_r\\) for **forced vibration**

The former constitutes the oscillatory part of the free vibration characteristic which, being **complex**, contains an exponential decay term as well:
\\[ x(t) = \sum\_{r=1}^N x\_r e^{-a\_r t} e^{i \omega\_r^\prime t} \\]
where \\(\omega\_r^\prime\\) may not be identical to \\(\bar{\omega}\_r\\) depending on the type and distribution of the damping.

The second definition comes from the general form of the FRF expression:
\\[ \alpha(\omega) = \sum\_{r=1}^N  \frac{C\_r}{\omega\_r^2 - \omega^2 + i D\_r} \\]
Here \\(C\_r\\) may be complex whereas \\(D\_r\\) is real.
\\(\omega\_r\\) is in general different to both \\(\bar{\omega}\_r\\) and \\(\omega\_r^\prime\\).

Table [8](#table--tab:frf-natural-frequencies) summarizes all the different cases.

<a id="table--tab:frf-natural-frequencies"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:frf-natural-frequencies">Table 8</a></span>:
  FRF Formulae and Natural Frequencies
</div>

| **Case**    | **C**                           | **D**                           | **Free** \\(\omega\_r^\prime\\)  | **Forced** \\(\omega\_r\\) |
|-------------|---------------------------------|---------------------------------|----------------------------------|----------------------------|
| Undamped    | \\(\mathbb{R}\\)                | 0                               | \\(\bar{\omega}\_r\\)            | \\(\bar{\omega}\_r\\)      |
| Prop. Hyst. | \\(\mathbb{R}\\)                | \\(\mathbb{R}\\)                | \\(\bar{\omega}\_r\\)            | \\(\bar{\omega}\_r\\)      |
| Prop. Visc. | \\(\mathbb{R}\\)                | \\(\mathbb{R}\\) (\\(\omega\\)) | \\(\omega\_r\sqrt{1-\xi\_r^2}\\) | \\(\bar{\omega}\_r\\)      |
| Gen. Hyst.  | \\(\mathbb{C}\\)                | \\(\mathbb{R}\\)                | \\(\omega\_r\\)                  | \\(\omega\_r\\)            |
| Gen. Visc.  | \\(\mathbb{C}\\) (\\(\omega\\)) | \\(\mathbb{R}\\) (\\(\omega\\)) | \\(\omega\_r\sqrt{1-\xi\_r^2}\\) | \\(\omega\_r\\)            |


#### Mobility and Impedance FRF Parameters {#mobility-and-impedance-frf-parameters}

As well as for SDOF systems, there are three main forms of FRF: using displacement (**receptance**), velocity (**mobility**) or acceleration (**inertance**) response.
There exist a further three formats for FRF data, these being the **inverses** of the standard receptance, mobility and inertance: the **dynamic stiffness**, **mechanical impedance** and **apparent mass**, respectively.

However, for MDOF systems it is usually **not feasible to measure the inverse properties**.
In general, we can determine the response of a structure to an excitation using the equation
\\[ {\dot{X}} = [Y(\omega)] \\{F\\} \\]
Equally, we can write the inverse equation using impedance instead of mobilities:
\\[ \\{F\\} = [Z(\omega)] \\{V\\} \\]

The problem arises because the general element in the mobility matrix \\(Y\_{ik}(\omega)\\) is not simply related to its counterpart in the impedance matrix \\(Z\_{ik}(\omega)\\) as was the case for SDOF systems (\\(Y\_{ik}(\omega) = Z\_{jk}^{-1}(\omega)\\)).

The reason for this is that
\\[ Y\_{kj}(\omega) = \left( \frac{V\_k}{F\_j} \right)\_{F\_l = 0}; \quad Z\_{jk}(\omega) = \left( \frac{F\_j}{V\_k} \right)\_{V\_l = 0}; \ l \neq k \\]

Thus, the measure of impedance property demands that **all DOFs expect one are grounded** which is almost impossible in practice.
The only types of FRF which we can expect to measure directly are the mobilities.


#### Display for Undamped System FRF data {#display-for-undamped-system-frf-data}


##### Construction of FRF plots for 2DOF system {#construction-of-frf-plots-for-2dof-system}

We can envisage the form which the total FRF curve will take as it is simply the summation of all the individual terms.
However, the exact shape of the curve also depends on the **phase** of each term.
Then the addition of various components is made to determine the complete receptance expression, the signs of the various terms are obviously of considerable importance.

Let's consider an example with two modes.
We write \\(\alpha\_{11}\\) the point FRF and \\(\alpha\_{21}\\) the transfer FRF:

\begin{align\*}
  \alpha\_{11}(\omega) &= \frac{0.5}{\omega\_1^2 - \omega^2} + \frac{0.5}{\omega\_2^2 - \omega^2} \\\\\\
  \alpha\_{21}(\omega) &= \frac{0.5}{\omega\_1^2 - \omega^2} - \frac{0.5}{\omega\_2^2 - \omega^2}
\end{align\*}

It can be seen that the only difference between the point and transfer receptance is in the sign of the modal constant of the second mode.

Consider the first point mobility (figure [9](#org1acadea)), between the two resonances, the two components have opposite signs so that they are substractive rather than additive, and indeed, at the point where they cross, their sum is zero.
On a logarithmic plot, this produces the antiresonance characteristic which reflects that of the resonance.

<a id="table--fig:mobility-frf-mdof"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:mobility-frf-mdof">Table 9</a></span>:
  Mobility FRF plot for undamped 2DOF system
</div>

| ![](/ox-hugo/ewins00_mobility_frf_mdof_point.png) | ![](/ox-hugo/ewins00_mobility_frf_mdof_transfer.png) |
|---------------------------------------------------|------------------------------------------------------|
| <a id="org1acadea"></a> Point FRF                 | <a id="orgff3476c"></a> Transfer FRF                 |
| width=\linewidth                                  | width=\linewidth                                     |

For the plot in figure [9](#orgff3476c), between the two resonances, the two components have the same sign and they add up, no antiresonance is present.


##### FRF modulus plots for MDOF systems {#frf-modulus-plots-for-mdof-systems}

The same principle may be extended to any number of DOF.
The fundamental rule is that **if two consecutive modes have the same sign for the modal constants**, then there will be an **antiresonance** at some frequency between the natural frequency of the two modes.
If they have apposite signs, there will not be an antiresonance.


#### Display of FRF Data for Damped systems {#display-of-frf-data-for-damped-systems}


##### Bode plots {#bode-plots}

The resonances and antiresonances are blunted by the inclusion of damping, and the phase angles are no longer exactly \\(\SI{0}{\degree}\\) or \\(\SI{180}{\degree}\\), but the general appearance of the plot is a natural extension of that for the system without damping.
Figure [7](#orga72841a) shows a plot for the same mobility as appears in figure [9](#org1acadea) but here for a system with added damping.

Most mobility plots have this general form as long as the modes are relatively well-separated.

This condition is satisfied unless the separation between adjacent natural frequencies is of the same order as, or less than, the modal damping factors, in which case it becomes difficult to distinguish the individual modes.

<a id="orga72841a"></a>

{{< figure src="/ox-hugo/ewins00_frf_damped_system.png" caption="Figure 7: Mobility plot of a damped system" >}}


##### Nyquist diagrams {#nyquist-diagrams}

Each of the frequency response of a MDOF system in the Nyquist plot is composed of a number of SDOF components.

Figure [10](#org498fea6) shows the result of plotting the point receptance \\(\alpha\_{11}\\) for the 2DOF system described above.

The plot for the transfer receptance \\(\alpha\_{21}\\) is presented in figure [10](#org6052b7b) where it may be seen that the opposing signs of the modal constants of the two modes have caused one of the modal circle to be in the upper half of the complex plane.

<a id="table--fig:nyquist-frf-plots"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:nyquist-frf-plots">Table 10</a></span>:
  Nyquist FRF plot for proportionally-damped system
</div>

| ![](/ox-hugo/ewins00_nyquist_point.png)  | ![](/ox-hugo/ewins00_nyquist_transfer.png)  |
|------------------------------------------|---------------------------------------------|
| <a id="org498fea6"></a> Point receptance | <a id="org6052b7b"></a> Transfer receptance |
| width=\linewidth                         | width=\linewidth                            |

In the two figures [11](#org6a1d778) and [11](#org58ff327), we show corresponding data for **non-proportional** damping.
In this case, a relative phase has been introduced between the first and second elements of the eigenvectors: of \\(\SI{30}{\degree}\\) in mode 1 and of \\(\SI{150}{\degree}\\) in mode 2.
Now we find that the individual modal circles are no longer "upright" but are **rotated by an amount dictated by the complexity of the modal constants**.

<a id="table--fig:nyquist-frf-nonpropdamp"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:nyquist-frf-nonpropdamp">Table 11</a></span>:
  Nyquist FRF plot for non-proportionally-damped system
</div>

| ![](/ox-hugo/ewins00_nyquist_nonpropdamp_point.png) | ![](/ox-hugo/ewins00_nyquist_nonpropdamp_transfer.png) |
|-----------------------------------------------------|--------------------------------------------------------|
| <a id="org6a1d778"></a> Point receptance            | <a id="org58ff327"></a> Transfer receptance            |
| width=\linewidth                                    | width=\linewidth                                       |


### Non-Sinusoidal vibration and FRF properties {#non-sinusoidal-vibration-and-frf-properties}

With receptance and other FRF data, we have a means of computing the response of a MDOF system to an excitation which consists of a set of harmonic forces of different amplitudes and phases but all of the same frequency.
In the general case we can simply write
\\[ \\{X\\} e^{i\omega t} = [\alpha(\omega)] \\{F\\} e^{i\omega t} \\]


#### Periodic vibration {#periodic-vibration}


##### Periodic signals as Fourier series {#periodic-signals-as-fourier-series}

Let's first consider the case of periodic vibration, in which the excitation (and thus the response) is not simply sinusoidal although it has a property of periodicity.

The easiest way of computing the responses in such a case is by mean of the **Fourier Series**.

The basic principle of Fourier analysis is that any periodic function can be represented by a series of sinudoids of suitable frequencies, amplitudes and phases based on the fundamental period \\(T\\):

\begin{equation}
  \tcmbox{f\_0(t) = \sum\_{n=1}^\infty {}\_0F\_n e^{i\omega\_n t}; \quad \omega\_n = \frac{2 \pi n}{T}}
\end{equation}

Once a frequency decomposition of the forcing function has been obtained, we may use the corresponding FRF data, computed at the specific frequencies present in the forcing spectrum, in order to compute the corresponding frequency components of the responses of interest:

\begin{equation}
  \tcmbox{x\_j(t) = \sum\_{n=1}^\infty \alpha\_{j0}(\omega\_n) {}\_0F\_ne^{i\omega\_n t}; \quad \omega\_n = \frac{2 \pi n}{T}}
\end{equation}


##### To derive FRF from periodic vibration signals {#to-derive-frf-from-periodic-vibration-signals}

It is possible to determine a system's FRF properties from excitation and response measurements when the vibration is periodic.
To do this, it is necessary to determine the **Fourier Series** components of **both the input force** signal and of the relevant **output response** signal.
Both these series will contain components at the same set of discrete frequencies; these being integer multiples of \\(2\pi/T\\).

One these two series are available, the FRF can be defined at the same set of frequency points by computing the **ratio of the response component to the input component**.


#### Transient vibration {#transient-vibration}


##### Analysis via Fourier transform {#analysis-via-fourier-transform}

For most transient cases, the input function \\(f(t)\\) will satisfy the **Dirichlet condition** and so its Fourier Transform \\(F(\omega)\\) can be computed from \eqref{eq:fourier_transform}.

\begin{equation} \label{eq:fourier\_transform}
  F(\omega) = \frac{1}{2 \pi} \int\_{-\infty}^\infty f(t) e^{i\omega t} dt
\end{equation}

Now, at any frequency \\(\omega\\), the corresponding Fourier Transform of the response \\(X(\omega)\\) can be determined from

\begin{equation}
  \tcmbox{X(\omega) = H(\omega) F(\omega)}
\end{equation}

where \\(H(\omega)\\) represents the appropriate version of the FRF for the particular input and output parameters considered.

We may then derive an expression for the response itself \\(x(t)\\) from the **Inverse Fourier Transform** of \\(X(\omega)\\)

\begin{equation}
  \tcmbox{x(t) = \int\_{-\infty}^\infty \left(H(\omega) F(\omega)\right)e^{i\omega t}d\omega}
\end{equation}


##### Response via time domain {#response-via-time-domain}

This alternative analysis is referred to as **convolution** and is based on the ability to compute the response of a system to a simple unit impulse.

Let consider a unit impulse excitation applied at \\(t = t^\prime\\) with infinite magnitude and that lasts for an infinitesimal period of time although the **area underneath it is equal to unity**.
The response of a system to such an excitation at \\(t>t^\prime\\) is defined as the system's unit **Impulse Response Function** (**IRF**) and has a direct relationship to the Frequency Response Function.

The IRF is written has
\\[ h(t - t^\prime) \\]

If we now consider a more general transient excitation, we see that it is possible to represent this as the **superposition of several impulses**, each of magnitude \\(f(t^\prime)dt^\prime\\) and occurring at different instants in time.
The response of a system at time \\(t\\) to just one of these incremental impulses at time \\(t^\prime\\) is
\\[ \delta x (t) = h(t - t^\prime) f(t^\prime) dt^\prime \\]
and the total response of the system will be given by superimposing or integrating all the incremental responses as follows
\\[ x(t) = \int\_{-\infty}^\infty h(t-t^\prime) f(t^\prime) dt^\prime; \quad h(t-t^\prime) = 0, \ t \leq t^\prime \\]

There is a very close relationship between \\(H(\omega)\\) and \\(h(t - t^\prime)\\).
Let's use the Fourier Transform approach to compute the response of a system to a unit impulse.
Thus, let \\(f(t) = \delta(0)\\) and determine its Fourier Transform \\(F(\omega)\\):
\\[ F(\omega) = \frac{1}{2 \pi} \int\_{-\infty}^\infty \delta(0) e^{i\omega t} dt = \frac{1}{2\pi} \\]
Then
\\[ x(t) = \frac{1}{2\pi} \int\_{-\infty}^{\infty} H(\omega) e^{i\omega t} d\omega \triangleq h(t) \\]

Thus, we find that the **Impulse and Frequency Response Functions constitute a Fourier Transform pair**.


##### To derive FRF from transient vibration signals {#to-derive-frf-from-transient-vibration-signals}

In order to obtain the structure's FRF properties using a transient vibration test, the calculation of the Fourier transforms of both the excitation and the response signals is required.
Then, the ratio of these two function can be computed

\begin{equation}
  H(\omega) = \frac{X(\omega)}{F(\omega)}
\end{equation}

This can be done provided that the time period of the measurement both excitation and response signals are effectively zero at the start and the end of the sample.


#### Random vibration {#random-vibration}


##### Random signals in time and frequency domains {#random-signals-in-time-and-frequency-domains}

We here consider both excitation and response described by random processes.
Neither excitation nor response signals can be subjected to a valid Fourier Transform calculation as they violate the Dirichlet condition.

It is necessary to introduce the **Correlation Function** and the **Spectral Densities**.

<div class="definition">
  <div></div>

The **Autocorrelation Function** \\(R\_{ff}(\tau)\\) of a random vibration parameter \\(f(t)\\), is defined as the expected value of the product \\(f(t) f(t + \tau)\\) computed along the time axis.
This will always be a **real and even function of time**, and is written

\begin{equation}
  R\_{ff}(\tau) = E[f(t) f(t + \tau)] \label{eq:autocorrelation}
\end{equation}

</div>

This correlation function, unlike the original quantity \\(f(t)\\) does satisfy the requirements for Fourier transformation and thus we can obtain its Fourier Transform by the usual equation.

The resulting parameter we shall call a **Spectral Density**, in this case the **Auto** or **Power Spectral Density** (PSD) \\(S\_{ff}(\omega)\\).

<div class="definition">
  <div></div>

**Power Spectral Density**:

\begin{equation}
  S\_{ff}(\omega) = \frac{1}{2\pi} \int\_{-\infty}^\infty R\_{ff}(\tau) e^{-i \omega \tau} d\tau \label{eq:powerspectraldensity}
\end{equation}

</div>

The Spectral Density is a real and even function of frequency, and does in fact provides a description of the frequency composition of the original function \\(f(t)\\).
It has units of \\(f^2/\omega\\).

Examples of random signals, autocorrelation function and power spectral density are shown on figure [12](#table--fig:random-signals).

<a id="table--fig:random-signals"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:random-signals">Table 12</a></span>:
  Random signals
</div>

| ![](/ox-hugo/ewins00_random_time.png) | ![](/ox-hugo/ewins00_random_autocorrelation.png) | ![](/ox-hugo/ewins00_random_psd.png)           |
|---------------------------------------|--------------------------------------------------|------------------------------------------------|
| <a id="orgc7de431"></a> Time history  | <a id="orge5f7f25"></a> Autocorrelation Function | <a id="org023b27f"></a> Power Spectral Density |
| width=\linewidth                      | width=\linewidth                                 | width=\linewidth                               |

A similar concept can be applied to a pair of functions such as \\(f(t)\\) and \\(x(t)\\) to produce **cross correlation** and **cross spectral density** functions.

<div class="definition">
  <div></div>

The **cross correlation function** \\(R\_{xf}(\tau)\\) between functions \\(f(t)\\) and \\(x(t)\\) is defined as

\begin{equation}
  R\_{xf}(\tau) = E[x(t) f(t + \tau)] \label{eq:crosscorelation}
\end{equation}

</div>

<div class="definition">
  <div></div>

The **Cross Spectral Density** (CSD) is defined as the Fourier Transform of the Cross Correlation function:

\begin{equation}
  S\_{xf}(\omega) = \frac{1}{2\pi} \int\_{-\infty}^\infty R\_{xf}(\tau) e^{-i \omega \tau} d\tau \label{eq:cross\_spectral\_density}
\end{equation}

</div>

Cross correlation functions are real, but not always even, functions of time, and cross spectral densities, unlike auto spectral densities, are generally complex functions of frequency with the particular **conjugate property** that
\\[ S\_{xf}(\omega) = S\_{fx}^\*(\omega) \\]

The analysis to obtain the input/output relationships for systems undergoing random vibrations is based on the general excitation/response relationship in the time domain:
\\[ x(t) = \int\_{-\infty}^\infty h(t - t^\prime) f(t^\prime) dt^\prime \\]

Using this property, it is possible to derive an expression for $x(t) and for \\(x(t - \tau)\\) and thus to calculate the response autocorrelation \\(R\_{xx}(\tau)\\)
\\[ R\_{xx}(\tau) = E[x(t) x(t + \tau)] \\]

This equation can be manipulated to describe the response autocorrelation in terms of the corresponding property of the excitation \\(R\_{ff}\\), but the result is complicated.
However, the same equation can be transform to the frequency domain

\begin{equation} \label{eq:psd\_input\_output}
  \tcmbox{ S\_{xx}(\omega) = \left| H(\omega) \right|^2 S\_{ff}(\omega) }
\end{equation}

Although very convenient, equation \eqref{eq:psd_input_output} does not provide a complete description of the random vibration conditions.
Further, it is clear that **is could not be used to determine the FRF** from measurement of excitation and response because it **contains only the modulus** of \\(H(\omega)\\), the phase information begin omitted from this formula.

A second equation is required and this may be obtain by a similar analysis, two alternative formulas can be obtained \eqref{eq:cross_relation_alternatives}.

<div class="important">
  <div></div>

\begin{align} \label{eq:cross\_relation\_alternatives}
  S\_{fx}(\omega) &= H(\omega) S\_{ff}(\omega) \\\\\\
  S\_{xx}(\omega) &= H(\omega) S\_{xf}(\omega)
\end{align}

</div>


##### To derive FRF from random vibration signals {#to-derive-frf-from-random-vibration-signals}

The pair of equations \eqref{eq:cross_relation_alternatives} provides the basic of determining a system's FRF properties from the measurements and analysis of a random vibration test.
Using either of them, we have a simple formula for determining the FRF from estimates of the relevant spectral densities \eqref{eq:H1} \eqref{eq:H2}.

<div class="important">
  <div></div>

\begin{equation} \label{eq:H1}
  H(\omega) = \frac{S\_{fx}(\omega)}{S\_{ff}(\omega)} = H\_1(\omega)
\end{equation}

\begin{equation} \label{eq:H2}
  H(\omega) = \frac{S\_{xx}(\omega)}{S\_{xf}(\omega)} = H\_2(\omega)
\end{equation}

</div>

The existence of two equations presents an opportunity to **check the quality** of calculations made using measured data.


##### Instrumental variable model for FRF {#instrumental-variable-model-for-frf}

There are difficulties to implement some of the above formulae in practice because of noise and other limitations concerned with the data acquisition and processing.

One technique involves **three quantities**, rather than two, in the definition of the output/input ratio.
The system considered can best be described with reference to figure [13](#table--fig:frf-determination) which shows first in [13](#orgc413fea) the traditional single-input single-output model upon which the previous formulae are based.
Then in [13](#org1dd02c9) is given a more detailed and representative model of the system which is used in a modal test.

<a id="table--fig:frf-determination"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:frf-determination">Table 13</a></span>:
  System for FRF determination
</div>

| ![](/ox-hugo/ewins00_frf_siso_model.png) | ![](/ox-hugo/ewins00_frf_feedback_model.png)     |
|------------------------------------------|--------------------------------------------------|
| <a id="orgc413fea"></a> Basic SISO model | <a id="org1dd02c9"></a> SISO model with feedback |
| width=\linewidth                         | width=\linewidth                                 |

In this configuration, it can be seen that there are two feedback mechanisms which apply.
We then introduce an alternative formula which is available for the determination of the system FRF from measurements of the input and output quantities \eqref{eq:H3}.

<div class="important">
  <div></div>

\begin{equation} \label{eq:H3}
  H(\omega) = \frac{S\_{x^\prime v}(\omega)}{S\_{f^\prime v(\omega)}} = H\_3(\omega)
\end{equation}

where \\(v\\) is a third signal in the system.

</div>


##### Derivation of FRF from MIMO data {#derivation-of-frf-from-mimo-data}

A diagram for the general n-input case is shown in figure [8](#orgad01713).

We obtain two alternative formulas:

\begin{align}
  \left[ H\_{xf}(\omega) \right]\_{n \times n} &= \left[ S\_{x^\prime v}(\omega) \right]\_{n \times n} \left[ S\_{f^\prime v}(\omega) \right]\_{n \times n}^{-1} \\\\\\
  \left[ H\_{xf}(\omega) \right]\_{n \times n} &= \left[ S\_{f^\prime f^\prime}(\omega) \right]\_{n \times n}^{-1} \left[ S\_{x^\prime f^\prime}(\omega) \right]\_{n \times n}
\end{align}

In practical application of both of these formulae, care must be taken to ensure the non-singularity of the spectral density matrix which is to be inverted, and it is in this respect that the former version may be found to be more reliable.

<a id="orgad01713"></a>

{{< figure src="/ox-hugo/ewins00_frf_mimo.png" caption="Figure 8: System for FRF determination via MIMO model" >}}


### Complete and Incomplete models {#complete-and-incomplete-models}


#### Some definitions {#some-definitions}

Most of the preceding theory has been concerned with complete models; that is, the analysis has been presented for an \\(N\\) degree-of-freedom system with the implicit assumption that all the mass, stiffness and damping properties are known and that all the elements in the eigenmatrices and the FRF matrix are available.
While this is a valid approach for a theoretical study, it is less generally applicable for experimentally-based investigations where it is **not usually possible to measure all the DOFs**, or to examine all the modes possessed by a structure.
Because of this limitation, it is necessary to extend our analysis to examine the **implications of having access to something less than a complete set of data**, or model, and this leads us to the concept of a **reduced** or **incomplete** type of model.

<div class="important">
  <div></div>

There are **different types of incomplete models**:

1.  There is the model which is reduced in size (from \\(N\\) to \\(n\\)) by simply **deleting information about certain degrees-of-freedom**.
    This process leads to a reduced model which retains **full accuracy for the DOFs which are retained**, but which **looses access to those which have been deleted**.
    The process can be **applied only to the modal and response models** and results in a modal model described by an \\(N\times N\\) eigenvalue matrix but by an eigenvector matrix which is only \\(n\times N\\).
    The corresponding response model is an incomplete FRF matrix of size \\(n \times n\\), although all the elements of that reduced matrix are themselves fully accurate.
2.  Another type of reduced model is one in which the **number of modes is reduced as well** (from \\(N\\) to \\(m\\)), so that the eigenvalue matrix is only \\(m \times m\\) in size.
    A consequence of this is that the elements in the reduced \\(n \times n\\) FRF matrix in this case are only **approximate**.
3.  Another type of model reduction can be achieved by **condensation** from \\(N\\) to \\(n\\) DOFs.
    This is a process in which a number of DOFs are again eliminated from the complete description but an attempt is made to include the effects of the masses and stiffnesses which are thereby eliminated in the retained DOFs.
    This is the **condensation process** which is applied in the **Guyan** and other **reduction techniques** used to contain the size of otherwise very large finite element models.
    In such a condensed model, the spatial, modal and response models are all reduced to \\(n \times n\\) matrices, and it must be noted that the properties of each are approximate in every respect.

</div>


#### Incomplete Response models {#incomplete-response-models}

There are two ways in which a model can be incomplete: by the **omission of some modes**, and/or by the **omission of some degrees-of-freedom**.


##### Omission of some DOFs {#omission-of-some-dofs}

Consider first the complete FRF matrix which is \\(N \times N\\):
\\[ \left[ H(\omega) \right]\_{N \times N} \\]
and then suppose that we decide to limit our description of the system to **include certain DOFs only**.
Our reduced response model is now
\\[ \left[ H^R(\omega) \right]\_{n \times n} \\]

Now it is clear that we have not altered the basic system, and it still has the same number of degrees-of-freedom even though we have **foregone our ability to describe the system's behavior at all of them**.
In this case, the elements which remain in the reduced FRF matrix are **identical** to the corresponding elements in the full \\(N \times N\\) matrix.

At this point, it is appropriate to mention the consequences of this type of reduction on the impedance type of FRF data.
The impedance matrix which corresponds to the reduced model defined by \\([H^R]\\) will be denoted as \\([Z^R]\\) and it is clear that
\\[ [Z^R(\omega)] = [H^R(\omega)]^{-1} \\]

It is also clear that the elements in the reduced impedance matrix such as \\(Z\_{jk}^R\\) are **not** the same quantities as the corresponding elements in the full impedance matrix, and indeed, a completely different impedance matrix applied to each specific reduction:
\\[ H\_{ij}^R(\omega) = H\_{ij}(\omega); \quad Z\_{ij}(\omega) \neq Z\_{ij}(\omega) \\]

We can also consider the implications of this form of reduction on the other types of model, namely the modal model and the spatial model.
For the **modal model**, elimination of the data pertaining to some of the DOFs results in a smaller eigenvector matrix, which then becomes rectangular of order \\(n \times N\\).
The corresponding eigenvalue matrix is still \\(N \times N\\) because we still have all \\(N\\) modes included.

For the **spatial model**, it is more difficult to effect a reduction of this type.
It is clearly not realistic simply to remove the rows and columns corresponding to eliminated DOFs from the mass and stiffness matrices as this would represent a drastic change to the system.
It is possible, however, to reduce these spatial matrices by a number of methods which have the effect of redistributing the mass and stiffness properties which relate to the redundant DOFs among those which are retained.
In this way, the total mass of the structure, and its correct-stiffness properties can be largely retained.
The **Guyan reduction procedure** is perhaps the best known of this type.
Such reduced spatial properties will be denoted as
\\[ \left[M^R\right], \ \left[K^R\right] \\]


##### Omission of some modes {#omission-of-some-modes}

Let's consider the other form of reduction in which only \\(m\\) of the \\(N\\) modes of the system are included.
Frequently, this is a necessary approach in that **many of the high-frequency modes will be of little interest** and almost certainly very difficult to measure.
Consider first the FRF matrix and include initially **all** the DOFs but suppose that each element in the matrix is computed using only \\(m\\) of the \\(N\\) terms in the summation
\\[ \tilde{H}\_{jk}(\omega) = \sum\_{r=1}^{m\leq N} \frac{{{}\_rA\_{jk}}}{\omega\_r^2 - \omega^2 + i \eta\_r \omega\_r^2} \\]
In full, we can write the FRF matrix as
\\[ \left[\tilde{H}(\omega)\right]\_{N\times N} = \left[\Phi\right]\_{N \times m} \left[\lambda\_r^2 - \omega^2\right]\_{m \times m}^{-1} \left[\Phi\right]\_{m \times N}^T  \\]


##### Combination of both reduction {#combination-of-both-reduction}

Of course, both types of reduction can be combined, the resulting matrix obtained would be
\\[ \left[ \hat{H}^R(\omega) \right]\_{n \times n} \\]
However, \\([\hat{H}^R(\omega)]\\) will in general be rank deficient, and thus is will not be possible to obtain the impedance matrix by numerical inversion.
In order to overcome this problem, it is often convenient to add a constant or **residual term** to each FRF:
\\[ [H(\omega)] = [\hat{H}(\omega)] + [R] \\]


#### Incomplete modal and spatial models {#incomplete-modal-and-spatial-models}

It has been shown that the **orthogonality properties** of the modal model provide a direct **link between the modal and the spatial model**:
\\[ [\Phi]^T [M] [\Phi] = [I]; \quad [\Phi]^T [K] [\Phi] = [\omega\_r^2] \\]
Which can be inverted to yield

\begin{equation} \label{eq:spatial\_model\_from\_modal}
  \begin{aligned}
    [M] &= [\Phi]^{-T}[\Phi]^{-1}\\\\\\
    [K] &= [\Phi]^{-T}[\omega\_r^2][\Phi]^{-1}
  \end{aligned}
\end{equation}

If the modal model is incomplete, then we can note the implications for the orthogonality properties.

First, if we have a **modal incompleteness** (\\(m<N\\) modes included), then we can write:

\begin{equation}
  \begin{aligned}
    [\Phi]\_{m\times N}^T [M] [\Phi]\_{N\times m} &= [I]\_{m\times m}\\\\\\
    [\Phi]\_{m\times N}^T [K] [\phi]\_{N\times m} &= [\omega\_r^2]\_{m\times m}
  \end{aligned}
\end{equation}

However, if we have **spatial incompleteness** (only \\(n<N\\) DOFs included), then we cannot express any orthogonality properties at all because the eigenvector matrix is not commutable with the system mass and stiffness matrices.

In both reduced-model cases, it is not possible to use equation \eqref{eq:spatial_model_from_modal} to re-construct the system mass and stiffness matrices.
First of all because the eigen matrices are generally singular and even if it is not, the obtained mass and stiffness matrices produced have no physical significance and should not be used.


### Sensitivity of models {#sensitivity-of-models}


#### Introduction {#introduction}

<div class="definition">
  <div></div>

The **sensitivity** of a model describe the rates of change of some of the key properties, such as the natural frequencies and mode shapes, with small changes in some of the modal parameters, such as individual masses of stiffnesses.

</div>

The model sensitivities are required for various purposes:

-   they help to locate errors in models
-   the are useful in guiding design optimization procedures
-   they are used in the course of curve-fitting for the purposes of testing the **reliability** of the modal analysis processes


#### Modal sensitivities {#modal-sensitivities}

The most commonly used sensitivities are those which describe the **rates of change of the modal parameters with the individual mass and stiffness elements in the spatial model**.
These quantities are defined as follows:
\\[ \frac{\partial \omega\_r}{\partial p} \text{ and } \frac{\partial \\{\phi\\}\_r}{\partial p} \\]
where \\(p\\) represents any variable of interest


##### SDOF system {#sdof-system}

It is useful to approach the general expressions for these parameters via a simple example based on an undamped SDOF system.
We can introduce the concept of sensitivity through the basic SDOF system comprising mass \\(m\\) and spring \\(k\\).
We can define the basic sensitivities of the system's natural frequency \\(\omega\_0\\):
\\[ \frac{\partial \omega\_0}{\partial m} \text{ and } \frac{\partial \omega\_0}{\partial k} \\]

We can show that:
\\[ \frac{\partial \omega\_0^2}{\partial m} = \frac{-\sqrt{k}}{m^2} ; \quad \frac{\partial \omega\_0}{\partial k} = \frac{1}{2 \sqrt{km}} \\]


##### MDOF systems - eigenvalue sensitivity {#mdof-systems-eigenvalue-sensitivity}

We can differentiate the following equation of motion of a MDOF system with respect to an arbitrary variable \\(p\\) that might be an individual mass \\(m\_i\\) of stiffness \\(k\_j\\).
\\[ \left( [K] - \omega\_r^2 [M] \right) \\{\phi\\}\_r = \\{0\\} \\]

We then obtain
\\[ \frac{\partial \omega\_r^2}{\partial p} = \\{\phi\\}\_r^T \left( \frac{\partial [K]}{\partial p} - \omega\_r^2 \frac{\partial [M]}{\partial p} \right) \\{\phi\\}\_r \\]


##### MDOF systems - eigenvector sensitivity {#mdof-systems-eigenvector-sensitivity}

A similar analysis can be made for the eigenvector sensitivity terms.


#### FRF sensitivities {#frf-sensitivities}

It may be seen it is also possible to derive **FRF sensitivities**.

If we consider first the simple SDOF system with a receptance FRF \\(\alpha(\omega)\\)
\\[ \alpha(\omega) = \frac{1}{k + i \omega c - \omega^2 m} \\]
We can differentiate this with respect to \\(m\\) and \\(k\\).

The same can be done with the more general case for \\(MDOF\\) system as follows:
\\[ \frac{\partial [\alpha(\omega)]}{\partial p} = [\alpha(\omega)] \left( \frac{\partial [K]}{\partial p} + i \omega \frac{\partial [C]}{\partial p} - \omega^2\frac{\partial [M]}{\partial p} \right) [\alpha(\omega)] \\]


#### Modal sensitivities from FRF data {#modal-sensitivities-from-frf-data}

There exists the possibility of deriving certain sensitivity parameters directly from FRF data such as can be measured in a modal test.
Essentially, it is possible to derive expressions for the **eigenvalue sensitivities to selected individual mass and stiffness parameters** by analyzing the point FRF properties at the selected DOFs.


## FRF Measurement Techniques {#frf-measurement-techniques}


### Introduction and Test Planning {#introduction-and-test-planning}


#### Introduction {#introduction}

There are **two types of vibration measurement**:

-   those in which just the response level is measured
-   those in which both input and response output parameters are measured

Recalling the basic relationship:
\\[ \tcmbox{ \text{response} = \text{properties} \times \text{input} } \\]

We can see that **only** when two of the three terms in this equation have been measured, we can defined completely what is going on in the vibration of the test object.
If we measure only the response, then we are unable to say whether a particularly large response level is due to a strong excitation or to a resonance of the structure.

For the second type of vibration measurement, both the excitation and the response are measured **simultaneously** so that basic equation can be used to deduce the system properties.

Our interest will first be on the **mobility measurements** or **FRF measurements** where the **excitation is applied at a single point**.
In that case, FRF data are directly obtained by "dividing" the measured responses by the measured excitation force.

Responses obtained using **several simultaneous excitations** yield **Operation Deflection Shapes** (ODSs) from which it is necessary to extract the required FRF data by sometimes complicated analysis procedures.
These are referred to as **MIMO tests**.


#### Test Planning {#test-planning}

It is clear that there will need to be an extensive test planning phase before full-scale measurements are made an decisions taken concerning the methods of excitation, signal processing and data analysis, as well as the proper selection of which data to measure, where to excite the structure and how to prepare and support it for those measurements.


#### Checking the quality of the measured data {#checking-the-quality-of-the-measured-data}


##### Signal Quality {#signal-quality}

It is sometimes found that the dynamic range of the measured quantities is extreme, especially when the frequency range being covered is wide.
What often happens is that there is a very large component of signal in one frequency range that dictates the gain settings on amplifiers and analysers such that lower-level components are difficult to measure accurately.


##### Signal fidelity {#signal-fidelity}

This arise when the signals obtained do not truly represent the quantity which is to be measured.
For example, large motion perpendicular to the measurement axis can contaminate the measurement and gives misleading indications.

One should verify that the labeling and the connection of transducers are correct.
This can be check by looking at the pattern of resonances visible on the FRF curves:

-   for excitation and response at the same DOF, resonances and anti-resonances must alternate
-   excitation and response points which are well separated on the test structure will tend to possess fewer anti-resonances


##### Measurement repeatability {#measurement-repeatability}

One essential check for any modal test is the repeatability of the measurements.
Certain FRF should be re-measured from time to time, just to check that neither the structure nor the measurement system have experienced any significant changes.


##### Measurement reliability {#measurement-reliability}

We here seek to establish that the measured data are independent of the measuring system.
One should measure the same quantity (usually an FRF) with a slightly different setup, or procedure such as a different excitation signal.
These checks are very important to demonstrate the underlying validity of the measurement method being used.


##### Measured data consistency, including reciprocity {#measured-data-consistency-including-reciprocity}

The various FRF data measured on a given structure should exhibit consistency, by which is meant that the underlying natural frequencies, damping factors and mode shapes visible in the FRF data must all derive from a common modal model.

The reciprocity expected to exist between FRFs such as \\(H\_{jk}\\) and \\(H\_{kj}\\) should be checked and found to be at an acceptable level.


### Basic Measurement System {#basic-measurement-system}

The experimental setup used for mobility measurement contains three major items:

1.  **An excitation mechanism**. This contains a source for the excitation signal (sinusoidal, periodic, random, transient), a power amplifier and a exciter (usually a shaker or an hammer)
2.  **A transduction system**. For the most part, piezoelectric transducer are used, although lasers and strain gauges are convenient because of their minimal interference with the test object. Conditioning amplifiers are used depending of the transducer used
3.  **An analyzer**

A typical layout for the measurement system is shown on figure [9](#org5658974).

<a id="org5658974"></a>

{{< figure src="/ox-hugo/ewins00_general_frf_measurement_setup.png" caption="Figure 9: General layout of FRF measurement system" >}}


### Structure preparation {#structure-preparation}


##### Free supports {#free-supports}

By "free" is meant that the test object is not attached to ground at any of its coordinates and is, in effect, freely suspended in space.
In this condition, the structure will exhibit rigid body modes which are determined solely by its mass and inertia properties and in which there is no bending or flexing at all.
Six rigid body modes are then obtained with a natural frequency of \\(\SI{0}{Hz}\\).
Mass and inertial properties can then be measured with such a support.

However, in practice it is not feasible to provide a truly free support.
Approximate to the free condition can be achieved by supporting the testpiece on very soft springs such that the frequency of the rigid body mode are less than \\(\SI{10}{\%}\\) of that of the lowest resonance frequency.


##### Grounded supports {#grounded-supports}

The other type of support is referred to as "grounded" because it attempts to fix selected points on the structure to ground.
In practice, it is very difficult to attach the test structure to a base structure which is sufficiently rigid to provide the necessary grounding.

The safest procedure is to measure the mobility FRF of the base structure itself over the frequency range for the test and to establish that this is a much lower mobility than the corresponding levels for the test structure at the point of attachment.
If this condition is satisfied for all the coordinates to be grounded, then the base structure can reasonably be assumed to be grounded.


##### Loaded boundaries {#loaded-boundaries}

A compromise procedure can be applied in which the test object is connected at certain coordinates to another simple component of known mobility, such as a specific mass.
The effects of the added component is then removed analytically.


### Excitation of the structure {#excitation-of-the-structure}

Devices for exciting the structure can be divided into two type:

-   **Contacting**: these involves the connection of an exciter of some form which remains attached to the structure throughout the test.
-   **Non-contacting**: devices which are either out of contact throughout the vibration (such as provided by a voice coil) or which are only in contact for a short period (such as a hammer)

Exciters are often limited at very low frequencies by the stroke rather than by the force generated.


#### Electromagnetic Exciters {#electromagnetic-exciters}

The most common type of exciter is the electromagnetic shaker in which a magnetic force is applied is applied on the structure without any physical contact.

The frequency and amplitude of the excitation are controlled independently of each other, which gives flexibility.

However, we need a direct measurement of the force applied to the structure (we cannot rely on the current going through the coil).

The shakers are usually stiff in the orthogonal directions to the excitation.
This can modify the response of the system in those directions.
In order to avoid that, a drive rod which is stiff in one direction and flexible in the other five directions is attached between the shaker and the structure as shown on figure [10](#org227d83a).
Typical size for the rod are \\(5\\) to \\(\SI{10}{mm}\\) long and \\(\SI{1}{mm}\\) in diameter, if the rod is longer, it may introduce the effect of its own resonances.

<a id="org227d83a"></a>

{{< figure src="/ox-hugo/ewins00_shaker_rod.png" caption="Figure 10: Exciter attachment and drive rod assembly" >}}

The support of shaker is also of primary importance.

The setup shown on figure [14](#org0d724dc) presents the most satisfactory arrangement in which the shaker is fixed to ground while the test structure is supported by a soft spring.

Figure [14](#orgf8ba17d) shows an alternative configuration in which the shaker itself is supported.
It may be necessary to add an additional inertia mass to the shaker in order to generate sufficient excitation forces at low frequencies.

Figure [14](#orge6e0404) shows an unsatisfactory setup. Indeed, the response measured at \\(A\\) would not be due solely to force applied at \\(B\\), but would also be caused by the forces applied at \\(C\\).

<a id="table--fig:shaker-mount"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:shaker-mount">Table 14</a></span>:
  Various mounting arrangement of exciter
</div>

| ![](/ox-hugo/ewins00_shaker_mount_1.png)    | ![](/ox-hugo/ewins00_shaker_mount_2.png)        | ![](/ox-hugo/ewins00_shaker_mount_3.png) |
|---------------------------------------------|-------------------------------------------------|------------------------------------------|
| <a id="org0d724dc"></a> Ideal Configuration | <a id="orgf8ba17d"></a> Suspended Configuration | <a id="orge6e0404"></a> Unsatisfactory   |
| width=\linewidth                            | width=\linewidth                                | width=\linewidth                         |


#### Hammer or Impactor Excitation {#hammer-or-impactor-excitation}

Although this type of test places greater demands on the analysis phase of the measurement process, it is a relatively simple means of exciting the structure.

A set of different **tips** and **heads** are used to extend the frequency and force level ranges for testing a variety of different structure.
A **load cell** (or force transducer) which detects the magnitude of the force felt by the impactor is included.

The magnitude of the impact is determined by the mass of the hammer head and its velocity when it hits the structure.

The frequency range which is effectively excited is controlled by the stiffness of the contacting surface and the mass of the impactor head: there is a resonance at a frequency given by \\(\sqrt{\frac{\text{contact stiffness}}{\text{impactor mass}}}\\) above which it is difficult to deliver energy into the test structure.

When the hammer tip impacts the test structure, this will experience a force pulse as shown on figure [11](#orgf285619).
A pulse of this type (half-sine shape) has a frequency content of the form illustrated on figure [11](#orgf285619).

<a id="orgf285619"></a>

{{< figure src="/ox-hugo/ewins00_hammer_impulse.png" caption="Figure 11: Typical impact force pulse and spectrum" >}}

The stiffer the materials, the shorter will be the duration of the pulse and the higher will be the frequency range covered by the impact.
Similarly, the lighter the impactor mass, the higher the effective frequency range.

Generally, as soft a tip as possible will be used in order to inject all the input energy into the frequency range of interest: using a stiffer tip than necessary will result in energy being input to vibrations outside the range of interest at the expense of those inside of that range.

One of the difficulties of applying excitation using a hammer is ensuring that **each impact is essentially the same** as the previous ones, not much in magnitude as in **position** and **orientation** relative to the normal of the surface.


### Transducers and Amplifiers {#transducers-and-amplifiers}

The piezoelectric type of transducer is by far the most popular and widely used transducer in modal tests.

Three types of piezoelectric transducers are available for mobility measurements:

-   **Force gauges**
-   **Accelerometers**
-   **Impedance heads**: simply a combination of force and acceleration sensitive elements in a single unit

The basic principle of operation makes use of the fact that an element of piezoelectric material generates an electric charge across its end faces when subjected to a mechanical stress.
By suitable design, such a material may be incorporated into a device which **induces** in it a **stress proportional to the physical quantity to be measured**.


#### Force Transducers {#force-transducers}

The force transducer is the simplest type of piezoelectric transducer.
The transmitter force \\(F\\) is applied directly across the crystal, which thus generates a corresponding charge \\(q\\), proportional to \\(F\\) (figure [12](#org7500151)).

<a id="org7500151"></a>

{{< figure src="/ox-hugo/ewins00_piezo_force_transducer.png" caption="Figure 12: Force transducer" >}}

There exists an undesirable possibility of a cross sensitivity, i.e. an electrical output when there is zero force \\(F\\) but, say, a transverse or shear loading.


#### Accelerometers {#accelerometers}

In an accelerometer, transduction is indirect and is achieved using a seismic mass (figure [13](#org8d7da26)).
In this configuration, the force exerted on the crystals is the inertia force of the seismic mass (\\(m\ddot{z}\\)).
Thus, so long as the body and the seismic mass move together, the output of the transducer will be proportional to the acceleration of its body \\(x\\).

<a id="org8d7da26"></a>

{{< figure src="/ox-hugo/ewins00_piezo_accelerometer.png" caption="Figure 13: Compression-type of piezoelectric accelerometer" >}}

Analysis of a simple dynamical model for this device shows that the ratio \\(\ddot{x}/\ddot{z}\\) is effectively unity over a wide range of frequency from zero upwards until the first resonant frequency of the transducer.

There is also a problem of cross or transverse sensitivity of accelerometers which can result from imperfections in the crystal geometry and from interaction through the casing.


#### Selection of accelerometers {#selection-of-accelerometers}

Accelerometer sensitivities vary between \\(1\\) and \\(\SI{10000}{pC/g}\\).
In general, we require as high a sensitivity as possible, however, the heavier the transducer, the lower is the transducer's resonant frequency and thus the maximum working frequency.
For accurate measurements, especially on complex structures which are liable to vibrate simultaneously in several directions, transducers with low transverse sensitivity (less than \\(\SI{1}{\%}\\)) should be selected.


#### Conditioning Amplifiers {#conditioning-amplifiers}

One of the advantages of the piezoelectric transducer is that it is an active device and does not require a power supply in order to function.
However, this means that it cannot measure truly static quantities and so there is a **low frequency limit** below which measurements are not practical.
This limit is usually determined not simply by the properties of the transducer itself, but also by those of the amplifiers used to boost the small electric charge that is generated by the crystals.

Two types of amplifier are available for this role that both have very high input impedance:

-   **Voltage amplifiers**
-   **Charge amplifiers**

Voltage amplifiers tend to be simpler and to have a better signal/noise characteristic than charge amplifiers.
However, they cannot be used at such low frequencies as the charge amplifiers and the overall gain is affected by the length and properties of the transducer cable whereas that for a charge amplifier it is effectively independent of the cable.


#### Attachment of transducers {#attachment-of-transducers}

The correct installation of transducers, especially accelerometers is important.

There are various means of fixing the transducers to the surface of the test structure, some more convenient than others.
Some of these methods are illustrated in figure [15](#orgf956916).

Shown on figure [15](#orga10bae6) are typical high frequency limits for each type of attachment.

<a id="table--fig:transducer-mounting"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:transducer-mounting">Table 15</a></span>:
  Accelerometer attachment characteristics
</div>

| ![](/ox-hugo/ewins00_transducer_mounting_types.png) | ![](/ox-hugo/ewins00_transducer_mounting_response.png)     |
|-----------------------------------------------------|------------------------------------------------------------|
| <a id="orgf956916"></a> Attachment methods          | <a id="orga10bae6"></a> Frequency response characteristics |
| width=\linewidth                                    | width=\linewidth                                           |


#### Location of transducers {#location-of-transducers}

Another problem which may require the removal of the transducer to another location is the possibility that it is **positioned at or very close to a node** of one or more of the structure's modes.
In that case, it will be very difficult to make an effective measurement of that particular mode.

Most modal test require a **point mobility measurement** as one of the measured FRF.
This is hard to achieve as both force and response transducer should be at the same point on the structure.
Three possibilities exist:

1.  Use an **impedance head**
2.  Place the force and acceleration transducers **in line** but on opposite sides of the structure
3.  Place the accelerometer **alongside**, as close as possible as the force gauge

The third option is the most practical but is the one that presents the problem.
Particular care is required to ensure that the measurement is really representative of a point mobility: the accelerometer should be as close as possible as the force gauge.


### Digital Signal Processing {#digital-signal-processing}


#### Objective {#objective}

The task of the spectrum analyser is to **estimate the Fourier transform** or **Spectral densities** of signals.

We here relate the two most relevant versions of the fundamental Fourier transformation between the time and frequency domains.

In its simplest form, this states that a function \\(x(t)\\), periodic in time \\(T\\), can be written as an infinite series:

\begin{equation}
  x(t) = \frac{a\_0}{2} + \sum\_{n=1}^\infty \left( a\_n \cos\frac{2 \pi n t}{T} + b\_n \sin\frac{2 \pi n t}{T} \right)
\end{equation}

where \\(a\_i\\) and \\(b\_i\\) can be computed from knowledge of \\(x(t)\\) via the relationships:

\begin{equation}
  \begin{aligned}
    a\_n &= \frac{2}{T} \int\_0^T x(t) \cos \left(\frac{2 \pi n t }{T} \right) \\\\\\
    b\_n &= \frac{2}{T} \int\_0^T x(t) \sin \left(\frac{2 \pi n t }{T} \right)
  \end{aligned}
\end{equation}

In the situation where \\(x(t)\\) is discretised and of finite duration, so that it is defined only at a set of \\(N\\) particular values of time (\\(t\_k; k = 1, \dots, N\\)), we can write a finite Fourier series for \\(k = 1, \dots, N\\):

\begin{align\*}
  x\_k &= x(t\_k) \\\\\\
      &= \frac{a\_0}{2} + \sum\_{n=1}^{N/2} \left( a\_n \cos\left(\frac{2 \pi n t\_k}{T}\right) + b\_n \sin\left(\frac{2 \pi n t\_k}{T}\right) \right)
\end{align\*}

The coefficients \\(a\_i\\) and \\(b\_i\\) are the Fourier or Spectral coefficients for the function \\(x(t)\\) and they are often displayed in **modulus and phase form**:

\begin{equation}
  \begin{aligned}
    x\_n &= \sqrt{a\_n^2 + b\_n^2} \\\\\\
    \phi\_n &= t g^{-1} \left( \frac{-b\_n}{a\_n} \right)
  \end{aligned}
\end{equation}


#### Basics of the DFT {#basics-of-the-dft}

In each case, the input signal is digitized and recorded as a set of \\(N\\) discrete values, evenly spaced in the period \\(T\\) during which the measurement is made.

There is a basic relationship between the sample length \\(T\\), the number of discrete values \\(N\\), the sampling rate \\(\omega\_s\\) and the range and resolution of the frequency spectrum.

The range of the spectrum is \\([0, \omega\_\text{max}]\\) (\\(\omega\_\text{max}\\) is called the Nyquist frequency), and the resolution of lines in the spectrum is \\(\Delta\_\omega\\):

\begin{equation}
  \begin{aligned}
  \omega\_{\text{max}} &= \frac{\omega\_s}{2} = \frac{1}{2} \left( \frac{2\pi N}{T} \right) \\\\\\
  \Delta\_\omega &= \frac{\omega\_s}{N} = \frac{2\pi}{T}
  \end{aligned}
\end{equation}

Various algorithms can be used to determine the spectral composition of the sampled signal, however, the most widely used is the **Fast Fourier Transform**.
That however requires \\(N\\) to be an integral power of \\(2\\).


#### Aliasing {#aliasing}

Aliasing originates from the discretisation of the originally continuous time history.
With this discretisation process, the **existence of very high frequencies in the original signal may well be misinterpreted if the sampling rate is too slow**.
These high frequencies will be **indistinguishable** from genuine low frequency components as shown on figure [14](#org88605d5).

<a id="org88605d5"></a>

{{< figure src="/ox-hugo/ewins00_aliasing.png" caption="Figure 14: The phenomenon of aliasing. On top: Low-frequency signal, On the bottom: High frequency signal" >}}

A signal of frequency \\(\omega\\) and one of frequency \\(\omega\_s-\omega\\) are indistinguishable and this causes a **distortion of the spectrum** measured via the DFT.

As a result, the part of the signal which has frequency components above \\(\omega\_s/2\\) will appear reflected or **aliased** in the range \\([0, \omega\_s/2]\\).
This is illustrated on figure [16](#table--fig:effect-aliasing).

<a id="table--fig:effect-aliasing"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:effect-aliasing">Table 16</a></span>:
  Alias distortion of spectrum by DFT
</div>

| ![](/ox-hugo/ewins00_aliasing_no_distortion.png) | ![](/ox-hugo/ewins00_aliasing_distortion.png)       |
|--------------------------------------------------|-----------------------------------------------------|
| <a id="org86930d6"></a> True spectrum of signal  | <a id="orgc744a70"></a> Indicated spectrum from DFT |
| width=\linewidth                                 | width=\linewidth                                    |

The solution of the problem is to use an **anti-aliasing filter** which subjects the original time signal to a low-pass, sharp cut-off filter.
Because the filters used are inevitably less than perfect, and have a finite cut-off rate, it remains necessary to reject the spectral measurement in a frequency range approaching the Nyquist frequency \\(\omega\_s/2\\).
Typically, the cut-off rate is set to \\(0.5 \times \omega\_s/2\\) for simple filters and \\(0.8 \times \omega\_s/2\\) for more advance filters.
As a results, frequencies near \\(\omega\_s/2\\) may still be contaminated by the imperfected anti-aliasing.


#### Leakage {#leakage}

Leakage is a problem which is a direct **consequence of the need to take only a finite length of time history coupled with the assumption of periodicity**.

<a id="table--fig:leakage"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:leakage">Table 17</a></span>:
  Sample length and leakage of spectrum
</div>

| ![](/ox-hugo/ewins00_leakage_ok.png) | ![](/ox-hugo/ewins00_leakage_nok.png)  |
|--------------------------------------|----------------------------------------|
| <a id="org5c4b348"></a> Ideal signal | <a id="org9371337"></a> Awkward signal |
| width=\linewidth                     | width=\linewidth                       |

The problem is illustrated on figure [17](#table--fig:leakage).
In the first case (figure [17](#org5c4b348)), the signal is perfectly periodic and the resulting spectrum is just a single line at the frequency of the sine wave.
In the second case (figure [17](#org9371337)), the periodicity assumption is not strictly valid as there is a discontinuity at each end of the sample.
As a result, the spectrum produced for this case does not indicate the single frequency which the original time signal possessed.
Energy has "leaked" into a number of the spectral lines close to the true frequency and the spectrum is spread over several lines.

Leakage is a serious problem in many applications, **ways of avoiding its effects** are:

-   Changing the duration of the measurement sample length to **match the periodicity of the signal**.
    This can only work if the signal is periodic and if the period can be determined
-   **Increasing the duration of the measurement** period \\(T\\) so that the separation between the spectral lines (the frequency resolution) is finer.
    Although this will not totally remove the leakage effect
-   **Adding zeroes to the end of the measured sample** ("zero padding"), thereby partially achieving the preceding result but without requiring more data
-   Modifying the sampled signal obtained in such a way as to reduce the severity of the leakage effect. This effect is referred to as **windowing**


#### Windowing {#windowing}

Windowing involves the imposition of a prescribed profile on the time signal prior to performing the Fourier transform.

The profiles, or "windows" are generally depicted as a time function \\(w(t)\\) as shown in figure [15](#org8903f56).

<a id="org8903f56"></a>

{{< figure src="/ox-hugo/ewins00_windowing_examples.png" caption="Figure 15: Different types of window. (a) Boxcar, (b) Hanning, (c) Cosine-taper, (d) Exponential" >}}

The analyzed signal is then \\(x^\prime(t) = x(t) w(t)\\).
The result of using a window is seen in the third column of figure [15](#org8903f56).

The **Hanning and Cosine Taper windows are typically used for continuous signals**, such as are produced by steady periodic or random vibration, while the **Exponential window is used for transient vibration** applications where much of the important information is concentrated in the initial part of the time record.

In all cases, a **re-scaling** is required to compensated for the attenuation of the signals by the application of the window.
However, **if both response and excitation signals are subjected to the same window**, and the results are used only to compute an FRF ratio, then the **re-scaling is not necessary**.


#### Filtering {#filtering}

The process of filtering has a direct parallel with windowing.
Common filters are: low-pass, high-pass, band-limited, narrow-band, notch.


#### Improving Resolution {#improving-resolution}

<a id="org2a431e7"></a>


##### Increasing transform size {#increasing-transform-size}

An immediate solution to this problem would be to use a larger transform.
However, this may not be possible in practice.


##### Zero padding {#zero-padding}

It may be possible to achieve the same resolution increase by adding a series of zeros to the short sample of the actual signal.
Care must be taken in such a procedure are it will smooth the resulting spectrum but no additional information is included.
This can be misleading in some cases.
For instance where two peaks are close and result in only one peak in the smooth data.


##### Zoom {#zoom}

The common solution to the need for finer frequency resolution is to zoom on the frequency range of interest and to concentrate all the spectral lines into a narrow band between \\(\omega\_\text{min}\\) and \\(\omega\_\text{max}\\).

There are various ways of achieving this result.
The easiest way is to use a frequency shifting process coupled with a controlled aliasing device.

Suppose the signal to be analyzed \\(x(t)\\) has a spectrum \\(X(\omega)\\) has shown on figure [18](#org41c500b), and that we are interested in a detailed analysis between \\(\omega\_1\\) and \\(\omega\_2\\).

If we apply a band-pass filter to the signal, as shown on figure [18](#orgfb95cfe), and perform a DFT between \\(0\\) and \\((\omega\_2 - \omega\_1)\\), then because of the aliasing phenomenon described earlier, the frequency components between \\(\omega\_1\\) and \\(\omega\_2\\) will appear between \\(0\\) and \\((\omega\_2 - \omega\_1)\\) with the advantage of a finer resolution (see figure [16](#org1dc44b8)).

<a id="table--fig:frequency-zoom"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:frequency-zoom">Table 18</a></span>:
  Controlled aliasing for frequency zoom
</div>

| ![](/ox-hugo/ewins00_zoom_range.png)           | ![](/ox-hugo/ewins00_zoom_bandpass.png)  |
|------------------------------------------------|------------------------------------------|
| <a id="org41c500b"></a> Spectrum of the signal | <a id="orgfb95cfe"></a> Band-pass filter |
| width=\linewidth                               | width=\linewidth                         |

<a id="org1dc44b8"></a>

{{< figure src="/ox-hugo/ewins00_zoom_result.png" caption="Figure 16: Effective frequency translation for zoom" >}}

When using zoom the measure FRF in a narrow frequency range, it is important to ensure that there is as little vibration energy as possible outside the frequency range of interest.


#### Averaging {#averaging}

When analyzing **random** vibrations signals, it is not sufficient to compute Fourier transforms (strictly, they do not exist for a random process) and we must instead obtain estimates for the **spectral densities and correlation functions** which are used to characterize this type of signal.

Although these properties are computed from the Fourier transforms, there are additional considerations concerning their accuracy and statistical reliability which must be given due attention.

Generally, it is necessary to perform an averaging process, involving several individual time records, or samples, before a result is obtained which can be used with confidence.
The two major considerations which determine the **number of average required** are:

-   the statistical reliability
-   the removal of spurious random noise from the signals

An indication of the requirements from a statistical standpoint may be provided by the "**statistical degrees of freedom**" \\(\kappa\\) which is provided by

\begin{equation}
  \kappa = 2 B T\_t
\end{equation}

where \\(B\\) is the frequency bandwidth and \\(T\_t\\) is the total time encompassing all data.
\\(T\_t = mT\\) for \\(m\\) samples each of \\(T\\) duration.

As a guide, this quantity \\(\kappa\\) should be a minimum of \\(10\\) and should approach \\(100\\) for reasonably reliable estimates.

An other way to average is to apply the DFT on overlapping data.
This is called **overlap averaging**.
It is clear that \\(100\\) averages performed in this way cannot have the same statistical properties as would \\(100\\) completely independent samples.
Nevertheless, the procedure is more effective than if all the data points are only used once.
This manifests by producing smoother spectra.


### Use of different excitation signals {#use-of-different-excitation-signals}

There are three different classes of signals used for the excitation signals:

-   **Periodic**: stepped sine, slow sine sweep, periodic, pseudo random, periodic random
-   **Transient**: burst sine, burst random, chirp, impulse
-   **Random**: true random, white noise, narrow-band random

All of these are in widespread use, each having its own particular merits and drawbacks.


#### Stepped-Sine testing {#stepped-sine-testing}

Stepped-sine testing comes from the classical method of measuring the FRF where a discrete sinusoidal with a fixed amplitude and frequency is used.

In order to encompass a frequency range of interest, the command signal frequency is stepped from one discrete value to another in such a way as to provide the necessary density of points in the FRF plot.
In  this technique, it is necessary to ensure that **steady-state** conditions have been attained before the measurements are made and this means delaying the start of the measurement process for a short while after a new frequency has been selected as there will be a transient response.
The extent of the unwanted transient response will depend on:

-   the proximity of the excitation frequency to the natural frequency of the structure
-   the abruptness of the changeover from the previous command signal to the new one
-   the lightness of the damping of the nearby structural modes

In practice, this is only in the vicinity of a lightly damped resonance that the necessary delay becomes significant and extra attention is needed.

One of the advantages is the facility of taking measurements where it is required.
For instance, the typical FRF curve has large region of relatively slow changes of level with frequency (away from resonances and anti-resonances) and in these regions it is sufficient to take measurements at relatively widely spaced frequency points.


#### Slow Sine Sweep testing {#slow-sine-sweep-testing}

This is the traditional method of FRF measurement and involves the use of a sweep oscillator to provide a sinusoidal command signal with a frequency that varies slowly in the range of interest.
It is necessary to check that progress through the frequency range is sufficiently slow to check that steady-state response conditions are attained.
If excessive sweep rate is used, then distortions of the FRF plot are introduced as shown on figure [17](#orgbb6a3e8).

<a id="orgbb6a3e8"></a>

{{< figure src="/ox-hugo/ewins00_sweep_distortions.png" caption="Figure 17: FRF measurements by sine sweep test" >}}

One way of checking the suitability of a sweep rate is to make the measurement twice, once sweeping up and the second time sweeping down through the frequency range.
If both curves obtained are the same, the sweep rate is not excessive.


#### Periodic Excitation {#periodic-excitation}

This is very similar to a sine wave test methods, however the input signal contains not one but many frequencies of interest.

The method of computing the FRF is quite simple: the discrete Fourier transform is computed for both the force and response signals and the **ratio of these transforms gives the FRF**.

Two types of periodic signals are used:

-   **Deterministic**: all the components are mixed with ordered amplitude and phase relationships (e.g. a square wave)
-   **Pseudo-random**: generation of a random mixture of amplitudes and phases for the various frequency components

The sequence is generated for a duration which equals the period of one sample in the analysis process, and is output repeatedly for several successive cycles.
A particular advantage of this type of excitation is its **exact periodicity** in the analyser bandwidth, resulting in **zero leakage errors** and therefore **requiring no windows** to be applied before its spectral analysis.

One should not that when there is no need to use a window of any form, as it is the case for periodic signals, then it is very important not to use one.


#### Random Excitation {#random-excitation}


##### FRF estimates using random excitation {#frf-estimates-using-random-excitation}

True random excitation are generally applied to the structure using a shaker.

For a such a random excitation, a different approach is required in order to determine the FRF.

The principle upon which the FRF is determined using random excitation relies on the following equations

\begin{equation}
  \begin{aligned}
    S\_{xx}(\omega) &= |H(\omega)|^2 S\_{ff}(\omega)\\\\\\
    S\_{fx}(\omega) &= H(\omega) S\_{ff}(\omega)\\\\\\
    S\_{xx}(\omega) &= H(\omega) S\_{xf}(\omega)
  \end{aligned}
\end{equation}

where

-   \\(S\_{xx}(\omega)\\) and \\(S\_{ff}(\omega)\\) are the **autospectra** of the response and excitation signals
-   \\(S\_{xf}(\omega)\\) is the **cross spectrum** between these two signals
-   \\(H(\omega)\\) is the FRF linking the quantities \\(x\\) and \\(f\\)

Such parameters can never be measured exactly with only a finite length of data.
However, we have the possibility of providing a **cross check** on the results by using the fact that the **FRF can be estimated using two sets of data**:

\begin{equation}
  \begin{aligned}
    H\_1(\omega) &= \frac{S\_{fx}(\omega)}{S\_{ff}(\omega)} \\\\\\
    H\_2(\omega) &= \frac{S\_{xx}(\omega)}{S\_{xf}(\omega)}
  \end{aligned}
\end{equation}

We now introduce a quantity \\(\gamma^2\\) which is called the **coherence** and which is defined as
\\[ \gamma^2 = \frac{H\_1(\omega)}{H\_2(\omega)}; \quad 0 \le \gamma^2 \le 1 \\]

Clearly, if all is well with the measurement, the coherence should be unity and we shall be looking for this condition in our test to reassure us that the measurements have been well made.
Small values of the coherence means that the FRF estimate obtained is unreliable and one should determine its cause.


##### Noisy Data {#noisy-data}

There are several situations in which an imperfect measurement might be made, and a low coherence recorded.
There may well be noise on one or other of the two signals which could degrade the measured spectra:

-   **Near resonance**: this is likely to influence the **force signal** so that \\(S\_{ff}(\omega)\\) becomes vulnerable and \\(H\_1(\omega)\\) will suffer the most, \\(H\_2(\omega)\\) might be a better indicator in that case
-   **Near anti-resonance**: it is the **response signal** which will suffer, making \\(S\_{xx}(\omega)\\) liable to errors and this is the opposite for \\(H\_1(\omega)\\) and \\(H\_2(\omega)\\)

This is shown by the following equations:

\begin{equation}
  \begin{aligned}
    H\_1(\omega) &= \frac{S\_{fx}(\omega)}{S\_{ff}(\omega) + S\_{nn}(\omega)} \\\\\\
    H\_2(\omega) &= \frac{S\_{xx}(\omega) + S\_{mm}(\omega)}{S\_{xf}(\omega)}
  \end{aligned}
\end{equation}

where \\(S\_{mm}(\omega)\\) and \\(S\_{nn}(\omega)\\) are the autospectra of the noise on the output and input, \\(m(t)\\) and \\(n(t)\\) respectively.

One suggestion which has been made is to define the FRF as the geometric mean of the two standard estimates:

\begin{equation}
  H\_v(\omega) = \sqrt{H\_1(\omega) H\_2(\omega)}
\end{equation}

Low coherence can arise when **more than one excitation is applied** to the structure.
Another possibility is that the structure is **not completely linear**.
Here again, the measured response cannot be completely attributed to the measured excitation.


##### Noise-free FRF estimates {#noise-free-frf-estimates}

A third estimator for the FRF can be defined in cases of random excitation, which is called the **instrumental variable estimate**, or \\(H\_3(\omega)\\).

This formula for the FRF is only possible if more than the usual two channels are being measured simultaneously.
The formula is of interest because it does provide an estimate for the FRF which is unbiased by noise on either the force or the response transducer signals.
The formula is:

\begin{equation}
  H\_3(\omega) = \frac{S\_{xv}(\omega)}{S\_{fv}(\omega)}
\end{equation}

where \\(v(t)\\) is a third signal in the system, such as the voltage supplied to the exciter, and it exploits the fact that noise on either input (force) or output (response) channels does not contaminate cross-spectral density estimates in the way that auto spectra are affected.


##### Leakage {#leakage}

It is known that a low coherence can arise in a measurement where the frequency resolution of the analyzer is not fine enough to describe adequately the very rapidly changing functions such as are encountered near resonance and anti-resonance on lightly-damped structures.

This is known as a **bias** error and leakage is often the most likely source of low coherence on lightly-damped structures as shown on figure [18](#org7b09a80).

<a id="org7b09a80"></a>

{{< figure src="/ox-hugo/ewins00_coherence_resonance.png" caption="Figure 18: Coherence \\(\gamma^2\\) and FRF estimate \\(H\_1(\omega)\\) for a lightly damped structure" >}}

It can be shown that near resonance, \\(H\_2(\omega)\\) is a much more accurate representation of the true FRF than \\(H\_1(\omega)\\).
When this situation is encountered, the best solution is usually to make a zoom measurement as explained previously.


##### Postscript {#postscript}

It is sometimes though that a poor coherence can be eliminated by taking many averages, but this is only possible if the reason for the low coherence is **random noise** which can be averaged out over a period of time.
If the reason if more systematic than that, the averaging will not help.

Lastly, mention should be made here of a type of excitation referred to as "periodic random" which is, in fact, a combination of pseudo-random and "true" random.
In this process, a pseudo-random (or periodic) excitation is generated and after a few cycles, a measurement of the input and the now steady-state response is made.
Then, a different pseudo-random sequence is generated, the procedure repeated and the result treated as the second sample in what will develop to be an ensemble of random samples.
The advantage over the simple random excitation is that due to the essential periodic nature of each of the pseudo-random samples, there are no leakage or bias errors in any of the measurements.
However, the cost is an increase in the measurement time as one has to wait for the steady response condition.


#### Transient excitation {#transient-excitation}

There are three types of excitation to be included in this section because they all share the same principle for their signals processing.
They are:

1.  **Burst** excitation: a short section of signal
2.  **Rapid sine sweep** (chirp) excitation
3.  **Impact** excitation from a hammer blow

The first and second of these generally require an attached shaker, but the last one can be implemented with a hammer.

The principle which all these signals share is that the excitation and the consequent response are completely contained within the single sample of measurement which is made.
In practice, it is common to repeat the transient even more than once and to **average** the results to get the final result.
How they differ is in the exact form of the transient excitation signal and in the nature of the repeated application.

In the burst type of signal, we have an excitation which is applied and analyzed as if it were a continuous signal, taking the successive samples for averaging one immediately after the other.
For the chirp and impulse excitations, each individual sample is collected and processed before making the next one, and averaged.


##### Burst excitation signals {#burst-excitation-signals}

Burst excitation signals consist of short sections of an underlying continuous signal (which may be a sine wave, a sine sweep or a random signal), followed by a period of zero output, resulting in a response which shows a transient build-up followed by a decay (see figure [19](#org98bdc4b)).

<a id="org98bdc4b"></a>

{{< figure src="/ox-hugo/ewins00_burst_excitation.png" caption="Figure 19: Example of burst excitation and response signals" >}}

The duration of the burst is under the control of the operator and it is selected so as to provide the ideal signal processing conditions, which are essentially that the **response signal has just died away by the end of the measurement period**.
If this condition has not been attained (burst too long), then leakage error will result.
If it has been reached well before the end of the period (burst too short), then the signal quality will be poor.

The final measurement will be the result of averaging several samples.
In the case of the burst sine excitation, each sample would be expected to be identical so that the averaging serves only to remove noise on the signals.
In the case of burst random, however, each individual burst will be different to the other and so in this case there is an element of averaging randomly varying behavior, a feature which is believed in some cases to enhance the measurement in the presence of weak non-linearities in the test structure.


##### Chirp excitation {#chirp-excitation}

The chirp consist of a short duration signal which has the form shown in figure [20](#orgb584cc5).

The frequency content of the chirp can be precisely chosen by the starting and finishing frequencies of the sweep.

<a id="orgb584cc5"></a>

{{< figure src="/ox-hugo/ewins00_chirp_excitation.png" caption="Figure 20: Example of chirp excitation and response signals" >}}


##### Impulsive excitation {#impulsive-excitation}

The hammer blow produces an input and response as shown in the figure [21](#org4db89b3).

This and the chirp excitation are very similar in the analysis point of view, the main difference is that the chirp offers the possibility of greater control of both amplitude and frequency content of the input and also permits the input of a greater amount of vibration energy.

<a id="org4db89b3"></a>

{{< figure src="/ox-hugo/ewins00_impulsive_excitation.png" caption="Figure 21: Example of impulsive excitation and response signals" >}}

The frequency content of the hammer blow is dictated by the **materials** involved and is rather more difficult to control.
However, it should be recorded that in the region below the first cut-off frequency induced by the elasticity of the hammer tip structure contact, the spectrum of the force signal tends to be **very flat**.

On some structures, the movement of the structure in response to the hammer blow can be such that it returns and **rebounds** on the hammer tip before the user has had time to move that out of the way.
In such cases, the spectrum of the excitation is seen to have "holes" in it at certain frequencies (figure [22](#orgb29cf45)).

<a id="orgb29cf45"></a>

{{< figure src="/ox-hugo/ewins00_double_hits.png" caption="Figure 22: Double hits time domain and frequency content" >}}

In order to perform the required Fourier analysis of all these cases of transient signals, an assumption is made that the data obtained from a single event can be regarded as representing one period of a **quasi-periodic process**.
This means that if exactly the same input was applied \\(T\\) seconds after the first one, then exactly the same response would be observed.

This can be difficult to obtain especially for lightly damped structures as the signal will take long time to die away.
In that case, one solution is to lengthen the period \\(T\\), but often this is not easily changeable.
A **window** applied to the raw data provides a more practical solution.
It is recommended to apply an **exponential window** to both signals.
By choosing an appropriate exponential decay rate, the modified signal can be made to have effectively died away by the end of the prescribed measurement period, thereby satisfying the signal processing needs.

However, one should be cautious when using such windowing as complex modes can be extracted from data treated this way.

An alternative to this problem is to use the **zoom** facility.
One of the consequences of using a zoom is that the frequency band is reduced by a proportionate amount.
However, by making a number (equal to the zoom factor) of separate measurements, each one for a different zoom band, it is possible to construct and FRF over the entire frequency range of interest with both the advantage of it being a window-free measurement and having a much finer frequency resolution.

One the pseudo-periodicity is established, a discrete Fourier series description can be obtained of both the input and response signals.
The FRF can be computed from
\\[ H(\omega\_k) = \frac{X(\omega\_k)}{F(\omega\_k)} \\]

Alternately, the force signals can be treated in the same way as for random excitation, and the formulae for \\(H\_1(\omega)\\) and \\(H\_2(\omega)\\) are used.
However, care must be exercise when interpreting the results since the **coherence function has different significance here**.

One of the parameters indicated by the coherence is the statistical reliability of an estimate based on a number of averages of a **random** process.
In the case of an FRF estimate obtained by treating the signals from a succession of nominally identical impacts as a random process, we must note that, strictly, each such sample is a **deterministic**, and not probabilistic, calculation and should contain no statistical uncertainty.

Thus, the **main source for low coherence** in this instance can only be **leakage errors**, **non-linearity** or **high noise levels**, not the same situation as for random excitation.

Another feature usually employed in transient testing is that of making a whole series of repeat measurements under nominally identical conditions and then averaging FRF estimates.
The idea behind this is that any one measurement is likely to be contaminated by noise, especially in the frequency regions away from resonance where the response levels are likely to be quite low.
While this averaging technique does indeed enhance the resulting plots, it may well be that several tens of samples need to be acquired before a smooth FRF plot is obtained and this will diminish somewhat any advantage of speed which is a potential attraction to the method.


### Calibration {#calibration}

For all measurement processes, it is necessary to **calibrate** the equipment which is used.
In the case of FRF measurements, there are **two levels of calibration** which should be made:

-   The first of these is a periodic **absolute calibration of individual transducers** (of force and response) to check that their sensitivities are sensibly the same as those specified by the manufacturer.
    Any marked deviation could indicate internal damage
-   The second type of calibration is one which can and should be carried out during each test, preferably twice, once at the outset and again at the end.
    This type of calibration is one which provides the **overall sensitivity of the complete instrumentation system** without examining the performance of the individual elements.

The first type of calibration is quite difficult to make accurately as it requires independent measurement of the quantity of interest.
The use of another transducer of the same type is not satisfactory as it is not strictly an independent measure.
Optical devices can be used for the calibration of displacement sensors.

One of the reasons why the absolute type of calibration has not been further developed for this particular application is the availability of a different type of calibration which is particularly attractive and convenient.
The parameters measured in a modal analysis are usually ratios between response and force levels, and so what is required is the ability to calibrate the whole measurement system.
The voltage measured are related to the physical quantities (force and acceleration) by the sensitivities of the respective transducers:

\begin{equation}
  \begin{aligned}
    v\_f &= E\_f f \\\\\\
    v\_{\ddot{x}} &= E\_{\ddot{x}} \ddot{x}
  \end{aligned}
\end{equation}

As mentioned, the difficulty is to determine the individual values for \\(E\_f\\) and \\(E\_{\ddot{x}}\\).
In practice, we only ever use the measured voltages as a **ratio** to obtain the FRF
\\[ \frac{\ddot{x}}{f} = \frac{v\_{\ddot{x}}}{v\_f} \frac{E\_f}{E\_{\ddot{x}}} = E \frac{v\_{\ddot{x}}}{v\_f} \\]
and so **what is required is the ratio of the two sensitivities**:

\begin{equation}
  E = \frac{E\_f}{E\_{\ddot{x}}}
\end{equation}

The overall sensitivity can be more readily obtained by a calibration process because we can easily make an independent measurement of the quantity now being measured: the ratio of response to force.
Suppose the response parameter is acceleration, then the FRF obtained is inertance which has the units of \\(1/\text{mass}\\), a quantity which can readily be independently measured by other means.

Figure [23](#orgddf08d1) shows a typical calibration setup.

<a id="orgddf08d1"></a>

{{< figure src="/ox-hugo/ewins00_calibration_setup.png" caption="Figure 23: Mass calibration procedure, measurement setup" >}}

A calibration procedure of this type has the distinct advantage that it is very easy to perform and can be carried out with all the measurement equipment.
Thus, frequent checks on the overall calibration factors are strongly recommended, ideally as the beginning and end of each test.


### Mass Cancellation {#mass-cancellation}

It is very important the ensure that the force is measured directly at the point at which it is applied to the structure, rather than deducing its magnitude from the current flowing in the shaker coil or other similar **indirect** processes.
This is because near resonance, the actual applied force becomes very small and is thus very prone to inaccuracy.

This same argument applies on a lesser scale as we examine the detail around the attachment to the structure, as shown in figure [24](#orgc770be3).

<a id="orgc770be3"></a>

{{< figure src="/ox-hugo/ewins00_mass_cancellation.png" caption="Figure 24: Added mass to be cancelled (crossed area)" >}}

Here, we see part of the structure, an accelerometer and a force transducer.
The dashed line shows the plane at which the force is actually measured.
Now, assuming that the extra material (shown by the cross hatching) behaves as a rigid mass \\(m^\*\\), we can state that the force actually applied to the structure \\(f\_t\\) is different from that measured by the transducer \\(f\_m\\) by an amount dependent on the acceleration level at the drive point \\(\ddot{m}\\) according to

\begin{equation}
  f\_t = f\_m - m^\* \ddot{x}
\end{equation}

Physically, what is happening is that some of the measured force is being "used" to move the additional mass so that the force actually applied to the structure is the measured force minus the inertia force of the extra mass.

Now, the frequency response quantity we actually require is \\(A\_t(\omega)\\) although we have measurements of \\(\ddot{X}\\) and \\(F\_m\\) only, yielding to \\(A\_m(\omega)\\).
If we express it in its real and imaginary parts, we obtain:

\begin{align\*}
  \text{Re}(F\_t) &= \text{Re}(F\_m) - m^\* \text{Re}(\ddot{X}) \\\\\\
  \text{Im}(F\_t) &= \text{Im}(F\_m) - m^\* \text{Im}(\ddot{X})
\end{align\*}

And

\begin{align\*}
  \text{Re}(1/A\_t) &= \text{Re}(1/A\_m) - m^\* \\\\\\
  \text{Im}(1/A\_t) &= \text{Im}(1/A\_m)
\end{align\*}

Mass cancellation is important when the mass to be cancelled (\\(m^\*\\)) is of the same order as the apparent mass of the modes of the structure under test,  and this latter is a quantity which varies from point to point on the structure.
If we are near an anti-node of a particular mode, then the apparent mass (and stiffness) will tend to be relatively small and here mass cancellation may be important.

One important feature of mass cancellation is that it can only be applied to point measurements (where the excitation and response are both considered at the same point).
This arises because the procedure described above corrects the measured force for the influence of the additional mass at the drive point.

It should be noted that the transducer's inertia is also effective not only in the direction of the excitation but also laterally and in rotation even though they cannot easily be compensated for.


### Rotational FRF measurement {#rotational-frf-measurement}


#### Significance of rotational FRF data {#significance-of-rotational-frf-data}

\\(\SI{50}{\%}\\) of all DOFs are rotations (as opposed to translations) and \\(\SI{75}{\%}\\) of all frequency response functions involve rotation DOFs.
However, it is relatively rare the find reference to methods for measurements of rotational DOFs.
This situation arises from a considerable difficulty which is encountered when trying to measure either rotational responses or excitations and also when trying to apply rotational excitation.


#### Measurement of Rotational FRFs using two or more transducers {#measurement-of-rotational-frfs-using-two-or-more-transducers}

There are two problems to be tackled:

1.  measurement of rotational responses
2.  generation of measurement of rotation excitation

The first of these is less difficult and techniques usually use a pair a matched conventional accelerometers placed at a short distance apart on the structure to be measured as shown on figure [25](#org672cadb).

<a id="org672cadb"></a>

{{< figure src="/ox-hugo/ewins00_rotational_measurement.png" caption="Figure 25: Measurement of rotational response" >}}

The principle of operation is that by measuring both accelerometer signals, the responses \\(x\_0\\) and \\(\theta\_0\\) can be deduced by taking the mean and difference of \\(x\_A\\) and \\(x\_B\\):

\begin{equation} \label{eq:rotational\_diff}
  \begin{aligned}
    x\_0 &= 0.5(x\_A + x\_B) \\\\\\
    \theta\_0 &= (x\_A - x\_B)/l
  \end{aligned}
\end{equation}

This approach permits us to measure half of the possible FRFs: all those which are of the \\(X/F\\) and \\(\Theta/F\\) type.
The others can only be measured directly by applying a moment excitation.

Figure [26](#org1e07ef2) shows a device to simulate a moment excitation.
First, a single applied excitation force \\(F\_1\\) corresponds to a simultaneous force \\(F\_0 = F\_1\\) and a moment \\(M\_0 = -F\_1 l\_1\\).
Then, the same excitation force is applied at the second position that gives a force \\(F\_0 = F\_2\\) and moment \\(M\_0 = F\_2 l\_2\\).
By adding and subtracting the responses produced by these two separate excitations conditions, we can deduce the translational and rotational responses to the translational force and the rotational moment separately, thus enabling the measurement of all four types of FRF: \\(X/F\\), \\(\Theta/F\\), \\(X/M\\) and \\(\Theta/M\\).

<a id="org1e07ef2"></a>

{{< figure src="/ox-hugo/ewins00_rotational_excitation.png" caption="Figure 26: Application of moment excitation" >}}

Then, the full \\(6 \times 6\\) mobility matrix can be measured, however this procedure is quite demanding.

Other methods for measuring rotational effects include specially developed rotational accelerometers and shakers.

However, there is a major problem that is encountered when measuring rotational FRF: the translational components of the structure's movement tends to overshadow those due to the rotational motions.
For example, the magnitude of the difference in equation \eqref{eq:rotational_diff} is often of the order of \\(\SI{1}{\%}\\) of the two individual values which is similar to the transverse sensitivity of the accelerometers: potential errors in rotations are thus enormous.


### Multi-point excitation methods {#multi-point-excitation-methods}


#### Multi-point excitation in general {#multi-point-excitation-in-general}

Multi-excitation methods for modal testing, called **MIMO test methods**, have been developed for FRF data which possesses a **high degree of consistency**.
There are other benefits:

-   the excitation of large structure with multiple points does more closely simulates their vibration environment in service than the single point excitation test
-   the facility of detecting and identifying double or repeated modes
-   the need to complete some tests in a very minimum of on-structure time

Although the majority of modal tests are still performed using single-point excitation procedure, multi-point excitation is today well developed and is largely used for aerospace structures.

The practical implementation of the different methods currently used are briefly discussed.


#### Appropriation or Normal mode testing {#appropriation-or-normal-mode-testing}

We here seek **establish vibration in a pure mode of vibration by careful selection of the locations and magnitudes of a set of sinusoidal excitation forces**.

This works for undamped system's natural frequencies, and in that case the force and response vectors are exactly in quadrature:
\\[ i\\{X\\} = [H\_\text{Re}(\omega) + i H\_\text{Im}(\omega)] \\{F\\} \\]

It follows that this equation is valid only if \\(\det |H\_{\text{Re}}(\omega)| = 0\\) and this condition provides the basis of a **method to locate the undamped system natural frequencies** from measured FRF data.


#### Multi-phase stepped-sine (MPSS) testing {#multi-phase-stepped-sine--mpss--testing}

We here excite a MDOF system at a single sinusoidal frequency \\(a\\) by a set of \\(p\\) excitation forces \\(\\{F\\}e^{i\omega t}\\) such that there is a set of steady-state responses \\(\\{X\\}e^{i\omega t}\\).
The two vectors are related by the system's FRF properties as:

\begin{equation} \label{eq:mpss\_equation}
  \\{X\\}\_{n\times 1} = [H(\omega)]\_{n\times p} \\{F\\}\_{p\times 1}
\end{equation}

However, it is not possible to derive the FRF matrix from the single equation \eqref{eq:mpss_equation}, because there will be insufficient data in the two vectors (one of length \\(p\\), the other of length \\(n\\)) to define completely the \\(n\times p\\) FRF matrix.

What is required is to make a series of \\(p^\prime\\) measurements of the same basic type using different excitation vectors \\(\\{F\\}\_i\\) that should be chosen such that the forcing matrix \\([F]\_{p\times p^\prime} = [\\{F\\}\_1, \dots, \\{F\\}\_p]\\) is non-singular.
This can be assured if:

-   there are at least as many vectors as there are forces: \\(p^\prime > p\\)
-   the individual force vectors are linearly independent of each other

A second matrix is also constructed containing the response vectors \\([X]\_{n\times p^\prime} = [\\{X\\}\_1, \dots, \\{X\\}\_{p^\prime}]\\).
Now, these two collections of measured data can be used to determine the required FRF matrix:

\begin{equation}
  [H(\omega)]\_{n\times p} = [X]\_{n\times p^\prime} [F]\_{p^\prime \times p}^+
\end{equation}

where \\(+\\) denotes the generalized inverse of the forcing matrix.


#### Multi-point random (MPR) testing {#multi-point-random--mpr--testing}


##### Concept {#concept}

In this method, advantage is taken of the incoherence of several uncorrelated random excitations which are applied simultaneously at several points.
Then, the need to repeat the test several times, as was necessary for the MPSS method, is avoided.

The purpose of this methods is to obtain the FRF data in an optimal way and to reduce the probability of introducing systematic errors to the FRF measurements.

Let's consider the simplest form of a multi excitation as that of a system excited by two simultaneous forces \\(f\_1(t)\\) and \\(f\_2(t)\\) where the response \\(x\_i(t)\\) is of particular interest.
We can derive expressions for the required FRF parameters functions of the auto and cross spectral densities between of three parameters of interest:

\begin{equation}
  \begin{aligned}
    H\_{i1}(\omega) &= \frac{S\_{1i}S\_{22} - S\_{2i}S\_{12}}{S\_{11}S\_{22} - S\_{12}S\_{21}}\\\\\\
    H\_{i1}(\omega) &= \frac{S\_{2i}S\_{11} - S\_{1i}S\_{21}}{S\_{11}S\_{22} - S\_{12}S\_{21}}
  \end{aligned}
\end{equation}

These expressions can be used provided that \\(S\_{11}S\_{22}\neq |S\_{12}|^2\\) which is equivalent of that the two excitation forces must not be fully correlated.


##### General formulation {#general-formulation}

In practice, the method is applied using different numbers of exciters, and several response points simultaneously.
We have that

\begin{equation}
  [H\_{xf}(\omega)]\_{n\times p} = [S\_{xf}(\omega)]\_{n\times p} [S\_{ff}(\omega)]\_{p\times p}^{-1}
\end{equation}

where it can be seen that the matrix of spectral densities for the forces \\([S\_{ff}(\omega)]\_{p\times p}\\) must be non singular.
Thus, care must be taken in practice to ensure this condition, noting that it is the applied forces and not the signal sources which must meet the requirement.

In practice, this is difficult to obtain as even if the input signals to the exciters' amplifiers are uncorrelated, the forces applied to the structure will certainly not be. This is particularly true near the resonances as the dynamic response is dominated by the one mode which is independent of the actual force pattern.


##### Coherence in MPR measurements {#coherence-in-mpr-measurements}

In a similar way in which we defined coherence for the SISO system, we can make use of the same concepts for a MIMO system.
During a MIMO test, we basically measure three matrices:
\\[ [S\_{ff}(\omega)]; \ [S\_{xx}(\omega)]; \ [S\_{fx}(\omega)] \\]
Then, we can derive an estimate for the FRF matrix:
\\[ H\_1(\omega)^T = [S\_{ff}(\omega)]^{-1} [S\_{fx}(\omega)] \\]
and then compute an estimate for the autospectrum of the response from:

\begin{align\*}
  [\tilde{S}\_{xx}(\omega)] &= [H\_1^\*(\omega)] [S\_{fx}(\omega)] \\\\\\
                           &= [S\_{xf}(\omega)] [S\_{ff}(\omega)]^{-1} [S\_{fx}(\omega)]
\end{align\*}

Now, by comparing the estimated response spectrum \\([\tilde{S}\_{xx}(\omega)]\\) with the actual measurement \\([S\_{xx}(\omega)]\\), we obtain a formula for the multiple coherence between the two parameters \\(\\{f(t)\\}\\) and \\(\\{x(t)\\}\\):

\begin{equation\*}
  \tcmbox{[\gamma^2(\omega)] = [S\_{xx}(\omega)]^{-1} [S\_{xf}(\omega)] [S\_{ff}(\omega)]^{-1} [S\_{fx}(\omega)]}
\end{equation\*}


#### Multiple-reference impact tests {#multiple-reference-impact-tests}

This class of hammer excitation is referred to as **Multi-reference Impact Tests** (**MRIT**).
Typically, three response references are measured (often, the \\(x\\), \\(y\\) and \\(z\\) components at the response measurement location) every time a hammer blow is applied to the structure.

FRF data collected by performing a test in this way will be the equivalent of exciting the structure at three points simultaneously while measuring the response at each of the \\(n\\) points of interest.
Thus, in the same sense that a multiple-input test is a multi-reference measurement (measuring several columns of the FRF matrix), so too is the MRIT since it provides a multi-reference measurement including several rows of the same FRF matrix.


## Modal Parameter Extraction Methods {#modal-parameter-extraction-methods}


### Introduction {#introduction}


#### Introduction to the concept of modal analysis {#introduction-to-the-concept-of-modal-analysis}

This section describes some of the many procedures that are used for **Modal Analysis** and attempts to explain their various advantages and limitations.
These methods generally consists of **curve-fitting a theoretical expression for an individual FRF to the actual measured data**.

<div class="important">
  <div></div>

Degree of complexity of curve-fitting:

1.  **part of single FRF curve**
2.  **complete curve** encompassing several resonances
3.  **a set of many FRF plots** all on the same structure

</div>

In every case, the task is basically to **find the coefficients in a theoretical expression** for the FRF which then most closely **matches the measured data**.

This phase of the modal test procedure is often referred to as **modal parameter extraction** or **modal analysis**.


#### Types of modal analysis {#types-of-modal-analysis}

A majority of current curve-fitting methods operate on the response characteristics in the frequency domain, but there are other procedures which perform a curve-fit in the time domain. These latter methods are based on the fact that the Impulse Response Function is another characteristic function of the system.

Modal analysis methods can be classified into a series of different groups.

<div class="important">
  <div></div>

**Classification - Analysis Domain**:

It depends on the **domain in which the analysis is performed**:

-   Frequency domain of FRFs
-   Time domain of IRFs

</div>

<div class="important">
  <div></div>

**Classification - Frequency range**:

Next, it is appropriate to consider the **frequency range** over which each individual analysis will be performed.
Either a single mode is to be extracted at a time, or several:

-   **SDOF methods**
-   **MDOF methods**

</div>

<div class="important">
  <div></div>

**Classification - Number of FRFs**:

A further classification relates to the **number of FRFs** which are to be included in a single analysis:

-   **SISO**: the FRF are measured individually
-   **SIMO**: a set of FRF are measured simultaneously at several response points but under the same single-point excitation.
    This describes the FRFs in a column or row of the FRF matrix
-   **MIMO**: the responses at several points are measured simultaneously while the structure is excited at several points, also simultaneously

</div>


#### Difficulties due to damping {#difficulties-due-to-damping}

Many of the problems encounter in practice are related to the difficulties associated with the **reliable modeling of damping effects**.
In practice, we are obliged to make certain assumptions about what model is to be used for the damping effects.
Sometimes, significant errors can be obtained in the modal parameter estimates (and not only in the damping parameters), as a result of a conflict between the assumed damping behavior and that which actually occurs in reality.

Another difficulty is that of **real modes and complex modes**.
In practice, all modes of practical structures are expected to be complex, although in the majority of cases, such complexity will be very small, and often quite negligible.


#### Difficulties of model order {#difficulties-of-model-order}

One problem is determining **how many modes are there in the measured FRF**.

This question is one of the most difficult to resolve in many practical situations where a combination of finite resolution and noise in the measured data combined to make the issue very unclear.

Many modern modal analysis curve-fitters are capable of fitting any FRF of almost any order, however, it might fit **fictitious modes** introduced in the analysis process.
Correct **differentiation between genuine and fictitious modes** remains a critical task in many modal tests.


### Preliminary checks of FRF data {#preliminary-checks-of-frf-data}


#### Visual Checks {#visual-checks}

Before starting the modal analysis of any measured FRF data, it is always important to do a few **simple checks** in order to ensure that no obvious error is present in the data.
Most of the checks are made using a **log log plot of the modulus of the measured FRF**.


##### Low-frequency asymptotes {#low-frequency-asymptotes}

If the structure is **grounded**, then we should clearly see a **stiffness-like** characteristic, appearing as asymptotic to a stiffness line at the lowest frequencies (below the first resonance) and the magnitude of this should correspond to that of the static stiffness of the structure at the point in question.

If the structure has been tested in a free condition, then we should expect to see a **mass-line** asymptote where its magnitude may be deduced from purely rigid-body considerations.

Deviations from this expected behavior may be caused by the frequency range of measurement not extending low enough to see the asymptotic trend, or they may indicate that the required support conditions have not in fact been achieved.


##### High-frequency asymptotes {#high-frequency-asymptotes}

In the upper end of the frequency range, is it sometimes found (especially on point mobility measurements), that the curve becomes asymptotic to a **mass line** or, more usually to a **stiffness line**.
Such situation can result in considerable difficulties for the modal analysis process and reflects a situation where the excitation is being applied at a point of very high mass of flexibility.
Then, modal parameters are difficult to extracts as they are overwhelmed by the dominant local effects.


##### Incidence of anti-resonances {#incidence-of-anti-resonances}

For a **point FRF**, there must be **antiresonance after each resonances**, while for transfer FRFs between two points well-separated on the structure, we should expect **more minima than antiresonances**.

A second check to be made is that the resonance peaks and the antiresonances exhibit the **same sharpness on a log-log plot**:

-   Frequency resolution limitation will cause blunt resonances
-   Inadequate vibration levels results in poor definition of the antiresonance regions


##### Overall shape of FRF skeleton {#overall-shape-of-frf-skeleton}

The relative position of the resonance, antiresonances and ambient levels of the FRF curve can give information on the validity of the data.
This will be further explained.


##### Nyquist plot inspection {#nyquist-plot-inspection}

When plotting the FRF data in a Nyquist format, we expect that each resonance traces out at least **part of a circular arc**, the extent of which depends largely on the interaction between adjacent modes.
For a system with well-separated modes, it is to be expected that each resonance will generate the major part of a circle, but when modal interference increases, only small segments will be identifiable.
However, within these bounds, the Nyquist plot should ideally exhibit a smooth curve, and failure to do so may be an indication of a poor measurement technique.


#### Assessment of multiple-FRF data set using SVD {#assessment-of-multiple-frf-data-set-using-svd}

When several FRFs are acquired (either from SIMO or MIMO data), the **Singular Value Decomposition** has proved to be a very useful tool to check the **quality**, **reliability** and **order** of the data.

The set of FRF which are to be assessed is stored in a series of vectors \\(\\{H\_{jk}(\omega)\\}\\) each of which contains the values for one FRF at all measured frequencies \\(\omega = \omega\_1, \dots, \omega\_L\\).
These vectors are assembled into a matrix
\\[ [A]\_{L\times np} = [\\{H\_{11}(\omega)\\}\_{L\times 1} \\{H\_{21}(\omega)\\}\_{L\times 1} \dots \\{H\_{np}(\omega)\\}\_{L\times 1} ] \\]
where \\(n\\) and \\(p\\) represent the number of measured DOFs and the number of excitation points.
\\(L\\) represents the number of frequencies at which the FRF data are defined.

<div class="definition">
  <div></div>

**Singular Value Decomposition**:

\begin{equation}
 [A]\_{L\times np} = [U]\_{L\times L} [\Sigma]\_{L\times np}  [V]\_{np\times np}^T
\end{equation}

</div>

<div class="important">
  <div></div>

Interpretation of SVD:

-   The **singular values** \\(\sigma\_1, \dots, \sigma\_w\\) describes the **amplitude** information
-   Number of **non-zero singular values** represents the **order of the system** (i.e. the number of independent modes of vibration which effectively contribute to the measured FRFs)
-   The columns of \\([U]\\) represent the **frequency distribution** of these amplitudes
-   The columns of \\([V]\\) represent their **spatial distribution**

</div>

<div class="definition">
  <div></div>

From the SVD, we can compute a new matrix \\([P]\_{L\times np}\\) which is referred to as the **Principal Response Function** (**PRF**) matrix.
Each column of the PRF contains a response function corresponding to one of the original FRFs:

\begin{equation}
  [U]\_{L\times L} [\Sigma]\_{L\times np} = [P]\_{L\times np}
\end{equation}

Then, each PRF is, simply, a particular combination of the original FRFs, and thus each FRF contains all the essential information included in those FRFs (eigenvalues for instance).

</div>

On example of this form of pre-processing is shown on figure [19](#table--fig:PRF-numerical) for a numerically-simulation test data, and another in figure [20](#table--fig:PRF-measured) for the case of real measured test data.

The second plot [19](#org354c67b) helps to determine the true order of the system because the number of non-zero singular values is equal to this parameter.
The third plot [19](#org9b16f79) shows the genuine modes distinct from the computational modes.

<div class="important">
  <div></div>

It can be seen that the PRFs tend to fall into **two groups**:

-   The most prominent are a set of response function, each of which has a small number of dominant peaks.
    It represents the **physical modes** of the system.
-   The lower group shows less distinct and clear-cut behavior.
    It represents the **noise or computational modes** present in the data.

The two groups are usually separated by a clear gap (depending of the noise present in the data):

-   If such gap is present, then is will be possible to extract the properties of the \\(m\\) modes which are active in the measured responses over the frequency range covered.
-   If not, then it may be impossible to perform a successful modal parameter extraction.

</div>

<a id="table--fig:PRF-numerical"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:PRF-numerical">Table 19</a></span>:
  FRF and PRF characteristics for numerical model
</div>

| ![](/ox-hugo/ewins00_PRF_numerical_FRF.png) | ![](/ox-hugo/ewins00_PRF_numerical_svd.png) | ![](/ox-hugo/ewins00_PRF_numerical_PRF.png) |
|---------------------------------------------|---------------------------------------------|---------------------------------------------|
| <a id="org7b84bb4"></a> FRF                 | <a id="org354c67b"></a> Singular Values     | <a id="org9b16f79"></a> PRF                 |
| width=\linewidth                            | width=\linewidth                            | width=\linewidth                            |

<a id="table--fig:PRF-measured"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:PRF-measured">Table 20</a></span>:
  FRF and PRF characteristics for measured model
</div>

| ![](/ox-hugo/ewins00_PRF_measured_FRF.png) | ![](/ox-hugo/ewins00_PRF_measured_svd.png) | ![](/ox-hugo/ewins00_PRF_measured_PRF.png) |
|--------------------------------------------|--------------------------------------------|--------------------------------------------|
| <a id="org9775a5d"></a> FRF                | <a id="org109aae1"></a> Singular Values    | <a id="orgcf6c0c3"></a> PRF                |
| width=\linewidth                           | width=\linewidth                           | width=\linewidth                           |


#### Mode Indicator Functions (MIFs) {#mode-indicator-functions--mifs}


##### General {#general}

The Mode Indicator Functions are usually used on \\(n\times p\\) FRF matrix where \\(n\\) is a relatively large number of measurement DOFs and \\(p\\) is the number of excitation DOFs, typically 3 or 4.

In these methods, the frequency dependent FRF matrix is subjected to an eigenvalue or singular value decomposition analysis which thus yields a small number (3 or 4) of eigen or singular values, these also being frequency dependent.

These methods are used to **determine the number of modes** present in a given frequency range, to **identify repeated natural frequencies** and to pre process the FRF data prior to modal analysis.


##### Complex mode indicator function (CMIF) {#complex-mode-indicator-function--cmif}

The Complex Mode Indicator Function is defined simply by the SVD of the FRF (sub) matrix.

<div class="definition">
  <div></div>

The **Complex mode indicator function** (CMIF) is defined as

\begin{align\*}
  [H(\omega)]\_{n\times p} &= [U(\omega)]\_{n\times n} [\Sigma(\omega)]\_{n\times p} [V(\omega)]\_{p\times p}^H\\\\\\
  [CMIF(\omega)]\_{p\times p} &= [\Sigma(\omega)]\_{p\times n}^T [\Sigma(\omega)]\_{n\times p}
\end{align\*}

</div>

The actual mode indicator values are provided by the squares of the singular values and are usually plotted as a function of frequency in logarithmic form as shown in figure [27](#org1684572):

-   **Natural frequencies are indicated by large values of the first CMIF** (the highest of the singular values)
-   **double or multiple modes by simultaneously large values of two or more CMIF**.

Associated with the CMIF values at each natural frequency \\(\omega\_r\\) are two vectors:

-   the left singular vector \\(\\{U(\omega\_r)\\}\_1\\) which approximates the **mode shape** of that mode
-   the right singular vector \\(\\{V(\omega\_r)\\}\_1\\) which represents the approximate **force pattern necessary to generate a response on that mode only**

<a id="org1684572"></a>

{{< figure src="/ox-hugo/ewins00_mifs.png" caption="Figure 27: Complex Mode Indicator Function (CMIF)" >}}

<div class="important">
  <div></div>

In addition to identifying all the significant natural frequencies, the CMIF can also be used to **generate a set of enhanced FRFs** from the formula:

\begin{equation} \label{eq:efrf}
  [EFRF(\omega)]\_{n\times p} = [H(\omega)]\_{n\times p} [V(\omega)]\_{p\times p}
\end{equation}

There is one non-trivial EFRF for each mode, the result of which is an almost **SDOF characteristic** response function which is then readily amenable to modal analysis by the simplest of methods.

As in the previous case, these modified FRFs are simply linear combinations of the original measured data and, as such, contain no more and no less information than in their original form.

However, such an approach lends itself to a very reliable extraction of the global properties (eigenvalues) for the measured FRF data set which can then be re-visited in a second stage to determine the local properties (mode shapes) for all the measured DOFs.

</div>


##### Other MIFs {#other-mifs}

There are multiple variants on the mode indicator function concepts. Some use the eigenvalue decomposition instead of the singular value decomposition.
Two are worth mentioning: the Multivariable Mode Indicator Function (MMIF) and the Real Mode Indicator Function (RMIF).


### SDOF Modal Analysis Methods {#sdof-modal-analysis-methods}


#### Review of SDOF modal analysis methods {#review-of-sdof-modal-analysis-methods}

The "SDOF" approach does not imply that the system being modeled is reduced to a single degree of freedom, that that just **one resonance is considered at a time**.

There are limitations to such simple approach, the principal one being that **very close modes cannot easily be separated**.

There are several implementations of the basic concept of SDOF analysis, ranging from the simple **peak-picking method**, through the classic **circle-fit approach** to more automatic algorithms such as the **inverse FRF "he-fit" method** and the general **least-squares methods**.

As the name implies, the method exploits the fact that in the vicinity of a resonance, the behavior of the system is dominated by a single mode (the magnitude is dominated by one of the terms in the series).

The general expression of the receptance FRF

\begin{equation}
  \alpha\_{jk}(\omega) = \sum\_{s=1}^N \frac{{}\_sA\_{jk}}{\omega\_s^2 - \omega^2 + i \eta\_s \omega\_s^2}
\end{equation}

can be rewritten as:

\begin{equation}
  \alpha\_{jk}(\omega) = \frac{{}\_rA\_{jk}}{\omega\_r^2 - \omega^2 + i \eta\_r \omega\_r^2} + \sum\_{\substack{s=1\\s \neq r}}^N \frac{{}\_sA\_{jk}}{\omega\_s^2 - \omega^2 + i \eta\_s \omega\_s^2}
\end{equation}

<div class="important">
  <div></div>

Now, the SDOF assumption is that for a small range of frequency in the vicinity of the natural frequency of mode \\(r\\), \\(\alpha\_{jk}(\omega)\\) can be approximated as

\begin{equation}
  \alpha\_{jk}(\omega)\_{\omega\approx\omega\_r} = \frac{{}\_rA\_{jk}}{\omega\_r^2 - \omega^2 + i \eta\_r \omega\_r^2} + {}\_rB\_{jk}
\end{equation}

</div>

This does not mean that the other modes are unimportant or negligible (their influence can be considerable), but rather that their combined effect can be represented as a **constant term** around this resonance.


#### SDOF Modal Analysis I - Peak-Amplitude method {#sdof-modal-analysis-i-peak-amplitude-method}

In this method, it is assumed that close to one local mode, any effects due to the other modes can be ignored.
This is a method which works adequately for structures whose FRF exhibit **well separated modes**.
This method is useful in obtaining initial estimates to the parameters.

The peak-picking method is applied as follows (illustrated on figure [28](#org00f64f0)):

1.  First, **individual resonance peaks** are detected on the FRF plot and the maximum responses frequency \\(\omega\_r\\) is taken as the **natural frequency** of that mode
2.  Second, the **local maximum value of the FRF** \\(|\hat{H}|\\) is noted and the **frequency bandwidth** of the function for a response level of \\(|\hat{H}|/\sqrt{2}\\) is determined.
    The two points thus identified as \\(\omega\_b\\) and \\(\omega\_a\\) are the "half power points"
3.  The **damping** of the mode in question can now be estimated from of the following formulae:

    \begin{equation}
      \begin{aligned}
        \eta\_r &= \frac{\omega\_a^2 - \omega\_b^2}{2 \omega\_r^2} \approx \frac{\Delta\omega}{\omega\_r} \\\\\\
        2\xi\_r &= \eta\_r
      \end{aligned}
    \end{equation}
4.  We now obtain an estimate for the **modal constant** of the mode being analyzed by assuming that the total response in this resonant region is attributed to a single term in the general FRF series:

    \begin{equation}
      |\hat{H}| = \frac{A\_r}{\omega\_r^2 \eta\_r} \Leftrightarrow A\_r = |\hat{H}| \omega\_r^2 \eta\_r
    \end{equation}

It must be noted that the estimates of both damping and modal constant depend heavily on the accuracy of the maximum FRF level \\(|\hat{H}|\\) which is difficult to measure with great accuracy, especially for lightly damped systems.
Only real modal constants and thus real modes can be deduced by this method.

<a id="org00f64f0"></a>

{{< figure src="/ox-hugo/ewins00_peak_amplitude.png" caption="Figure 28: Peak Amplitude method of modal analysis" >}}

Alternatives of this method can be applied using the real part of the receptance FRF instead of the modulus plot.


#### SDOF Modal Analysis II - Circle Fit Method {#sdof-modal-analysis-ii-circle-fit-method}


##### Properties of the modal circle {#properties-of-the-modal-circle}

MDOF systems produce Nyquist plots of FRF data which include **sections of near circular arcs** corresponding to the regions near the natural frequencies.
This characteristic provides the basic of the "**SDOF circle-fit method**".

We here use **structural damping** and we use the **receptance** form of FRF data as this will produces an exact circle in a Nyquist plot.
However, if it is required to use a model incorporating viscous damping, then the mobility version of the FRF data should be used.

In the case of a system assumed to have structural damping, the basic function with which we are dealing is

\begin{equation}
  \alpha(\omega) = \frac{1}{\omega\_r^2\left( 1 - \left(\omega/\omega\_r\right)^2 + i\eta\_r \right)}
\end{equation}

since the only effect of including the modal constant \\({}\_rA\_{jk}\\) is to scale the size of the circle by \\(|{}\_rA\_{jk}|\\) and to rotate it by \\(\angle {}\_rA\_{jk}\\).
A plot of the quantity \\(\alpha(\omega)\\) is given in figure [21](#orga9233a4).

<a id="table--fig:modal-circle-figures"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:modal-circle-figures">Table 21</a></span>:
  Modal Circle
</div>

| ![](/ox-hugo/ewins00_modal_circle.png) | ![](/ox-hugo/ewins00_modal_circle_bis.png)                         |
|----------------------------------------|--------------------------------------------------------------------|
| <a id="orga9233a4"></a> Properties     | <a id="org0ad9bc7"></a> \\(\omega\_b\\) and \\(\omega\_a\\) points |
| width=\linewidth                       | width=\linewidth                                                   |

For any frequency \\(\omega\\), we have the following relationship:

\begin{equation} \label{eq:modal\_circle\_tan}
  \begin{aligned}
    \tan \gamma &= \frac{\eta\_r}{1 - (\omega/\omega\_r)^2}\\\\\\
    \tan(\SI{90}{\degree}-\gamma) &= \tan\left(\frac{\theta}{2}\right) = \frac{1 - (\omega/\omega\_r)^2}{\eta\_r}
  \end{aligned}
\end{equation}

From \eqref{eq:modal_circle_tan}, we obtain:

\begin{equation} \label{eq:modal\_circle\_omega}
  \omega^2 = \omega\_r^2 \left(1 - \eta\_r \tan\left(\frac{\theta}{2}\right) \right)
\end{equation}

If we differentiate \eqref{eq:modal_circle_omega} with respect to \\(\theta\\), we obtain:

\begin{equation}
  \frac{d\omega^2}{d\theta} = \frac{-\omega\_r^2 \eta\_r}{2} \frac{\left(1 - (\omega/\omega\_r)^2\right)^2}{\eta\_r^2}
\end{equation}

The reciprocal of this quantity is a **measure of the rate at which the locus sweeps around the circular arc**.
It may be seen to reach a maximum value when \\(\omega=\omega\_r\\):

\begin{equation}
  \tcmbox{\frac{d}{d\omega} \left(\frac{d\omega^2}{d\theta}\right) = 0 \text{ when } \omega\_r^2 - \omega^2 = 0}
\end{equation}

It may also be seen that an **estimate of the damping** is provided by the sweep rate:

\begin{equation} \label{eq:estimate\_damping\_sweep\_rate}
  \tcmbox{\left(\frac{d\theta}{d\omega^2}\right)\_{\omega=\omega\_r} = -\frac{2}{\omega\_r^2 \eta\_r}}
\end{equation}

Suppose now we have two specific points on the circle, one corresponding to a frequency \\(\omega\_b\\) below the natural frequency and the other one \\(\omega\_a\\) above the natural frequency.
Referring to figure [21](#org0ad9bc7), we can write:

\begin{equation}
  \begin{aligned}
    \tan\left(\frac{\theta\_b}{2}\right) &= \frac{1 - (\omega\_b/\omega\_r)^2}{\eta\_r}\\\\\\
    \tan\left(\frac{\theta\_a}{2}\right) &= \frac{(\omega\_a/\omega\_r)^2 - 1}{\eta\_r}
  \end{aligned}
\end{equation}

From these two equations, we can obtain an expression for the **damping of the mode**:

\begin{equation} \label{eq:estimate\_damping}
  \tcmbox{\eta\_r = \frac{\omega\_a^2 - \omega\_b^2}{\omega\_r^2 \left(\tan(\theta\_a/2) + \tan(\theta\_b/2)\right)}}
\end{equation}

which is an exact expression and applies for all levels of damping.

If we take two points for which \\(\theta\_a = \theta\_b = \SI{90}{\degree}\\), we obtain:

\begin{equation}
  \begin{aligned}
    \eta\_r &= \frac{\omega\_2^2 - \omega\_1^2}{2 \omega\_r^2}\\\\\\
    \eta\_r &= \frac{\omega\_2 - \omega\_1}{\omega\_r} \text{ for light damping}
  \end{aligned}
\end{equation}

When scaled by a modal constant \\({}\_rA\_{jk}\\) added in the numerator, the diameter of the circle will be
\\[ {}\_rD\_{jk} = \frac{\left|{}\_rA\_{jk}\right|}{\omega\_r^2 \eta\_r} \\]
and the whole circle will be rotated so that the principal diameter (the one passing through the natural frequency point) is oriented at an angle \\(\arg({}\_rA\_{jk})\\) to the negative Imaginary axis.

For SDOF system with **viscous** damping, rather than structural damping, the **mobility** is
\\[ Y(\omega) = \frac{i\omega}{(k - \omega^2 m) + i \omega c} \\]

And we have

\begin{equation}
  \tan\left(\frac{\theta}{2}\right) = \frac{1 - (\omega/\omega\_r)^2}{2 \xi \omega/\omega\_r}
\end{equation}

From points at \\(\omega\_a\\) and \\(\omega\_b\\), we obtain

\begin{equation}
  \begin{aligned}
    \xi &= \frac{\omega\_a^2 - \omega\_b^2}{2 \omega\_r \left( \omega\_a \tan(\theta\_a/2) + \omega\_b \tan(\theta\_b/2) \right)}\\\\\\
        &= \frac{\omega\_a - \omega\_b}{\omega\_r \left( \tan(\theta\_a/2) + \tan(\theta\_b/2) \right)} \text{ for light damping}
  \end{aligned}
\end{equation}

Finally, selecting two points for which \\(\theta\_a = \theta\_b = \SI{90}{\degree}\\):

\begin{equation}
  \xi = \frac{\omega\_2 - \omega\_1}{2 \omega\_r}
\end{equation}


##### Circle-fit analysis procedure {#circle-fit-analysis-procedure}

The sequence is:

1.  **Select points to be used**.
2.  **Fit circle, calculate quality of fit**.
    It is generally done by a least-square algorithm.
    Then we obtain the **center** and **radius** of the circle and the **quality factor** is the mean square deviation of the chosen points from the circle.
3.  **Locate natural frequency, obtain damping estimate**.
    The rate of sweep through the region is estimated numerically and the frequency at which it reaches the maximum is deduced.
    At the same time, an estimate of the damping is derived using \eqref{eq:estimate_damping_sweep_rate}.
    A typical example is shown on figure [29](#org751f6e5).
4.  **Calculate multiple damping estimates, and scatter**.
    A set of damping estimates using all possible combination of the selected data points are computed using \eqref{eq:estimate_damping}.
    Then, we can choose the damping estimate to be the mean value.
    We also look at the distribution of the obtained damping estimates as is permits a useful diagnostic of the quality of the entire analysis:
    -   Good measured data should lead to a smooth plot of these damping estimates, any roughness of the surface can be explained in terms of noise in the original data.
    -   However, any systematic distortion of the plot is almost certainly caused by some form of error in the data, in the analysis or in the assumed behavior of the system.
5.  **Determine modal constant modulus and argument**.
    The magnitude and argument of the modal constant is determined from the diameter of the circle and from its orientation relative to the Real and Imaginary axis.

<a id="org751f6e5"></a>

{{< figure src="/ox-hugo/ewins00_circle_fit_natural_frequency.png" caption="Figure 29: Location of natural frequency for a Circle-fit modal analysis" >}}

Then, the theoretically regenerated FRF can be plotted against the original measured data for comparison.
In order to determines the contribution of other modes on the resonance of mode \\(r\\), the distance from the top of the principal diameter to the origin has to be measured and is equal to \\({}\_rB\_{jk}\\).


#### SDOF Modal Analysis III - Inverse or Line-fit method {#sdof-modal-analysis-iii-inverse-or-line-fit-method}


##### Properties of inverse FRF plots {#properties-of-inverse-frf-plots}

The original version of this method uses the fact that a function which generates a circle when plotted in the complex plane will, when plotted as a reciprocal, trace out a **straight line**.
Thus, if we were to plot the reciprocal of receptance of a SDOF system with structural damping, we would find that in the Argand diagram it produces a straight line:

\begin{equation}
  \begin{aligned}
    \alpha(\omega) &= \frac{(k - \omega^2 m) - i d}{(k - \omega^2 m)^2 + d^2}\\\\\\
    \frac{1}{\alpha(\omega)} &= (k - \omega^2 m) + i d
  \end{aligned}
\end{equation}

First, a least squares best-fit straight line is constructed through the data points and an **estimate for the damping parameters** is immediately available from the **intercept of the line with the Imaginary axis**.
Furthermore, an indication of the reliability of that estimate may be gained from the nature of the deviations of the data points from the line itself.
We can here determine whether the damping is structural (imaginary part constant with frequency) or viscous (imaginary part linear with frequency).

Then, a second least squares operation is performed, this time on the deviation between the real part of the measured data points and that of the theoretical model.
Resulting from this, we obtain **estimates for the mass and stiffness parameters**.

It should be noted that this approach is best suited to systems with real modes and to relatively well-separated modes.


##### General inverse analysis method {#general-inverse-analysis-method}

It has been shown that if a purely SDOF system FRF is plotted in this way, then both plots demonstrate straight lines, and separately reveal useful information about the mass, stiffness and damping properties of the measured system.

The inverse FRF of a MDOF system is not as convenient as SDOF system as:

\begin{align\*}
  H\_{jk}^{-1} (\omega) &= \frac{1}{\sum (k - \omega^2 m) + i \omega c}\\\\\\
                       &\neq \sum \frac{1}{(k - \omega^2 m) + i \omega c}
\end{align\*}

Thus, in order to determine the modal parameters of a MDOF system using inverse method, some modifications to the basic formulation must be found.

We start with the basic formula for SDOF analysis:
\\[ \alpha\_{jk}(\omega)\_{\omega\simeq\omega\_r} \simeq \frac{{}\_rA\_{jk}}{\omega\_r^2 - \omega^2 + i \eta\_r \omega\_r^2} + {}\_rB\_{jk} \\]
We can note that the presence of the \\({}\_rB\_{jk}\\) term is problematic for the inverse plot.

The trick is to define a **new FRF term** \\(\alpha^\prime\_{ik}(\omega)\\) which is the difference between the actual FRF and the value of the FRF at one fixed frequency \\(\Omega\\) in the range of interest called "**fixing frequency**":
\\[ \alpha^\prime\_{jk}(\omega) = \alpha\_{jk}(\omega) - \alpha\_{jk}(\Omega) \\]
from which the inverse FRF parameter that we shall use for the modal analysis \\(\Delta(\omega)\\), can be defined as:

\begin{align\*}
  \Delta(\omega) &= (\omega^2 - \Omega^2)/\alpha^\prime\_{jk}(\omega)\\\\\\
                 &= \text{Re}(\Delta) + i \text{Im}(\Delta)
\end{align\*}

It can be seen that
\\[ \text{Re}(\Delta) = m\_R \omega^2 + c\_R; \quad  \text{Im}(\Delta) = m\_I \omega^2 + c\_I \\]
and that

\begin{align\*}
  m\_R &= a\_R(\Omega^2 - \omega\_r^2) - b\_r (\omega\_r^2 \eta\_r) \\\\\\
  m\_I &= -b\_R(\Omega^2 - \omega\_r^2) - a\_r (\omega\_r^2 \eta\_r) \\\\\\
  {}\_rA\_{jk} &= a\_R + i b\_r
\end{align\*}

The first step of our **analysis procedure** can be made, as follows:

1.  Using the FRF data measured in the vicinity of the resonance \\(\omega\_r\\), choose the fixing frequency \\(\Omega\_j\\) and then calculate \\(\Delta(\omega)\\)
2.  Plot these values on \\(\text{Re vs } \omega^2\\) and \\(\text{Im vs }\omega^2\\) plots and compute the best fit straight line in order to determine \\(m\_R(\Omega\_j)\\) and \\(m\_I(\Omega\_j)\\)

Now it can be shown that both these straight line slopes \\(m\_R\\) and \\(m\_I\\) are simple functions of \\(\Omega\\), and we can write:
\\[ m\_R = n\_R \Omega^2 + d\_R \text{ and } m\_I = n\_I \Omega^2 + d\_I \\]
where

\begin{equation} \label{eq:four\_parameters}
  \begin{aligned}
    n\_R &= a\_r; \quad n\_I = -b\_r \\\\\\
    d\_R &= -b\_r(\omega\_r^2 \eta\_r) - a\_r \omega\_r^2; \quad d\_I = b\_r \omega\_r^2 - a\_r\omega\_r^2\eta\_r
  \end{aligned}
\end{equation}

Now let \\(p = n\_I/n\_R \text{ and } q = d\_I/d\_R\\), and noting that

\begin{equation} \label{eq:modal\_parameters\_formula}
  \begin{aligned}
    \eta\_r &= \frac{q - p}{1 + pq}; \quad \omega\_r^2 = \frac{d\_R}{(p\eta\_r - 1)n\_R} \\\\\\
    a\_r &= \frac{\omega\_r^2(p\eta\_r - 1)}{(1 + p^2)d\_R}; \quad b\_r = -a\_r p
  \end{aligned}
\end{equation}

we now have sufficient information to extract estimates for the four parameters for the resonance which has been analyzed: \\(\omega\_r, \eta\_r, \text{ and } {}\_rA\_{jk} = a\_r + i b\_r\\).

<ol class="org-ol">
<li value="3">Plot graphs of \\(m\_R(\Omega)\\) vs \\(\Omega^2\\) and of \\(m\_I(\Omega)\\) vs \\(\Omega^2\\) using the results from step 1., each time using a different measurement points as the fixing frequency \\(\Omega\_j\\)</li>
<li>Determine the slopes of the best fit straight lines through these two plots, \\(n\_R\\) and \\(n\_I\\), and their intercepts with the vertical axis \\(d\_R\\) and \\(d\_I\\)</li>
<li>Use these four quantities, and equation \eqref{eq:modal_parameters_formula}, to determine the **four modal parameters** required for that mode</li>
</ol>

This procedure which places more weight to points slightly away from the resonance region is likely to be less sensitive to measurement difficulties of measuring the resonance region.


#### Residuals {#residuals}


##### Concept of residual terms {#concept-of-residual-terms}

We need to introduce the concept of **residual terms**, necessary in the modal analysis process to take account of those modes which we do not analyze directly but which nevertheless exist and have an influence on the FRF data we use.

The first occasion on which the residual problem is encountered is generally at the end of the analysis of a single FRF curve, such as by the repeated application of an SDOF curve-fit to each of the resonances in turn until all modes visible on the plot have been identified.
At this point, it is often desired to construct a theoretical curve (called "**regenerated**"), based on the modal parameters extracted from the measured data, and to overlay this on the original measured data to assess the success of the curve-fit process.
Then the regenerated curve is compared with the original measurements, the result is often disappointing, as illustrated in figure [22](#orgf043f5e).
However, by the inclusion of two simple extra terms (the "**residuals**"), the modified regenerated curve is seen to correlate very well with the original experimental data as shown on figure [22](#org1a33e90).

<a id="table--fig:residual-modes"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:residual-modes">Table 22</a></span>:
  Effects of residual terms on FRF regeneration
</div>

| ![](/ox-hugo/ewins00_residual_without.png) | ![](/ox-hugo/ewins00_residual_with.png) |
|--------------------------------------------|-----------------------------------------|
| <a id="orgf043f5e"></a> without residual   | <a id="org1a33e90"></a> with residuals  |
| width=\linewidth                           | width=\linewidth                        |

If we regenerate an FRF curve from the modal parameters we have extracted from the measured data, we shall use a formula of the type

\begin{equation}
  H\_{jk}(\omega) = \sum\_{r = m\_1}^{m\_2} \frac{{}\_rA\_{jk}}{\omega\_r^2 - \omega^2 + i \eta\_r \omega\_r^2}
\end{equation}

in which \\(m\_1\\) and \\(m\_2\\) reflects that we do not always start at the first mode (\\(r = 1\\)) and continue to the highest mode (\\(r = N\\)).

However, the equation which most closely represents the measured data is:

\begin{equation}
  H\_{jk}(\omega) = \sum\_{r = 1}^{N} \frac{{}\_rA\_{jk}}{\omega\_r^2 - \omega^2 + i \eta\_r \omega\_r^2}
\end{equation}

which may be rewritten as

\begin{equation} \label{eq:sum\_modes}
  H\_{jk}(\omega) = \left( \sum\_{r=1}^{m\_1-1} + \sum\_{r=m\_1}^{m\_2} + \sum\_{r = m\_2+1}^{N} \right) \frac{{}\_rA\_{jk}}{\omega\_r^2 - \omega^2 + i \eta\_r \omega\_r^2}
\end{equation}

The three terms corresponds to:

1.  the **low frequency modes** not identified
2.  the **high frequency modes** not identified
3.  the **modes actually identified**

These three terms are illustrated on figure [30](#orgd0e499e).

<a id="orgd0e499e"></a>

{{< figure src="/ox-hugo/ewins00_low_medium_high_modes.png" caption="Figure 30: Numerical simulation of contribution of low, medium and high frequency modes" >}}

From the sketch, it may be seen that within the frequency range of interest:

-   the first term tends to approximate to a **mass-like behavior**
-   the third term approximates to a **stiffness effect**

Thus, we have a basis for the residual terms and shall rewrite equation \eqref{eq:sum_modes}:

\begin{equation}
  H\_{jk}(\omega) \simeq -\frac{1}{\omega^2 M\_{jk}^R} + \sum\_{r=m\_1}^{m\_2} \left( \frac{{}\_rA\_{jk}}{\omega\_r^2 - \omega^2 + i \eta\_r \omega\_r^2} \right) + \frac{1}{K\_{jk}^R}
\end{equation}

where the quantities \\(M\_{jk}^R\\) and \\(K\_{jk}^R\\) are the **residual mass and stiffness** for that **particular FRF** and **chosen frequency range**.


##### Calculation of residual mass and stiffness terms {#calculation-of-residual-mass-and-stiffness-terms}

First, we compute a few values of the regenerated FRF curve at the lower frequencies covered by the tests, using only the identified modal parameters.
Then, by comparing these values with those from actual measurements, we estimate a mass residual constant which, when added to the regenerated curve, brings this closely into line with the measured data.

Then, the process is repeated at the top end of the frequency range, this time seeking a residual stiffness.
Often, the process is more effective if there is an antiresonance near either end of the frequency range which this is then used as the point of adjustment.

The procedure outlined here may need to be repeated **iteratively** in case the addition of the stiffness residual term then upsets the effectiveness of the mass term.

It should be noted that often there is a **physical significance to the residual terms**.
If the test structure is freely-supported and its rigid body modes are well below the minimum frequency of measurement, then the mass residual term will be a direct reflection of the rigid body mass and inertia properties of the structure.
The high frequency residual can represent the local flexibility at the drive point.


##### Residual and pseudo modes {#residual-and-pseudo-modes}

Sometimes it is convenient to **treat the residual terms as if they were modes**.
Instead of representing each residual effect by a constant, each can be represented by a pseudo mode.
For the low frequency residual effects, this pseudo mode has a natural frequency below the lowest frequency on the measured FRF, and for the high frequency residual effects, that pseudo mode has a natural frequency which is above the highest frequency of the measured FRF.
These pseudo modes can be conveniently included in the list of modes which have been extracted by modal analysis of that FRF.

Using pseudo modes instead of simple residual mass and stiffness terms is a more accurate way of representing the out-of-range modes.
There is one warning, however, and that is to point out that these pseudo modes are **not** genuine modes and that they cannot be used to deduce the corresponding contributions of these same modes for any other FRF curve.


#### Refinement of SDOF modal analysis methods {#refinement-of-sdof-modal-analysis-methods}

In the modal analysis methods discussed above, an assumption is made that near the resonance under analysis, the effect of **all** the other modes could be represented by a constant.
When there are neighboring modes close to the one being analyzed, this assumption may not be valid.

<div class="definition">
  <div></div>

**"Close" modes** is loosely defined as a situation where the separation between the natural frequencies of two adjacent modes is less than the typical damping level, both measured as percentage.

</div>

However, we can usually remove that restriction and thereby make a more precise analysis of the data.

We can write the receptance in the frequency range of interest as:

\begin{equation} \label{eq:second\_term\_refinement}
  \begin{aligned}
    H\_{jk}(\omega) &= \sum\_{s=m\_1}^{m\_2} \left( \frac{{}\_sA\_{jk}}{\omega\_s^2 - \omega^2 + i \eta\_s \omega\_s^2} \right) + \frac{1}{K\_{jk}^R}-\frac{1}{\omega^2 M\_{jk}^R} \\\\\\
                   &= \left( \frac{{}\_rA\_{jk}}{\omega\_r^2 - \omega^2 + i\eta\_r \omega\_r^2} \right) \\\\\\
                   &+  \left(\sum\_{\substack{s=m\_1 \cr s \neq r}}^{m\_2} \frac{{}\_sA\_{jk}}{\omega\_s^2 - \omega^2 + i\eta\_s \omega\_s^2} + \frac{1}{K\_{jk}^R} - \frac{1}{\omega^2 M\_{jk}^R} \right)
  \end{aligned}
\end{equation}

In the previous methods, the second term was assumed to be a constant in the curve-fit procedure for mode \\(r\\).
However, if we have good **estimates** for the coefficients which constitutes the second term, for example by having already completed an SDOF analysis, we may remove the restriction on the analysis.
Indeed, suppose we take a set of measured data points around the resonance at \\(\omega\_r\\), and that we can compute the magnitude of the second term in \eqref{eq:second_term_refinement}, we then subtract this from the measurement and we obtain adjusted data points that are conform to a true SDOF behavior and we can use the same technique as before to obtain **improved estimated** to the modal parameters of more \\(r\\).

This procedure can be repeated iteratively for all the modes in the range of interest and it can significantly enhance the quality of found modal parameters for system with **strong coupling**.


### MDOF Modal analysis in the frequency domain (SISO) {#mdof-modal-analysis-in-the-frequency-domain--siso}


#### General Approach {#general-approach}

There are a number of situations in which the SDOF approach to modal analysis is inadequate and for these there exist several alternative methods which may generally be classified as MDOF modal analysis methods.
These situations are generally those with closely coupled modes where the single mode approximation is inappropriate and those with extremely light damping for which measurements at resonance are inaccurate.

<div class="important">
  <div></div>

Three approach to curve-fit the entire FRF in one step are considered here:

1.  a general approach to multi-mode curve-fitting
2.  a method based on the rational fraction FRF formulation
3.  a method particularly suited to very lightly-damped structures

</div>


#### Method I - General Curve Fit approach - Non-linear Least Squares (NLLS) {#method-i-general-curve-fit-approach-non-linear-least-squares--nlls}

We shall denote the individual FRF measured data as:
\\[ H\_{jk}^m(\Omega\_l) = H\_l^m \\]
while the corresponding "theoretical" values are:

\begin{equation}
  \begin{aligned}
    H\_l &=H\_{jk}(\Omega\_l) \\\\\\
        &= \sum\_{s=m\_1}^{m\_2}\frac{{}\_sA\_{jk}}{\omega\_s^2 - \Omega\_l^2 + i \eta\_s \omega\_s^2} + \frac{1}{K\_{jk}^R} - \frac{1}{\Omega\_l^2 M\_{jk}^R}
  \end{aligned}
\end{equation}

where the coefficients \\({}\_1A\_{jk}, {}\_2A\_{jk}, \dots, \omega\_1, \omega\_2, \dots, \eta\_1, \eta\_2, \dots, K\_{jk}^R \text{ and }M\_{jk}^R\\) are all to be **determined**.

We can define an **individual error** as:

\begin{equation}
  \epsilon\_l = H\_l^m - H\_l
\end{equation}

and express this as a scalar quantity:

\begin{equation}
  E\_l = \left| \epsilon\_l^2 \right|
\end{equation}

If we further increase the generality by attaching a **weighting factor** \\(w\_l\\) to each frequency point of interest, then the curve fit process has to determine the values of the unknown coefficients such that the total error:

\begin{equation} \label{eq:error\_weighted}
  E = \sum\_{l = 1}^p w\_l E\_l
\end{equation}

is minimized.

This is achieved by differentiating \eqref{eq:error_weighted} with respect to each unknown in turn, thus generating a set of as many equations as there are unknown:

\begin{equation}
  \frac{d E}{d q} = 0; \quad q = {}\_1A\_{jk}, {}\_2A\_{jk}, \dots
\end{equation}

Unfortunately, this set of equations are **not linear** in many of the coefficients and thus cannot be solved directly.
It is from this point that the differing algorithms choose their individual procedures: making various simplifications, assumptions or linearizing the expressions.


#### Method II - Rational Fraction Polynomial Method (RFP) {#method-ii-rational-fraction-polynomial-method--rfp}

The method which has emerged as one the **standard** frequency domain modal analysis methods is that known as the **Rational Fraction Polynomial** (**RFP**) method.
This method is a special version of the general curve fitting approach but is based on a different formulation for the theoretical expression used for the FRF.

<div class="important">
  <div></div>

Rational fraction FRF formulation:

\begin{equation}
  H(\omega) = \sum\_{r=1}^N \frac{A\_r}{\omega\_r^2 - \omega^2 + 2 i \omega \omega\_r \xi\_r} \label{eq:frf\_clasic}
\end{equation}

\begin{equation}
  H(\omega) = \frac{b\_0 + b\_1(i\omega) + \dots + b\_{2N-1}(i\omega)^{2N-1}}{a\_0 + a\_1(i\omega) + \dots + a\_{2N}(i\omega)^{2N}} \label{eq:frf\_rational}
\end{equation}

In this formulation, we have adopted the **viscous damping model**.

</div>

The unknown coefficients \\(a\_0, \dots, a\_{2N}, b\_0, \dots, b\_{2N-1}\\) are not the modal properties but are related to them and are computed in a further stage of processing.

The particular advantage of this approach is the possibility of formulating the curve fitting problem as a **linear set of equations**, thereby making the solution amenable to a direct matrix solution.

We shall denote each of our measured FRF data point by \\(\hat{H}\_k\\), where \\(\hat{H}\_k = \hat{H}(\omega\_k)\\), and define the error between that measured value and the corresponding value derived from the curve-fit expression as

\begin{equation}
  e\_k = \frac{b\_0 + b\_1(i\omega\_k) + \dots + b\_{2m-1}(i\omega\_k)^{2m-1}}{a\_0 + a\_1(i\omega\_k) + \dots + a\_{2m}(i\omega\_k)^{2m}} - \hat{H}\_k
\end{equation}

leading to the modified, but more convenient version actually used in the analysis

\begin{equation} \label{eq:rpf\_error}
  \begin{aligned}
    e\_k^\prime &= \left( b\_0 + b\_1(i\omega\_k) + \dots + b\_{2m-1}(i\omega\_k)^{2m-1} \right)\\\\\\
              &- \hat{H}\_k\left( a\_0 + a\_1(i\omega\_k) + \dots + a\_{2m}(i\omega\_k)^{2m} \right)
  \end{aligned}
\end{equation}

In these expressions, only \\(m\\) modes are included in the theoretical FRF formula: the true number of modes, \\(N\\), is actually one of the **unknowns** to be determined during the analysis.
Equation \eqref{eq:rpf_error} can be rewritten as follows:

\begin{equation}
  \begin{aligned}
  e\_k^\prime &= \begin{Bmatrix} 1 & i \omega\_k & \dots & (i\omega\_k)^{2m-1} \end{Bmatrix}
    \begin{Bmatrix} b\_0 \\ \vdots \\ b\_{2m-1} \end{Bmatrix}\\\\\\
  &- \hat{H}\_k \begin{Bmatrix} 1 & i\omega\_k & \dots & (i\omega\_k)^{2m-1} \end{Bmatrix}
     \begin{Bmatrix} a\_0 \\ \vdots \\ a\_{2m-1} \end{Bmatrix}\\\\\\
  &- \hat{H}\_k (i\omega\_k)^{2m} a\_{2m}
  \end{aligned}
\end{equation}

and the \\(L\\) linear equations corresponding to \\(L\\) individual frequency points can be combined in matrix form:

\begin{equation}
\begin{aligned}
  \\{E^\prime\\}\_{L \times 1} &= [P]\_{L\times 2m} \\{b\\}\_{2m\times 1}\\\\\\
    &- [T]\_{L\times(2m+1)} \\{a\\}\_{(2m+1)\times 1}\\\\\\
    &- \\{W\\}\_{L\times 1}
\end{aligned}
\end{equation}

Solution for the unknown coefficients \\(a\_j, \dots, b\_k, \dots\\) is achieved by minimizing the error function

\begin{equation}
  J = \\{E^\*\\}^T\\{E\\}
\end{equation}

and this leads to

\begin{equation}
  \begin{bmatrix}
    [Y] & [X] \\\\\\
    [X]^T & [Z]
  \end{bmatrix}\_{L \times (4m+1)}
  \begin{Bmatrix}
    \\{b\\} \\ \\{a\\}
  \end{Bmatrix}\_{(4m+1) \times 1}
  = \begin{Bmatrix}
    \\{B\\} \\ \\{F\\}
  \end{Bmatrix}\_{L \times 1}
\end{equation}

where \\([X], [Y], [Z], \\{G\\}\\) and \\(\\{F\\}\\) are known measured quantities:

\begin{equation}
  \begin{aligned}
    [Y]   &= \text{Re}\left( [P^\*]^T[P] \right);\quad [X] = \text{Re}\left( [P^\*]^T[T] \right); \\\\\\
    [Z]   &= \text{Re}\left( [T^\*]^T[T] \right); \\\\\\
    \\{G\\} &= \text{Re}\left( [P^\*]\\{W\\} \right);\quad \\{F\\} = \text{Re}\left( [T^\*]\\{W\\} \right);
  \end{aligned}
\end{equation}

Once the solution has been obtained for the coefficients \\(a\_k, \dots , b\_k, \dots\\) then the second stage of the modal analysis can be performed in which the required **modal parameters are derived**.
This is usually done by solving the two polynomial expressions which form the numerator and denominator of equations \eqref{eq:frf_clasic} and \eqref{eq:frf_rational}:

-   the denominator is used to obtain the natural frequencies \\(\omega\_r\\) and damping factors \\(\xi\_r\\)
-   the numerator is used to determine the complex modal constants \\(A\_r\\)

In order to determine the order, the analysis is repeated using different assumed values for the order \\(m\\) and are compared.
For each analysis, there will be properties found for as many modes as prescribed by the chosen model order.
Some of these will be genuine modes while others will be fictitious modes.
Various strategies may be adopted to separate the fictitious and real modes:

-   measuring the difference between the original FRF curve and that regenerated using the modal properties derived
-   measuring the consistency of the various modal parameters for different model order choices and eliminating those which vary widely from run to run

In all these checks, interest is concentrated on the **repeatability** of the various modal properties: modes which reappear for all choices of data and model condition are believed to be genuine, while those which vary from run to run are more likely to have computational features due to the curve-fitting requirements as their origins, rather than physical ones.


#### Method III - Lightly Damped Structures {#method-iii-lightly-damped-structures}

It is found that some structures do not provide FRF data which respond very well to the above modal analysis procedures mainly because of the difficulties encountered in acquiring good measurements near resonance.

For such structures, it is often the case that interest is confined to an **undamped model** of the test structure since the damping in a complete structural assembly is provided mostly from the joints and not from the components themselves.
Thus, there is scope for an alternative method of modal analysis which is capable of providing the required modal properties, in this case **natural frequencies** and **real modal constants**, using data measured **away from the resonance regions**.

The requirements for the analysis are as follows:

1.  measure the FRF over the frequency range of interest
2.  locate the resonances and note the corresponding natural frequencies
3.  select individual FRF measurement data points from as many frequencies as there are modes, plus two, confining the selection to points away from resonance
4.  using the data thus gathered, compute the modal constants
5.  construct a regenerated curve and compare this with the full set of measured data points


### Global modal analysis methods in the frequency domain {#global-modal-analysis-methods-in-the-frequency-domain}


#### General Approach {#general-approach}

More recent curve fitting procedures are capable of performing a multi curve fit instead of just working with individual FRF curves.
They **fit several FRF curves simultaneously**, taking due account of the fact that the **properties of all the individual curves are related** by being from the **same structure**:
all FRF plots on a given testpiece should indicate the same values for natural frequencies and damping factor of each mode.

Such methods have the advantage of producing a **unique and consistent model** as direct output.

<div class="important">
  <div></div>

A way in which a set of measured FRF curves may be used collectively, rather than singly, is by the construction of a single **Composite Response Function**:

\begin{equation}
  \sum\_j\sum\_k H\_{jk}(\omega) = \sum\_j\sum\_k\sum\_{r=1}^N (\dots) = HH(\omega)
\end{equation}

with
\\[ H\_{jk} = \sum\_{r=1}^n \frac{{}\_rA\_{jk}}{\omega\_r^2 - \omega^2 + i \eta\_r \omega\_r^2} \\]

</div>

The composite function \\(HH(\omega)\\) can provide a useful means of determining a single (average) value for the natural frequency and damping factor for each mode where the individual functions would each indicate slightly different values.
As an example, a set of mobilities measured are shown individually in figure [23](#org2873c75) and their summation shown as a single composite curve in figure [23](#orge18611d).

<a id="table--fig:composite"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:composite">Table 23</a></span>:
  Set of measured FRF
</div>

| ![](/ox-hugo/ewins00_composite_raw.png)   | ![](/ox-hugo/ewins00_composite_sum.png) |
|-------------------------------------------|-----------------------------------------|
| <a id="org2873c75"></a> Individual curves | <a id="orge18611d"></a> Composite curve |
| width=\linewidth                          | width=\linewidth                        |

The global analysis methods have the disadvantages first, that the computation power required is high and second that there may be valid reasons why the various FRF curves exhibit slight differences in their characteristics and it may not always be appropriate to average them.


#### Global Rational Fraction Polynomial Method (GRFP) {#global-rational-fraction-polynomial-method--grfp}

The basic Rational Fraction Polynomial (RFP) method that was described in the context of single FRF curve can be generalized to multi-FRF data.
Indeed, all the FRFs from the same structure will have identical numerator polynomials.
The number of unknown coefficients in a problem where there are \\(n\\) measured FRFs and \\(m\\) modes of vibration is of the order \\((n+1)(2m + 1)\\).


#### Global SVD method {#global-svd-method}

A set of FRFs with a signal reference (such as are contained within a column from the complete FRF matrix) can be referred to the underlying modal model of the structure (assumed to have viscous damping) by the equation:

\begin{align\*}
  \\{H(\omega)\\}\_k &= \begin{Bmatrix} H\_{1k}(\omega) \\ \vdots \\ H\_{nk}(\omega) \\ \end{Bmatrix}\_{n\times 1} \\\\\\
                  &= [\Phi]\_{n\times N} \\{g\_k(\omega)\\}\_{N\times 1} + \\{R\_k(\omega)\\}\_{n\times 1}
\end{align\*}

where \\(\\{R\_k(\omega)\\}\\) is a vector containing the relevant residual terms and \\(\\{g\_k(\omega)\\}\\) is defined as:
\\[ \\{g\_k(\omega)\\}\_{N\times 1} = [i \omega - s\_r]\_{N\times N}^{-1} \\{\phi\_k\\}\_{N\times 1} \\]

Also
\\[ \\{\dot{H}(\omega)\\}\_k = [\Phi] [s\_r] \\{g\_k(\omega)\\} + \\{\dot{R}\_k(\omega)\\}  \\]

Next, we can write the following expressions

\begin{equation}
\begin{aligned}
  \\{\Delta H(\omega\_i)\\}\_k       &= \\{H(\omega\_i)\\}\_k - \\{H(\omega\_{i+c})\\}\_k \\\\\\
                                 &\approx [\Phi] \\{\Delta g\_k(\omega\_i)\\}\_{N\times 1} \\\\\\
  \\{\Delta \dot{H}(\omega\_i)\\}\_k &\approx [\Phi] [s\_r] \\{\Delta g\_k(\omega\_i)\\}\_{N\times 1}
\end{aligned}
\end{equation}

If we now consider data at several different frequencies \\(i = 1, 2, \dots, L\\), we can write

\begin{equation}
  \begin{aligned}
    [\Delta H\_k]\_{n\times L}       &= [\Phi] [\Delta g\_k]\_{N\times L} \\\\\\
    [\Delta \dot{H}\_k]\_{n\times L} &= [\Phi] [s\_r] [\Delta g\_k]\_{N\times L}
  \end{aligned}
\end{equation}

We can construct an eigenvalue problem:
\\[ \left( [\Delta \dot{H}\_k]^T - s\_r [\Delta H\_k]^T \right) \\{z\\}\_r = \\{0\\} \\]
where
\\[ [z] = [\Phi]^{+T} \\]

If we solve \\([z] = [\Phi]^{+T}\\) using the SVD, we can determine the rank of the FRF matrices and thus the correct number of modes \\(m\\) to be identified, leading to the appropriate eigenvalues \\(s\_r;\ r=1, \dots, m\\).

Then, in order to determine the mode shapes, the modal constants can be recovered from:

\begin{equation}
\begin{aligned}
  \begin{Bmatrix} H\_{jk}(\omega\_1) \\ \vdots \\ H\_{jk}(\omega\_L) \\ \end{Bmatrix}\_{L\times 1} = &\begin{bmatrix}
  (i\omega\_1 - s\_1)^{-1} & (i\omega\_1 - s\_2)^{-1} & \dots \\\\\\
  (i\omega\_2 - s\_1)^{-1} & (i\omega\_2 - s\_2)^{-1} & \dots \\\\\\
  \vdots & \dots & \dots \\\\\\
  \vdots & \dots & (i\omega\_L - s\_m)^{-1} \\\\\\
\end{bmatrix}\\\\\\
  &\begin{Bmatrix}
  {}\_1A\_{jk}\\ \vdots \\ {}\_mA\_{jk}
\end{Bmatrix}\_{m\times 1}
\end{aligned}
\end{equation}

Using this approach, it is possible to extract a consistent set of modal parameters for the model whose FRFs have been supplied.


### Concluding comments {#concluding-comments}

In the task of extracting modal model parameters from measured test data, the analyst must rely on the skill of others who have coded the various analysis algorithms since these are generally complex.
Because of this, the analyst must develop the various skills which enable him to **select the most appropriate analysis procedure** for each case and to make the best interpretation of the output of these analysis methods.

In this chapter, we have first highlighted the **need for accuracy and reliability in the measured data** that is the source of a modal analysis.
If these data are not of high quality, the resulting modal model cannot be expected to be any better.
Thus, attention must be paid at the initial phases to ascertain and to assure the necessary quality of the raw data.
Question as to the **correct order for the model** and the **most appropriate model for damping** are often foremost among these early interpretations.

A hierarchy of different types of modal analysis procedure have been cataloged, from the simple SDOF one-mode-at-a-time for a single response function, through MDOF methods which reveal several modes at a time, to global analysis methods where several modes are extracted simultaneously from several FRFs.


## Derivation of Mathematical Models {#derivation-of-mathematical-models}


### Introduction {#introduction}

We consider now the derivation of a mathematical model to describe the dynamic behavior of the test structure.
Various types of model exists and are suitable in different cases.
The most important aspect of the modeling process is to **decide exactly which type of model we should seek** before setting out on the acquisition and processing of experimental data.

Three main categories of model are identified:

-   **Spatial model**: mass, stiffness and damping
-   **Modal model**: natural frequencies, mode shapes
-   **Response model**: frequency response functions

There exist **complete models** of each type and the more realistic **incomplete models** we are obliged to consider in practical cases.

The three types of model are usually derived as \\(\text{Spatial}\Rightarrow\text{Modal}\Rightarrow\text{Response}\\) for theoretical analysis, and conversely, as \\(\text{Response}\Rightarrow\text{Modal}\Rightarrow\text{Spatial}\\) for an experimental study.
We may now view them in a different order, according to the facility with which each may be derived from the test data: Modal, Response and then Spatial.
This reflects the quantity of the completeness of data required in each case.

<div class="important">
  <div></div>

A **modal model** can be constructed using just one single mode, and including only a handful of degrees of freedom, even though the structure has many modes and many DOFs.
Such a model can be built up by adding data from more modes, but it is not a requirement that **all** the modes should be included nor even that all the modes in the frequency range of interest be taken into account.
Thus such a model may be derived with relatively few, or equally, with many data.

</div>

<div class="important">
  <div></div>

The **response type of model** in the form of a FRF matrix, such as the mobility matrix, also needs only to include information concerning a limited number of point of interest: not all the DOFs need be considered.
However, in this case, it is generally required that the model be valid over a specified frequency range, and here it is necessary that all the modes in that range be included.
Also, some account should be taken of the modes whose natural frequencies lie outside of the range of interest to allow for the residual effects.
Thus, the response type of model demands more data to be collected from the tests.

</div>

<div class="important">
  <div></div>

A representative **spatial model** can only be obtained if we have measured most of the modes of the structure and if we have made measurements at a great many of the DOFs it possesses.
This is generally a very demanding requirement to meet, and as result, the derivation of a spatial model from test data is very difficult to achieve.

</div>

This chapter is organized with the following structure:

1.  We shall describe what data must be measured in order to construct a suitable model and what checks can be made to access the reliability of the model.
2.  We shall discuss a number of techniques for "**refining**" the model which is obtained from the test so that it matches a number of features of the analytical model.
    For instance, it is common to extract complex mode shapes from the test data on real structures but the analytical models are usually undamped so that their modes are real.
3.  We may wish to expand our experimental model, or, alternatively, reduce the theoretical ones so that the two models which are to be compared are at least of the same order.
4.  We shall explore some of the properties of the models which can be derived by the means described here.


### Modal models {#modal-models}


#### Requirements to construct modal model {#requirements-to-construct-modal-model}

A **modal model** of a structure consists of **two matrices**:

-   one containing the **natural frequencies** and **damping factors**: the eigenvalues
-   one which describes the **shapes of the corresponding modes**: the eigenvectors

Thus, we can construct such a model with just a single mode, and a more complete model is assembled simply by **adding together a set of these single-mode descriptions**.

The basic method of deriving a modal model is as follows.
First, we note that from a single FRF curve, \\(H\_{jk}(\omega)\\), it is possible to extract certain modal properties for the \\(r^\text{th}\\) mode by modal analysis:

\begin{equation} \label{eq:modal\_model\_from\_frf}
  H\_{jk}(\omega) \longrightarrow \omega\_r, \eta\_r, {}\_rA\_{jk}; \quad r=1, m
\end{equation}

Now, although this gives us the natural frequency and damping properties directly, it does not explicitly yield the mode shape: only a modal constant \\({}\_rA\_{jk}\\) which is formed from the mode shape data.
In order to extract the individual elements \\(\phi\_{jr}\\) of the mode shape matrix \\([\Phi]\\), it is necessary to make a series of measurements of specific FRFs including, especially, the point FRF at the excitation position.
If we measure \\(H\_{kk}\\), then by using \eqref{eq:modal_model_from_frf}, we also obtain the specific elements in the mode shape matrix corresponding to the excitation point:

\begin{equation}
  H\_{kk}(\omega) \longrightarrow \omega\_r, \eta\_r, {}\_rA\_{jk} \longrightarrow \phi\_{kr}; \quad r=1, m
\end{equation}

If we then measure an associated transfer FRF using the same excitation position, such as \\(H\_{jk}\\), we are able to deduce the mode shape element corresponding to the new response point \\(\phi\_{jr}\\) using the fact that the relevant modal constants may be combined with those from the point measurement:

\begin{equation}
  \tcmbox{\phi\_{jr} = \frac{{}\_rA\_{jk}}{\phi\_{kr}}}
\end{equation}

Hence, we find that in order to derive a modal model referred to a particular set of \\(n\\) coordinates, we need to measure and analysis a set of \\(n\\) FRF curves, **all sharing the same excitation point** and thus constituting one point FRF and \\((n-1)\\) transfer FRFs.
In terms of the complete FRF matrix, this corresponds to measure the individual FRF of **one entire column**.
It is also possible to measure one row of the FRF matrix. This corresponds of a set of \\(n\\) FRF curves sharing the same measurement point and varied excitation point.

Often, several additional elements from the FRF matrix would be measured to provide a check, or to replace poor data, and sometimes measurement of a complete **second column** or row might be advised in order to ensure that one or more modes have not been missed by an unfortunate choice of exciter location.
Indeed, if the exciter is placed at a nodal point of one of the modes, then there would be no indications at all of the existence of that mode because every modal constant would be zero for that mode.
It may then require more than one measurement to confirm that we are not exciting the structure at a nodal point.

Once all the selected FRF curves have been measured and individually analyzed, we obtain a set of modal properties containing **more data than needed**:

-   we may have determined many separate estimates for the natural frequencies and damping factors as these parameters are extracted from each FRF curve
-   in the even we have measured more than one row or one column for the FRF matrix, we also obtain separate estimates for the mode shapes

The simplest procedure is to average all the individual estimates that results in means values \\(\tilde{\omega}\_r\\) and \\(\tilde{\eta}\_r\\).
In practice, not all the estimates should carry equal weight because some would probably be derived from much more satisfactory curve fits than others.
A refined procedure would be to calculate a **weighted mean** of all the estimate using the quality factor obtained from the curve-fit procedure.

If we choose to accept a revised value for \\(\omega\_r\\) and \\(\eta\_r\\) of a particular mode, then the value for the modal constant should also be revised:

\begin{equation}
  {}\_r\tilde{A}\_{jk} = {}\_rA\_{jk}\frac{\tilde{\omega}\_r^2 \tilde{\eta}\_r}{\omega\_r^2 \eta\_r}
\end{equation}

The final reduced model obtained consist of the two matrices which constitute a modal model, namely:
\\[ \left[ \omega\_r^2(1 + i\eta\_r) \right]\_{m\times m};\quad \left[ \Phi \right]\_{n\times m} \\]


#### Double modes or repeated roots {#double-modes-or-repeated-roots}

When a structure has two modes that are very close in frequency, it may be impossible to derive a true model for the structure.
All we can define in these circumstances is a single equivalent mode which is, in fact, a combination of the two actual modes that are difficult to identify individually.

However, single equivalent modes can lead to erroneous models and it is very important that we can detect the presence of double modes and that we can identify all the modes which are present.

The only way repeated modes can be detected and identified in a modal test is by using data from more than on reference.
This means that we must measure FRF data from **more than a single row or column** (as many rows/columns as there are repeated roots).


#### Constructing models of NSA structures {#constructing-models-of-nsa-structures}

Structures which are classified as Non-Self-Adjoint (NSA) have **non-symmetric mass**, **stiffness** or **damping matrices**.
This often occurs in structures with rotating components.
As a result, we cannot take advantage of the symmetry of the system matrices and just measuring a single row or column of the FRF matrix.

In the case of NSA structures, we are required to measure and analyze the elements in **both a row and a column of the FRF matrix**.
A mathematical explanation is that this class of system have two types of eigenvectors (left-hand and right-hand) and thus there are twice as many eigenvectors elements to identify.


#### Quality checks for modal models {#quality-checks-for-modal-models}

It is important to check the **reliability** of the obtain results.
There are two such checks that can be recommended for this phase of the process.

First, it is possible to **regenerate FRFs** from the modal model.
These FRFs can be compared with measured data that as been used for the modal analysis.
Furthermore, it is also possible to synthesize FRFs that have not yet been measured (and thus not used for the model), and then to measure the corresponding FRF on the structure and to compare.
This test provides a powerful demonstration of the validity of the modal model.

A second, more demanding but also more convincing, demonstration of the validity of the modal model is to use the model to predict how the dynamic properties of the test structure will change if it is subjected to a small structural modification, such as can be occasioned by adding a small mass at a selected point.
Then such modification can be made and the real structure, measurements done and compare with the modified model.


### Refinement of modal models {#refinement-of-modal-models}


#### Need for model refinement {#need-for-model-refinement}

Several differences exist between most test-derived models and analytical models that make their comparison difficult.

The first difference are on the **mode shapes**:

-   **test-derived**: generally complex
-   **analytical**: usually real if we use an undamped model

Objective comparison between complex mode shapes and real mode shapes is then not possible and some refinement of one of the two sets are required.

A second incompatibility lies in the difference in the **order of the models**:

-   **test-derived**: relatively small order given by the number of measured DOFs \\(n\\)
-   **analytical**: generally an order of magnitude greater than \\(n\\)

There is then a desire to **refine** one or other model to **bring them both to the same size** for meaningful comparison.

However, all the refinements involve **approximations** which means that a compromise has been made in order to achieve the greater degree of compatibility which is desired.


#### Complex-to-real conversion {#complex-to-real-conversion}

As we usually don't know the nature, extend and distribution of damping present in the system, the analytical model is chosen to be **undamped**.
We wish here to be able to determine what would be the mode shapes of the tested structure if, by some means, we could remove the damping but leave everything else the same.
Then we should be able to compare the modes.


##### Simple method {#simple-method}

This simple method is to convert the mode shape vectors from complex to real by taking the modulus of each element and by assigning a phase to each of \\(\SI{0}{\degree}\\) or \\(\SI{180}{\degree}\\).

Any phase angle of a complex mode shape element which is between \\(\SI{-90}{\degree}\\) and \\(\SI{90}{\degree}\\) is set to \\(\SI{0}{\degree}\\), while those between \\(\SI{90}{\degree}\\) and \\(\SI{270}{\degree}\\) are set to \\(\SI{180}{\degree}\\).
This procedure can become difficult to apply in borderline cases when the phase is poorly defined.


##### Multi point excitation - Asher's method {#multi-point-excitation-asher-s-method}

In this method, the test-derived model based on complex modes is used to synthesize the response that would be produced by the application of several simultaneous harmonic forces in order to establish what those forces would need to be in order to produce a mono-modal response vector.

If the optimum set of excitation forces for a given mode can be found, then they represent the forces that are actually being generated by the damping in the system at resonance of that mode.
We can then deduce the dynamic properties of the structure with these effects removed.

The sequence of steps required to determine this solution is as follows:

1.  Compute \\([\alpha(\omega)]\\) from the complex modal model
2.  Determine the undamped system natural frequencies \\(\omega\_r\\) by solving the equation \\(\det|\text{Re}[\alpha(\omega)]|=0\\)
3.  Calculate the mono-phase vector for each mode of interest using \\(\text{Re}[\alpha(\omega)]\\{\hat{F}\\} = \\{0\\}\\)
4.  Calculate the undamped system mode shapes \\(\\{\psi\_u\\}\\) using the just-derived force vector: \\(\\{\psi\_u\\} = \text{Im}[\alpha(\omega)]\\{\hat{F}\\}\\)


##### Matrix transformation {#matrix-transformation}

We here seek a numerical solution to the expression linking the known damped modes and the unknown undamped modes.
The steps are:

1.  Assume that \\(\text{Re}[T\_1]\\) is unity and calculate \\(\text{Im}[T\_1]\\) from
    \\[ \text{Im}[T\_1] = -[\text{Re}[\phi\_d]]^T [\text{Re}[\phi\_d]]^{-1} [\text{Re}[\phi\_d]]^T \text{Im}[\phi\_d] \\]
2.  calculate \\([M\_1]\\) and \\([K\_1]\\) from
    \\[ [M\_1] = [T\_1]^T[T\_1]; \quad [K\_1] = [T\_1]^T[\lambda^2][T\_1] \\]
3.  Solve the eigen-problem formed by \\([M\_1]\\) and \\([K\_1]\\) leading to
    \\[ [\omega\_r^2]; \quad [T\_2] \\]
4.  Calculate the real modes using
    \\[ [\phi\_u] = [\phi\_d][T\_1][T\_2] \\]


#### Expansion of models {#expansion-of-models}

<div class="definition">
  <div></div>

An important model refinement is called **expansion** and consist of the addition to the actually measured modal data of estimates for selected DOFs which were not measured for one reason or another.

</div>

Prior to conducting each modal test, decisions have to be made as to **which of the many DOFs** that exist on the structure **will be measured**.
These decisions are made for various practical reasons:

-   Limited test time
-   Inaccessibility of some DOFs
-   Anticipated low importance of motion in certain DOFs

**Three approaches** to the expansion of measured modes will be mentioned here:

1.  **Geometric interpolation** using spline functions
2.  Expansion using the analytical model's **spatial properties**
3.  Expansion using the analytical model's **modal properties**

<div class="important">
  <div></div>

In all three approached, we are in effect seeking a transformation matrix \\([T]\\) that allows us to construct a long eigenvector \\(\\{\phi\\}\_{N\times 1}\\) from knowledge of a short (incomplete) one \\(\\{\phi\\}\_{n\times 1}\\):
\\[ \\{\phi\\}\_{N\times 1} = [T]\_{N\times n} \\{\phi\\}\_{n\times 1} \\]

</div>


##### Interpolation {#interpolation}

Simple interpolation has a limited range of application and can only be used on structures which have **large regions of relatively homogeneous structure**: those with joints of abrupt changes are must less likely to respond to this form of expansion.

The method is simply geometric interpolation between the measured points themselves, such as by fitting a polynomial function through the measured points.


##### Expansion using theoretical spatial model - Kidder's method {#expansion-using-theoretical-spatial-model-kidder-s-method}

This interpolation uses a **theoretical model's mass and stiffness matrices** in a form of an inverse Guyan reduction procedure.

If we **partition** the eigenvector of interest, \\(\\{\phi\_A\\}\_r\\), into:

-   the DOFs to be included: \\(\\{{}\_A\phi\_1\\}\_r\\)
-   the DOFs which are not available from the measurements: \\(\\{{}\_A\phi\_2\\}\_r\\)

then we may write:

\begin{equation\*}
  \left( \begin{bmatrix}
      {}\_AK\_{11} & {}\_AK\_{12} \\\\\\
      {}\_AK\_{21} & {}\_AK\_{22}
    \end{bmatrix} - \omega\_r^2 \begin{bmatrix}
      {}\_AM\_{11} & {}\_AM\_{12} \\\\\\
      {}\_AM\_{21} & {}\_AM\_{22}
    \end{bmatrix} \right) \begin{bmatrix}
    {}\_A\phi\_1 \\\\\\
    {}\_A\phi\_2
  \end{bmatrix} = \\{0\\}
\end{equation\*}

We can use this relationship between the measured and unmeasured DOFs as the basic for an expansion of the incomplete measured mode shapes:
\\[ \\{{}\_A\phi\_2\\}\_r = [T\_{21}]\\{{}\_A\phi\_1\\}\_r \\]
with
\\[ [T\_{12}] = - \left( [{}\_AK\_{22}] - \omega\_r^2[{}\_AM\_{22}] \right)^{-1} \left( [{}\_AK\_{21}] - \omega\_r^2[{}\_AM\_{21}] \right) \\]

The relation between the incomplete measured vector to the complete expanded vector is then

\begin{equation}
  \tcmbox{ \\{\tilde{\phi}\_X\\}\_r = \begin{Bmatrix}
  {}\_X\phi\_1 \\ {}\_X\tilde{\phi}\_2
\end{Bmatrix} = \begin{bmatrix}
  [I] \\ [T\_{21}]
\end{bmatrix} \\{{}\_X\phi\_1\\}\_r }
\end{equation}


##### Expansion using analytical model mode shapes {#expansion-using-analytical-model-mode-shapes}

This method uses the analytical model for the interpolation, but is based on the **mode shapes derived from the analytical modal spatial matrices**, rather than on these matrices themselves.

We may write the following expression which relates the experimental model mode shapes to those of the analytical model:

\begin{equation\*}
  \begin{bmatrix}
  {}\_X\phi\_1 \\\\\\
  {}\_X\phi\_2
\end{bmatrix} = \begin{bmatrix}
  [{}\_A\Phi\_{11}] & [{}\_A\Phi\_{12}] \\\\\\
  [{}\_A\Phi\_{21}] & [{}\_A\Phi\_{22}]
\end{bmatrix} \begin{bmatrix}
  \gamma\_1 \\\\\\
  \gamma\_2
\end{bmatrix}\_r
\end{equation\*}

The basic of this method is to assume that the measured mode shape submatrix can be represented exactly by the simple relationship (which assumes that \\(\\{\gamma\_2\\}\_r\\) can be taken to be zero):

\begin{equation}
  \\{{}\_X\phi\_1\\}\_r = [{}\_A\Phi\_{11}] \\{\gamma\_1\\}\_r
\end{equation}

so that an estimate can be provided for the unmeasured part of the eigenvector from

\begin{equation}
  \begin{aligned}
    \\{{}\_X\tilde{\phi}\_2\\} &= [T\_{21}] \\{{}\_X\phi\_1\\}\_r \\\\\\
    &= [{}\_A\Phi\_{21}][{}\_A\Phi\_{11}]^{-1} \\{{}\_X\phi\_1\\}\_r
  \end{aligned}
\end{equation}

Thus, we can write the full transformation as:

\begin{equation\*}
  \tcmbox{ \\{\tilde{\phi}\_X\\}\_r = \begin{Bmatrix}
  {}\_X\phi\_1 \\ {}\_X\tilde{\phi}\_2
\end{Bmatrix} = \begin{bmatrix}
  [{}\_A\Phi\_{11}] \\ [{}\_A\Phi\_{21}]
\end{bmatrix} [{}\_A\Phi\_{11}]^{-1} \\{{}\_X\phi\_1\\}\_r }
\end{equation\*}

This formula can be generalized to a single expression which covers several measured modes:

\begin{equation\*}
  \tcmbox{[\tilde{\Phi}\_X]\_{N\times m\_X} = \underbrace{[\Phi\_A]\_{N\times m\_A} [{}\_A\Phi\_{11}]\_{m\_A \times n}^+}\_{[T]\_{N\times n}} [{}\_A\Phi\_1]\_{n\times m\_X}}
\end{equation\*}

where \\(m\_X\\) and \\(m\_A\\) are the number of experimental and analytical modes used, respectively.

Other formulations for \\([T]\\) are possible, they involve various combinations of the available experimental mode shape data and those from the analytical model:

\begin{equation}
  \begin{aligned}
    [T\_{(1)}] &= [\Phi\_A][{}\_A\Phi\_1]^+ & \text{A model - based} \\\\\\
    [T\_{(2)}] &= [\Phi\_A][{}\_X\Phi\_1]^+ & \text{X model - based} \\\\\\
    [T\_{(3)}] &= \begin{bmatrix}
      {}\_X\Phi\_1 \\\\\\
      {}\_A\Phi\_2
    \end{bmatrix}[{}\_A\Phi\_1]^+ & \text{Mixed/A - based} \\\\\\
    [T\_{(4)}] &= \begin{bmatrix}
      {}\_X\Phi\_1 \\\\\\
      {}\_A\Phi\_2
    \end{bmatrix}[{}\_X\Phi\_1]^+ & \text{Mixed/X - based}
  \end{aligned}
\end{equation}

It must be pointed out that all the above formula are approximate because of the initial assumption that the higher modes are not required to be included in the process (that \\(\\{\gamma\_2\\}\\) is zero).


#### Reduction of models {#reduction-of-models}

The model reduction, which is the inverse of the expansion process, is used when it is decided to obtain compatibility between two otherwise disparate models by reducing the size of the larger of the two models (almost always, the analytical model).

Model reduction has less importance nowadays as computing power is widely available and because such reduction introduces approximations.

There are basically **two different types of model reduction**, both of which are applied to the spatial model (as opposed to the modal model as is the case in model expansion), and both achieve the same end result of yielding a smaller order model, with system matrices which are \\(n\times n\\) instead of \\(N\times N\\):

1.  a **condensed model** which seeks to represent the entire structure completely at a smaller number of DOFs. This type of model introduces approximation.
2.  a **reduced model** which has removed information related to the DOFs that are eliminated from the model, and which is thus an incomplete model. However, for the retained DOFs, no information is lost.

Let's summarize the basic feature of model reduction by **condensation**.
The basic equation of motion for the original model can be expressed as:
\\[ [M] \ddot{x} + [K]\\{x\\} = \\{f\\} \\]
and this can be partitioned into the **kept DOFs** \\(\\{x\_1\\}\\) and the **eliminated DOFs** \\(\\{x\_2\\}\\) (which by definition cannot have any excitation forces applied to them):

\begin{equation\*}
\begin{bmatrix}
  M\_{11} & M\_{12} \\\\\\
  M\_{21} & M\_{22}
\end{bmatrix} \begin{Bmatrix}
  \ddot{x}\_1 \\ \ddot{x}\_2
\end{Bmatrix} + \begin{bmatrix}
  K\_{11} & K\_{12} \\\\\\
  K\_{21} & K\_{22}
\end{bmatrix} \begin{Bmatrix}
  x\_1 \\ x\_2
\end{Bmatrix} = \begin{Bmatrix}
  f\_1 \\ 0
\end{Bmatrix}
\end{equation\*}

A relationship between the kept and eliminated DOFs can be written in the form:

\begin{equation}
  \begin{Bmatrix}
  x\_1 \\ x\_2
\end{Bmatrix}\_{N\times 1} = \begin{bmatrix}
  [I] \\ [T]
\end{bmatrix}\_{N\times n} \\{x\_1\\}\_{n\times 1}
\end{equation}

where the transformation matrix \\([T]\\) can be defined by

\begin{equation\*}
  [T] = (1 - \beta)\left(-[K\_{22}]^{-1}[K\_{21}]\right) + \beta\left(-[M\_{22}]^{-1}[M\_{21}]\right)
\end{equation\*}

in which \\(\beta\\) is a reduction coefficient whose limiting values are \\(\beta = 0\\) for **static reduction** and \\(\beta = 1\\) for **dynamic reduction**.

The **reduced mass and stiffness matrices** which are produced by this process are:

\begin{align\*}
  \left[M^R\right]\_{n\times n} &= \begin{bmatrix}[I] & [T]^T\end{bmatrix}\_{n\times N} \begin{bmatrix}
  M\_{22} & M\_{21} \\ M\_{12} & M\_{22}
\end{bmatrix}\_{N\times N} \begin{bmatrix}
  [I] \\ [T]
\end{bmatrix}\_{N\times n}\\\\\\
  \left[K^R\right]\_{n\times n} &= \begin{bmatrix}[I] & [T]^T\end{bmatrix}\_{n\times N} \begin{bmatrix}
  K\_{22} & K\_{21} \\ K\_{12} & K\_{22}
\end{bmatrix}\_{N\times N} \begin{bmatrix}
  [I] \\ [T]
\end{bmatrix}\_{N\times n}
\end{align\*}

The two limiting cases of static and dynamic reduction are of particular interest.
In each case, one of the two system matrices is unchanged and the other one is:

\begin{align\*}
  \beta = 1:\ &[M^{R\text{static}}] = [M\_{12}] \left(-[M\_{22}]^{-1}[M\_{21}]\right)^{-1} + [M\_{11}]\\\\\\
  &[K^{R\text{static}}] = [K]\\\\\\
  \beta = 0:\ &[M^{R\text{dynamic}}] = [M]\\\\\\
  &[K^{R\text{dynamic}}] = [K\_{12}] \left(-[K\_{22}]^{-1}[K\_{21}]\right)^{-1} + [K\_{11}]
\end{align\*}

These reduction procedure can provide useful approximate models of the structure if an optimum choice of which DOFs to retain and which can be eliminated is made.
However, a reduced theoretical model of this type does not correspond to a similarly low-order model which is obtained from experiments since that is formed simply by ignoring the eliminated DOFs.
The measured data for the included DOFs are the same no matter how many DOFs are eliminated.
Thus, there are inherent difficulties involved in using this mixture of condensed (but complete) theoretical models and reduced (but incomplete) experimental models.


### Display of modal models {#display-of-modal-models}

One of the attraction of the modal model is possibility of obtaining a **graphic display** of its form by plotting the mode shapes.

There are basically two choices for the graphical display of a modal model:

-   a **static plot**
-   a **dynamic** (animated) **display**


#### Static Displays {#static-displays}


##### Deflected shapes {#deflected-shapes}

A static display is often adequate for depicting relatively simple mode shapes.
Measured coordinates of the test structure are first linked as shown on figure [31](#org6eef557) (a).
Then, the grid of measured coordinate points is redrawn on the same plot but this time displaced by an amount proportional to the corresponding element in the mode shape vector as shown on figure [31](#org6eef557) (b).
The elements in the vector are scaled according the normalization process used (usually mass-normalized), and their absolute magnitudes have no particular significance.

<a id="org6eef557"></a>

{{< figure src="/ox-hugo/ewins00_static_display.png" caption="Figure 31: Static display of modes shapes. (a) basic grid (b) single-frame deflection pattern (c) multiple-frame deflection pattern (d) complex mode (e) Argand diagram - quasi-real mode (f) Argand diagram - complex mode" >}}

It is customary to select the largest eigenvector element and to scale the whole vector by an amount that makes that displacement on the plot a viable amount.


##### Multiple frames {#multiple-frames}

If a series of deflection patterns that has been computed for a different instant of time are superimposed, we obtain a result as shown on figure [31](#org6eef557) (c).
Some indication of the motion of the structure can be obtained, and the points of zero motion (nodes) can be clearly identified.

It is also possible, in this format, to give some indication of the essence of complex modes, as shown in figure [31](#org6eef557) (d).
Complex modes do not, in general, exhibit fixed nodal points.


##### Argand diagram plots {#argand-diagram-plots}

Another form of representation which is useful for complex modes is the representation of the individual complex elements of the eigenvectors on a polar plot, as shown in the examples of figure [31](#org6eef557) (e) and (f).
Although there is no attempt to show the physical deformation of the actual structure in this format, the complexity of the mode shape is graphically displayed.


#### Dynamic Display {#dynamic-display}

The coordinates for the basic picture are computed and stored for multiple fractions of a cycle.
Then, 10 to 20 frames are stored and displayed with an update rate which is suitable to give a clear picture of the distortion of the structure during vibration.

The dynamic character of animation is the only really effective way to view modal complexity and is very useful to display complex modes.


#### Interpretation of mode shape displays {#interpretation-of-mode-shape-displays}

There are a number of features associated with mode shape displays that warrant a mention in the context of ensuring that the **correct interpretation** is made from viewing these displays.

The first concerns the consequences of viewing an **incomplete model**.
In that case, there are no mode shape data from some of the points which comprise the grid which outlines the structure, and the indicated result is zero motion of those DOFs and this can be very **misleading**.
For instance, if we measure the displacement of grid points in only one direction, \\(x\\) for instance, then the shape display will show significant x-direction motion of those points with no motion in the other transverse directions.
We then tend to interpret this as a motion which is purely in the x-direction which may be clearly not true.

The second problem arises when the **grid of measurement points** that is chosen to display the mode shapes is **too coarse in relation to the complexity of the deformation patterns** that are to be displayed.
This can be illustrated using a very simple example: suppose that our test structure is a straight beam, and that we decide to use just three response measurements points.
If we consider the first six modes of the beam, whose mode shapes are sketched in figure [32](#org77a201c), then we see that with this few measurement points, modes 1 and 5 look the same as do modes 2, 4 and 6.
All the higher modes will be indistinguishable from these first few.
This is a well known problem of **spatial aliasing**.

<a id="org77a201c"></a>

{{< figure src="/ox-hugo/ewins00_beam_modes.png" caption="Figure 32: Misinterpretation of mode shapes by spatial aliasing" >}}


### Response models {#response-models}

<div class="important">
  <div></div>

There are two main requirements demanded for a response model:

-   the capability of regeneration "theoretical" curves for the FRFs actually measured and analyzed
-   synthesizing the other response functions which were not measured

</div>

In general, the form of response model with which we are concerned is an **FRF matrix** whose order is dictated by the number of coordinates \\(n\\) included in the test.
Also, as explained, it is normal in practice to measured and to analyze just a **subset of the FRF matrix** but rather to measure the full FRF matrix.
Usually **one column** or **one row** with a few additional elements are measured.
Thus, if we are to construct an acceptable response model, it will be necessary to synthesize those elements which have not been directly measured.
However, in principle, this need present no major problem as it is possible to compute the full FRF matrix from a modal model using:

\begin{equation} \label{eq:regenerate\_full\_frf\_matrix}
  \tcmbox{[H]\_{n\times n} = [\Phi]\_{n\times m} [\lambda\_r^2 - \omega^2]\_{m\times m}^{-1} [\Phi]\_{m\times n}^T}
\end{equation}


#### Regenerated FRF curves {#regenerated-frf-curves}

It is usual practice to regenerate an FRF curve using the results from the modal analysis as a mean of **checking the success of that analysis**.

It should be noted that in order to construct an acceptable response model, it is essential that all the modes in the frequency range of interest be included, and that suitable residual terms are added to take account of out-of-range modes.
In this respect, the demands of the response model are more stringent that those of the modal model.


#### Synthesis of FRF curves {#synthesis-of-frf-curves}

One of the implications of equation \eqref{eq:regenerate_full_frf_matrix} is that **it is possible to synthesize the FRF curves which were not measured**.
This arises because if we measured three individual FRF such as \\(H\_{ik}(\omega)\\), \\(H\_{jk}(\omega)\\) and \\(K\_{kk}(\omega)\\), then modal analysis of these yields the modal parameters from which it is possible to generate the FRF \\(H\_{ij}(\omega)\\), \\(H\_{jj}(\omega)\\), etc.

However, it must be noted that there is an important **limitation to this procedure** which is highlighted in the example below.

<div class="exampl">
  <div></div>

As an example, suppose that FRF data \\(H\_{11}\\) and \\(H\_{21}\\) are measured and analyzed in order to synthesize the FRF \\(H\_{22}\\) initially unmeasured.
The predict curve is compared with the measurements on figure [24](#orgf256093).
Clearly, the agreement is poor and would tend to indicate that the measurement/analysis process had not been successful.
However, the synthesized curve contained only those terms relating to the modes which had actually been studied from \\(H\_{11}\\) and \\(H\_{21}\\) and this set of modes did not include **all** the modes of the structure.
Thus, \\(H\_{22}\\) **omitted the influence of out-of-range modes**.
The inclusion of these two additional terms (obtained here only after measuring and analyzing \\(H\_{22}\\) itself) resulted in the greatly improved predicted vs measured comparison shown in figure [24](#org15312a1).

</div>

<a id="table--fig:H22"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:H22">Table 24</a></span>:
  Synthesized FRF plot
</div>

| ![](/ox-hugo/ewins00_H22_without_residual.png)         | ![](/ox-hugo/ewins00_H22_with_residual.png)               |
|--------------------------------------------------------|-----------------------------------------------------------|
| <a id="orgf256093"></a> Using measured modal data only | <a id="org15312a1"></a> After inclusion of residual terms |
| width=\linewidth                                       | width=\linewidth                                          |

The appropriate expression for a "correct" response model, derived via a set of modal properties is thus

\begin{equation}
  [H] = [\Phi] [\lambda\_r^2 - \omega^2]^{-1} [\Phi]^T + [\text{Res}]
\end{equation}

In order to obtain all the data necessary to form such a model, we must first derive the modal model on which it is based and then find some means of **determining the elements in the residual matrix** \\([\text{Res}]\\).
This latter task may be done in several ways:

-   It may be most accurately achieved by **measuring all** (or at least over half) **of the elements in the FRF matrix**, but this would increase a lot the quantity of data to be measured.
-   **Extend the frequency range of the modal test** beyond that over which the model is eventually required.
    In this way, much of the content of the residual terms is included in separate modes and their actual magnitudes can be reduced to relatively unimportant dimensions.
-   Try to access **which of the many FRF elements are liable to need large residual terms** and to make sure that these are included in the list of those which are measured and analyzed.
    We noted earlier that it is the point mobilities which are expected to have the highest-valued residuals and the remote transfers which will have the smallest.
    Thus, the significant terms in the \\([\text{Res}]\\) matrix will generally be grouped close to the leading diagonal, and this suggests **making measurements of most of the point mobility parameters**.


#### Direct measurement {#direct-measurement}

It should be noted that it is quite possible to develop a response model by measuring and analyzing all the elements in one half of the FRF matrix (this being symmetric) and by storing the results of this process without constructing a modal model.
This procedure clearly solves the residual problem discussed above, but it will introduce **inconsistencies** into to model which renders it unsatisfactory.


#### Transmissibilities {#transmissibilities}

One vibration parameter which has not been mentioned so far is that of **transmissibility**.
This is a quantity which is quite widely used in vibration engineering practice to indicate the relative vibration levels between two points.

In general, transmissibility is considered to be a frequency dependent response function \\(T\_{jk}(\omega)\\) which defines the ratio between the response levels at two DOFs \\(j\\) and \\(k\\).
Simply defined, we can write:

\begin{equation}
  T\_{jk} (\omega) = \frac{X\_j e^{i\omega t}}{X\_k e^{i\omega t}}
\end{equation}

but, in fact, we need also to **specify the excitation conditions that give rise to the two responses** in question and these are missing from the above definition which is thus not rigorous.
It does not give us enough information to be able to reproduce the conditions which have been used to measured \\(T\_{jk}(\omega)\\).

<div class="definition">
  <div></div>

If the **transmissibility** is measured during a modal test which has a single excitation, say at DOF \\(i\\), then we can define the transmissibility thus obtained more precisely:

\begin{equation}
  {}\_iT\_{jk}(\omega) = \frac{H\_{ji}(\omega)}{H\_{ki}(\omega)}
\end{equation}

</div>

In general, the transmissibility **depends significantly on the excitation point** (\\({}\_iT\_{jk}(\omega) \neq {}\_qT\_{jk}(\omega)\\) where \\(q\\) is a different DOF than \\(i\\)) and it is shown on figure [33](#orga7adcfa).
This may explain why transmissibilities are not widely used in modal analysis.

<a id="orga7adcfa"></a>

{{< figure src="/ox-hugo/ewins00_transmissibility_plots.png" caption="Figure 33: Transmissibility plots" >}}


#### Base excitation {#base-excitation}

The one application area where transmissibilities can be used as part of modal testing is in the case of **base excitation**.
Base excitation is a type of test where the input is measured as a response at the drive point \\(x\_0(t)\\), instead of as a force \\(f\_1(t)\\), as illustrated in figure [25](#table--fig:base-excitation-configuration).

We can show that it is possible to determine, from measurements of \\(x\_i\\) and \\(x\_0\\), modal properties of natural frequency, damping factor and **unscaled** mode shape for each of the modes that are visible in the frequency range of measurement.
The fact that the excitation force is not measured is responsible for the lack of formal scaling of the mode shapes.

<a id="table--fig:base-excitation-configuration"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--fig:base-excitation-configuration">Table 25</a></span>:
  Base excitation configuration
</div>

| ![](/ox-hugo/ewins00_conventional_modal_test_setup.png) | ![](/ox-hugo/ewins00_base_excitation_modal_setup.png) |
|---------------------------------------------------------|-------------------------------------------------------|
| <a id="orga22fea4"></a> Conventional modal test setup   | <a id="orgba3a30c"></a> Base excitation setup         |
| height=4cm                                              | height=4cm                                            |


### Spatial models {#spatial-models}

It would appear from the basic orthogonality properties of the modal model that there exists a simple means of constructing a spatial model from the modal model, thus this is not so.
We have that:

\begin{equation}
  \begin{aligned}
    [\Phi]^T[M][\Phi] &= [I]\\\\\\
    [\Phi]^T[K][\Phi] &= [\lambda\_r^2]
  \end{aligned}
\end{equation}

from which is would appear that we can write

\begin{equation} \label{eq:m\_k\_from\_modes}
  \begin{aligned}
    [M] &= [\Phi]^{-T} [I]           [\Phi]^{-1}\\\\\\
    [K] &= [\Phi]^{-T} [\lambda\_r^2] [\Phi]^{-1}
  \end{aligned}
\end{equation}

However, equation \eqref{eq:m_k_from_modes} is **only applicable when we have available the complete \\(N \times N\\) modal model**.

It is much more usual to have an incomplete model in which the eigenvector matrix is rectangle and, as such, is non-invertible.
One step which can be made using the incomplete data is the construction of "pseudo" flexibility and inverse-mass matrices.
This is accomplished using the above equation in the form:

\begin{equation}
  \begin{aligned}
    [K]\_{n\times n}^{-1} &= [\Phi]\_{n\times m} [\lambda\_r^2]\_{m\times m}^{-1} [\Phi]\_{m\times n}^T\\\\\\
    [M]\_{n\times n}^{-1} &= [\Phi]\_{n\times m}  [\Phi]\_{m\times n}^T
  \end{aligned}
\end{equation}

Because the rank of each pseudo matrix is less than its order, it cannot be inverted and so we are unable to construct stiffness or mass matrix from this approach.


## Bibliography {#bibliography}

<a id="org300069f"></a>Ewins, DJ. 2000. _Modal Testing: Theory, Practice and Application_. _Research Studies Pre, 2nd Ed., ISBN-13_. Baldock, Hertfordshire, England Philadelphia, PA: Wiley-Blackwell.
